# ncurses 6.1 - patch 20180714 - Thomas E. Dickey
#
# ------------------------------------------------------------------------------
#
# Ncurses 6.1 is at
# 	ftp.gnu.org:/pub/gnu
#
# Patches for ncurses 6.1 can be found at
# 	ftp://ftp.invisible-island.net/ncurses/6.1
#	http://invisible-mirror.net/archives/ncurses/6.1 
#
# ------------------------------------------------------------------------------
# ftp://ftp.invisible-island.net/ncurses/6.1/ncurses-6.1-20180714.patch.gz
# patch by Thomas E. Dickey <dickey@invisible-island.net>
# created  Sun Jul 15 00:59:40 UTC 2018
# ------------------------------------------------------------------------------
# NEWS                             |    6 
# VERSION                          |    2 
# aclocal.m4                       |   71 
# configure                        | 4685 ++++++++++++++++++++-----------------
# configure.in                     |    5 
# dist.mk                          |    4 
# form/fty_regex.c                 |   13 
# include/ncurses_defs             |    7 
# man/form_field_validation.3x     |  108 
# package/debian-mingw/changelog   |    4 
# package/debian-mingw64/changelog |    4 
# package/debian/changelog         |    4 
# package/mingw-ncurses.nsi        |    4 
# package/mingw-ncurses.spec       |    3 
# package/ncurses.spec             |    2 
# test/demo_forms.c                |   37 
# 16 files changed, 2798 insertions(+), 2161 deletions(-)
# ------------------------------------------------------------------------------
Index: NEWS
Prereq:  1.3156 
--- ncurses-6.1-20180707+/NEWS	2018-07-07 23:38:46.000000000 +0000
+++ ncurses-6.1-20180714/NEWS	2018-07-14 23:25:22.000000000 +0000
@@ -25,7 +25,7 @@
 -- sale, use or other dealings in this Software without prior written        --
 -- authorization.                                                            --
 -------------------------------------------------------------------------------
--- $Id: NEWS,v 1.3156 2018/07/07 23:38:46 tom Exp $
+-- $Id: NEWS,v 1.3159 2018/07/14 23:25:22 tom Exp $
 -------------------------------------------------------------------------------
 
 This is a log of changes that ncurses has gone through since Zeyd started
@@ -45,6 +45,10 @@
 Changes through 1.9.9e did not credit all contributions;
 it is not possible to add this information.
 
+20180714
+	+ add enum, regex examples to test/demo_forms
+	+ add configure check for pcre-posix library to help with MinGW port.
+
 20180707
 	+ build-fixes for gcc8.
 	+ correct order of WINDOW._ttytype versus WINDOW._windowlist in
Index: VERSION
--- ncurses-6.1-20180707+/VERSION	2018-07-01 14:34:06.000000000 +0000
+++ ncurses-6.1-20180714/VERSION	2018-07-14 14:25:29.000000000 +0000
@@ -1 +1 @@
-5:0:10	6.1	20180707
+5:0:10	6.1	20180714
Index: aclocal.m4
Prereq:  1.839 
--- ncurses-6.1-20180707+/aclocal.m4	2018-06-21 00:23:13.000000000 +0000
+++ ncurses-6.1-20180714/aclocal.m4	2018-07-14 23:48:44.000000000 +0000
@@ -28,7 +28,7 @@
 dnl
 dnl Author: Thomas E. Dickey 1995-on
 dnl
-dnl $Id: aclocal.m4,v 1.839 2018/06/21 00:23:13 tom Exp $
+dnl $Id: aclocal.m4,v 1.841 2018/07/14 23:48:44 tom Exp $
 dnl Macros used in NCURSES auto-configuration script.
 dnl
 dnl These macros are maintained separately from NCURSES.  The copyright on
@@ -6931,6 +6931,33 @@
 AC_SUBST(top_builddir)
 ])dnl
 dnl ---------------------------------------------------------------------------
+dnl CF_TRY_PKG_CONFIG version: 5 updated: 2013/07/06 21:27:06
+dnl -----------------
+dnl This is a simple wrapper to use for pkg-config, for libraries which may be
+dnl available in that form.
+dnl
+dnl $1 = package name
+dnl $2 = extra logic to use, if any, after updating CFLAGS and LIBS
+dnl $3 = logic to use if pkg-config does not have the package
+AC_DEFUN([CF_TRY_PKG_CONFIG],[
+AC_REQUIRE([CF_PKG_CONFIG])
+
+if test "$PKG_CONFIG" != none && "$PKG_CONFIG" --exists $1; then
+	CF_VERBOSE(found package $1)
+	cf_pkgconfig_incs="`$PKG_CONFIG --cflags $1 2>/dev/null`"
+	cf_pkgconfig_libs="`$PKG_CONFIG --libs   $1 2>/dev/null`"
+	CF_VERBOSE(package $1 CFLAGS: $cf_pkgconfig_incs)
+	CF_VERBOSE(package $1 LIBS: $cf_pkgconfig_libs)
+	CF_ADD_CFLAGS($cf_pkgconfig_incs)
+	CF_ADD_LIBS($cf_pkgconfig_libs)
+	ifelse([$2],,:,[$2])
+else
+	cf_pkgconfig_incs=
+	cf_pkgconfig_libs=
+	ifelse([$3],,:,[$3])
+fi
+])
+dnl ---------------------------------------------------------------------------
 dnl CF_TRY_XOPEN_SOURCE version: 2 updated: 2018/06/20 20:23:13
 dnl -------------------
 dnl If _XOPEN_SOURCE is not defined in the compile environment, check if we
@@ -7747,6 +7774,48 @@
 
 ])dnl
 dnl ---------------------------------------------------------------------------
+dnl CF_WITH_PCRE2 version: 2 updated: 2018/07/14 16:47:56
+dnl -------------
+dnl Add PCRE2 (Perl-compatible regular expressions v2) to the build if it is
+dnl available and the user requests it.  Assume the application will otherwise
+dnl use the POSIX interface.
+dnl
+dnl TODO allow $withval to specify package location
+AC_DEFUN([CF_WITH_PCRE2],
+[
+AC_REQUIRE([CF_PKG_CONFIG])
+
+AC_MSG_CHECKING(if you want to use PCRE2 for regular-expressions)
+AC_ARG_WITH(pcre2,
+	[  --with-pcre2            use PCRE2 for regular-expressions])
+test -z "$with_pcre2" && with_pcre2=no
+AC_MSG_RESULT($with_pcre2)
+
+if test "x$with_pcre2" != xno ; then
+	CF_TRY_PKG_CONFIG(libpcre2,,[
+	CF_TRY_PKG_CONFIG(libpcre,,[
+			AC_MSG_ERROR(Cannot find PCRE2 library)])])
+
+	AC_DEFINE(HAVE_LIB_PCRE2,1,[Define to 1 if we can/should compile with the PCRE2 library])
+
+	# if pkgconfig gave no results, look for the libraries directly
+	case $LIBS in
+	(*pcre2-posix*|*pcreposix*)
+		;;
+	(*)
+		AC_CHECK_LIB(pcre2-posix,regcomp,[
+			CF_ADD_LIB(pcre2-posix)],
+			[AC_CHECK_LIB(pcreposix,regcomp,[
+			 CF_ADD_LIB(pcreposix)
+			],[AC_MSG_ERROR(Cannot find PCRE2 POSIX library)])])
+		;;
+	esac
+
+	# either way, check for the library header files
+	AC_CHECK_HEADERS(pcre2-posix.h pcreposix.h)
+fi
+])dnl
+dnl ---------------------------------------------------------------------------
 dnl CF_WITH_PKG_CONFIG_LIBDIR version: 10 updated: 2015/08/22 17:10:56
 dnl -------------------------
 dnl Allow the choice of the pkg-config library directory to be overridden.
Index: configure
--- ncurses-6.1-20180707+/configure	2018-06-21 00:23:13.000000000 +0000
+++ ncurses-6.1-20180714/configure	2018-07-14 21:08:46.000000000 +0000
@@ -1,5 +1,5 @@
 #! /bin/sh
-# From configure.in Revision: 1.659 .
+# From configure.in Revision: 1.660 .
 # Guess values for system-dependent variables and create Makefiles.
 # Generated by Autoconf 2.52.20170501.
 #
@@ -745,6 +745,7 @@
   --with-versioned-syms=X markup versioned symbols using ld
   --with-gpm              use Alessandro Rubini's GPM library
   --without-dlsym         do not use dlsym() to load GPM dynamically
+  --with-pcre2            use PCRE2 for regular-expressions
   --with-sysmouse         use sysmouse (FreeBSD console)
   --disable-lib-suffixes  disable library suffixes
   --disable-rpath-hack    don't add rpath options for additional libraries
@@ -1041,7 +1042,7 @@
 fi
 for ac_site_file in $CONFIG_SITE; do
   if test -r "$ac_site_file"; then
-    { echo "$as_me:1044: loading site script $ac_site_file" >&5
+    { echo "$as_me:1045: loading site script $ac_site_file" >&5
 echo "$as_me: loading site script $ac_site_file" >&6;}
     cat "$ac_site_file" >&5
     . "$ac_site_file"
@@ -1052,7 +1053,7 @@
   # Some versions of bash will fail to source /dev/null (special
   # files actually), so we avoid doing that.
   if test -f "$cache_file"; then
-    { echo "$as_me:1055: loading cache $cache_file" >&5
+    { echo "$as_me:1056: loading cache $cache_file" >&5
 echo "$as_me: loading cache $cache_file" >&6;}
     case $cache_file in
       [\\/]* | ?:[\\/]* ) . $cache_file;;
@@ -1060,7 +1061,7 @@
     esac
   fi
 else
-  { echo "$as_me:1063: creating cache $cache_file" >&5
+  { echo "$as_me:1064: creating cache $cache_file" >&5
 echo "$as_me: creating cache $cache_file" >&6;}
   >$cache_file
 fi
@@ -1076,21 +1077,21 @@
   eval ac_new_val="\$ac_env_${ac_var}_value"
   case $ac_old_set,$ac_new_set in
     set,)
-      { echo "$as_me:1079: error: \`$ac_var' was set to \`$ac_old_val' in the previous run" >&5
+      { echo "$as_me:1080: error: \`$ac_var' was set to \`$ac_old_val' in the previous run" >&5
 echo "$as_me: error: \`$ac_var' was set to \`$ac_old_val' in the previous run" >&2;}
       ac_cache_corrupted=: ;;
     ,set)
-      { echo "$as_me:1083: error: \`$ac_var' was not set in the previous run" >&5
+      { echo "$as_me:1084: error: \`$ac_var' was not set in the previous run" >&5
 echo "$as_me: error: \`$ac_var' was not set in the previous run" >&2;}
       ac_cache_corrupted=: ;;
     ,);;
     *)
       if test "x$ac_old_val" != "x$ac_new_val"; then
-        { echo "$as_me:1089: error: \`$ac_var' has changed since the previous run:" >&5
+        { echo "$as_me:1090: error: \`$ac_var' has changed since the previous run:" >&5
 echo "$as_me: error: \`$ac_var' has changed since the previous run:" >&2;}
-        { echo "$as_me:1091:   former value:  $ac_old_val" >&5
+        { echo "$as_me:1092:   former value:  $ac_old_val" >&5
 echo "$as_me:   former value:  $ac_old_val" >&2;}
-        { echo "$as_me:1093:   current value: $ac_new_val" >&5
+        { echo "$as_me:1094:   current value: $ac_new_val" >&5
 echo "$as_me:   current value: $ac_new_val" >&2;}
         ac_cache_corrupted=:
       fi;;
@@ -1109,9 +1110,9 @@
   fi
 done
 if $ac_cache_corrupted; then
-  { echo "$as_me:1112: error: changes in the environment can compromise the build" >&5
+  { echo "$as_me:1113: error: changes in the environment can compromise the build" >&5
 echo "$as_me: error: changes in the environment can compromise the build" >&2;}
-  { { echo "$as_me:1114: error: run \`make distclean' and/or \`rm $cache_file' and start over" >&5
+  { { echo "$as_me:1115: error: run \`make distclean' and/or \`rm $cache_file' and start over" >&5
 echo "$as_me: error: run \`make distclean' and/or \`rm $cache_file' and start over" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -1132,10 +1133,10 @@
 echo "#! $SHELL" >conftest.sh
 echo  "exit 0"   >>conftest.sh
 chmod +x conftest.sh
-if { (echo "$as_me:1135: PATH=\".;.\"; conftest.sh") >&5
+if { (echo "$as_me:1136: PATH=\".;.\"; conftest.sh") >&5
   (PATH=".;."; conftest.sh) 2>&5
   ac_status=$?
-  echo "$as_me:1138: \$? = $ac_status" >&5
+  echo "$as_me:1139: \$? = $ac_status" >&5
   (exit $ac_status); }; then
   ac_path_separator=';'
 else
@@ -1148,7 +1149,7 @@
 
 top_builddir=`pwd`
 
-echo "$as_me:1151: checking for egrep" >&5
+echo "$as_me:1152: checking for egrep" >&5
 echo $ECHO_N "checking for egrep... $ECHO_C" >&6
 if test "${ac_cv_prog_egrep+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -1158,11 +1159,11 @@
 		else ac_cv_prog_egrep='egrep'
 	fi
 fi
-echo "$as_me:1161: result: $ac_cv_prog_egrep" >&5
+echo "$as_me:1162: result: $ac_cv_prog_egrep" >&5
 echo "${ECHO_T}$ac_cv_prog_egrep" >&6
 	EGREP=$ac_cv_prog_egrep
 
-	test -z "$EGREP" && { { echo "$as_me:1165: error: No egrep program found" >&5
+	test -z "$EGREP" && { { echo "$as_me:1166: error: No egrep program found" >&5
 echo "$as_me: error: No egrep program found" >&2;}
    { (exit 1); exit 1; }; }
 
@@ -1172,11 +1173,11 @@
 cf_cv_abi_version=${NCURSES_MAJOR}
 cf_cv_rel_version=${NCURSES_MAJOR}.${NCURSES_MINOR}
 cf_cv_timestamp=`date`
-echo "$as_me:1175: result: Configuring NCURSES $cf_cv_rel_version ABI $cf_cv_abi_version ($cf_cv_timestamp)" >&5
+echo "$as_me:1176: result: Configuring NCURSES $cf_cv_rel_version ABI $cf_cv_abi_version ($cf_cv_timestamp)" >&5
 echo "${ECHO_T}Configuring NCURSES $cf_cv_rel_version ABI $cf_cv_abi_version ($cf_cv_timestamp)" >&6
 
 if test -f $srcdir/VERSION ; then
-	echo "$as_me:1179: checking for package version" >&5
+	echo "$as_me:1180: checking for package version" >&5
 echo $ECHO_N "checking for package version... $ECHO_C" >&6
 
 	# if there are not enough fields, cut returns the last one...
@@ -1188,39 +1189,39 @@
 	VERSION="$cf_field1"
 
 	VERSION_MAJOR=`echo "$cf_field2" | sed -e 's/\..*//'`
-	test -z "$VERSION_MAJOR" && { { echo "$as_me:1191: error: missing major-version" >&5
+	test -z "$VERSION_MAJOR" && { { echo "$as_me:1192: error: missing major-version" >&5
 echo "$as_me: error: missing major-version" >&2;}
    { (exit 1); exit 1; }; }
 
 	VERSION_MINOR=`echo "$cf_field2" | sed -e 's/^[^.]*\.//' -e 's/-.*//'`
-	test -z "$VERSION_MINOR" && { { echo "$as_me:1196: error: missing minor-version" >&5
+	test -z "$VERSION_MINOR" && { { echo "$as_me:1197: error: missing minor-version" >&5
 echo "$as_me: error: missing minor-version" >&2;}
    { (exit 1); exit 1; }; }
 
-	echo "$as_me:1200: result: ${VERSION_MAJOR}.${VERSION_MINOR}" >&5
+	echo "$as_me:1201: result: ${VERSION_MAJOR}.${VERSION_MINOR}" >&5
 echo "${ECHO_T}${VERSION_MAJOR}.${VERSION_MINOR}" >&6
 
-	echo "$as_me:1203: checking for package patch date" >&5
+	echo "$as_me:1204: checking for package patch date" >&5
 echo $ECHO_N "checking for package patch date... $ECHO_C" >&6
 	VERSION_PATCH=`echo "$cf_field3" | sed -e 's/^[^-]*-//'`
 	case .$VERSION_PATCH in
 	(.)
-		{ { echo "$as_me:1208: error: missing patch-date $VERSION_PATCH" >&5
+		{ { echo "$as_me:1209: error: missing patch-date $VERSION_PATCH" >&5
 echo "$as_me: error: missing patch-date $VERSION_PATCH" >&2;}
    { (exit 1); exit 1; }; }
 		;;
 	(.[0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9])
 		;;
 	(*)
-		{ { echo "$as_me:1215: error: illegal patch-date $VERSION_PATCH" >&5
+		{ { echo "$as_me:1216: error: illegal patch-date $VERSION_PATCH" >&5
 echo "$as_me: error: illegal patch-date $VERSION_PATCH" >&2;}
    { (exit 1); exit 1; }; }
 		;;
 	esac
-	echo "$as_me:1220: result: $VERSION_PATCH" >&5
+	echo "$as_me:1221: result: $VERSION_PATCH" >&5
 echo "${ECHO_T}$VERSION_PATCH" >&6
 else
-	{ { echo "$as_me:1223: error: did not find $srcdir/VERSION" >&5
+	{ { echo "$as_me:1224: error: did not find $srcdir/VERSION" >&5
 echo "$as_me: error: did not find $srcdir/VERSION" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -1228,19 +1229,19 @@
 # show the actual data that we have for versions:
 test -n "$verbose" && echo "	ABI VERSION $VERSION" 1>&6
 
-echo "${as_me:-configure}:1231: testing ABI VERSION $VERSION ..." 1>&5
+echo "${as_me:-configure}:1232: testing ABI VERSION $VERSION ..." 1>&5
 
 test -n "$verbose" && echo "	VERSION_MAJOR $VERSION_MAJOR" 1>&6
 
-echo "${as_me:-configure}:1235: testing VERSION_MAJOR $VERSION_MAJOR ..." 1>&5
+echo "${as_me:-configure}:1236: testing VERSION_MAJOR $VERSION_MAJOR ..." 1>&5
 
 test -n "$verbose" && echo "	VERSION_MINOR $VERSION_MINOR" 1>&6
 
-echo "${as_me:-configure}:1239: testing VERSION_MINOR $VERSION_MINOR ..." 1>&5
+echo "${as_me:-configure}:1240: testing VERSION_MINOR $VERSION_MINOR ..." 1>&5
 
 test -n "$verbose" && echo "	VERSION_PATCH $VERSION_PATCH" 1>&6
 
-echo "${as_me:-configure}:1243: testing VERSION_PATCH $VERSION_PATCH ..." 1>&5
+echo "${as_me:-configure}:1244: testing VERSION_PATCH $VERSION_PATCH ..." 1>&5
 
 	cf_PACKAGE=NCURSES
 	PACKAGE=ncurses
@@ -1264,7 +1265,7 @@
 # Check whether --with-rel-version or --without-rel-version was given.
 if test "${with_rel_version+set}" = set; then
   withval="$with_rel_version"
-  { echo "$as_me:1267: WARNING: overriding release version $cf_cv_rel_version to $withval" >&5
+  { echo "$as_me:1268: WARNING: overriding release version $cf_cv_rel_version to $withval" >&5
 echo "$as_me: WARNING: overriding release version $cf_cv_rel_version to $withval" >&2;}
  cf_cv_rel_version=$withval
 fi;
@@ -1277,13 +1278,13 @@
   ([0-9]*)
  	;;
   (*)
-	{ { echo "$as_me:1280: error: Release major-version is not a number: $NCURSES_MAJOR" >&5
+	{ { echo "$as_me:1281: error: Release major-version is not a number: $NCURSES_MAJOR" >&5
 echo "$as_me: error: Release major-version is not a number: $NCURSES_MAJOR" >&2;}
    { (exit 1); exit 1; }; }
  	;;
   esac
 else
-  { { echo "$as_me:1286: error: Release major-version value is empty" >&5
+  { { echo "$as_me:1287: error: Release major-version value is empty" >&5
 echo "$as_me: error: Release major-version value is empty" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -1293,13 +1294,13 @@
   ([0-9]*)
  	;;
   (*)
-	{ { echo "$as_me:1296: error: Release minor-version is not a number: $NCURSES_MINOR" >&5
+	{ { echo "$as_me:1297: error: Release minor-version is not a number: $NCURSES_MINOR" >&5
 echo "$as_me: error: Release minor-version is not a number: $NCURSES_MINOR" >&2;}
    { (exit 1); exit 1; }; }
  	;;
   esac
 else
-  { { echo "$as_me:1302: error: Release minor-version value is empty" >&5
+  { { echo "$as_me:1303: error: Release minor-version value is empty" >&5
 echo "$as_me: error: Release minor-version value is empty" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -1312,7 +1313,7 @@
 
 	if test "x$cf_cv_abi_version" != "x$withval"
 	then
-		{ echo "$as_me:1315: WARNING: overriding ABI version $cf_cv_abi_version to $withval" >&5
+		{ echo "$as_me:1316: WARNING: overriding ABI version $cf_cv_abi_version to $withval" >&5
 echo "$as_me: WARNING: overriding ABI version $cf_cv_abi_version to $withval" >&2;}
 		case $cf_cv_rel_version in
 		(5.*)
@@ -1331,13 +1332,13 @@
   ([0-9]*)
  	;;
   (*)
-	{ { echo "$as_me:1334: error: ABI version is not a number: $cf_cv_abi_version" >&5
+	{ { echo "$as_me:1335: error: ABI version is not a number: $cf_cv_abi_version" >&5
 echo "$as_me: error: ABI version is not a number: $cf_cv_abi_version" >&2;}
    { (exit 1); exit 1; }; }
  	;;
   esac
 else
-  { { echo "$as_me:1340: error: ABI version value is empty" >&5
+  { { echo "$as_me:1341: error: ABI version value is empty" >&5
 echo "$as_me: error: ABI version value is empty" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -1368,7 +1369,7 @@
   fi
 done
 if test -z "$ac_aux_dir"; then
-  { { echo "$as_me:1371: error: cannot find install-sh or install.sh in $srcdir $srcdir/.. $srcdir/../.." >&5
+  { { echo "$as_me:1372: error: cannot find install-sh or install.sh in $srcdir $srcdir/.. $srcdir/../.." >&5
 echo "$as_me: error: cannot find install-sh or install.sh in $srcdir $srcdir/.. $srcdir/../.." >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -1378,11 +1379,11 @@
 
 # Make sure we can run config.sub.
 $ac_config_sub sun4 >/dev/null 2>&1 ||
-  { { echo "$as_me:1381: error: cannot run $ac_config_sub" >&5
+  { { echo "$as_me:1382: error: cannot run $ac_config_sub" >&5
 echo "$as_me: error: cannot run $ac_config_sub" >&2;}
    { (exit 1); exit 1; }; }
 
-echo "$as_me:1385: checking build system type" >&5
+echo "$as_me:1386: checking build system type" >&5
 echo $ECHO_N "checking build system type... $ECHO_C" >&6
 if test "${ac_cv_build+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -1391,23 +1392,23 @@
 test -z "$ac_cv_build_alias" &&
   ac_cv_build_alias=`$ac_config_guess`
 test -z "$ac_cv_build_alias" &&
-  { { echo "$as_me:1394: error: cannot guess build type; you must specify one" >&5
+  { { echo "$as_me:1395: error: cannot guess build type; you must specify one" >&5
 echo "$as_me: error: cannot guess build type; you must specify one" >&2;}
    { (exit 1); exit 1; }; }
 ac_cv_build=`$ac_config_sub $ac_cv_build_alias` ||
-  { { echo "$as_me:1398: error: $ac_config_sub $ac_cv_build_alias failed." >&5
+  { { echo "$as_me:1399: error: $ac_config_sub $ac_cv_build_alias failed." >&5
 echo "$as_me: error: $ac_config_sub $ac_cv_build_alias failed." >&2;}
    { (exit 1); exit 1; }; }
 
 fi
-echo "$as_me:1403: result: $ac_cv_build" >&5
+echo "$as_me:1404: result: $ac_cv_build" >&5
 echo "${ECHO_T}$ac_cv_build" >&6
 build=$ac_cv_build
 build_cpu=`echo $ac_cv_build | sed 's/^\([^-]*\)-\([^-]*\)-\(.*\)$/\1/'`
 build_vendor=`echo $ac_cv_build | sed 's/^\([^-]*\)-\([^-]*\)-\(.*\)$/\2/'`
 build_os=`echo $ac_cv_build | sed 's/^\([^-]*\)-\([^-]*\)-\(.*\)$/\3/'`
 
-echo "$as_me:1410: checking host system type" >&5
+echo "$as_me:1411: checking host system type" >&5
 echo $ECHO_N "checking host system type... $ECHO_C" >&6
 if test "${ac_cv_host+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -1416,12 +1417,12 @@
 test -z "$ac_cv_host_alias" &&
   ac_cv_host_alias=$ac_cv_build_alias
 ac_cv_host=`$ac_config_sub $ac_cv_host_alias` ||
-  { { echo "$as_me:1419: error: $ac_config_sub $ac_cv_host_alias failed" >&5
+  { { echo "$as_me:1420: error: $ac_config_sub $ac_cv_host_alias failed" >&5
 echo "$as_me: error: $ac_config_sub $ac_cv_host_alias failed" >&2;}
    { (exit 1); exit 1; }; }
 
 fi
-echo "$as_me:1424: result: $ac_cv_host" >&5
+echo "$as_me:1425: result: $ac_cv_host" >&5
 echo "${ECHO_T}$ac_cv_host" >&6
 host=$ac_cv_host
 host_cpu=`echo $ac_cv_host | sed 's/^\([^-]*\)-\([^-]*\)-\(.*\)$/\1/'`
@@ -1429,7 +1430,7 @@
 host_os=`echo $ac_cv_host | sed 's/^\([^-]*\)-\([^-]*\)-\(.*\)$/\3/'`
 
 if test -f $srcdir/config.guess || test -f $ac_aux_dir/config.guess ; then
-	echo "$as_me:1432: checking target system type" >&5
+	echo "$as_me:1433: checking target system type" >&5
 echo $ECHO_N "checking target system type... $ECHO_C" >&6
 if test "${ac_cv_target+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -1438,12 +1439,12 @@
 test "x$ac_cv_target_alias" = "x" &&
   ac_cv_target_alias=$ac_cv_host_alias
 ac_cv_target=`$ac_config_sub $ac_cv_target_alias` ||
-  { { echo "$as_me:1441: error: $ac_config_sub $ac_cv_target_alias failed" >&5
+  { { echo "$as_me:1442: error: $ac_config_sub $ac_cv_target_alias failed" >&5
 echo "$as_me: error: $ac_config_sub $ac_cv_target_alias failed" >&2;}
    { (exit 1); exit 1; }; }
 
 fi
-echo "$as_me:1446: result: $ac_cv_target" >&5
+echo "$as_me:1447: result: $ac_cv_target" >&5
 echo "${ECHO_T}$ac_cv_target" >&6
 target=$ac_cv_target
 target_cpu=`echo $ac_cv_target | sed 's/^\([^-]*\)-\([^-]*\)-\(.*\)$/\1/'`
@@ -1475,13 +1476,13 @@
 fi
 
 test -z "$system_name" && system_name="$cf_cv_system_name"
-test -n "$cf_cv_system_name" && echo "$as_me:1478: result: Configuring for $cf_cv_system_name" >&5
+test -n "$cf_cv_system_name" && echo "$as_me:1479: result: Configuring for $cf_cv_system_name" >&5
 echo "${ECHO_T}Configuring for $cf_cv_system_name" >&6
 
 if test ".$system_name" != ".$cf_cv_system_name" ; then
-	echo "$as_me:1482: result: Cached system name ($system_name) does not agree with actual ($cf_cv_system_name)" >&5
+	echo "$as_me:1483: result: Cached system name ($system_name) does not agree with actual ($cf_cv_system_name)" >&5
 echo "${ECHO_T}Cached system name ($system_name) does not agree with actual ($cf_cv_system_name)" >&6
-	{ { echo "$as_me:1484: error: \"Please remove config.cache and try again.\"" >&5
+	{ { echo "$as_me:1485: error: \"Please remove config.cache and try again.\"" >&5
 echo "$as_me: error: \"Please remove config.cache and try again.\"" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -1489,7 +1490,7 @@
 # Check whether --with-system-type or --without-system-type was given.
 if test "${with_system_type+set}" = set; then
   withval="$with_system_type"
-  { echo "$as_me:1492: WARNING: overriding system type to $withval" >&5
+  { echo "$as_me:1493: WARNING: overriding system type to $withval" >&5
 echo "$as_me: WARNING: overriding system type to $withval" >&2;}
 	cf_cv_system_name=$withval
 	host_os=$withval
@@ -1501,7 +1502,7 @@
 
 ###	Default install-location
 
-echo "$as_me:1504: checking for prefix" >&5
+echo "$as_me:1505: checking for prefix" >&5
 echo $ECHO_N "checking for prefix... $ECHO_C" >&6
 if test "x$prefix" = "xNONE" ; then
 	case "$cf_cv_system_name" in
@@ -1513,11 +1514,11 @@
 		;;
 	esac
 fi
-echo "$as_me:1516: result: $prefix" >&5
+echo "$as_me:1517: result: $prefix" >&5
 echo "${ECHO_T}$prefix" >&6
 
 if test "x$prefix" = "xNONE" ; then
-echo "$as_me:1520: checking for default include-directory" >&5
+echo "$as_me:1521: checking for default include-directory" >&5
 echo $ECHO_N "checking for default include-directory... $ECHO_C" >&6
 test -n "$verbose" && echo 1>&6
 for cf_symbol in \
@@ -1540,7 +1541,7 @@
 	fi
 	test -n "$verbose"  && echo "	tested $cf_dir" 1>&6
 done
-echo "$as_me:1543: result: $includedir" >&5
+echo "$as_me:1544: result: $includedir" >&5
 echo "${ECHO_T}$includedir" >&6
 fi
 
@@ -1602,7 +1603,7 @@
   do
     # Extract the first word of "$ac_tool_prefix$ac_prog", so it can be a program name with args.
 set dummy $ac_tool_prefix$ac_prog; ac_word=$2
-echo "$as_me:1605: checking for $ac_word" >&5
+echo "$as_me:1606: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_CC+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -1617,7 +1618,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_CC="$ac_tool_prefix$ac_prog"
-echo "$as_me:1620: found $ac_dir/$ac_word" >&5
+echo "$as_me:1621: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -1625,10 +1626,10 @@
 fi
 CC=$ac_cv_prog_CC
 if test -n "$CC"; then
-  echo "$as_me:1628: result: $CC" >&5
+  echo "$as_me:1629: result: $CC" >&5
 echo "${ECHO_T}$CC" >&6
 else
-  echo "$as_me:1631: result: no" >&5
+  echo "$as_me:1632: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -1641,7 +1642,7 @@
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-echo "$as_me:1644: checking for $ac_word" >&5
+echo "$as_me:1645: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_ac_ct_CC+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -1656,7 +1657,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_ac_ct_CC="$ac_prog"
-echo "$as_me:1659: found $ac_dir/$ac_word" >&5
+echo "$as_me:1660: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -1664,10 +1665,10 @@
 fi
 ac_ct_CC=$ac_cv_prog_ac_ct_CC
 if test -n "$ac_ct_CC"; then
-  echo "$as_me:1667: result: $ac_ct_CC" >&5
+  echo "$as_me:1668: result: $ac_ct_CC" >&5
 echo "${ECHO_T}$ac_ct_CC" >&6
 else
-  echo "$as_me:1670: result: no" >&5
+  echo "$as_me:1671: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -1677,32 +1678,32 @@
   CC=$ac_ct_CC
 fi
 
-test -z "$CC" && { { echo "$as_me:1680: error: no acceptable cc found in \$PATH" >&5
+test -z "$CC" && { { echo "$as_me:1681: error: no acceptable cc found in \$PATH" >&5
 echo "$as_me: error: no acceptable cc found in \$PATH" >&2;}
    { (exit 1); exit 1; }; }
 
 # Provide some information about the compiler.
-echo "$as_me:1685:" \
+echo "$as_me:1686:" \
      "checking for C compiler version" >&5
 ac_compiler=`set X $ac_compile; echo $2`
-{ (eval echo "$as_me:1688: \"$ac_compiler --version </dev/null >&5\"") >&5
+{ (eval echo "$as_me:1689: \"$ac_compiler --version </dev/null >&5\"") >&5
   (eval $ac_compiler --version </dev/null >&5) 2>&5
   ac_status=$?
-  echo "$as_me:1691: \$? = $ac_status" >&5
+  echo "$as_me:1692: \$? = $ac_status" >&5
   (exit $ac_status); }
-{ (eval echo "$as_me:1693: \"$ac_compiler -v </dev/null >&5\"") >&5
+{ (eval echo "$as_me:1694: \"$ac_compiler -v </dev/null >&5\"") >&5
   (eval $ac_compiler -v </dev/null >&5) 2>&5
   ac_status=$?
-  echo "$as_me:1696: \$? = $ac_status" >&5
+  echo "$as_me:1697: \$? = $ac_status" >&5
   (exit $ac_status); }
-{ (eval echo "$as_me:1698: \"$ac_compiler -V </dev/null >&5\"") >&5
+{ (eval echo "$as_me:1699: \"$ac_compiler -V </dev/null >&5\"") >&5
   (eval $ac_compiler -V </dev/null >&5) 2>&5
   ac_status=$?
-  echo "$as_me:1701: \$? = $ac_status" >&5
+  echo "$as_me:1702: \$? = $ac_status" >&5
   (exit $ac_status); }
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 1705 "configure"
+#line 1706 "configure"
 #include "confdefs.h"
 
 int
@@ -1718,13 +1719,13 @@
 # Try to create an executable without -o first, disregard a.out.
 # It will help us diagnose broken compilers, and finding out an intuition
 # of exeext.
-echo "$as_me:1721: checking for C compiler default output" >&5
+echo "$as_me:1722: checking for C compiler default output" >&5
 echo $ECHO_N "checking for C compiler default output... $ECHO_C" >&6
 ac_link_default=`echo "$ac_link" | sed 's/ -o *conftest[^ ]*//'`
-if { (eval echo "$as_me:1724: \"$ac_link_default\"") >&5
+if { (eval echo "$as_me:1725: \"$ac_link_default\"") >&5
   (eval $ac_link_default) 2>&5
   ac_status=$?
-  echo "$as_me:1727: \$? = $ac_status" >&5
+  echo "$as_me:1728: \$? = $ac_status" >&5
   (exit $ac_status); }; then
   # Find the output, starting from the most likely.  This scheme is
 # not robust to junk in `.', hence go to wildcards (a.*) only as a last
@@ -1747,34 +1748,34 @@
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
-{ { echo "$as_me:1750: error: C compiler cannot create executables" >&5
+{ { echo "$as_me:1751: error: C compiler cannot create executables" >&5
 echo "$as_me: error: C compiler cannot create executables" >&2;}
    { (exit 77); exit 77; }; }
 fi
 
 ac_exeext=$ac_cv_exeext
-echo "$as_me:1756: result: $ac_file" >&5
+echo "$as_me:1757: result: $ac_file" >&5
 echo "${ECHO_T}$ac_file" >&6
 
 # Check the compiler produces executables we can run.  If not, either
 # the compiler is broken, or we cross compile.
-echo "$as_me:1761: checking whether the C compiler works" >&5
+echo "$as_me:1762: checking whether the C compiler works" >&5
 echo $ECHO_N "checking whether the C compiler works... $ECHO_C" >&6
 # FIXME: These cross compiler hacks should be removed for Autoconf 3.0
 # If not cross compiling, check that we can run a simple program.
 if test "$cross_compiling" != yes; then
   if { ac_try='./$ac_file'
-  { (eval echo "$as_me:1767: \"$ac_try\"") >&5
+  { (eval echo "$as_me:1768: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:1770: \$? = $ac_status" >&5
+  echo "$as_me:1771: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
     cross_compiling=no
   else
     if test "$cross_compiling" = maybe; then
 	cross_compiling=yes
     else
-	{ { echo "$as_me:1777: error: cannot run C compiled programs.
+	{ { echo "$as_me:1778: error: cannot run C compiled programs.
 If you meant to cross compile, use \`--host'." >&5
 echo "$as_me: error: cannot run C compiled programs.
 If you meant to cross compile, use \`--host'." >&2;}
@@ -1782,24 +1783,24 @@
     fi
   fi
 fi
-echo "$as_me:1785: result: yes" >&5
+echo "$as_me:1786: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 rm -f a.out a.exe conftest$ac_cv_exeext
 ac_clean_files=$ac_clean_files_save
 # Check the compiler produces executables we can run.  If not, either
 # the compiler is broken, or we cross compile.
-echo "$as_me:1792: checking whether we are cross compiling" >&5
+echo "$as_me:1793: checking whether we are cross compiling" >&5
 echo $ECHO_N "checking whether we are cross compiling... $ECHO_C" >&6
-echo "$as_me:1794: result: $cross_compiling" >&5
+echo "$as_me:1795: result: $cross_compiling" >&5
 echo "${ECHO_T}$cross_compiling" >&6
 
-echo "$as_me:1797: checking for executable suffix" >&5
+echo "$as_me:1798: checking for executable suffix" >&5
 echo $ECHO_N "checking for executable suffix... $ECHO_C" >&6
-if { (eval echo "$as_me:1799: \"$ac_link\"") >&5
+if { (eval echo "$as_me:1800: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:1802: \$? = $ac_status" >&5
+  echo "$as_me:1803: \$? = $ac_status" >&5
   (exit $ac_status); }; then
   # If both `conftest.exe' and `conftest' are `present' (well, observable)
 # catch `conftest.exe'.  For instance with Cygwin, `ls conftest' will
@@ -1815,25 +1816,25 @@
   esac
 done
 else
-  { { echo "$as_me:1818: error: cannot compute EXEEXT: cannot compile and link" >&5
+  { { echo "$as_me:1819: error: cannot compute EXEEXT: cannot compile and link" >&5
 echo "$as_me: error: cannot compute EXEEXT: cannot compile and link" >&2;}
    { (exit 1); exit 1; }; }
 fi
 
 rm -f conftest$ac_cv_exeext
-echo "$as_me:1824: result: $ac_cv_exeext" >&5
+echo "$as_me:1825: result: $ac_cv_exeext" >&5
 echo "${ECHO_T}$ac_cv_exeext" >&6
 
 rm -f conftest.$ac_ext
 EXEEXT=$ac_cv_exeext
 ac_exeext=$EXEEXT
-echo "$as_me:1830: checking for object suffix" >&5
+echo "$as_me:1831: checking for object suffix" >&5
 echo $ECHO_N "checking for object suffix... $ECHO_C" >&6
 if test "${ac_cv_objext+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 1836 "configure"
+#line 1837 "configure"
 #include "confdefs.h"
 
 int
@@ -1845,10 +1846,10 @@
 }
 _ACEOF
 rm -f conftest.o conftest.obj
-if { (eval echo "$as_me:1848: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:1849: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:1851: \$? = $ac_status" >&5
+  echo "$as_me:1852: \$? = $ac_status" >&5
   (exit $ac_status); }; then
   for ac_file in `(ls conftest.o conftest.obj; ls conftest.*) 2>/dev/null`; do
   case $ac_file in
@@ -1860,24 +1861,24 @@
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
-{ { echo "$as_me:1863: error: cannot compute OBJEXT: cannot compile" >&5
+{ { echo "$as_me:1864: error: cannot compute OBJEXT: cannot compile" >&5
 echo "$as_me: error: cannot compute OBJEXT: cannot compile" >&2;}
    { (exit 1); exit 1; }; }
 fi
 
 rm -f conftest.$ac_cv_objext conftest.$ac_ext
 fi
-echo "$as_me:1870: result: $ac_cv_objext" >&5
+echo "$as_me:1871: result: $ac_cv_objext" >&5
 echo "${ECHO_T}$ac_cv_objext" >&6
 OBJEXT=$ac_cv_objext
 ac_objext=$OBJEXT
-echo "$as_me:1874: checking whether we are using the GNU C compiler" >&5
+echo "$as_me:1875: checking whether we are using the GNU C compiler" >&5
 echo $ECHO_N "checking whether we are using the GNU C compiler... $ECHO_C" >&6
 if test "${ac_cv_c_compiler_gnu+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 1880 "configure"
+#line 1881 "configure"
 #include "confdefs.h"
 
 int
@@ -1892,16 +1893,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:1895: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:1896: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:1898: \$? = $ac_status" >&5
+  echo "$as_me:1899: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:1901: \"$ac_try\"") >&5
+  { (eval echo "$as_me:1902: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:1904: \$? = $ac_status" >&5
+  echo "$as_me:1905: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_compiler_gnu=yes
 else
@@ -1913,19 +1914,19 @@
 ac_cv_c_compiler_gnu=$ac_compiler_gnu
 
 fi
-echo "$as_me:1916: result: $ac_cv_c_compiler_gnu" >&5
+echo "$as_me:1917: result: $ac_cv_c_compiler_gnu" >&5
 echo "${ECHO_T}$ac_cv_c_compiler_gnu" >&6
 GCC=`test $ac_compiler_gnu = yes && echo yes`
 ac_test_CFLAGS=${CFLAGS+set}
 ac_save_CFLAGS=$CFLAGS
 CFLAGS="-g"
-echo "$as_me:1922: checking whether $CC accepts -g" >&5
+echo "$as_me:1923: checking whether $CC accepts -g" >&5
 echo $ECHO_N "checking whether $CC accepts -g... $ECHO_C" >&6
 if test "${ac_cv_prog_cc_g+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 1928 "configure"
+#line 1929 "configure"
 #include "confdefs.h"
 
 int
@@ -1937,16 +1938,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:1940: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:1941: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:1943: \$? = $ac_status" >&5
+  echo "$as_me:1944: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:1946: \"$ac_try\"") >&5
+  { (eval echo "$as_me:1947: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:1949: \$? = $ac_status" >&5
+  echo "$as_me:1950: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_prog_cc_g=yes
 else
@@ -1956,7 +1957,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:1959: result: $ac_cv_prog_cc_g" >&5
+echo "$as_me:1960: result: $ac_cv_prog_cc_g" >&5
 echo "${ECHO_T}$ac_cv_prog_cc_g" >&6
 if test "$ac_test_CFLAGS" = set; then
   CFLAGS=$ac_save_CFLAGS
@@ -1983,16 +1984,16 @@
 #endif
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:1986: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:1987: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:1989: \$? = $ac_status" >&5
+  echo "$as_me:1990: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:1992: \"$ac_try\"") >&5
+  { (eval echo "$as_me:1993: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:1995: \$? = $ac_status" >&5
+  echo "$as_me:1996: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   for ac_declaration in \
    ''\
@@ -2004,7 +2005,7 @@
    'void exit (int);'
 do
   cat >conftest.$ac_ext <<_ACEOF
-#line 2007 "configure"
+#line 2008 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 $ac_declaration
@@ -2017,16 +2018,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:2020: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:2021: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:2023: \$? = $ac_status" >&5
+  echo "$as_me:2024: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:2026: \"$ac_try\"") >&5
+  { (eval echo "$as_me:2027: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:2029: \$? = $ac_status" >&5
+  echo "$as_me:2030: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   :
 else
@@ -2036,7 +2037,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
   cat >conftest.$ac_ext <<_ACEOF
-#line 2039 "configure"
+#line 2040 "configure"
 #include "confdefs.h"
 $ac_declaration
 int
@@ -2048,16 +2049,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:2051: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:2052: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:2054: \$? = $ac_status" >&5
+  echo "$as_me:2055: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:2057: \"$ac_try\"") >&5
+  { (eval echo "$as_me:2058: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:2060: \$? = $ac_status" >&5
+  echo "$as_me:2061: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   break
 else
@@ -2087,15 +2088,15 @@
 
 GCC_VERSION=none
 if test "$GCC" = yes ; then
-	echo "$as_me:2090: checking version of $CC" >&5
+	echo "$as_me:2091: checking version of $CC" >&5
 echo $ECHO_N "checking version of $CC... $ECHO_C" >&6
 	GCC_VERSION="`${CC} --version 2>/dev/null | sed -e '2,$d' -e 's/^.*(GCC[^)]*) //' -e 's/^.*(Debian[^)]*) //' -e 's/^[^0-9.]*//' -e 's/[^0-9.].*//'`"
 	test -z "$GCC_VERSION" && GCC_VERSION=unknown
-	echo "$as_me:2094: result: $GCC_VERSION" >&5
+	echo "$as_me:2095: result: $GCC_VERSION" >&5
 echo "${ECHO_T}$GCC_VERSION" >&6
 fi
 
-echo "$as_me:2098: checking for $CC option to accept ANSI C" >&5
+echo "$as_me:2099: checking for $CC option to accept ANSI C" >&5
 echo $ECHO_N "checking for $CC option to accept ANSI C... $ECHO_C" >&6
 if test "${ac_cv_prog_cc_stdc+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -2103,7 +2104,7 @@
   ac_cv_prog_cc_stdc=no
 ac_save_CC=$CC
 cat >conftest.$ac_ext <<_ACEOF
-#line 2106 "configure"
+#line 2107 "configure"
 #include "confdefs.h"
 #include <stdarg.h>
 #include <stdio.h>
@@ -2152,16 +2153,16 @@
 do
   CC="$ac_save_CC $ac_arg"
   rm -f conftest.$ac_objext
-if { (eval echo "$as_me:2155: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:2156: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:2158: \$? = $ac_status" >&5
+  echo "$as_me:2159: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:2161: \"$ac_try\"") >&5
+  { (eval echo "$as_me:2162: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:2164: \$? = $ac_status" >&5
+  echo "$as_me:2165: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_prog_cc_stdc=$ac_arg
 break
@@ -2178,10 +2179,10 @@
 
 case "x$ac_cv_prog_cc_stdc" in
   x|xno)
-    echo "$as_me:2181: result: none needed" >&5
+    echo "$as_me:2182: result: none needed" >&5
 echo "${ECHO_T}none needed" >&6 ;;
   *)
-    echo "$as_me:2184: result: $ac_cv_prog_cc_stdc" >&5
+    echo "$as_me:2185: result: $ac_cv_prog_cc_stdc" >&5
 echo "${ECHO_T}$ac_cv_prog_cc_stdc" >&6
     CC="$CC $ac_cv_prog_cc_stdc" ;;
 esac
@@ -2189,13 +2190,13 @@
 # This should have been defined by AC_PROG_CC
 : ${CC:=cc}
 
-echo "$as_me:2192: checking \$CC variable" >&5
+echo "$as_me:2193: checking \$CC variable" >&5
 echo $ECHO_N "checking \$CC variable... $ECHO_C" >&6
 case "$CC" in
 (*[\ \	]-*)
-	echo "$as_me:2196: result: broken" >&5
+	echo "$as_me:2197: result: broken" >&5
 echo "${ECHO_T}broken" >&6
-	{ echo "$as_me:2198: WARNING: your environment misuses the CC variable to hold CFLAGS/CPPFLAGS options" >&5
+	{ echo "$as_me:2199: WARNING: your environment misuses the CC variable to hold CFLAGS/CPPFLAGS options" >&5
 echo "$as_me: WARNING: your environment misuses the CC variable to hold CFLAGS/CPPFLAGS options" >&2;}
 	# humor him...
 	cf_prog=`echo "$CC" | sed -e 's/	/ /g' -e 's/[ ]* / /g' -e 's/[ ]*[ ]-[^ ].*//'`
@@ -2312,19 +2313,19 @@
 	done
 	test -n "$verbose" && echo "	resulting CC: '$CC'" 1>&6
 
-echo "${as_me:-configure}:2315: testing resulting CC: '$CC' ..." 1>&5
+echo "${as_me:-configure}:2316: testing resulting CC: '$CC' ..." 1>&5
 
 	test -n "$verbose" && echo "	resulting CFLAGS: '$CFLAGS'" 1>&6
 
-echo "${as_me:-configure}:2319: testing resulting CFLAGS: '$CFLAGS' ..." 1>&5
+echo "${as_me:-configure}:2320: testing resulting CFLAGS: '$CFLAGS' ..." 1>&5
 
 	test -n "$verbose" && echo "	resulting CPPFLAGS: '$CPPFLAGS'" 1>&6
 
-echo "${as_me:-configure}:2323: testing resulting CPPFLAGS: '$CPPFLAGS' ..." 1>&5
+echo "${as_me:-configure}:2324: testing resulting CPPFLAGS: '$CPPFLAGS' ..." 1>&5
 
 	;;
 (*)
-	echo "$as_me:2327: result: ok" >&5
+	echo "$as_me:2328: result: ok" >&5
 echo "${ECHO_T}ok" >&6
 	;;
 esac
@@ -2335,7 +2336,7 @@
 ac_link='$CC -o conftest$ac_exeext $CFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
 ac_compiler_gnu=$ac_cv_c_compiler_gnu
 ac_main_return=return
-echo "$as_me:2338: checking how to run the C preprocessor" >&5
+echo "$as_me:2339: checking how to run the C preprocessor" >&5
 echo $ECHO_N "checking how to run the C preprocessor... $ECHO_C" >&6
 # On Suns, sometimes $CPP names a directory.
 if test -n "$CPP" && test -d "$CPP"; then
@@ -2356,18 +2357,18 @@
   # On the NeXT, cc -E runs the code through the compiler's parser,
   # not just through cpp. "Syntax error" is here to catch this case.
   cat >conftest.$ac_ext <<_ACEOF
-#line 2359 "configure"
+#line 2360 "configure"
 #include "confdefs.h"
 #include <assert.h>
                      Syntax error
 _ACEOF
-if { (eval echo "$as_me:2364: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:2365: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:2370: \$? = $ac_status" >&5
+  echo "$as_me:2371: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -2390,17 +2391,17 @@
   # OK, works on sane cases.  Now check whether non-existent headers
   # can be detected and how.
   cat >conftest.$ac_ext <<_ACEOF
-#line 2393 "configure"
+#line 2394 "configure"
 #include "confdefs.h"
 #include <ac_nonexistent.h>
 _ACEOF
-if { (eval echo "$as_me:2397: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:2398: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:2403: \$? = $ac_status" >&5
+  echo "$as_me:2404: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -2437,7 +2438,7 @@
 else
   ac_cv_prog_CPP=$CPP
 fi
-echo "$as_me:2440: result: $CPP" >&5
+echo "$as_me:2441: result: $CPP" >&5
 echo "${ECHO_T}$CPP" >&6
 ac_preproc_ok=false
 for ac_c_preproc_warn_flag in '' yes
@@ -2447,18 +2448,18 @@
   # On the NeXT, cc -E runs the code through the compiler's parser,
   # not just through cpp. "Syntax error" is here to catch this case.
   cat >conftest.$ac_ext <<_ACEOF
-#line 2450 "configure"
+#line 2451 "configure"
 #include "confdefs.h"
 #include <assert.h>
                      Syntax error
 _ACEOF
-if { (eval echo "$as_me:2455: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:2456: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:2461: \$? = $ac_status" >&5
+  echo "$as_me:2462: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -2481,17 +2482,17 @@
   # OK, works on sane cases.  Now check whether non-existent headers
   # can be detected and how.
   cat >conftest.$ac_ext <<_ACEOF
-#line 2484 "configure"
+#line 2485 "configure"
 #include "confdefs.h"
 #include <ac_nonexistent.h>
 _ACEOF
-if { (eval echo "$as_me:2488: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:2489: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:2494: \$? = $ac_status" >&5
+  echo "$as_me:2495: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -2519,7 +2520,7 @@
 if $ac_preproc_ok; then
   :
 else
-  { { echo "$as_me:2522: error: C preprocessor \"$CPP\" fails sanity check" >&5
+  { { echo "$as_me:2523: error: C preprocessor \"$CPP\" fails sanity check" >&5
 echo "$as_me: error: C preprocessor \"$CPP\" fails sanity check" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -2532,14 +2533,14 @@
 ac_main_return=return
 
 if test $ac_cv_c_compiler_gnu = yes; then
-    echo "$as_me:2535: checking whether $CC needs -traditional" >&5
+    echo "$as_me:2536: checking whether $CC needs -traditional" >&5
 echo $ECHO_N "checking whether $CC needs -traditional... $ECHO_C" >&6
 if test "${ac_cv_prog_gcc_traditional+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
     ac_pattern="Autoconf.*'x'"
   cat >conftest.$ac_ext <<_ACEOF
-#line 2542 "configure"
+#line 2543 "configure"
 #include "confdefs.h"
 #include <sgtty.h>
 int Autoconf = TIOCGETP;
@@ -2554,7 +2555,7 @@
 
   if test $ac_cv_prog_gcc_traditional = no; then
     cat >conftest.$ac_ext <<_ACEOF
-#line 2557 "configure"
+#line 2558 "configure"
 #include "confdefs.h"
 #include <termio.h>
 int Autoconf = TCGETA;
@@ -2567,14 +2568,14 @@
 
   fi
 fi
-echo "$as_me:2570: result: $ac_cv_prog_gcc_traditional" >&5
+echo "$as_me:2571: result: $ac_cv_prog_gcc_traditional" >&5
 echo "${ECHO_T}$ac_cv_prog_gcc_traditional" >&6
   if test $ac_cv_prog_gcc_traditional = yes; then
     CC="$CC -traditional"
   fi
 fi
 
-echo "$as_me:2577: checking whether $CC understands -c and -o together" >&5
+echo "$as_me:2578: checking whether $CC understands -c and -o together" >&5
 echo $ECHO_N "checking whether $CC understands -c and -o together... $ECHO_C" >&6
 if test "${cf_cv_prog_CC_c_o+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -2589,15 +2590,15 @@
 # We do the test twice because some compilers refuse to overwrite an
 # existing .o file with -o, though they will create one.
 ac_try='$CC $CFLAGS $CPPFLAGS -c conftest.$ac_ext -o conftest2.$ac_objext >&5'
-if { (eval echo "$as_me:2592: \"$ac_try\"") >&5
+if { (eval echo "$as_me:2593: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:2595: \$? = $ac_status" >&5
+  echo "$as_me:2596: \$? = $ac_status" >&5
   (exit $ac_status); } &&
-  test -f conftest2.$ac_objext && { (eval echo "$as_me:2597: \"$ac_try\"") >&5
+  test -f conftest2.$ac_objext && { (eval echo "$as_me:2598: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:2600: \$? = $ac_status" >&5
+  echo "$as_me:2601: \$? = $ac_status" >&5
   (exit $ac_status); };
 then
   eval cf_cv_prog_CC_c_o=yes
@@ -2608,10 +2609,10 @@
 
 fi
 if test $cf_cv_prog_CC_c_o = yes; then
-  echo "$as_me:2611: result: yes" >&5
+  echo "$as_me:2612: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
-  echo "$as_me:2614: result: no" >&5
+  echo "$as_me:2615: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -2625,7 +2626,7 @@
 	(*) LDPATH=$PATH:/sbin:/usr/sbin
 		# Extract the first word of "ldconfig", so it can be a program name with args.
 set dummy ldconfig; ac_word=$2
-echo "$as_me:2628: checking for $ac_word" >&5
+echo "$as_me:2629: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_LDCONFIG+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -2642,7 +2643,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_LDCONFIG="$ac_dir/$ac_word"
-   echo "$as_me:2645: found $ac_dir/$ac_word" >&5
+   echo "$as_me:2646: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -2653,10 +2654,10 @@
 LDCONFIG=$ac_cv_path_LDCONFIG
 
 if test -n "$LDCONFIG"; then
-  echo "$as_me:2656: result: $LDCONFIG" >&5
+  echo "$as_me:2657: result: $LDCONFIG" >&5
 echo "${ECHO_T}$LDCONFIG" >&6
 else
-  echo "$as_me:2659: result: no" >&5
+  echo "$as_me:2660: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -2664,7 +2665,7 @@
 	esac
 fi
 
-echo "$as_me:2667: checking if you want to ensure bool is consistent with C++" >&5
+echo "$as_me:2668: checking if you want to ensure bool is consistent with C++" >&5
 echo $ECHO_N "checking if you want to ensure bool is consistent with C++... $ECHO_C" >&6
 
 # Check whether --with-cxx or --without-cxx was given.
@@ -2674,7 +2675,7 @@
 else
   cf_with_cxx=yes
 fi;
-echo "$as_me:2677: result: $cf_with_cxx" >&5
+echo "$as_me:2678: result: $cf_with_cxx" >&5
 echo "${ECHO_T}$cf_with_cxx" >&6
 if test "X$cf_with_cxx" = Xno ; then
 	CXX=""
@@ -2692,7 +2693,7 @@
   do
     # Extract the first word of "$ac_tool_prefix$ac_prog", so it can be a program name with args.
 set dummy $ac_tool_prefix$ac_prog; ac_word=$2
-echo "$as_me:2695: checking for $ac_word" >&5
+echo "$as_me:2696: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_CXX+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -2707,7 +2708,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_CXX="$ac_tool_prefix$ac_prog"
-echo "$as_me:2710: found $ac_dir/$ac_word" >&5
+echo "$as_me:2711: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -2715,10 +2716,10 @@
 fi
 CXX=$ac_cv_prog_CXX
 if test -n "$CXX"; then
-  echo "$as_me:2718: result: $CXX" >&5
+  echo "$as_me:2719: result: $CXX" >&5
 echo "${ECHO_T}$CXX" >&6
 else
-  echo "$as_me:2721: result: no" >&5
+  echo "$as_me:2722: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -2731,7 +2732,7 @@
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-echo "$as_me:2734: checking for $ac_word" >&5
+echo "$as_me:2735: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_ac_ct_CXX+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -2746,7 +2747,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_ac_ct_CXX="$ac_prog"
-echo "$as_me:2749: found $ac_dir/$ac_word" >&5
+echo "$as_me:2750: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -2754,10 +2755,10 @@
 fi
 ac_ct_CXX=$ac_cv_prog_ac_ct_CXX
 if test -n "$ac_ct_CXX"; then
-  echo "$as_me:2757: result: $ac_ct_CXX" >&5
+  echo "$as_me:2758: result: $ac_ct_CXX" >&5
 echo "${ECHO_T}$ac_ct_CXX" >&6
 else
-  echo "$as_me:2760: result: no" >&5
+  echo "$as_me:2761: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -2769,32 +2770,32 @@
 fi
 
 # Provide some information about the compiler.
-echo "$as_me:2772:" \
+echo "$as_me:2773:" \
      "checking for C++ compiler version" >&5
 ac_compiler=`set X $ac_compile; echo $2`
-{ (eval echo "$as_me:2775: \"$ac_compiler --version </dev/null >&5\"") >&5
+{ (eval echo "$as_me:2776: \"$ac_compiler --version </dev/null >&5\"") >&5
   (eval $ac_compiler --version </dev/null >&5) 2>&5
   ac_status=$?
-  echo "$as_me:2778: \$? = $ac_status" >&5
+  echo "$as_me:2779: \$? = $ac_status" >&5
   (exit $ac_status); }
-{ (eval echo "$as_me:2780: \"$ac_compiler -v </dev/null >&5\"") >&5
+{ (eval echo "$as_me:2781: \"$ac_compiler -v </dev/null >&5\"") >&5
   (eval $ac_compiler -v </dev/null >&5) 2>&5
   ac_status=$?
-  echo "$as_me:2783: \$? = $ac_status" >&5
+  echo "$as_me:2784: \$? = $ac_status" >&5
   (exit $ac_status); }
-{ (eval echo "$as_me:2785: \"$ac_compiler -V </dev/null >&5\"") >&5
+{ (eval echo "$as_me:2786: \"$ac_compiler -V </dev/null >&5\"") >&5
   (eval $ac_compiler -V </dev/null >&5) 2>&5
   ac_status=$?
-  echo "$as_me:2788: \$? = $ac_status" >&5
+  echo "$as_me:2789: \$? = $ac_status" >&5
   (exit $ac_status); }
 
-echo "$as_me:2791: checking whether we are using the GNU C++ compiler" >&5
+echo "$as_me:2792: checking whether we are using the GNU C++ compiler" >&5
 echo $ECHO_N "checking whether we are using the GNU C++ compiler... $ECHO_C" >&6
 if test "${ac_cv_cxx_compiler_gnu+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 2797 "configure"
+#line 2798 "configure"
 #include "confdefs.h"
 
 int
@@ -2809,16 +2810,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:2812: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:2813: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:2815: \$? = $ac_status" >&5
+  echo "$as_me:2816: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:2818: \"$ac_try\"") >&5
+  { (eval echo "$as_me:2819: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:2821: \$? = $ac_status" >&5
+  echo "$as_me:2822: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_compiler_gnu=yes
 else
@@ -2830,19 +2831,19 @@
 ac_cv_cxx_compiler_gnu=$ac_compiler_gnu
 
 fi
-echo "$as_me:2833: result: $ac_cv_cxx_compiler_gnu" >&5
+echo "$as_me:2834: result: $ac_cv_cxx_compiler_gnu" >&5
 echo "${ECHO_T}$ac_cv_cxx_compiler_gnu" >&6
 GXX=`test $ac_compiler_gnu = yes && echo yes`
 ac_test_CXXFLAGS=${CXXFLAGS+set}
 ac_save_CXXFLAGS=$CXXFLAGS
 CXXFLAGS="-g"
-echo "$as_me:2839: checking whether $CXX accepts -g" >&5
+echo "$as_me:2840: checking whether $CXX accepts -g" >&5
 echo $ECHO_N "checking whether $CXX accepts -g... $ECHO_C" >&6
 if test "${ac_cv_prog_cxx_g+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 2845 "configure"
+#line 2846 "configure"
 #include "confdefs.h"
 
 int
@@ -2854,16 +2855,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:2857: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:2858: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:2860: \$? = $ac_status" >&5
+  echo "$as_me:2861: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:2863: \"$ac_try\"") >&5
+  { (eval echo "$as_me:2864: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:2866: \$? = $ac_status" >&5
+  echo "$as_me:2867: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_prog_cxx_g=yes
 else
@@ -2873,7 +2874,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:2876: result: $ac_cv_prog_cxx_g" >&5
+echo "$as_me:2877: result: $ac_cv_prog_cxx_g" >&5
 echo "${ECHO_T}$ac_cv_prog_cxx_g" >&6
 if test "$ac_test_CXXFLAGS" = set; then
   CXXFLAGS=$ac_save_CXXFLAGS
@@ -2900,7 +2901,7 @@
    'void exit (int);'
 do
   cat >conftest.$ac_ext <<_ACEOF
-#line 2903 "configure"
+#line 2904 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 $ac_declaration
@@ -2913,16 +2914,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:2916: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:2917: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:2919: \$? = $ac_status" >&5
+  echo "$as_me:2920: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:2922: \"$ac_try\"") >&5
+  { (eval echo "$as_me:2923: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:2925: \$? = $ac_status" >&5
+  echo "$as_me:2926: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   :
 else
@@ -2932,7 +2933,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
   cat >conftest.$ac_ext <<_ACEOF
-#line 2935 "configure"
+#line 2936 "configure"
 #include "confdefs.h"
 $ac_declaration
 int
@@ -2944,16 +2945,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:2947: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:2948: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:2950: \$? = $ac_status" >&5
+  echo "$as_me:2951: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:2953: \"$ac_try\"") >&5
+  { (eval echo "$as_me:2954: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:2956: \$? = $ac_status" >&5
+  echo "$as_me:2957: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   break
 else
@@ -2987,7 +2988,7 @@
 	then
 		# Several of the C++ configurations do not work, particularly when
 		# cross-compiling (20140913 -TD)
-		echo "$as_me:2990: checking if $CXX works" >&5
+		echo "$as_me:2991: checking if $CXX works" >&5
 echo $ECHO_N "checking if $CXX works... $ECHO_C" >&6
 
 		save_CPPFLAGS="$CPPFLAGS"
@@ -2995,7 +2996,7 @@
 		CPPFLAGS="$CPPFLAGS -I${cf_includedir}"
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 2998 "configure"
+#line 2999 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -3012,16 +3013,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:3015: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:3016: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:3018: \$? = $ac_status" >&5
+  echo "$as_me:3019: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:3021: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3022: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3024: \$? = $ac_status" >&5
+  echo "$as_me:3025: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cxx_works=yes
 else
@@ -3032,11 +3033,11 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 		CPPFLAGS="$save_CPPFLAGS"
 
-		echo "$as_me:3035: result: $cf_cxx_works" >&5
+		echo "$as_me:3036: result: $cf_cxx_works" >&5
 echo "${ECHO_T}$cf_cxx_works" >&6
 		if test "x$cf_cxx_works" = xno
 		then
-			{ echo "$as_me:3039: WARNING: Ignore $CXX, since it cannot compile hello-world." >&5
+			{ echo "$as_me:3040: WARNING: Ignore $CXX, since it cannot compile hello-world." >&5
 echo "$as_me: WARNING: Ignore $CXX, since it cannot compile hello-world." >&2;}
 			cf_with_cxx=no; CXX=""; GXX="";
 		fi
@@ -3052,7 +3053,7 @@
 	if test "$CXX" = "g++" ; then
 		# Extract the first word of "g++", so it can be a program name with args.
 set dummy g++; ac_word=$2
-echo "$as_me:3055: checking for $ac_word" >&5
+echo "$as_me:3056: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_CXX+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3069,7 +3070,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_CXX="$ac_dir/$ac_word"
-   echo "$as_me:3072: found $ac_dir/$ac_word" >&5
+   echo "$as_me:3073: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -3080,17 +3081,17 @@
 CXX=$ac_cv_path_CXX
 
 if test -n "$CXX"; then
-  echo "$as_me:3083: result: $CXX" >&5
+  echo "$as_me:3084: result: $CXX" >&5
 echo "${ECHO_T}$CXX" >&6
 else
-  echo "$as_me:3086: result: no" >&5
+  echo "$as_me:3087: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
 	fi
 	case "x$CXX" in
 	(x|xg++)
-		{ echo "$as_me:3093: WARNING: You don't have any C++ compiler, too bad" >&5
+		{ echo "$as_me:3094: WARNING: You don't have any C++ compiler, too bad" >&5
 echo "$as_me: WARNING: You don't have any C++ compiler, too bad" >&2;}
 		cf_with_cxx=no; CXX=""; GXX="";
 		;;
@@ -3099,7 +3100,7 @@
 
 GXX_VERSION=none
 if test "$GXX" = yes; then
-	echo "$as_me:3102: checking version of ${CXX:-g++}" >&5
+	echo "$as_me:3103: checking version of ${CXX:-g++}" >&5
 echo $ECHO_N "checking version of ${CXX:-g++}... $ECHO_C" >&6
 	GXX_VERSION="`${CXX:-g++} --version| sed -e '2,$d' -e 's/^.*(GCC) //' -e 's/^[^0-9.]*//' -e 's/[^0-9.].*//'`"
 	if test -z "$GXX_VERSION"
@@ -3107,7 +3108,7 @@
 		GXX_VERSION=unknown
 		GXX=no
 	fi
-	echo "$as_me:3110: result: $GXX_VERSION" >&5
+	echo "$as_me:3111: result: $GXX_VERSION" >&5
 echo "${ECHO_T}$GXX_VERSION" >&6
 fi
 
@@ -3115,12 +3116,12 @@
 (1*|2.[0-6]*)
 	# GXX=""; CXX=""; ac_cv_prog_gxx=no
 	# cf_cxx_library=no
-	{ echo "$as_me:3118: WARNING: templates do not work" >&5
+	{ echo "$as_me:3119: WARNING: templates do not work" >&5
 echo "$as_me: WARNING: templates do not work" >&2;}
 	;;
 esac
 
-echo "$as_me:3123: checking if you want to build C++ binding and demo" >&5
+echo "$as_me:3124: checking if you want to build C++ binding and demo" >&5
 echo $ECHO_N "checking if you want to build C++ binding and demo... $ECHO_C" >&6
 
 # Check whether --with-cxx-binding or --without-cxx-binding was given.
@@ -3130,15 +3131,15 @@
 else
   cf_with_cxx_binding=$cf_with_cxx
 fi;
-echo "$as_me:3133: result: $cf_with_cxx_binding" >&5
+echo "$as_me:3134: result: $cf_with_cxx_binding" >&5
 echo "${ECHO_T}$cf_with_cxx_binding" >&6
 
-echo "$as_me:3136: checking if you want to build with Ada95" >&5
+echo "$as_me:3137: checking if you want to build with Ada95" >&5
 echo $ECHO_N "checking if you want to build with Ada95... $ECHO_C" >&6
-echo "$as_me:3138: result: $cf_with_ada" >&5
+echo "$as_me:3139: result: $cf_with_ada" >&5
 echo "${ECHO_T}$cf_with_ada" >&6
 
-echo "$as_me:3141: checking if you want to install terminal database" >&5
+echo "$as_me:3142: checking if you want to install terminal database" >&5
 echo $ECHO_N "checking if you want to install terminal database... $ECHO_C" >&6
 
 # Check whether --enable-db-install or --disable-db-install was given.
@@ -3148,10 +3149,10 @@
 else
   cf_with_db_install=yes
 fi;
-echo "$as_me:3151: result: $cf_with_db_install" >&5
+echo "$as_me:3152: result: $cf_with_db_install" >&5
 echo "${ECHO_T}$cf_with_db_install" >&6
 
-echo "$as_me:3154: checking if you want to install manpages" >&5
+echo "$as_me:3155: checking if you want to install manpages" >&5
 echo $ECHO_N "checking if you want to install manpages... $ECHO_C" >&6
 
 # Check whether --with-manpages or --without-manpages was given.
@@ -3161,10 +3162,10 @@
 else
   cf_with_manpages=yes
 fi;
-echo "$as_me:3164: result: $cf_with_manpages" >&5
+echo "$as_me:3165: result: $cf_with_manpages" >&5
 echo "${ECHO_T}$cf_with_manpages" >&6
 
-echo "$as_me:3167: checking if you want to build programs such as tic" >&5
+echo "$as_me:3168: checking if you want to build programs such as tic" >&5
 echo $ECHO_N "checking if you want to build programs such as tic... $ECHO_C" >&6
 
 # Check whether --with-progs or --without-progs was given.
@@ -3174,18 +3175,18 @@
 else
   cf_with_progs=yes
 fi;
-echo "$as_me:3177: result: $cf_with_progs" >&5
+echo "$as_me:3178: result: $cf_with_progs" >&5
 echo "${ECHO_T}$cf_with_progs" >&6
 
 if test -f $srcdir/tack/tack.h; then
 	if test "x$cross_compiling" = xyes ; then
 		test -n "$verbose" && echo "	ignoring tack because we are cross-compiling" 1>&6
 
-echo "${as_me:-configure}:3184: testing ignoring tack because we are cross-compiling ..." 1>&5
+echo "${as_me:-configure}:3185: testing ignoring tack because we are cross-compiling ..." 1>&5
 
 		cf_with_tack=no
 	else
-		echo "$as_me:3188: checking if you want to build the tack program" >&5
+		echo "$as_me:3189: checking if you want to build the tack program" >&5
 echo $ECHO_N "checking if you want to build the tack program... $ECHO_C" >&6
 
 # Check whether --with-tack or --without-tack was given.
@@ -3195,14 +3196,14 @@
 else
   cf_with_tack=$cf_with_progs
 fi;
-		echo "$as_me:3198: result: $cf_with_tack" >&5
+		echo "$as_me:3199: result: $cf_with_tack" >&5
 echo "${ECHO_T}$cf_with_tack" >&6
 	fi
 else
 	cf_with_tack=no
 fi
 
-echo "$as_me:3205: checking if you want to build test-programs" >&5
+echo "$as_me:3206: checking if you want to build test-programs" >&5
 echo $ECHO_N "checking if you want to build test-programs... $ECHO_C" >&6
 
 # Check whether --with-tests or --without-tests was given.
@@ -3212,10 +3213,10 @@
 else
   cf_with_tests=yes
 fi;
-echo "$as_me:3215: result: $cf_with_tests" >&5
+echo "$as_me:3216: result: $cf_with_tests" >&5
 echo "${ECHO_T}$cf_with_tests" >&6
 
-echo "$as_me:3218: checking if you wish to install curses.h" >&5
+echo "$as_me:3219: checking if you wish to install curses.h" >&5
 echo $ECHO_N "checking if you wish to install curses.h... $ECHO_C" >&6
 
 # Check whether --with-curses-h or --without-curses-h was given.
@@ -3225,7 +3226,7 @@
 else
   with_curses_h=yes
 fi;
-echo "$as_me:3228: result: $with_curses_h" >&5
+echo "$as_me:3229: result: $with_curses_h" >&5
 echo "${ECHO_T}$with_curses_h" >&6
 
 modules_to_build="ncurses"
@@ -3250,7 +3251,7 @@
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-echo "$as_me:3253: checking for $ac_word" >&5
+echo "$as_me:3254: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_AWK+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3265,7 +3266,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_AWK="$ac_prog"
-echo "$as_me:3268: found $ac_dir/$ac_word" >&5
+echo "$as_me:3269: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -3273,21 +3274,21 @@
 fi
 AWK=$ac_cv_prog_AWK
 if test -n "$AWK"; then
-  echo "$as_me:3276: result: $AWK" >&5
+  echo "$as_me:3277: result: $AWK" >&5
 echo "${ECHO_T}$AWK" >&6
 else
-  echo "$as_me:3279: result: no" >&5
+  echo "$as_me:3280: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
   test -n "$AWK" && break
 done
 
-test -z "$AWK" && { { echo "$as_me:3286: error: No awk program found" >&5
+test -z "$AWK" && { { echo "$as_me:3287: error: No awk program found" >&5
 echo "$as_me: error: No awk program found" >&2;}
    { (exit 1); exit 1; }; }
 
-echo "$as_me:3290: checking for egrep" >&5
+echo "$as_me:3291: checking for egrep" >&5
 echo $ECHO_N "checking for egrep... $ECHO_C" >&6
 if test "${ac_cv_prog_egrep+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3297,11 +3298,11 @@
 		else ac_cv_prog_egrep='egrep'
 	fi
 fi
-echo "$as_me:3300: result: $ac_cv_prog_egrep" >&5
+echo "$as_me:3301: result: $ac_cv_prog_egrep" >&5
 echo "${ECHO_T}$ac_cv_prog_egrep" >&6
 	EGREP=$ac_cv_prog_egrep
 
-	test -z "$EGREP" && { { echo "$as_me:3304: error: No egrep program found" >&5
+	test -z "$EGREP" && { { echo "$as_me:3305: error: No egrep program found" >&5
 echo "$as_me: error: No egrep program found" >&2;}
    { (exit 1); exit 1; }; }
 
@@ -3317,7 +3318,7 @@
 # AFS /usr/afsws/bin/install, which mishandles nonexistent args
 # SVR4 /usr/ucb/install, which tries to use the nonexistent group "staff"
 # ./install, which can be erroneously created by make from ./install.sh.
-echo "$as_me:3320: checking for a BSD compatible install" >&5
+echo "$as_me:3321: checking for a BSD compatible install" >&5
 echo $ECHO_N "checking for a BSD compatible install... $ECHO_C" >&6
 if test -z "$INSTALL"; then
 if test "${ac_cv_path_install+set}" = set; then
@@ -3366,7 +3367,7 @@
     INSTALL=$ac_install_sh
   fi
 fi
-echo "$as_me:3369: result: $INSTALL" >&5
+echo "$as_me:3370: result: $INSTALL" >&5
 echo "${ECHO_T}$INSTALL" >&6
 
 # Use test -z because SunOS4 sh mishandles braces in ${var-val}.
@@ -3391,7 +3392,7 @@
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-echo "$as_me:3394: checking for $ac_word" >&5
+echo "$as_me:3395: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_LINT+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3406,7 +3407,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_LINT="$ac_prog"
-echo "$as_me:3409: found $ac_dir/$ac_word" >&5
+echo "$as_me:3410: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -3414,28 +3415,28 @@
 fi
 LINT=$ac_cv_prog_LINT
 if test -n "$LINT"; then
-  echo "$as_me:3417: result: $LINT" >&5
+  echo "$as_me:3418: result: $LINT" >&5
 echo "${ECHO_T}$LINT" >&6
 else
-  echo "$as_me:3420: result: no" >&5
+  echo "$as_me:3421: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
   test -n "$LINT" && break
 done
 
-echo "$as_me:3427: checking whether ln -s works" >&5
+echo "$as_me:3428: checking whether ln -s works" >&5
 echo $ECHO_N "checking whether ln -s works... $ECHO_C" >&6
 LN_S=$as_ln_s
 if test "$LN_S" = "ln -s"; then
-  echo "$as_me:3431: result: yes" >&5
+  echo "$as_me:3432: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
-  echo "$as_me:3434: result: no, using $LN_S" >&5
+  echo "$as_me:3435: result: no, using $LN_S" >&5
 echo "${ECHO_T}no, using $LN_S" >&6
 fi
 
-echo "$as_me:3438: checking if $LN_S -f options work" >&5
+echo "$as_me:3439: checking if $LN_S -f options work" >&5
 echo $ECHO_N "checking if $LN_S -f options work... $ECHO_C" >&6
 
 rm -f conf$$.src conf$$dst
@@ -3447,12 +3448,12 @@
 	cf_prog_ln_sf=no
 fi
 rm -f conf$$.dst conf$$src
-echo "$as_me:3450: result: $cf_prog_ln_sf" >&5
+echo "$as_me:3451: result: $cf_prog_ln_sf" >&5
 echo "${ECHO_T}$cf_prog_ln_sf" >&6
 
 test "$cf_prog_ln_sf" = yes && LN_S="$LN_S -f"
 
-echo "$as_me:3455: checking for long file names" >&5
+echo "$as_me:3456: checking for long file names" >&5
 echo $ECHO_N "checking for long file names... $ECHO_C" >&6
 if test "${ac_cv_sys_long_file_names+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3491,7 +3492,7 @@
   rm -rf $ac_xdir 2>/dev/null
 done
 fi
-echo "$as_me:3494: result: $ac_cv_sys_long_file_names" >&5
+echo "$as_me:3495: result: $ac_cv_sys_long_file_names" >&5
 echo "${ECHO_T}$ac_cv_sys_long_file_names" >&6
 if test $ac_cv_sys_long_file_names = yes; then
 
@@ -3510,7 +3511,7 @@
   withval="$with_config_suffix"
   case "x$withval" in
 	(xyes|xno)
-		{ echo "$as_me:3513: WARNING: expected a value for config-suffix option" >&5
+		{ echo "$as_me:3514: WARNING: expected a value for config-suffix option" >&5
 echo "$as_me: WARNING: expected a value for config-suffix option" >&2;}
 		;;
 	(*)	cf_config_suffix="$withval"
@@ -3520,7 +3521,7 @@
 
 # If we find pkg-config, check if we should install the ".pc" files.
 
-echo "$as_me:3523: checking if you want to use pkg-config" >&5
+echo "$as_me:3524: checking if you want to use pkg-config" >&5
 echo $ECHO_N "checking if you want to use pkg-config... $ECHO_C" >&6
 
 # Check whether --with-pkg-config or --without-pkg-config was given.
@@ -3530,7 +3531,7 @@
 else
   cf_pkg_config=yes
 fi;
-echo "$as_me:3533: result: $cf_pkg_config" >&5
+echo "$as_me:3534: result: $cf_pkg_config" >&5
 echo "${ECHO_T}$cf_pkg_config" >&6
 
 case $cf_pkg_config in
@@ -3542,7 +3543,7 @@
 if test -n "$ac_tool_prefix"; then
   # Extract the first word of "${ac_tool_prefix}pkg-config", so it can be a program name with args.
 set dummy ${ac_tool_prefix}pkg-config; ac_word=$2
-echo "$as_me:3545: checking for $ac_word" >&5
+echo "$as_me:3546: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PKG_CONFIG+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3559,7 +3560,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PKG_CONFIG="$ac_dir/$ac_word"
-   echo "$as_me:3562: found $ac_dir/$ac_word" >&5
+   echo "$as_me:3563: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -3570,10 +3571,10 @@
 PKG_CONFIG=$ac_cv_path_PKG_CONFIG
 
 if test -n "$PKG_CONFIG"; then
-  echo "$as_me:3573: result: $PKG_CONFIG" >&5
+  echo "$as_me:3574: result: $PKG_CONFIG" >&5
 echo "${ECHO_T}$PKG_CONFIG" >&6
 else
-  echo "$as_me:3576: result: no" >&5
+  echo "$as_me:3577: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -3582,7 +3583,7 @@
   ac_pt_PKG_CONFIG=$PKG_CONFIG
   # Extract the first word of "pkg-config", so it can be a program name with args.
 set dummy pkg-config; ac_word=$2
-echo "$as_me:3585: checking for $ac_word" >&5
+echo "$as_me:3586: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_ac_pt_PKG_CONFIG+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3599,7 +3600,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_ac_pt_PKG_CONFIG="$ac_dir/$ac_word"
-   echo "$as_me:3602: found $ac_dir/$ac_word" >&5
+   echo "$as_me:3603: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -3611,10 +3612,10 @@
 ac_pt_PKG_CONFIG=$ac_cv_path_ac_pt_PKG_CONFIG
 
 if test -n "$ac_pt_PKG_CONFIG"; then
-  echo "$as_me:3614: result: $ac_pt_PKG_CONFIG" >&5
+  echo "$as_me:3615: result: $ac_pt_PKG_CONFIG" >&5
 echo "${ECHO_T}$ac_pt_PKG_CONFIG" >&6
 else
-  echo "$as_me:3617: result: no" >&5
+  echo "$as_me:3618: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -3657,24 +3658,24 @@
 	PKG_CONFIG=`echo $PKG_CONFIG | sed -e s%NONE%$cf_path_syntax%`
 	;;
 (*)
-	{ { echo "$as_me:3660: error: expected a pathname, not \"$PKG_CONFIG\"" >&5
+	{ { echo "$as_me:3661: error: expected a pathname, not \"$PKG_CONFIG\"" >&5
 echo "$as_me: error: expected a pathname, not \"$PKG_CONFIG\"" >&2;}
    { (exit 1); exit 1; }; }
 	;;
 esac
 
 elif test "x$cf_pkg_config" != xno ; then
-	{ echo "$as_me:3667: WARNING: pkg-config is not installed" >&5
+	{ echo "$as_me:3668: WARNING: pkg-config is not installed" >&5
 echo "$as_me: WARNING: pkg-config is not installed" >&2;}
 fi
 
 case $PKG_CONFIG in
 (no|none|yes)
-	echo "$as_me:3673: checking for pkg-config library directory" >&5
+	echo "$as_me:3674: checking for pkg-config library directory" >&5
 echo $ECHO_N "checking for pkg-config library directory... $ECHO_C" >&6
 	;;
 (*)
-	echo "$as_me:3677: checking for $PKG_CONFIG library directory" >&5
+	echo "$as_me:3678: checking for $PKG_CONFIG library directory" >&5
 echo $ECHO_N "checking for $PKG_CONFIG library directory... $ECHO_C" >&6
 	;;
 esac
@@ -3729,18 +3730,18 @@
 
 	test -n "$verbose" && echo "	list..." 1>&6
 
-echo "${as_me:-configure}:3732: testing list... ..." 1>&5
+echo "${as_me:-configure}:3733: testing list... ..." 1>&5
 
 	for cf_config in $cf_search_path
 	do
 		test -n "$verbose" && echo "	checking $cf_config/pkgconfig" 1>&6
 
-echo "${as_me:-configure}:3738: testing checking $cf_config/pkgconfig ..." 1>&5
+echo "${as_me:-configure}:3739: testing checking $cf_config/pkgconfig ..." 1>&5
 
 		if test -d $cf_config/pkgconfig
 		then
 			PKG_CONFIG_LIBDIR=$cf_config/pkgconfig
-			echo "$as_me:3743: checking done" >&5
+			echo "$as_me:3744: checking done" >&5
 echo $ECHO_N "checking done... $ECHO_C" >&6
 			break
 		fi
@@ -3751,16 +3752,16 @@
 esac
 
 if test "x$PKG_CONFIG_LIBDIR" != xno ; then
-	echo "$as_me:3754: result: $PKG_CONFIG_LIBDIR" >&5
+	echo "$as_me:3755: result: $PKG_CONFIG_LIBDIR" >&5
 echo "${ECHO_T}$PKG_CONFIG_LIBDIR" >&6
 fi
 
 if test "x$PKG_CONFIG" != xnone
 then
-	echo "$as_me:3760: checking if we should install .pc files for $PKG_CONFIG" >&5
+	echo "$as_me:3761: checking if we should install .pc files for $PKG_CONFIG" >&5
 echo $ECHO_N "checking if we should install .pc files for $PKG_CONFIG... $ECHO_C" >&6
 else
-	echo "$as_me:3763: checking if we should install .pc files" >&5
+	echo "$as_me:3764: checking if we should install .pc files" >&5
 echo $ECHO_N "checking if we should install .pc files... $ECHO_C" >&6
 fi
 
@@ -3771,7 +3772,7 @@
 else
   enable_pc_files=no
 fi;
-echo "$as_me:3774: result: $enable_pc_files" >&5
+echo "$as_me:3775: result: $enable_pc_files" >&5
 echo "${ECHO_T}$enable_pc_files" >&6
 
 if test "x$enable_pc_files" != xno
@@ -3779,7 +3780,7 @@
 	MAKE_PC_FILES=
 	case "x$PKG_CONFIG_LIBDIR" in
 	(xno|xyes)
-		{ echo "$as_me:3782: WARNING: no PKG_CONFIG_LIBDIR was found" >&5
+		{ echo "$as_me:3783: WARNING: no PKG_CONFIG_LIBDIR was found" >&5
 echo "$as_me: WARNING: no PKG_CONFIG_LIBDIR was found" >&2;}
 		;;
 	(*)
@@ -3809,7 +3810,7 @@
 	PKG_CONFIG_LIBDIR=`echo $PKG_CONFIG_LIBDIR | sed -e s%NONE%$cf_path_syntax%`
 	;;
 (*)
-	{ { echo "$as_me:3812: error: expected a pathname, not \"$PKG_CONFIG_LIBDIR\"" >&5
+	{ { echo "$as_me:3813: error: expected a pathname, not \"$PKG_CONFIG_LIBDIR\"" >&5
 echo "$as_me: error: expected a pathname, not \"$PKG_CONFIG_LIBDIR\"" >&2;}
    { (exit 1); exit 1; }; }
 	;;
@@ -3823,7 +3824,7 @@
 
 if test -z "$MAKE_PC_FILES"
 then
-	echo "$as_me:3826: checking for suffix to add to pc-files" >&5
+	echo "$as_me:3827: checking for suffix to add to pc-files" >&5
 echo $ECHO_N "checking for suffix to add to pc-files... $ECHO_C" >&6
 
 # Check whether --with-pc-suffix or --without-pc-suffix was given.
@@ -3838,13 +3839,13 @@
 	esac
 fi;
 	test -z "$PC_MODULE_SUFFIX" && PC_MODULE_SUFFIX=none
-	echo "$as_me:3841: result: $PC_MODULE_SUFFIX" >&5
+	echo "$as_me:3842: result: $PC_MODULE_SUFFIX" >&5
 echo "${ECHO_T}$PC_MODULE_SUFFIX" >&6
 	test "$PC_MODULE_SUFFIX" = none && PC_MODULE_SUFFIX=
 
 fi
 
-echo "$as_me:3847: checking if we should assume mixed-case filenames" >&5
+echo "$as_me:3848: checking if we should assume mixed-case filenames" >&5
 echo $ECHO_N "checking if we should assume mixed-case filenames... $ECHO_C" >&6
 
 # Check whether --enable-mixed-case or --disable-mixed-case was given.
@@ -3854,11 +3855,11 @@
 else
   enable_mixedcase=auto
 fi;
-echo "$as_me:3857: result: $enable_mixedcase" >&5
+echo "$as_me:3858: result: $enable_mixedcase" >&5
 echo "${ECHO_T}$enable_mixedcase" >&6
 if test "$enable_mixedcase" = "auto" ; then
 
-echo "$as_me:3861: checking if filesystem supports mixed-case filenames" >&5
+echo "$as_me:3862: checking if filesystem supports mixed-case filenames" >&5
 echo $ECHO_N "checking if filesystem supports mixed-case filenames... $ECHO_C" >&6
 if test "${cf_cv_mixedcase+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3885,7 +3886,7 @@
 fi
 
 fi
-echo "$as_me:3888: result: $cf_cv_mixedcase" >&5
+echo "$as_me:3889: result: $cf_cv_mixedcase" >&5
 echo "${ECHO_T}$cf_cv_mixedcase" >&6
 test "$cf_cv_mixedcase" = yes &&
 cat >>confdefs.h <<\EOF
@@ -3904,7 +3905,7 @@
 fi
 
 # do this after mixed-case option (tags/TAGS is not as important as tic).
-echo "$as_me:3907: checking whether ${MAKE-make} sets \${MAKE}" >&5
+echo "$as_me:3908: checking whether ${MAKE-make} sets \${MAKE}" >&5
 echo $ECHO_N "checking whether ${MAKE-make} sets \${MAKE}... $ECHO_C" >&6
 set dummy ${MAKE-make}; ac_make=`echo "$2" | sed 'y,./+-,__p_,'`
 if eval "test \"\${ac_cv_prog_make_${ac_make}_set+set}\" = set"; then
@@ -3924,11 +3925,11 @@
 rm -f conftest.make
 fi
 if eval "test \"`echo '$ac_cv_prog_make_'${ac_make}_set`\" = yes"; then
-  echo "$as_me:3927: result: yes" >&5
+  echo "$as_me:3928: result: yes" >&5
 echo "${ECHO_T}yes" >&6
   SET_MAKE=
 else
-  echo "$as_me:3931: result: no" >&5
+  echo "$as_me:3932: result: no" >&5
 echo "${ECHO_T}no" >&6
   SET_MAKE="MAKE=${MAKE-make}"
 fi
@@ -3937,7 +3938,7 @@
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-echo "$as_me:3940: checking for $ac_word" >&5
+echo "$as_me:3941: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_CTAGS+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3952,7 +3953,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_CTAGS="$ac_prog"
-echo "$as_me:3955: found $ac_dir/$ac_word" >&5
+echo "$as_me:3956: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -3960,10 +3961,10 @@
 fi
 CTAGS=$ac_cv_prog_CTAGS
 if test -n "$CTAGS"; then
-  echo "$as_me:3963: result: $CTAGS" >&5
+  echo "$as_me:3964: result: $CTAGS" >&5
 echo "${ECHO_T}$CTAGS" >&6
 else
-  echo "$as_me:3966: result: no" >&5
+  echo "$as_me:3967: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -3974,7 +3975,7 @@
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-echo "$as_me:3977: checking for $ac_word" >&5
+echo "$as_me:3978: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_ETAGS+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3989,7 +3990,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_ETAGS="$ac_prog"
-echo "$as_me:3992: found $ac_dir/$ac_word" >&5
+echo "$as_me:3993: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -3997,10 +3998,10 @@
 fi
 ETAGS=$ac_cv_prog_ETAGS
 if test -n "$ETAGS"; then
-  echo "$as_me:4000: result: $ETAGS" >&5
+  echo "$as_me:4001: result: $ETAGS" >&5
 echo "${ECHO_T}$ETAGS" >&6
 else
-  echo "$as_me:4003: result: no" >&5
+  echo "$as_me:4004: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4009,7 +4010,7 @@
 
 # Extract the first word of "${CTAGS:-ctags}", so it can be a program name with args.
 set dummy ${CTAGS:-ctags}; ac_word=$2
-echo "$as_me:4012: checking for $ac_word" >&5
+echo "$as_me:4013: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_MAKE_LOWER_TAGS+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4024,7 +4025,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_MAKE_LOWER_TAGS="yes"
-echo "$as_me:4027: found $ac_dir/$ac_word" >&5
+echo "$as_me:4028: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4033,17 +4034,17 @@
 fi
 MAKE_LOWER_TAGS=$ac_cv_prog_MAKE_LOWER_TAGS
 if test -n "$MAKE_LOWER_TAGS"; then
-  echo "$as_me:4036: result: $MAKE_LOWER_TAGS" >&5
+  echo "$as_me:4037: result: $MAKE_LOWER_TAGS" >&5
 echo "${ECHO_T}$MAKE_LOWER_TAGS" >&6
 else
-  echo "$as_me:4039: result: no" >&5
+  echo "$as_me:4040: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
 if test "$cf_cv_mixedcase" = yes ; then
 	# Extract the first word of "${ETAGS:-etags}", so it can be a program name with args.
 set dummy ${ETAGS:-etags}; ac_word=$2
-echo "$as_me:4046: checking for $ac_word" >&5
+echo "$as_me:4047: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_MAKE_UPPER_TAGS+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4058,7 +4059,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_MAKE_UPPER_TAGS="yes"
-echo "$as_me:4061: found $ac_dir/$ac_word" >&5
+echo "$as_me:4062: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4067,10 +4068,10 @@
 fi
 MAKE_UPPER_TAGS=$ac_cv_prog_MAKE_UPPER_TAGS
 if test -n "$MAKE_UPPER_TAGS"; then
-  echo "$as_me:4070: result: $MAKE_UPPER_TAGS" >&5
+  echo "$as_me:4071: result: $MAKE_UPPER_TAGS" >&5
 echo "${ECHO_T}$MAKE_UPPER_TAGS" >&6
 else
-  echo "$as_me:4073: result: no" >&5
+  echo "$as_me:4074: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4090,7 +4091,7 @@
 	MAKE_LOWER_TAGS="#"
 fi
 
-echo "$as_me:4093: checking for makeflags variable" >&5
+echo "$as_me:4094: checking for makeflags variable" >&5
 echo $ECHO_N "checking for makeflags variable... $ECHO_C" >&6
 if test "${cf_cv_makeflags+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4120,7 +4121,7 @@
 			;;
 		(*)
 
-echo "${as_me:-configure}:4123: testing given option \"$cf_option\",no match \"$cf_result\" ..." 1>&5
+echo "${as_me:-configure}:4124: testing given option \"$cf_option\",no match \"$cf_result\" ..." 1>&5
 
 			;;
 		esac
@@ -4128,13 +4129,13 @@
 	rm -f cf_makeflags.tmp
 
 fi
-echo "$as_me:4131: result: $cf_cv_makeflags" >&5
+echo "$as_me:4132: result: $cf_cv_makeflags" >&5
 echo "${ECHO_T}$cf_cv_makeflags" >&6
 
 if test -n "$ac_tool_prefix"; then
   # Extract the first word of "${ac_tool_prefix}ranlib", so it can be a program name with args.
 set dummy ${ac_tool_prefix}ranlib; ac_word=$2
-echo "$as_me:4137: checking for $ac_word" >&5
+echo "$as_me:4138: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_RANLIB+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4149,7 +4150,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_RANLIB="${ac_tool_prefix}ranlib"
-echo "$as_me:4152: found $ac_dir/$ac_word" >&5
+echo "$as_me:4153: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4157,10 +4158,10 @@
 fi
 RANLIB=$ac_cv_prog_RANLIB
 if test -n "$RANLIB"; then
-  echo "$as_me:4160: result: $RANLIB" >&5
+  echo "$as_me:4161: result: $RANLIB" >&5
 echo "${ECHO_T}$RANLIB" >&6
 else
-  echo "$as_me:4163: result: no" >&5
+  echo "$as_me:4164: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4169,7 +4170,7 @@
   ac_ct_RANLIB=$RANLIB
   # Extract the first word of "ranlib", so it can be a program name with args.
 set dummy ranlib; ac_word=$2
-echo "$as_me:4172: checking for $ac_word" >&5
+echo "$as_me:4173: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_ac_ct_RANLIB+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4184,7 +4185,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_ac_ct_RANLIB="ranlib"
-echo "$as_me:4187: found $ac_dir/$ac_word" >&5
+echo "$as_me:4188: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4193,10 +4194,10 @@
 fi
 ac_ct_RANLIB=$ac_cv_prog_ac_ct_RANLIB
 if test -n "$ac_ct_RANLIB"; then
-  echo "$as_me:4196: result: $ac_ct_RANLIB" >&5
+  echo "$as_me:4197: result: $ac_ct_RANLIB" >&5
 echo "${ECHO_T}$ac_ct_RANLIB" >&6
 else
-  echo "$as_me:4199: result: no" >&5
+  echo "$as_me:4200: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4208,7 +4209,7 @@
 if test -n "$ac_tool_prefix"; then
   # Extract the first word of "${ac_tool_prefix}ld", so it can be a program name with args.
 set dummy ${ac_tool_prefix}ld; ac_word=$2
-echo "$as_me:4211: checking for $ac_word" >&5
+echo "$as_me:4212: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_LD+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4223,7 +4224,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_LD="${ac_tool_prefix}ld"
-echo "$as_me:4226: found $ac_dir/$ac_word" >&5
+echo "$as_me:4227: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4231,10 +4232,10 @@
 fi
 LD=$ac_cv_prog_LD
 if test -n "$LD"; then
-  echo "$as_me:4234: result: $LD" >&5
+  echo "$as_me:4235: result: $LD" >&5
 echo "${ECHO_T}$LD" >&6
 else
-  echo "$as_me:4237: result: no" >&5
+  echo "$as_me:4238: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4243,7 +4244,7 @@
   ac_ct_LD=$LD
   # Extract the first word of "ld", so it can be a program name with args.
 set dummy ld; ac_word=$2
-echo "$as_me:4246: checking for $ac_word" >&5
+echo "$as_me:4247: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_ac_ct_LD+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4258,7 +4259,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_ac_ct_LD="ld"
-echo "$as_me:4261: found $ac_dir/$ac_word" >&5
+echo "$as_me:4262: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4267,10 +4268,10 @@
 fi
 ac_ct_LD=$ac_cv_prog_ac_ct_LD
 if test -n "$ac_ct_LD"; then
-  echo "$as_me:4270: result: $ac_ct_LD" >&5
+  echo "$as_me:4271: result: $ac_ct_LD" >&5
 echo "${ECHO_T}$ac_ct_LD" >&6
 else
-  echo "$as_me:4273: result: no" >&5
+  echo "$as_me:4274: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4282,7 +4283,7 @@
 if test -n "$ac_tool_prefix"; then
   # Extract the first word of "${ac_tool_prefix}ar", so it can be a program name with args.
 set dummy ${ac_tool_prefix}ar; ac_word=$2
-echo "$as_me:4285: checking for $ac_word" >&5
+echo "$as_me:4286: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_AR+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4297,7 +4298,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_AR="${ac_tool_prefix}ar"
-echo "$as_me:4300: found $ac_dir/$ac_word" >&5
+echo "$as_me:4301: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4305,10 +4306,10 @@
 fi
 AR=$ac_cv_prog_AR
 if test -n "$AR"; then
-  echo "$as_me:4308: result: $AR" >&5
+  echo "$as_me:4309: result: $AR" >&5
 echo "${ECHO_T}$AR" >&6
 else
-  echo "$as_me:4311: result: no" >&5
+  echo "$as_me:4312: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4317,7 +4318,7 @@
   ac_ct_AR=$AR
   # Extract the first word of "ar", so it can be a program name with args.
 set dummy ar; ac_word=$2
-echo "$as_me:4320: checking for $ac_word" >&5
+echo "$as_me:4321: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_ac_ct_AR+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4332,7 +4333,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_ac_ct_AR="ar"
-echo "$as_me:4335: found $ac_dir/$ac_word" >&5
+echo "$as_me:4336: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4341,10 +4342,10 @@
 fi
 ac_ct_AR=$ac_cv_prog_ac_ct_AR
 if test -n "$ac_ct_AR"; then
-  echo "$as_me:4344: result: $ac_ct_AR" >&5
+  echo "$as_me:4345: result: $ac_ct_AR" >&5
 echo "${ECHO_T}$ac_ct_AR" >&6
 else
-  echo "$as_me:4347: result: no" >&5
+  echo "$as_me:4348: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4356,7 +4357,7 @@
 if test -n "$ac_tool_prefix"; then
   # Extract the first word of "${ac_tool_prefix}nm", so it can be a program name with args.
 set dummy ${ac_tool_prefix}nm; ac_word=$2
-echo "$as_me:4359: checking for $ac_word" >&5
+echo "$as_me:4360: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_NM+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4371,7 +4372,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_NM="${ac_tool_prefix}nm"
-echo "$as_me:4374: found $ac_dir/$ac_word" >&5
+echo "$as_me:4375: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4379,10 +4380,10 @@
 fi
 NM=$ac_cv_prog_NM
 if test -n "$NM"; then
-  echo "$as_me:4382: result: $NM" >&5
+  echo "$as_me:4383: result: $NM" >&5
 echo "${ECHO_T}$NM" >&6
 else
-  echo "$as_me:4385: result: no" >&5
+  echo "$as_me:4386: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4391,7 +4392,7 @@
   ac_ct_NM=$NM
   # Extract the first word of "nm", so it can be a program name with args.
 set dummy nm; ac_word=$2
-echo "$as_me:4394: checking for $ac_word" >&5
+echo "$as_me:4395: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_ac_ct_NM+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4406,7 +4407,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_ac_ct_NM="nm"
-echo "$as_me:4409: found $ac_dir/$ac_word" >&5
+echo "$as_me:4410: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4415,10 +4416,10 @@
 fi
 ac_ct_NM=$ac_cv_prog_ac_ct_NM
 if test -n "$ac_ct_NM"; then
-  echo "$as_me:4418: result: $ac_ct_NM" >&5
+  echo "$as_me:4419: result: $ac_ct_NM" >&5
 echo "${ECHO_T}$ac_ct_NM" >&6
 else
-  echo "$as_me:4421: result: no" >&5
+  echo "$as_me:4422: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4430,7 +4431,7 @@
 if test -n "$ac_tool_prefix"; then
   # Extract the first word of "${ac_tool_prefix}ar", so it can be a program name with args.
 set dummy ${ac_tool_prefix}ar; ac_word=$2
-echo "$as_me:4433: checking for $ac_word" >&5
+echo "$as_me:4434: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_AR+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4445,7 +4446,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_AR="${ac_tool_prefix}ar"
-echo "$as_me:4448: found $ac_dir/$ac_word" >&5
+echo "$as_me:4449: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4453,10 +4454,10 @@
 fi
 AR=$ac_cv_prog_AR
 if test -n "$AR"; then
-  echo "$as_me:4456: result: $AR" >&5
+  echo "$as_me:4457: result: $AR" >&5
 echo "${ECHO_T}$AR" >&6
 else
-  echo "$as_me:4459: result: no" >&5
+  echo "$as_me:4460: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4465,7 +4466,7 @@
   ac_ct_AR=$AR
   # Extract the first word of "ar", so it can be a program name with args.
 set dummy ar; ac_word=$2
-echo "$as_me:4468: checking for $ac_word" >&5
+echo "$as_me:4469: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_ac_ct_AR+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4480,7 +4481,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_ac_ct_AR="ar"
-echo "$as_me:4483: found $ac_dir/$ac_word" >&5
+echo "$as_me:4484: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4489,10 +4490,10 @@
 fi
 ac_ct_AR=$ac_cv_prog_ac_ct_AR
 if test -n "$ac_ct_AR"; then
-  echo "$as_me:4492: result: $ac_ct_AR" >&5
+  echo "$as_me:4493: result: $ac_ct_AR" >&5
 echo "${ECHO_T}$ac_ct_AR" >&6
 else
-  echo "$as_me:4495: result: no" >&5
+  echo "$as_me:4496: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4501,7 +4502,7 @@
   AR="$ac_cv_prog_AR"
 fi
 
-echo "$as_me:4504: checking for options to update archives" >&5
+echo "$as_me:4505: checking for options to update archives" >&5
 echo $ECHO_N "checking for options to update archives... $ECHO_C" >&6
 if test "${cf_cv_ar_flags+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4524,13 +4525,13 @@
 		rm -f conftest.a
 
 		cat >conftest.$ac_ext <<EOF
-#line 4527 "configure"
+#line 4528 "configure"
 int	testdata[3] = { 123, 456, 789 };
 EOF
-		if { (eval echo "$as_me:4530: \"$ac_compile\"") >&5
+		if { (eval echo "$as_me:4531: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:4533: \$? = $ac_status" >&5
+  echo "$as_me:4534: \$? = $ac_status" >&5
   (exit $ac_status); } ; then
 			echo "$AR $ARFLAGS $cf_ar_flags conftest.a conftest.$ac_cv_objext" >&5
 			$AR $ARFLAGS $cf_ar_flags conftest.a conftest.$ac_cv_objext 2>&5 1>/dev/null
@@ -4541,7 +4542,7 @@
 		else
 			test -n "$verbose" && echo "	cannot compile test-program" 1>&6
 
-echo "${as_me:-configure}:4544: testing cannot compile test-program ..." 1>&5
+echo "${as_me:-configure}:4545: testing cannot compile test-program ..." 1>&5
 
 			break
 		fi
@@ -4549,7 +4550,7 @@
 	rm -f conftest.a conftest.$ac_ext conftest.$ac_cv_objext
 
 fi
-echo "$as_me:4552: result: $cf_cv_ar_flags" >&5
+echo "$as_me:4553: result: $cf_cv_ar_flags" >&5
 echo "${ECHO_T}$cf_cv_ar_flags" >&6
 
 if test -n "$ARFLAGS" ; then
@@ -4560,7 +4561,7 @@
 	ARFLAGS=$cf_cv_ar_flags
 fi
 
-echo "$as_me:4563: checking if you have specified an install-prefix" >&5
+echo "$as_me:4564: checking if you have specified an install-prefix" >&5
 echo $ECHO_N "checking if you have specified an install-prefix... $ECHO_C" >&6
 
 # Check whether --with-install-prefix or --without-install-prefix was given.
@@ -4573,7 +4574,7 @@
 		;;
 	esac
 fi;
-echo "$as_me:4576: result: $DESTDIR" >&5
+echo "$as_me:4577: result: $DESTDIR" >&5
 echo "${ECHO_T}$DESTDIR" >&6
 
 ###############################################################################
@@ -4601,7 +4602,7 @@
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-echo "$as_me:4604: checking for $ac_word" >&5
+echo "$as_me:4605: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_BUILD_CC+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4616,7 +4617,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_BUILD_CC="$ac_prog"
-echo "$as_me:4619: found $ac_dir/$ac_word" >&5
+echo "$as_me:4620: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4624,10 +4625,10 @@
 fi
 BUILD_CC=$ac_cv_prog_BUILD_CC
 if test -n "$BUILD_CC"; then
-  echo "$as_me:4627: result: $BUILD_CC" >&5
+  echo "$as_me:4628: result: $BUILD_CC" >&5
 echo "${ECHO_T}$BUILD_CC" >&6
 else
-  echo "$as_me:4630: result: no" >&5
+  echo "$as_me:4631: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4636,12 +4637,12 @@
 test -n "$BUILD_CC" || BUILD_CC="none"
 
 fi;
-	echo "$as_me:4639: checking for native build C compiler" >&5
+	echo "$as_me:4640: checking for native build C compiler" >&5
 echo $ECHO_N "checking for native build C compiler... $ECHO_C" >&6
-	echo "$as_me:4641: result: $BUILD_CC" >&5
+	echo "$as_me:4642: result: $BUILD_CC" >&5
 echo "${ECHO_T}$BUILD_CC" >&6
 
-	echo "$as_me:4644: checking for native build C preprocessor" >&5
+	echo "$as_me:4645: checking for native build C preprocessor" >&5
 echo $ECHO_N "checking for native build C preprocessor... $ECHO_C" >&6
 
 # Check whether --with-build-cpp or --without-build-cpp was given.
@@ -4651,10 +4652,10 @@
 else
   BUILD_CPP='${BUILD_CC} -E'
 fi;
-	echo "$as_me:4654: result: $BUILD_CPP" >&5
+	echo "$as_me:4655: result: $BUILD_CPP" >&5
 echo "${ECHO_T}$BUILD_CPP" >&6
 
-	echo "$as_me:4657: checking for native build C flags" >&5
+	echo "$as_me:4658: checking for native build C flags" >&5
 echo $ECHO_N "checking for native build C flags... $ECHO_C" >&6
 
 # Check whether --with-build-cflags or --without-build-cflags was given.
@@ -4662,10 +4663,10 @@
   withval="$with_build_cflags"
   BUILD_CFLAGS="$withval"
 fi;
-	echo "$as_me:4665: result: $BUILD_CFLAGS" >&5
+	echo "$as_me:4666: result: $BUILD_CFLAGS" >&5
 echo "${ECHO_T}$BUILD_CFLAGS" >&6
 
-	echo "$as_me:4668: checking for native build C preprocessor-flags" >&5
+	echo "$as_me:4669: checking for native build C preprocessor-flags" >&5
 echo $ECHO_N "checking for native build C preprocessor-flags... $ECHO_C" >&6
 
 # Check whether --with-build-cppflags or --without-build-cppflags was given.
@@ -4673,10 +4674,10 @@
   withval="$with_build_cppflags"
   BUILD_CPPFLAGS="$withval"
 fi;
-	echo "$as_me:4676: result: $BUILD_CPPFLAGS" >&5
+	echo "$as_me:4677: result: $BUILD_CPPFLAGS" >&5
 echo "${ECHO_T}$BUILD_CPPFLAGS" >&6
 
-	echo "$as_me:4679: checking for native build linker-flags" >&5
+	echo "$as_me:4680: checking for native build linker-flags" >&5
 echo $ECHO_N "checking for native build linker-flags... $ECHO_C" >&6
 
 # Check whether --with-build-ldflags or --without-build-ldflags was given.
@@ -4684,10 +4685,10 @@
   withval="$with_build_ldflags"
   BUILD_LDFLAGS="$withval"
 fi;
-	echo "$as_me:4687: result: $BUILD_LDFLAGS" >&5
+	echo "$as_me:4688: result: $BUILD_LDFLAGS" >&5
 echo "${ECHO_T}$BUILD_LDFLAGS" >&6
 
-	echo "$as_me:4690: checking for native build linker-libraries" >&5
+	echo "$as_me:4691: checking for native build linker-libraries" >&5
 echo $ECHO_N "checking for native build linker-libraries... $ECHO_C" >&6
 
 # Check whether --with-build-libs or --without-build-libs was given.
@@ -4695,7 +4696,7 @@
   withval="$with_build_libs"
   BUILD_LIBS="$withval"
 fi;
-	echo "$as_me:4698: result: $BUILD_LIBS" >&5
+	echo "$as_me:4699: result: $BUILD_LIBS" >&5
 echo "${ECHO_T}$BUILD_LIBS" >&6
 
 	# this assumes we're on Unix.
@@ -4705,7 +4706,7 @@
 	: ${BUILD_CC:='${CC}'}
 
 	if ( test "$BUILD_CC" = "$CC" || test "$BUILD_CC" = '${CC}' ) ; then
-		{ { echo "$as_me:4708: error: Cross-build requires two compilers.
+		{ { echo "$as_me:4709: error: Cross-build requires two compilers.
 Use --with-build-cc to specify the native compiler." >&5
 echo "$as_me: error: Cross-build requires two compilers.
 Use --with-build-cc to specify the native compiler." >&2;}
@@ -4730,7 +4731,7 @@
 ### shared, for example.
 cf_list_models=""
 
-echo "$as_me:4733: checking if libtool -version-number should be used" >&5
+echo "$as_me:4734: checking if libtool -version-number should be used" >&5
 echo $ECHO_N "checking if libtool -version-number should be used... $ECHO_C" >&6
 
 # Check whether --enable-libtool-version or --disable-libtool-version was given.
@@ -4747,7 +4748,7 @@
 	cf_libtool_version=yes
 
 fi;
-echo "$as_me:4750: result: $cf_libtool_version" >&5
+echo "$as_me:4751: result: $cf_libtool_version" >&5
 echo "${ECHO_T}$cf_libtool_version" >&6
 
 if test "$cf_libtool_version" = yes ; then
@@ -4756,25 +4757,25 @@
 	LIBTOOL_VERSION="-version-info"
 	case "x$VERSION" in
 	(x)
-		{ echo "$as_me:4759: WARNING: VERSION was not set" >&5
+		{ echo "$as_me:4760: WARNING: VERSION was not set" >&5
 echo "$as_me: WARNING: VERSION was not set" >&2;}
 		;;
 	(x*.*.*)
 		ABI_VERSION="$VERSION"
 		test -n "$verbose" && echo "	ABI_VERSION: $ABI_VERSION" 1>&6
 
-echo "${as_me:-configure}:4766: testing ABI_VERSION: $ABI_VERSION ..." 1>&5
+echo "${as_me:-configure}:4767: testing ABI_VERSION: $ABI_VERSION ..." 1>&5
 
 		;;
 	(x*:*:*)
 		ABI_VERSION=`echo "$VERSION" | sed -e 's/:/./g'`
 		test -n "$verbose" && echo "	ABI_VERSION: $ABI_VERSION" 1>&6
 
-echo "${as_me:-configure}:4773: testing ABI_VERSION: $ABI_VERSION ..." 1>&5
+echo "${as_me:-configure}:4774: testing ABI_VERSION: $ABI_VERSION ..." 1>&5
 
 		;;
 	(*)
-		{ echo "$as_me:4777: WARNING: unexpected VERSION value: $VERSION" >&5
+		{ echo "$as_me:4778: WARNING: unexpected VERSION value: $VERSION" >&5
 echo "$as_me: WARNING: unexpected VERSION value: $VERSION" >&2;}
 		;;
 	esac
@@ -4796,7 +4797,7 @@
 LIB_INSTALL=
 LIB_UNINSTALL=
 
-echo "$as_me:4799: checking if you want to build libraries with libtool" >&5
+echo "$as_me:4800: checking if you want to build libraries with libtool" >&5
 echo $ECHO_N "checking if you want to build libraries with libtool... $ECHO_C" >&6
 
 # Check whether --with-libtool or --without-libtool was given.
@@ -4806,7 +4807,7 @@
 else
   with_libtool=no
 fi;
-echo "$as_me:4809: result: $with_libtool" >&5
+echo "$as_me:4810: result: $with_libtool" >&5
 echo "${ECHO_T}$with_libtool" >&6
 if test "$with_libtool" != "no"; then
 
@@ -4837,7 +4838,7 @@
 	with_libtool=`echo $with_libtool | sed -e s%NONE%$cf_path_syntax%`
 	;;
 (*)
-	{ { echo "$as_me:4840: error: expected a pathname, not \"$with_libtool\"" >&5
+	{ { echo "$as_me:4841: error: expected a pathname, not \"$with_libtool\"" >&5
 echo "$as_me: error: expected a pathname, not \"$with_libtool\"" >&2;}
    { (exit 1); exit 1; }; }
 	;;
@@ -4850,7 +4851,7 @@
   do
     # Extract the first word of "$ac_tool_prefix$ac_prog", so it can be a program name with args.
 set dummy $ac_tool_prefix$ac_prog; ac_word=$2
-echo "$as_me:4853: checking for $ac_word" >&5
+echo "$as_me:4854: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_LIBTOOL+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4865,7 +4866,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_LIBTOOL="$ac_tool_prefix$ac_prog"
-echo "$as_me:4868: found $ac_dir/$ac_word" >&5
+echo "$as_me:4869: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4873,10 +4874,10 @@
 fi
 LIBTOOL=$ac_cv_prog_LIBTOOL
 if test -n "$LIBTOOL"; then
-  echo "$as_me:4876: result: $LIBTOOL" >&5
+  echo "$as_me:4877: result: $LIBTOOL" >&5
 echo "${ECHO_T}$LIBTOOL" >&6
 else
-  echo "$as_me:4879: result: no" >&5
+  echo "$as_me:4880: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4889,7 +4890,7 @@
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-echo "$as_me:4892: checking for $ac_word" >&5
+echo "$as_me:4893: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_ac_ct_LIBTOOL+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4904,7 +4905,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_ac_ct_LIBTOOL="$ac_prog"
-echo "$as_me:4907: found $ac_dir/$ac_word" >&5
+echo "$as_me:4908: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4912,10 +4913,10 @@
 fi
 ac_ct_LIBTOOL=$ac_cv_prog_ac_ct_LIBTOOL
 if test -n "$ac_ct_LIBTOOL"; then
-  echo "$as_me:4915: result: $ac_ct_LIBTOOL" >&5
+  echo "$as_me:4916: result: $ac_ct_LIBTOOL" >&5
 echo "${ECHO_T}$ac_ct_LIBTOOL" >&6
 else
-  echo "$as_me:4918: result: no" >&5
+  echo "$as_me:4919: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4946,7 +4947,7 @@
   do
     # Extract the first word of "$ac_tool_prefix$ac_prog", so it can be a program name with args.
 set dummy $ac_tool_prefix$ac_prog; ac_word=$2
-echo "$as_me:4949: checking for $ac_word" >&5
+echo "$as_me:4950: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_LIBTOOL+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4961,7 +4962,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_LIBTOOL="$ac_tool_prefix$ac_prog"
-echo "$as_me:4964: found $ac_dir/$ac_word" >&5
+echo "$as_me:4965: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -4969,10 +4970,10 @@
 fi
 LIBTOOL=$ac_cv_prog_LIBTOOL
 if test -n "$LIBTOOL"; then
-  echo "$as_me:4972: result: $LIBTOOL" >&5
+  echo "$as_me:4973: result: $LIBTOOL" >&5
 echo "${ECHO_T}$LIBTOOL" >&6
 else
-  echo "$as_me:4975: result: no" >&5
+  echo "$as_me:4976: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -4985,7 +4986,7 @@
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-echo "$as_me:4988: checking for $ac_word" >&5
+echo "$as_me:4989: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_ac_ct_LIBTOOL+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5000,7 +5001,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_ac_ct_LIBTOOL="$ac_prog"
-echo "$as_me:5003: found $ac_dir/$ac_word" >&5
+echo "$as_me:5004: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -5008,10 +5009,10 @@
 fi
 ac_ct_LIBTOOL=$ac_cv_prog_ac_ct_LIBTOOL
 if test -n "$ac_ct_LIBTOOL"; then
-  echo "$as_me:5011: result: $ac_ct_LIBTOOL" >&5
+  echo "$as_me:5012: result: $ac_ct_LIBTOOL" >&5
 echo "${ECHO_T}$ac_ct_LIBTOOL" >&6
 else
-  echo "$as_me:5014: result: no" >&5
+  echo "$as_me:5015: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -5033,7 +5034,7 @@
 		fi
 	fi
 	if test -z "$LIBTOOL" ; then
-		{ { echo "$as_me:5036: error: Cannot find libtool" >&5
+		{ { echo "$as_me:5037: error: Cannot find libtool" >&5
 echo "$as_me: error: Cannot find libtool" >&2;}
    { (exit 1); exit 1; }; }
 	fi
@@ -5049,7 +5050,7 @@
 
 if test -n "$LIBTOOL" && test "$LIBTOOL" != none
 then
-	echo "$as_me:5052: checking version of $LIBTOOL" >&5
+	echo "$as_me:5053: checking version of $LIBTOOL" >&5
 echo $ECHO_N "checking version of $LIBTOOL... $ECHO_C" >&6
 
 if test -n "$LIBTOOL" && test "$LIBTOOL" != none
@@ -5060,15 +5061,15 @@
 fi
 test -z "$cf_cv_libtool_version" && unset cf_cv_libtool_version
 
-	echo "$as_me:5063: result: $cf_cv_libtool_version" >&5
+	echo "$as_me:5064: result: $cf_cv_libtool_version" >&5
 echo "${ECHO_T}$cf_cv_libtool_version" >&6
 	if test -z "$cf_cv_libtool_version" ; then
-		{ { echo "$as_me:5066: error: This is not GNU libtool" >&5
+		{ { echo "$as_me:5067: error: This is not GNU libtool" >&5
 echo "$as_me: error: This is not GNU libtool" >&2;}
    { (exit 1); exit 1; }; }
 	fi
 else
-	{ { echo "$as_me:5071: error: GNU libtool has not been found" >&5
+	{ { echo "$as_me:5072: error: GNU libtool has not been found" >&5
 echo "$as_me: error: GNU libtool has not been found" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -5104,7 +5105,7 @@
 
 else
 
-echo "$as_me:5107: checking if you want to build shared libraries" >&5
+echo "$as_me:5108: checking if you want to build shared libraries" >&5
 echo $ECHO_N "checking if you want to build shared libraries... $ECHO_C" >&6
 
 # Check whether --with-shared or --without-shared was given.
@@ -5114,11 +5115,11 @@
 else
   with_shared=no
 fi;
-echo "$as_me:5117: result: $with_shared" >&5
+echo "$as_me:5118: result: $with_shared" >&5
 echo "${ECHO_T}$with_shared" >&6
 test "x$with_shared" = "xyes" && cf_list_models="$cf_list_models shared"
 
-echo "$as_me:5121: checking if you want to build static libraries" >&5
+echo "$as_me:5122: checking if you want to build static libraries" >&5
 echo $ECHO_N "checking if you want to build static libraries... $ECHO_C" >&6
 
 # Check whether --with-normal or --without-normal was given.
@@ -5128,11 +5129,11 @@
 else
   with_normal=yes
 fi;
-echo "$as_me:5131: result: $with_normal" >&5
+echo "$as_me:5132: result: $with_normal" >&5
 echo "${ECHO_T}$with_normal" >&6
 test "x$with_normal" = "xyes" && cf_list_models="$cf_list_models normal"
 
-echo "$as_me:5135: checking if you want to build debug libraries" >&5
+echo "$as_me:5136: checking if you want to build debug libraries" >&5
 echo $ECHO_N "checking if you want to build debug libraries... $ECHO_C" >&6
 
 # Check whether --with-debug or --without-debug was given.
@@ -5142,11 +5143,11 @@
 else
   with_debug=yes
 fi;
-echo "$as_me:5145: result: $with_debug" >&5
+echo "$as_me:5146: result: $with_debug" >&5
 echo "${ECHO_T}$with_debug" >&6
 test "x$with_debug" = "xyes" && cf_list_models="$cf_list_models debug"
 
-echo "$as_me:5149: checking if you want to build profiling libraries" >&5
+echo "$as_me:5150: checking if you want to build profiling libraries" >&5
 echo $ECHO_N "checking if you want to build profiling libraries... $ECHO_C" >&6
 
 # Check whether --with-profile or --without-profile was given.
@@ -5156,7 +5157,7 @@
 else
   with_profile=no
 fi;
-echo "$as_me:5159: result: $with_profile" >&5
+echo "$as_me:5160: result: $with_profile" >&5
 echo "${ECHO_T}$with_profile" >&6
 test "x$with_profile" = "xyes" && cf_list_models="$cf_list_models profile"
 
@@ -5164,7 +5165,7 @@
 
 if test "X$cf_with_cxx_binding" != Xno; then
 if test "x$with_shared" = "xyes"; then
-echo "$as_me:5167: checking if you want to build C++ shared libraries" >&5
+echo "$as_me:5168: checking if you want to build C++ shared libraries" >&5
 echo $ECHO_N "checking if you want to build C++ shared libraries... $ECHO_C" >&6
 
 # Check whether --with-cxx-shared or --without-cxx-shared was given.
@@ -5174,26 +5175,26 @@
 else
   with_shared_cxx=no
 fi;
-echo "$as_me:5177: result: $with_shared_cxx" >&5
+echo "$as_me:5178: result: $with_shared_cxx" >&5
 echo "${ECHO_T}$with_shared_cxx" >&6
 fi
 fi
 
 ###############################################################################
 
-echo "$as_me:5184: checking for specified models" >&5
+echo "$as_me:5185: checking for specified models" >&5
 echo $ECHO_N "checking for specified models... $ECHO_C" >&6
 test -z "$cf_list_models" && cf_list_models=normal
 test "$with_libtool" != "no" && cf_list_models=libtool
-echo "$as_me:5188: result: $cf_list_models" >&5
+echo "$as_me:5189: result: $cf_list_models" >&5
 echo "${ECHO_T}$cf_list_models" >&6
 
 ### Use the first model as the default, and save its suffix for use in building
 ### up test-applications.
-echo "$as_me:5193: checking for default model" >&5
+echo "$as_me:5194: checking for default model" >&5
 echo $ECHO_N "checking for default model... $ECHO_C" >&6
 DFT_LWR_MODEL=`echo "$cf_list_models" | $AWK '{print $1}'`
-echo "$as_me:5196: result: $DFT_LWR_MODEL" >&5
+echo "$as_me:5197: result: $DFT_LWR_MODEL" >&5
 echo "${ECHO_T}$DFT_LWR_MODEL" >&6
 
 DFT_UPR_MODEL=`echo "$DFT_LWR_MODEL" | sed y%abcdefghijklmnopqrstuvwxyz./-%ABCDEFGHIJKLMNOPQRSTUVWXYZ___%`
@@ -5207,7 +5208,7 @@
 LIB_DIR=../lib
 LIB_2ND=../../lib
 
-echo "$as_me:5210: checking if you want to have a library-prefix" >&5
+echo "$as_me:5211: checking if you want to have a library-prefix" >&5
 echo $ECHO_N "checking if you want to have a library-prefix... $ECHO_C" >&6
 
 # Check whether --with-lib-prefix or --without-lib-prefix was given.
@@ -5217,7 +5218,7 @@
 else
   with_lib_prefix=auto
 fi;
-echo "$as_me:5220: result: $with_lib_prefix" >&5
+echo "$as_me:5221: result: $with_lib_prefix" >&5
 echo "${ECHO_T}$with_lib_prefix" >&6
 
 if test $with_lib_prefix = auto
@@ -5245,19 +5246,19 @@
 
 LIB_SUFFIX=
 
-	echo "$as_me:5248: checking for PATH separator" >&5
+	echo "$as_me:5249: checking for PATH separator" >&5
 echo $ECHO_N "checking for PATH separator... $ECHO_C" >&6
 	case $cf_cv_system_name in
 	(os2*)	PATH_SEPARATOR=';'  ;;
 	(*)	${PATH_SEPARATOR:=':'}  ;;
 	esac
 
-	echo "$as_me:5255: result: $PATH_SEPARATOR" >&5
+	echo "$as_me:5256: result: $PATH_SEPARATOR" >&5
 echo "${ECHO_T}$PATH_SEPARATOR" >&6
 
 ###############################################################################
 
-echo "$as_me:5260: checking if you want to build a separate terminfo library" >&5
+echo "$as_me:5261: checking if you want to build a separate terminfo library" >&5
 echo $ECHO_N "checking if you want to build a separate terminfo library... $ECHO_C" >&6
 
 # Check whether --with-termlib or --without-termlib was given.
@@ -5267,10 +5268,10 @@
 else
   with_termlib=no
 fi;
-echo "$as_me:5270: result: $with_termlib" >&5
+echo "$as_me:5271: result: $with_termlib" >&5
 echo "${ECHO_T}$with_termlib" >&6
 
-echo "$as_me:5273: checking if you want to build a separate tic library" >&5
+echo "$as_me:5274: checking if you want to build a separate tic library" >&5
 echo $ECHO_N "checking if you want to build a separate tic library... $ECHO_C" >&6
 
 # Check whether --with-ticlib or --without-ticlib was given.
@@ -5280,7 +5281,7 @@
 else
   with_ticlib=no
 fi;
-echo "$as_me:5283: result: $with_ticlib" >&5
+echo "$as_me:5284: result: $with_ticlib" >&5
 echo "${ECHO_T}$with_ticlib" >&6
 
 if test X"$CC_G_OPT" = X"" ; then
@@ -5293,7 +5294,7 @@
 	test -n "$GXX" && test "x${ac_cv_prog_cxx_g}" != xyes && CXX_G_OPT=''
 fi
 
-echo "$as_me:5296: checking for default loader flags" >&5
+echo "$as_me:5297: checking for default loader flags" >&5
 echo $ECHO_N "checking for default loader flags... $ECHO_C" >&6
 case $DFT_LWR_MODEL in
 (libtool) LD_MODEL=''   ;;
@@ -5302,13 +5303,13 @@
 (profile) LD_MODEL='-pg';;
 (shared)  LD_MODEL=''   ;;
 esac
-echo "$as_me:5305: result: $LD_MODEL" >&5
+echo "$as_me:5306: result: $LD_MODEL" >&5
 echo "${ECHO_T}$LD_MODEL" >&6
 
 case $DFT_LWR_MODEL in
 (shared)
 
-echo "$as_me:5311: checking if rpath option should be used" >&5
+echo "$as_me:5312: checking if rpath option should be used" >&5
 echo $ECHO_N "checking if rpath option should be used... $ECHO_C" >&6
 
 # Check whether --enable-rpath or --disable-rpath was given.
@@ -5318,10 +5319,10 @@
 else
   cf_cv_enable_rpath=no
 fi;
-echo "$as_me:5321: result: $cf_cv_enable_rpath" >&5
+echo "$as_me:5322: result: $cf_cv_enable_rpath" >&5
 echo "${ECHO_T}$cf_cv_enable_rpath" >&6
 
-echo "$as_me:5324: checking if shared libraries should be relinked during install" >&5
+echo "$as_me:5325: checking if shared libraries should be relinked during install" >&5
 echo $ECHO_N "checking if shared libraries should be relinked during install... $ECHO_C" >&6
 
 # Check whether --enable-relink or --disable-relink was given.
@@ -5331,7 +5332,7 @@
 else
   cf_cv_do_relink=yes
 fi;
-echo "$as_me:5334: result: $cf_cv_do_relink" >&5
+echo "$as_me:5335: result: $cf_cv_do_relink" >&5
 echo "${ECHO_T}$cf_cv_do_relink" >&6
 	;;
 esac
@@ -5340,7 +5341,7 @@
 rel_builddir=..
 
 LD_RPATH_OPT=
-echo "$as_me:5343: checking for an rpath option" >&5
+echo "$as_me:5344: checking for an rpath option" >&5
 echo $ECHO_N "checking for an rpath option... $ECHO_C" >&6
 case $cf_cv_system_name in
 (irix*)
@@ -5371,12 +5372,12 @@
 (*)
 	;;
 esac
-echo "$as_me:5374: result: $LD_RPATH_OPT" >&5
+echo "$as_me:5375: result: $LD_RPATH_OPT" >&5
 echo "${ECHO_T}$LD_RPATH_OPT" >&6
 
 case "x$LD_RPATH_OPT" in
 (x-R*)
-	echo "$as_me:5379: checking if we need a space after rpath option" >&5
+	echo "$as_me:5380: checking if we need a space after rpath option" >&5
 echo $ECHO_N "checking if we need a space after rpath option... $ECHO_C" >&6
 	cf_save_LIBS="$LIBS"
 
@@ -5397,7 +5398,7 @@
 LIBS="$cf_add_libs"
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 5400 "configure"
+#line 5401 "configure"
 #include "confdefs.h"
 
 int
@@ -5409,16 +5410,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5412: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5413: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5415: \$? = $ac_status" >&5
+  echo "$as_me:5416: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5418: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5419: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5421: \$? = $ac_status" >&5
+  echo "$as_me:5422: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_rpath_space=no
 else
@@ -5428,7 +5429,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 	LIBS="$cf_save_LIBS"
-	echo "$as_me:5431: result: $cf_rpath_space" >&5
+	echo "$as_me:5432: result: $cf_rpath_space" >&5
 echo "${ECHO_T}$cf_rpath_space" >&6
 	test "$cf_rpath_space" = yes && LD_RPATH_OPT="$LD_RPATH_OPT "
 	;;
@@ -5449,7 +5450,7 @@
 	cf_ld_rpath_opt=
 	test "$cf_cv_enable_rpath" = yes && cf_ld_rpath_opt="$LD_RPATH_OPT"
 
-	echo "$as_me:5452: checking if release/abi version should be used for shared libs" >&5
+	echo "$as_me:5453: checking if release/abi version should be used for shared libs" >&5
 echo $ECHO_N "checking if release/abi version should be used for shared libs... $ECHO_C" >&6
 
 # Check whether --with-shlib-version or --without-shlib-version was given.
@@ -5464,9 +5465,9 @@
 		cf_cv_shlib_version=$withval
 		;;
 	(*)
-		echo "$as_me:5467: result: $withval" >&5
+		echo "$as_me:5468: result: $withval" >&5
 echo "${ECHO_T}$withval" >&6
-		{ { echo "$as_me:5469: error: option value must be one of: rel, abi, or auto" >&5
+		{ { echo "$as_me:5470: error: option value must be one of: rel, abi, or auto" >&5
 echo "$as_me: error: option value must be one of: rel, abi, or auto" >&2;}
    { (exit 1); exit 1; }; }
 		;;
@@ -5475,7 +5476,7 @@
 else
   cf_cv_shlib_version=auto
 fi;
-	echo "$as_me:5478: result: $cf_cv_shlib_version" >&5
+	echo "$as_me:5479: result: $cf_cv_shlib_version" >&5
 echo "${ECHO_T}$cf_cv_shlib_version" >&6
 
 	cf_cv_rm_so_locs=no
@@ -5498,14 +5499,14 @@
 
 	if test "$cf_try_fPIC" = yes
 	then
-		echo "$as_me:5501: checking which $CC option to use" >&5
+		echo "$as_me:5502: checking which $CC option to use" >&5
 echo $ECHO_N "checking which $CC option to use... $ECHO_C" >&6
 		cf_save_CFLAGS="$CFLAGS"
 		for CC_SHARED_OPTS in -fPIC -fpic ''
 		do
 			CFLAGS="$cf_save_CFLAGS $CC_SHARED_OPTS"
 			cat >conftest.$ac_ext <<_ACEOF
-#line 5508 "configure"
+#line 5509 "configure"
 #include "confdefs.h"
 #include <stdio.h>
 int
@@ -5517,16 +5518,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:5520: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:5521: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:5523: \$? = $ac_status" >&5
+  echo "$as_me:5524: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:5526: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5527: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5529: \$? = $ac_status" >&5
+  echo "$as_me:5530: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   break
 else
@@ -5535,7 +5536,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 		done
-		echo "$as_me:5538: result: $CC_SHARED_OPTS" >&5
+		echo "$as_me:5539: result: $CC_SHARED_OPTS" >&5
 echo "${ECHO_T}$CC_SHARED_OPTS" >&6
 		CFLAGS="$cf_save_CFLAGS"
 	fi
@@ -5606,7 +5607,7 @@
 		MK_SHARED_LIB='${CC} ${LDFLAGS} ${CFLAGS} -dynamiclib -install_name ${libdir}/`basename $@` -compatibility_version ${ABI_VERSION} -current_version ${ABI_VERSION} -o $@'
 		test "$cf_cv_shlib_version" = auto && cf_cv_shlib_version=abi
 		cf_cv_shlib_version_infix=yes
-		echo "$as_me:5609: checking if ld -search_paths_first works" >&5
+		echo "$as_me:5610: checking if ld -search_paths_first works" >&5
 echo $ECHO_N "checking if ld -search_paths_first works... $ECHO_C" >&6
 if test "${cf_cv_ldflags_search_paths_first+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5615,7 +5616,7 @@
 			cf_save_LDFLAGS=$LDFLAGS
 			LDFLAGS="$LDFLAGS -Wl,-search_paths_first"
 			cat >conftest.$ac_ext <<_ACEOF
-#line 5618 "configure"
+#line 5619 "configure"
 #include "confdefs.h"
 
 int
@@ -5627,16 +5628,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5630: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5631: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5633: \$? = $ac_status" >&5
+  echo "$as_me:5634: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5636: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5637: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5639: \$? = $ac_status" >&5
+  echo "$as_me:5640: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_ldflags_search_paths_first=yes
 else
@@ -5647,7 +5648,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 				LDFLAGS=$cf_save_LDFLAGS
 fi
-echo "$as_me:5650: result: $cf_cv_ldflags_search_paths_first" >&5
+echo "$as_me:5651: result: $cf_cv_ldflags_search_paths_first" >&5
 echo "${ECHO_T}$cf_cv_ldflags_search_paths_first" >&6
 		if test $cf_cv_ldflags_search_paths_first = yes; then
 			LDFLAGS="$LDFLAGS -Wl,-search_paths_first"
@@ -5872,7 +5873,7 @@
 			do
 				CFLAGS="$cf_shared_opts $cf_save_CFLAGS"
 				cat >conftest.$ac_ext <<_ACEOF
-#line 5875 "configure"
+#line 5876 "configure"
 #include "confdefs.h"
 #include <stdio.h>
 int
@@ -5884,16 +5885,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:5887: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:5888: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:5890: \$? = $ac_status" >&5
+  echo "$as_me:5891: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:5893: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5894: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5896: \$? = $ac_status" >&5
+  echo "$as_me:5897: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   break
 else
@@ -5930,7 +5931,7 @@
 			test "$cf_cv_do_symlinks" = no && cf_cv_do_symlinks=yes
 			;;
 		(*)
-			{ echo "$as_me:5933: WARNING: ignored --with-shlib-version" >&5
+			{ echo "$as_me:5934: WARNING: ignored --with-shlib-version" >&5
 echo "$as_me: WARNING: ignored --with-shlib-version" >&2;}
 			;;
 		esac
@@ -5940,7 +5941,7 @@
 	if test -n "$cf_try_cflags"
 	then
 cat > conftest.$ac_ext <<EOF
-#line 5943 "${as_me:-configure}"
+#line 5944 "${as_me:-configure}"
 #include <stdio.h>
 int main(int argc, char *argv[])
 {
@@ -5952,18 +5953,18 @@
 		for cf_opt in $cf_try_cflags
 		do
 			CFLAGS="$cf_save_CFLAGS -$cf_opt"
-			echo "$as_me:5955: checking if CFLAGS option -$cf_opt works" >&5
+			echo "$as_me:5956: checking if CFLAGS option -$cf_opt works" >&5
 echo $ECHO_N "checking if CFLAGS option -$cf_opt works... $ECHO_C" >&6
-			if { (eval echo "$as_me:5957: \"$ac_compile\"") >&5
+			if { (eval echo "$as_me:5958: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:5960: \$? = $ac_status" >&5
+  echo "$as_me:5961: \$? = $ac_status" >&5
   (exit $ac_status); }; then
-				echo "$as_me:5962: result: yes" >&5
+				echo "$as_me:5963: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 				cf_save_CFLAGS="$CFLAGS"
 			else
-				echo "$as_me:5966: result: no" >&5
+				echo "$as_me:5967: result: no" >&5
 echo "${ECHO_T}no" >&6
 			fi
 		done
@@ -5978,17 +5979,17 @@
 
 	test -n "$verbose" && echo "	CC_SHARED_OPTS: $CC_SHARED_OPTS" 1>&6
 
-echo "${as_me:-configure}:5981: testing CC_SHARED_OPTS: $CC_SHARED_OPTS ..." 1>&5
+echo "${as_me:-configure}:5982: testing CC_SHARED_OPTS: $CC_SHARED_OPTS ..." 1>&5
 
 	test -n "$verbose" && echo "	MK_SHARED_LIB:  $MK_SHARED_LIB" 1>&6
 
-echo "${as_me:-configure}:5985: testing MK_SHARED_LIB:  $MK_SHARED_LIB ..." 1>&5
+echo "${as_me:-configure}:5986: testing MK_SHARED_LIB:  $MK_SHARED_LIB ..." 1>&5
 
 for model in $cf_list_models; do
 	case $model in
 	(libtool)
 
-echo "$as_me:5991: checking for additional libtool options" >&5
+echo "$as_me:5992: checking for additional libtool options" >&5
 echo $ECHO_N "checking for additional libtool options... $ECHO_C" >&6
 
 # Check whether --with-libtool-opts or --without-libtool-opts was given.
@@ -5998,7 +5999,7 @@
 else
   with_libtool_opts=no
 fi;
-echo "$as_me:6001: result: $with_libtool_opts" >&5
+echo "$as_me:6002: result: $with_libtool_opts" >&5
 echo "${ECHO_T}$with_libtool_opts" >&6
 
 case .$with_libtool_opts in
@@ -6009,7 +6010,7 @@
 	;;
 esac
 
-echo "$as_me:6012: checking if exported-symbols file should be used" >&5
+echo "$as_me:6013: checking if exported-symbols file should be used" >&5
 echo $ECHO_N "checking if exported-symbols file should be used... $ECHO_C" >&6
 
 # Check whether --with-export-syms or --without-export-syms was given.
@@ -6024,7 +6025,7 @@
 	with_export_syms='${top_srcdir}/package/${PACKAGE}.sym'
 
 fi
-echo "$as_me:6027: result: $with_export_syms" >&5
+echo "$as_me:6028: result: $with_export_syms" >&5
 echo "${ECHO_T}$with_export_syms" >&6
 if test "x$with_export_syms" != xno
 then
@@ -6035,15 +6036,15 @@
 		;;
 	(shared)
 		if test "$CC_SHARED_OPTS" = "unknown"; then
-			{ { echo "$as_me:6038: error: Shared libraries are not supported in this version" >&5
+			{ { echo "$as_me:6039: error: Shared libraries are not supported in this version" >&5
 echo "$as_me: error: Shared libraries are not supported in this version" >&2;}
    { (exit 1); exit 1; }; }
 		fi
 		# workaround for inept transition to PIE vs PIC...
-		echo "$as_me:6043: checking if current CFLAGS link properly" >&5
+		echo "$as_me:6044: checking if current CFLAGS link properly" >&5
 echo $ECHO_N "checking if current CFLAGS link properly... $ECHO_C" >&6
 		cat >conftest.$ac_ext <<_ACEOF
-#line 6046 "configure"
+#line 6047 "configure"
 #include "confdefs.h"
 #include <stdio.h>
 int
@@ -6055,16 +6056,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6058: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6059: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6061: \$? = $ac_status" >&5
+  echo "$as_me:6062: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6064: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6065: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6067: \$? = $ac_status" >&5
+  echo "$as_me:6068: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cflags_work=yes
 else
@@ -6073,18 +6074,18 @@
 cf_cflags_work=no
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
-		echo "$as_me:6076: result: $cf_cflags_work" >&5
+		echo "$as_me:6077: result: $cf_cflags_work" >&5
 echo "${ECHO_T}$cf_cflags_work" >&6
 		if test "$cf_cflags_work" = no
 		then
 			test -n "$verbose" && echo "	try to work around by appending shared-options" 1>&6
 
-echo "${as_me:-configure}:6082: testing try to work around by appending shared-options ..." 1>&5
+echo "${as_me:-configure}:6083: testing try to work around by appending shared-options ..." 1>&5
 
 			CFLAGS="$CFLAGS $CC_SHARED_OPTS"
 		fi
 
-echo "$as_me:6087: checking if versioned-symbols file should be used" >&5
+echo "$as_me:6088: checking if versioned-symbols file should be used" >&5
 echo $ECHO_N "checking if versioned-symbols file should be used... $ECHO_C" >&6
 
 # Check whether --with-versioned-syms or --without-versioned-syms was given.
@@ -6099,7 +6100,7 @@
 	with_versioned_syms='${top_srcdir}/package/${PACKAGE}.map'
 
 fi
-echo "$as_me:6102: result: $with_versioned_syms" >&5
+echo "$as_me:6103: result: $with_versioned_syms" >&5
 echo "${ECHO_T}$with_versioned_syms" >&6
 
 RESULTING_SYMS=
@@ -6115,7 +6116,7 @@
 		MK_SHARED_LIB=`echo "$MK_SHARED_LIB" | sed -e "s%-Wl,%\\${VERSIONED_SYMS} -Wl,%"`
 		test -n "$verbose" && echo "	MK_SHARED_LIB:  $MK_SHARED_LIB" 1>&6
 
-echo "${as_me:-configure}:6118: testing MK_SHARED_LIB:  $MK_SHARED_LIB ..." 1>&5
+echo "${as_me:-configure}:6119: testing MK_SHARED_LIB:  $MK_SHARED_LIB ..." 1>&5
 
 		;;
 	(*-dy\ *)
@@ -6123,11 +6124,11 @@
 		MK_SHARED_LIB=`echo "$MK_SHARED_LIB" | sed -e "s%-dy%\\${VERSIONED_SYMS} -dy%"`
 		test -n "$verbose" && echo "	MK_SHARED_LIB:  $MK_SHARED_LIB" 1>&6
 
-echo "${as_me:-configure}:6126: testing MK_SHARED_LIB:  $MK_SHARED_LIB ..." 1>&5
+echo "${as_me:-configure}:6127: testing MK_SHARED_LIB:  $MK_SHARED_LIB ..." 1>&5
 
 		;;
 	(*)
-		{ echo "$as_me:6130: WARNING: this system does not support versioned-symbols" >&5
+		{ echo "$as_me:6131: WARNING: this system does not support versioned-symbols" >&5
 echo "$as_me: WARNING: this system does not support versioned-symbols" >&2;}
 		;;
 	esac
@@ -6139,7 +6140,7 @@
 	# symbols.
 	if test "x$VERSIONED_SYMS" != "x"
 	then
-		echo "$as_me:6142: checking if wildcards can be used to selectively omit symbols" >&5
+		echo "$as_me:6143: checking if wildcards can be used to selectively omit symbols" >&5
 echo $ECHO_N "checking if wildcards can be used to selectively omit symbols... $ECHO_C" >&6
 		WILDCARD_SYMS=no
 
@@ -6176,7 +6177,7 @@
 } submodule_1.0;
 EOF
 		cat >conftest.$ac_ext <<EOF
-#line 6179 "configure"
+#line 6180 "configure"
 int	_ismissing(void) { return 1; }
 int	_localf1(void) { return 1; }
 int	_localf2(void) { return 2; }
@@ -6207,7 +6208,7 @@
 			cf_missing=`nm -P conftest.so 2>&5 |fgrep _ismissing | egrep '[ 	][DT][ 	]'`
 			test -n "$cf_missing" && WILDCARD_SYMS=yes
 		fi
-		echo "$as_me:6210: result: $WILDCARD_SYMS" >&5
+		echo "$as_me:6211: result: $WILDCARD_SYMS" >&5
 echo "${ECHO_T}$WILDCARD_SYMS" >&6
 		rm -f conftest.*
 	fi
@@ -6220,7 +6221,7 @@
 ### Checks for special libraries, must be done up-front.
 SHLIB_LIST=""
 
-echo "$as_me:6223: checking if you want to link with the GPM mouse library" >&5
+echo "$as_me:6224: checking if you want to link with the GPM mouse library" >&5
 echo $ECHO_N "checking if you want to link with the GPM mouse library... $ECHO_C" >&6
 
 # Check whether --with-gpm or --without-gpm was given.
@@ -6230,27 +6231,27 @@
 else
   with_gpm=maybe
 fi;
-echo "$as_me:6233: result: $with_gpm" >&5
+echo "$as_me:6234: result: $with_gpm" >&5
 echo "${ECHO_T}$with_gpm" >&6
 
 if test "$with_gpm" != no ; then
-	echo "$as_me:6237: checking for gpm.h" >&5
+	echo "$as_me:6238: checking for gpm.h" >&5
 echo $ECHO_N "checking for gpm.h... $ECHO_C" >&6
 if test "${ac_cv_header_gpm_h+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6243 "configure"
+#line 6244 "configure"
 #include "confdefs.h"
 #include <gpm.h>
 _ACEOF
-if { (eval echo "$as_me:6247: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:6248: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:6253: \$? = $ac_status" >&5
+  echo "$as_me:6254: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -6269,7 +6270,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:6272: result: $ac_cv_header_gpm_h" >&5
+echo "$as_me:6273: result: $ac_cv_header_gpm_h" >&5
 echo "${ECHO_T}$ac_cv_header_gpm_h" >&6
 if test $ac_cv_header_gpm_h = yes; then
 
@@ -6280,7 +6281,7 @@
 		if test "$with_gpm" != yes && test "$with_gpm" != maybe ; then
 			test -n "$verbose" && echo "	assuming we really have GPM library" 1>&6
 
-echo "${as_me:-configure}:6283: testing assuming we really have GPM library ..." 1>&5
+echo "${as_me:-configure}:6284: testing assuming we really have GPM library ..." 1>&5
 
 cat >>confdefs.h <<\EOF
 #define HAVE_LIBGPM 1
@@ -6288,7 +6289,7 @@
 
 			with_gpm=yes
 		else
-			echo "$as_me:6291: checking for Gpm_Open in -lgpm" >&5
+			echo "$as_me:6292: checking for Gpm_Open in -lgpm" >&5
 echo $ECHO_N "checking for Gpm_Open in -lgpm... $ECHO_C" >&6
 if test "${ac_cv_lib_gpm_Gpm_Open+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -6296,7 +6297,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lgpm  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 6299 "configure"
+#line 6300 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -6315,16 +6316,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6318: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6319: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6321: \$? = $ac_status" >&5
+  echo "$as_me:6322: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6324: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6325: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6327: \$? = $ac_status" >&5
+  echo "$as_me:6328: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_gpm_Gpm_Open=yes
 else
@@ -6335,18 +6336,18 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:6338: result: $ac_cv_lib_gpm_Gpm_Open" >&5
+echo "$as_me:6339: result: $ac_cv_lib_gpm_Gpm_Open" >&5
 echo "${ECHO_T}$ac_cv_lib_gpm_Gpm_Open" >&6
 if test $ac_cv_lib_gpm_Gpm_Open = yes; then
   with_gpm=yes
 else
 
 				if test "$with_gpm" = maybe; then
-					{ echo "$as_me:6345: WARNING: Cannot link with GPM library" >&5
+					{ echo "$as_me:6346: WARNING: Cannot link with GPM library" >&5
 echo "$as_me: WARNING: Cannot link with GPM library" >&2;}
 					with_gpm=no
 				else
-					{ { echo "$as_me:6349: error: Cannot link with GPM library" >&5
+					{ { echo "$as_me:6350: error: Cannot link with GPM library" >&5
 echo "$as_me: error: Cannot link with GPM library" >&2;}
    { (exit 1); exit 1; }; }
 				fi
@@ -6357,7 +6358,7 @@
 
 else
 
-		test "$with_gpm" != maybe && { echo "$as_me:6360: WARNING: Cannot find GPM header" >&5
+		test "$with_gpm" != maybe && { echo "$as_me:6361: WARNING: Cannot find GPM header" >&5
 echo "$as_me: WARNING: Cannot find GPM header" >&2;}
 		with_gpm=no
 
@@ -6366,7 +6367,7 @@
 fi
 
 if test "$with_gpm" != no ; then
-	echo "$as_me:6369: checking if you want to load GPM dynamically" >&5
+	echo "$as_me:6370: checking if you want to load GPM dynamically" >&5
 echo $ECHO_N "checking if you want to load GPM dynamically... $ECHO_C" >&6
 
 # Check whether --with-dlsym or --without-dlsym was given.
@@ -6376,18 +6377,18 @@
 else
   with_dlsym=yes
 fi;
-	echo "$as_me:6379: result: $with_dlsym" >&5
+	echo "$as_me:6380: result: $with_dlsym" >&5
 echo "${ECHO_T}$with_dlsym" >&6
 	if test "x$with_dlsym" = xyes ; then
 
 cf_have_dlsym=no
-echo "$as_me:6384: checking for dlsym" >&5
+echo "$as_me:6385: checking for dlsym" >&5
 echo $ECHO_N "checking for dlsym... $ECHO_C" >&6
 if test "${ac_cv_func_dlsym+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6390 "configure"
+#line 6391 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char dlsym (); below.  */
@@ -6418,16 +6419,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6421: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6422: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6424: \$? = $ac_status" >&5
+  echo "$as_me:6425: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6427: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6428: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6430: \$? = $ac_status" >&5
+  echo "$as_me:6431: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_dlsym=yes
 else
@@ -6437,14 +6438,14 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:6440: result: $ac_cv_func_dlsym" >&5
+echo "$as_me:6441: result: $ac_cv_func_dlsym" >&5
 echo "${ECHO_T}$ac_cv_func_dlsym" >&6
 if test $ac_cv_func_dlsym = yes; then
   cf_have_dlsym=yes
 else
 
 cf_have_libdl=no
-echo "$as_me:6447: checking for dlsym in -ldl" >&5
+echo "$as_me:6448: checking for dlsym in -ldl" >&5
 echo $ECHO_N "checking for dlsym in -ldl... $ECHO_C" >&6
 if test "${ac_cv_lib_dl_dlsym+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -6452,7 +6453,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-ldl  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 6455 "configure"
+#line 6456 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -6471,16 +6472,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6474: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6475: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6477: \$? = $ac_status" >&5
+  echo "$as_me:6478: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6480: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6481: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6483: \$? = $ac_status" >&5
+  echo "$as_me:6484: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_dl_dlsym=yes
 else
@@ -6491,7 +6492,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:6494: result: $ac_cv_lib_dl_dlsym" >&5
+echo "$as_me:6495: result: $ac_cv_lib_dl_dlsym" >&5
 echo "${ECHO_T}$ac_cv_lib_dl_dlsym" >&6
 if test $ac_cv_lib_dl_dlsym = yes; then
 
@@ -6520,10 +6521,10 @@
 LIBS="$cf_add_libs"
  }
 
-	echo "$as_me:6523: checking whether able to link to dl*() functions" >&5
+	echo "$as_me:6524: checking whether able to link to dl*() functions" >&5
 echo $ECHO_N "checking whether able to link to dl*() functions... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 6526 "configure"
+#line 6527 "configure"
 #include "confdefs.h"
 #include <dlfcn.h>
 int
@@ -6541,16 +6542,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6544: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6545: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6547: \$? = $ac_status" >&5
+  echo "$as_me:6548: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6550: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6551: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6553: \$? = $ac_status" >&5
+  echo "$as_me:6554: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 cat >>confdefs.h <<\EOF
@@ -6561,15 +6562,15 @@
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		{ { echo "$as_me:6564: error: Cannot link test program for libdl" >&5
+		{ { echo "$as_me:6565: error: Cannot link test program for libdl" >&5
 echo "$as_me: error: Cannot link test program for libdl" >&2;}
    { (exit 1); exit 1; }; }
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
-	echo "$as_me:6569: result: ok" >&5
+	echo "$as_me:6570: result: ok" >&5
 echo "${ECHO_T}ok" >&6
 else
-	{ { echo "$as_me:6572: error: Cannot find dlsym function" >&5
+	{ { echo "$as_me:6573: error: Cannot find dlsym function" >&5
 echo "$as_me: error: Cannot find dlsym function" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -6577,12 +6578,12 @@
 		if test "x$with_gpm" != xyes ; then
 			test -n "$verbose" && echo "	assuming soname for gpm is $with_gpm" 1>&6
 
-echo "${as_me:-configure}:6580: testing assuming soname for gpm is $with_gpm ..." 1>&5
+echo "${as_me:-configure}:6581: testing assuming soname for gpm is $with_gpm ..." 1>&5
 
 			cf_cv_gpm_soname="$with_gpm"
 		else
 
-echo "$as_me:6585: checking for soname of gpm library" >&5
+echo "$as_me:6586: checking for soname of gpm library" >&5
 echo $ECHO_N "checking for soname of gpm library... $ECHO_C" >&6
 if test "${cf_cv_gpm_soname+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -6616,15 +6617,15 @@
 done
 LIBS="$cf_add_libs"
 
-	if { (eval echo "$as_me:6619: \"$ac_compile\"") >&5
+	if { (eval echo "$as_me:6620: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:6622: \$? = $ac_status" >&5
+  echo "$as_me:6623: \$? = $ac_status" >&5
   (exit $ac_status); } ; then
-		if { (eval echo "$as_me:6624: \"$ac_link\"") >&5
+		if { (eval echo "$as_me:6625: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6627: \$? = $ac_status" >&5
+  echo "$as_me:6628: \$? = $ac_status" >&5
   (exit $ac_status); } ; then
 			cf_cv_gpm_soname=`ldd conftest$ac_exeext 2>/dev/null | sed -e 's,^.*/,,' -e 's, .*$,,' | fgrep libgpm.`
 			test -z "$cf_cv_gpm_soname" && cf_cv_gpm_soname=unknown
@@ -6635,7 +6636,7 @@
 fi
 
 fi
-echo "$as_me:6638: result: $cf_cv_gpm_soname" >&5
+echo "$as_me:6639: result: $cf_cv_gpm_soname" >&5
 echo "${ECHO_T}$cf_cv_gpm_soname" >&6
 
 		fi
@@ -6703,7 +6704,7 @@
 #define HAVE_LIBGPM 1
 EOF
 
-echo "$as_me:6706: checking for Gpm_Wgetch in -lgpm" >&5
+echo "$as_me:6707: checking for Gpm_Wgetch in -lgpm" >&5
 echo $ECHO_N "checking for Gpm_Wgetch in -lgpm... $ECHO_C" >&6
 if test "${ac_cv_lib_gpm_Gpm_Wgetch+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -6711,7 +6712,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lgpm  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 6714 "configure"
+#line 6715 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -6730,16 +6731,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6733: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6734: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6736: \$? = $ac_status" >&5
+  echo "$as_me:6737: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6739: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6740: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6742: \$? = $ac_status" >&5
+  echo "$as_me:6743: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_gpm_Gpm_Wgetch=yes
 else
@@ -6750,11 +6751,11 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:6753: result: $ac_cv_lib_gpm_Gpm_Wgetch" >&5
+echo "$as_me:6754: result: $ac_cv_lib_gpm_Gpm_Wgetch" >&5
 echo "${ECHO_T}$ac_cv_lib_gpm_Gpm_Wgetch" >&6
 if test $ac_cv_lib_gpm_Gpm_Wgetch = yes; then
 
-echo "$as_me:6757: checking if GPM is weakly bound to curses library" >&5
+echo "$as_me:6758: checking if GPM is weakly bound to curses library" >&5
 echo $ECHO_N "checking if GPM is weakly bound to curses library... $ECHO_C" >&6
 if test "${cf_cv_check_gpm_wgetch+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -6778,15 +6779,15 @@
 	# to rely on the static library, noting that some packagers may not
 	# include it.
 	LIBS="-static -lgpm -dynamic $LIBS"
-	if { (eval echo "$as_me:6781: \"$ac_compile\"") >&5
+	if { (eval echo "$as_me:6782: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:6784: \$? = $ac_status" >&5
+  echo "$as_me:6785: \$? = $ac_status" >&5
   (exit $ac_status); } ; then
-		if { (eval echo "$as_me:6786: \"$ac_link\"") >&5
+		if { (eval echo "$as_me:6787: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6789: \$? = $ac_status" >&5
+  echo "$as_me:6790: \$? = $ac_status" >&5
   (exit $ac_status); } ; then
 			cf_cv_check_gpm_wgetch=`nm conftest$ac_exeext | egrep '\<wgetch\>' | egrep '\<[vVwW]\>'`
 			test -n "$cf_cv_check_gpm_wgetch" && cf_cv_check_gpm_wgetch=yes
@@ -6798,11 +6799,11 @@
 fi
 
 fi
-echo "$as_me:6801: result: $cf_cv_check_gpm_wgetch" >&5
+echo "$as_me:6802: result: $cf_cv_check_gpm_wgetch" >&5
 echo "${ECHO_T}$cf_cv_check_gpm_wgetch" >&6
 
 if test "$cf_cv_check_gpm_wgetch" != yes ; then
-	{ echo "$as_me:6805: WARNING: GPM library is already linked with curses - read the FAQ" >&5
+	{ echo "$as_me:6806: WARNING: GPM library is already linked with curses - read the FAQ" >&5
 echo "$as_me: WARNING: GPM library is already linked with curses - read the FAQ" >&2;}
 fi
 
@@ -6810,9 +6811,505 @@
 
 fi
 
+echo "$as_me:6814: checking if you want to use PCRE2 for regular-expressions" >&5
+echo $ECHO_N "checking if you want to use PCRE2 for regular-expressions... $ECHO_C" >&6
+
+# Check whether --with-pcre2 or --without-pcre2 was given.
+if test "${with_pcre2+set}" = set; then
+  withval="$with_pcre2"
+
+fi;
+test -z "$with_pcre2" && with_pcre2=no
+echo "$as_me:6823: result: $with_pcre2" >&5
+echo "${ECHO_T}$with_pcre2" >&6
+
+if test "x$with_pcre2" != xno ; then
+
+if test "$PKG_CONFIG" != none && "$PKG_CONFIG" --exists libpcre2; then
+	test -n "$verbose" && echo "	found package libpcre2" 1>&6
+
+echo "${as_me:-configure}:6831: testing found package libpcre2 ..." 1>&5
+
+	cf_pkgconfig_incs="`$PKG_CONFIG --cflags libpcre2 2>/dev/null`"
+	cf_pkgconfig_libs="`$PKG_CONFIG --libs   libpcre2 2>/dev/null`"
+	test -n "$verbose" && echo "	package libpcre2 CFLAGS: $cf_pkgconfig_incs" 1>&6
+
+echo "${as_me:-configure}:6837: testing package libpcre2 CFLAGS: $cf_pkgconfig_incs ..." 1>&5
+
+	test -n "$verbose" && echo "	package libpcre2 LIBS: $cf_pkgconfig_libs" 1>&6
+
+echo "${as_me:-configure}:6841: testing package libpcre2 LIBS: $cf_pkgconfig_libs ..." 1>&5
+
+cf_fix_cppflags=no
+cf_new_cflags=
+cf_new_cppflags=
+cf_new_extra_cppflags=
+
+for cf_add_cflags in $cf_pkgconfig_incs
+do
+case $cf_fix_cppflags in
+(no)
+	case $cf_add_cflags in
+	(-undef|-nostdinc*|-I*|-D*|-U*|-E|-P|-C)
+		case $cf_add_cflags in
+		(-D*)
+			cf_tst_cflags=`echo ${cf_add_cflags} |sed -e 's/^-D[^=]*='\''\"[^"]*//'`
+
+			test "x${cf_add_cflags}" != "x${cf_tst_cflags}" \
+				&& test -z "${cf_tst_cflags}" \
+				&& cf_fix_cppflags=yes
+
+			if test $cf_fix_cppflags = yes ; then
+
+	test -n "$cf_new_extra_cppflags" && cf_new_extra_cppflags="$cf_new_extra_cppflags "
+	cf_new_extra_cppflags="${cf_new_extra_cppflags}$cf_add_cflags"
+
+				continue
+			elif test "${cf_tst_cflags}" = "\"'" ; then
+
+	test -n "$cf_new_extra_cppflags" && cf_new_extra_cppflags="$cf_new_extra_cppflags "
+	cf_new_extra_cppflags="${cf_new_extra_cppflags}$cf_add_cflags"
+
+				continue
+			fi
+			;;
+		esac
+		case "$CPPFLAGS" in
+		(*$cf_add_cflags)
+			;;
+		(*)
+			case $cf_add_cflags in
+			(-D*)
+				cf_tst_cppflags=`echo "x$cf_add_cflags" | sed -e 's/^...//' -e 's/=.*//'`
+
+CPPFLAGS=`echo "$CPPFLAGS" | \
+	sed	-e 's/-[UD]'"$cf_tst_cppflags"'\(=[^ 	]*\)\?[ 	]/ /g' \
+		-e 's/-[UD]'"$cf_tst_cppflags"'\(=[^ 	]*\)\?$//g'`
+
+				;;
+			esac
+
+	test -n "$cf_new_cppflags" && cf_new_cppflags="$cf_new_cppflags "
+	cf_new_cppflags="${cf_new_cppflags}$cf_add_cflags"
+
+			;;
+		esac
+		;;
+	(*)
+
+	test -n "$cf_new_cflags" && cf_new_cflags="$cf_new_cflags "
+	cf_new_cflags="${cf_new_cflags}$cf_add_cflags"
+
+		;;
+	esac
+	;;
+(yes)
+
+	test -n "$cf_new_extra_cppflags" && cf_new_extra_cppflags="$cf_new_extra_cppflags "
+	cf_new_extra_cppflags="${cf_new_extra_cppflags}$cf_add_cflags"
+
+	cf_tst_cflags=`echo ${cf_add_cflags} |sed -e 's/^[^"]*"'\''//'`
+
+	test "x${cf_add_cflags}" != "x${cf_tst_cflags}" \
+		&& test -z "${cf_tst_cflags}" \
+		&& cf_fix_cppflags=no
+	;;
+esac
+done
+
+if test -n "$cf_new_cflags" ; then
+
+	test -n "$CFLAGS" && CFLAGS="$CFLAGS "
+	CFLAGS="${CFLAGS}$cf_new_cflags"
+
+fi
+
+if test -n "$cf_new_cppflags" ; then
+
+	test -n "$CPPFLAGS" && CPPFLAGS="$CPPFLAGS "
+	CPPFLAGS="${CPPFLAGS}$cf_new_cppflags"
+
+fi
+
+if test -n "$cf_new_extra_cppflags" ; then
+
+	test -n "$EXTRA_CPPFLAGS" && EXTRA_CPPFLAGS="$EXTRA_CPPFLAGS "
+	EXTRA_CPPFLAGS="${EXTRA_CPPFLAGS}$cf_new_extra_cppflags"
+
+fi
+
+cf_add_libs="$cf_pkgconfig_libs"
+# Filter out duplicates - this happens with badly-designed ".pc" files...
+for cf_add_1lib in $LIBS
+do
+	for cf_add_2lib in $cf_add_libs
+	do
+		if test "x$cf_add_1lib" = "x$cf_add_2lib"
+		then
+			cf_add_1lib=
+			break
+		fi
+	done
+	test -n "$cf_add_1lib" && cf_add_libs="$cf_add_libs $cf_add_1lib"
+done
+LIBS="$cf_add_libs"
+
+	:
+else
+	cf_pkgconfig_incs=
+	cf_pkgconfig_libs=
+
+if test "$PKG_CONFIG" != none && "$PKG_CONFIG" --exists libpcre; then
+	test -n "$verbose" && echo "	found package libpcre" 1>&6
+
+echo "${as_me:-configure}:6965: testing found package libpcre ..." 1>&5
+
+	cf_pkgconfig_incs="`$PKG_CONFIG --cflags libpcre 2>/dev/null`"
+	cf_pkgconfig_libs="`$PKG_CONFIG --libs   libpcre 2>/dev/null`"
+	test -n "$verbose" && echo "	package libpcre CFLAGS: $cf_pkgconfig_incs" 1>&6
+
+echo "${as_me:-configure}:6971: testing package libpcre CFLAGS: $cf_pkgconfig_incs ..." 1>&5
+
+	test -n "$verbose" && echo "	package libpcre LIBS: $cf_pkgconfig_libs" 1>&6
+
+echo "${as_me:-configure}:6975: testing package libpcre LIBS: $cf_pkgconfig_libs ..." 1>&5
+
+cf_fix_cppflags=no
+cf_new_cflags=
+cf_new_cppflags=
+cf_new_extra_cppflags=
+
+for cf_add_cflags in $cf_pkgconfig_incs
+do
+case $cf_fix_cppflags in
+(no)
+	case $cf_add_cflags in
+	(-undef|-nostdinc*|-I*|-D*|-U*|-E|-P|-C)
+		case $cf_add_cflags in
+		(-D*)
+			cf_tst_cflags=`echo ${cf_add_cflags} |sed -e 's/^-D[^=]*='\''\"[^"]*//'`
+
+			test "x${cf_add_cflags}" != "x${cf_tst_cflags}" \
+				&& test -z "${cf_tst_cflags}" \
+				&& cf_fix_cppflags=yes
+
+			if test $cf_fix_cppflags = yes ; then
+
+	test -n "$cf_new_extra_cppflags" && cf_new_extra_cppflags="$cf_new_extra_cppflags "
+	cf_new_extra_cppflags="${cf_new_extra_cppflags}$cf_add_cflags"
+
+				continue
+			elif test "${cf_tst_cflags}" = "\"'" ; then
+
+	test -n "$cf_new_extra_cppflags" && cf_new_extra_cppflags="$cf_new_extra_cppflags "
+	cf_new_extra_cppflags="${cf_new_extra_cppflags}$cf_add_cflags"
+
+				continue
+			fi
+			;;
+		esac
+		case "$CPPFLAGS" in
+		(*$cf_add_cflags)
+			;;
+		(*)
+			case $cf_add_cflags in
+			(-D*)
+				cf_tst_cppflags=`echo "x$cf_add_cflags" | sed -e 's/^...//' -e 's/=.*//'`
+
+CPPFLAGS=`echo "$CPPFLAGS" | \
+	sed	-e 's/-[UD]'"$cf_tst_cppflags"'\(=[^ 	]*\)\?[ 	]/ /g' \
+		-e 's/-[UD]'"$cf_tst_cppflags"'\(=[^ 	]*\)\?$//g'`
+
+				;;
+			esac
+
+	test -n "$cf_new_cppflags" && cf_new_cppflags="$cf_new_cppflags "
+	cf_new_cppflags="${cf_new_cppflags}$cf_add_cflags"
+
+			;;
+		esac
+		;;
+	(*)
+
+	test -n "$cf_new_cflags" && cf_new_cflags="$cf_new_cflags "
+	cf_new_cflags="${cf_new_cflags}$cf_add_cflags"
+
+		;;
+	esac
+	;;
+(yes)
+
+	test -n "$cf_new_extra_cppflags" && cf_new_extra_cppflags="$cf_new_extra_cppflags "
+	cf_new_extra_cppflags="${cf_new_extra_cppflags}$cf_add_cflags"
+
+	cf_tst_cflags=`echo ${cf_add_cflags} |sed -e 's/^[^"]*"'\''//'`
+
+	test "x${cf_add_cflags}" != "x${cf_tst_cflags}" \
+		&& test -z "${cf_tst_cflags}" \
+		&& cf_fix_cppflags=no
+	;;
+esac
+done
+
+if test -n "$cf_new_cflags" ; then
+
+	test -n "$CFLAGS" && CFLAGS="$CFLAGS "
+	CFLAGS="${CFLAGS}$cf_new_cflags"
+
+fi
+
+if test -n "$cf_new_cppflags" ; then
+
+	test -n "$CPPFLAGS" && CPPFLAGS="$CPPFLAGS "
+	CPPFLAGS="${CPPFLAGS}$cf_new_cppflags"
+
+fi
+
+if test -n "$cf_new_extra_cppflags" ; then
+
+	test -n "$EXTRA_CPPFLAGS" && EXTRA_CPPFLAGS="$EXTRA_CPPFLAGS "
+	EXTRA_CPPFLAGS="${EXTRA_CPPFLAGS}$cf_new_extra_cppflags"
+
+fi
+
+cf_add_libs="$cf_pkgconfig_libs"
+# Filter out duplicates - this happens with badly-designed ".pc" files...
+for cf_add_1lib in $LIBS
+do
+	for cf_add_2lib in $cf_add_libs
+	do
+		if test "x$cf_add_1lib" = "x$cf_add_2lib"
+		then
+			cf_add_1lib=
+			break
+		fi
+	done
+	test -n "$cf_add_1lib" && cf_add_libs="$cf_add_libs $cf_add_1lib"
+done
+LIBS="$cf_add_libs"
+
+	:
+else
+	cf_pkgconfig_incs=
+	cf_pkgconfig_libs=
+
+			{ { echo "$as_me:7096: error: Cannot find PCRE2 library" >&5
+echo "$as_me: error: Cannot find PCRE2 library" >&2;}
+   { (exit 1); exit 1; }; }
+fi
+
+fi
+
+cat >>confdefs.h <<\EOF
+#define HAVE_LIB_PCRE2 1
+EOF
+
+	# if pkgconfig gave no results, look for the libraries directly
+	case $LIBS in
+	(*pcre2-posix*|*pcreposix*)
+		;;
+	(*)
+		echo "$as_me:7112: checking for regcomp in -lpcre2-posix" >&5
+echo $ECHO_N "checking for regcomp in -lpcre2-posix... $ECHO_C" >&6
+if test "${ac_cv_lib_pcre2_posix_regcomp+set}" = set; then
+  echo $ECHO_N "(cached) $ECHO_C" >&6
+else
+  ac_check_lib_save_LIBS=$LIBS
+LIBS="-lpcre2-posix  $LIBS"
+cat >conftest.$ac_ext <<_ACEOF
+#line 7120 "configure"
+#include "confdefs.h"
+
+/* Override any gcc2 internal prototype to avoid an error.  */
+#ifdef __cplusplus
+extern "C"
+#endif
+/* We use char because int might match the return type of a gcc2
+   builtin and then its argument prototype would still apply.  */
+char regcomp ();
+int
+main (void)
+{
+regcomp ();
+  ;
+  return 0;
+}
+_ACEOF
+rm -f conftest.$ac_objext conftest$ac_exeext
+if { (eval echo "$as_me:7139: \"$ac_link\"") >&5
+  (eval $ac_link) 2>&5
+  ac_status=$?
+  echo "$as_me:7142: \$? = $ac_status" >&5
+  (exit $ac_status); } &&
+         { ac_try='test -s conftest$ac_exeext'
+  { (eval echo "$as_me:7145: \"$ac_try\"") >&5
+  (eval $ac_try) 2>&5
+  ac_status=$?
+  echo "$as_me:7148: \$? = $ac_status" >&5
+  (exit $ac_status); }; }; then
+  ac_cv_lib_pcre2_posix_regcomp=yes
+else
+  echo "$as_me: failed program was:" >&5
+cat conftest.$ac_ext >&5
+ac_cv_lib_pcre2_posix_regcomp=no
+fi
+rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
+LIBS=$ac_check_lib_save_LIBS
+fi
+echo "$as_me:7159: result: $ac_cv_lib_pcre2_posix_regcomp" >&5
+echo "${ECHO_T}$ac_cv_lib_pcre2_posix_regcomp" >&6
+if test $ac_cv_lib_pcre2_posix_regcomp = yes; then
+
+cf_add_libs="-lpcre2-posix"
+# Filter out duplicates - this happens with badly-designed ".pc" files...
+for cf_add_1lib in $LIBS
+do
+	for cf_add_2lib in $cf_add_libs
+	do
+		if test "x$cf_add_1lib" = "x$cf_add_2lib"
+		then
+			cf_add_1lib=
+			break
+		fi
+	done
+	test -n "$cf_add_1lib" && cf_add_libs="$cf_add_libs $cf_add_1lib"
+done
+LIBS="$cf_add_libs"
+
+else
+  echo "$as_me:7180: checking for regcomp in -lpcreposix" >&5
+echo $ECHO_N "checking for regcomp in -lpcreposix... $ECHO_C" >&6
+if test "${ac_cv_lib_pcreposix_regcomp+set}" = set; then
+  echo $ECHO_N "(cached) $ECHO_C" >&6
+else
+  ac_check_lib_save_LIBS=$LIBS
+LIBS="-lpcreposix  $LIBS"
+cat >conftest.$ac_ext <<_ACEOF
+#line 7188 "configure"
+#include "confdefs.h"
+
+/* Override any gcc2 internal prototype to avoid an error.  */
+#ifdef __cplusplus
+extern "C"
+#endif
+/* We use char because int might match the return type of a gcc2
+   builtin and then its argument prototype would still apply.  */
+char regcomp ();
+int
+main (void)
+{
+regcomp ();
+  ;
+  return 0;
+}
+_ACEOF
+rm -f conftest.$ac_objext conftest$ac_exeext
+if { (eval echo "$as_me:7207: \"$ac_link\"") >&5
+  (eval $ac_link) 2>&5
+  ac_status=$?
+  echo "$as_me:7210: \$? = $ac_status" >&5
+  (exit $ac_status); } &&
+         { ac_try='test -s conftest$ac_exeext'
+  { (eval echo "$as_me:7213: \"$ac_try\"") >&5
+  (eval $ac_try) 2>&5
+  ac_status=$?
+  echo "$as_me:7216: \$? = $ac_status" >&5
+  (exit $ac_status); }; }; then
+  ac_cv_lib_pcreposix_regcomp=yes
+else
+  echo "$as_me: failed program was:" >&5
+cat conftest.$ac_ext >&5
+ac_cv_lib_pcreposix_regcomp=no
+fi
+rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
+LIBS=$ac_check_lib_save_LIBS
+fi
+echo "$as_me:7227: result: $ac_cv_lib_pcreposix_regcomp" >&5
+echo "${ECHO_T}$ac_cv_lib_pcreposix_regcomp" >&6
+if test $ac_cv_lib_pcreposix_regcomp = yes; then
+
+cf_add_libs="-lpcreposix"
+# Filter out duplicates - this happens with badly-designed ".pc" files...
+for cf_add_1lib in $LIBS
+do
+	for cf_add_2lib in $cf_add_libs
+	do
+		if test "x$cf_add_1lib" = "x$cf_add_2lib"
+		then
+			cf_add_1lib=
+			break
+		fi
+	done
+	test -n "$cf_add_1lib" && cf_add_libs="$cf_add_libs $cf_add_1lib"
+done
+LIBS="$cf_add_libs"
+
+else
+  { { echo "$as_me:7248: error: Cannot find PCRE2 POSIX library" >&5
+echo "$as_me: error: Cannot find PCRE2 POSIX library" >&2;}
+   { (exit 1); exit 1; }; }
+fi
+
+fi
+
+		;;
+	esac
+
+	# either way, check for the library header files
+
+for ac_header in pcre2-posix.h pcreposix.h
+do
+as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
+echo "$as_me:7263: checking for $ac_header" >&5
+echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
+if eval "test \"\${$as_ac_Header+set}\" = set"; then
+  echo $ECHO_N "(cached) $ECHO_C" >&6
+else
+  cat >conftest.$ac_ext <<_ACEOF
+#line 7269 "configure"
+#include "confdefs.h"
+#include <$ac_header>
+_ACEOF
+if { (eval echo "$as_me:7273: \"$ac_cpp conftest.$ac_ext\"") >&5
+  (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
+  ac_status=$?
+  egrep -v '^ *\+' conftest.er1 >conftest.err
+  rm -f conftest.er1
+  cat conftest.err >&5
+  echo "$as_me:7279: \$? = $ac_status" >&5
+  (exit $ac_status); } >/dev/null; then
+  if test -s conftest.err; then
+    ac_cpp_err=$ac_c_preproc_warn_flag
+  else
+    ac_cpp_err=
+  fi
+else
+  ac_cpp_err=yes
+fi
+if test -z "$ac_cpp_err"; then
+  eval "$as_ac_Header=yes"
+else
+  echo "$as_me: failed program was:" >&5
+  cat conftest.$ac_ext >&5
+  eval "$as_ac_Header=no"
+fi
+rm -f conftest.err conftest.$ac_ext
+fi
+echo "$as_me:7298: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
+if test `eval echo '${'$as_ac_Header'}'` = yes; then
+  cat >>confdefs.h <<EOF
+#define `echo "HAVE_$ac_header" | $as_tr_cpp` 1
+EOF
+
+fi
+done
+
+fi
+
 # not everyone has "test -c"
 if test -c /dev/sysmouse 2>/dev/null ; then
-echo "$as_me:6815: checking if you want to use sysmouse" >&5
+echo "$as_me:7312: checking if you want to use sysmouse" >&5
 echo $ECHO_N "checking if you want to use sysmouse... $ECHO_C" >&6
 
 # Check whether --with-sysmouse or --without-sysmouse was given.
@@ -6824,7 +7321,7 @@
 fi;
 	if test "$cf_with_sysmouse" != no ; then
 	cat >conftest.$ac_ext <<_ACEOF
-#line 6827 "configure"
+#line 7324 "configure"
 #include "confdefs.h"
 
 #include <osreldate.h>
@@ -6847,16 +7344,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:6850: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:7347: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:6853: \$? = $ac_status" >&5
+  echo "$as_me:7350: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:6856: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7353: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6859: \$? = $ac_status" >&5
+  echo "$as_me:7356: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_with_sysmouse=yes
 else
@@ -6866,7 +7363,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 	fi
-echo "$as_me:6869: result: $cf_with_sysmouse" >&5
+echo "$as_me:7366: result: $cf_with_sysmouse" >&5
 echo "${ECHO_T}$cf_with_sysmouse" >&6
 test "$cf_with_sysmouse" = yes &&
 cat >>confdefs.h <<\EOF
@@ -6876,7 +7373,7 @@
 fi
 
 # pretend that ncurses==ncursesw==ncursest
-echo "$as_me:6879: checking if you want to disable library suffixes" >&5
+echo "$as_me:7376: checking if you want to disable library suffixes" >&5
 echo $ECHO_N "checking if you want to disable library suffixes... $ECHO_C" >&6
 
 # Check whether --enable-lib-suffixes or --disable-lib-suffixes was given.
@@ -6893,13 +7390,13 @@
 	disable_lib_suffixes=no
 
 fi;
-echo "$as_me:6896: result: $disable_lib_suffixes" >&5
+echo "$as_me:7393: result: $disable_lib_suffixes" >&5
 echo "${ECHO_T}$disable_lib_suffixes" >&6
 
 ### If we're building with rpath, try to link non-standard libs that way too.
 if test "$DFT_LWR_MODEL" = "shared"; then
 
-echo "$as_me:6902: checking if rpath-hack should be disabled" >&5
+echo "$as_me:7399: checking if rpath-hack should be disabled" >&5
 echo $ECHO_N "checking if rpath-hack should be disabled... $ECHO_C" >&6
 
 # Check whether --enable-rpath-hack or --disable-rpath-hack was given.
@@ -6916,21 +7413,21 @@
 	cf_disable_rpath_hack=no
 
 fi;
-echo "$as_me:6919: result: $cf_disable_rpath_hack" >&5
+echo "$as_me:7416: result: $cf_disable_rpath_hack" >&5
 echo "${ECHO_T}$cf_disable_rpath_hack" >&6
 if test "$cf_disable_rpath_hack" = no ; then
 
-echo "$as_me:6923: checking for updated LDFLAGS" >&5
+echo "$as_me:7420: checking for updated LDFLAGS" >&5
 echo $ECHO_N "checking for updated LDFLAGS... $ECHO_C" >&6
 if test -n "$LD_RPATH_OPT" ; then
-	echo "$as_me:6926: result: maybe" >&5
+	echo "$as_me:7423: result: maybe" >&5
 echo "${ECHO_T}maybe" >&6
 
 	for ac_prog in ldd
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-echo "$as_me:6933: checking for $ac_word" >&5
+echo "$as_me:7430: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_cf_ldd_prog+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -6945,7 +7442,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_cf_ldd_prog="$ac_prog"
-echo "$as_me:6948: found $ac_dir/$ac_word" >&5
+echo "$as_me:7445: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -6953,10 +7450,10 @@
 fi
 cf_ldd_prog=$ac_cv_prog_cf_ldd_prog
 if test -n "$cf_ldd_prog"; then
-  echo "$as_me:6956: result: $cf_ldd_prog" >&5
+  echo "$as_me:7453: result: $cf_ldd_prog" >&5
 echo "${ECHO_T}$cf_ldd_prog" >&6
 else
-  echo "$as_me:6959: result: no" >&5
+  echo "$as_me:7456: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -6970,7 +7467,7 @@
 		cf_rpath_oops=
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 6973 "configure"
+#line 7470 "configure"
 #include "confdefs.h"
 #include <stdio.h>
 int
@@ -6982,16 +7479,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6985: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7482: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6988: \$? = $ac_status" >&5
+  echo "$as_me:7485: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6991: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7488: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6994: \$? = $ac_status" >&5
+  echo "$as_me:7491: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_rpath_oops=`$cf_ldd_prog conftest$ac_exeext | fgrep ' not found' | sed -e 's% =>.*$%%' |sort | uniq`
 		 cf_rpath_list=`$cf_ldd_prog conftest$ac_exeext | fgrep / | sed -e 's%^.*[ 	]/%/%' -e 's%/[^/][^/]*$%%' |sort | uniq`
@@ -7019,7 +7516,7 @@
 					then
 						test -n "$verbose" && echo "	...adding -L$cf_rpath_dir/lib to LDFLAGS for $cf_rpath_src" 1>&6
 
-echo "${as_me:-configure}:7022: testing ...adding -L$cf_rpath_dir/lib to LDFLAGS for $cf_rpath_src ..." 1>&5
+echo "${as_me:-configure}:7519: testing ...adding -L$cf_rpath_dir/lib to LDFLAGS for $cf_rpath_src ..." 1>&5
 
 						LDFLAGS="$LDFLAGS -L$cf_rpath_dir/lib"
 						break
@@ -7031,11 +7528,11 @@
 
 	test -n "$verbose" && echo "	...checking EXTRA_LDFLAGS $EXTRA_LDFLAGS" 1>&6
 
-echo "${as_me:-configure}:7034: testing ...checking EXTRA_LDFLAGS $EXTRA_LDFLAGS ..." 1>&5
+echo "${as_me:-configure}:7531: testing ...checking EXTRA_LDFLAGS $EXTRA_LDFLAGS ..." 1>&5
 
 test -n "$verbose" && echo "	...checking LDFLAGS $LDFLAGS" 1>&6
 
-echo "${as_me:-configure}:7038: testing ...checking LDFLAGS $LDFLAGS ..." 1>&5
+echo "${as_me:-configure}:7535: testing ...checking LDFLAGS $LDFLAGS ..." 1>&5
 
 cf_rpath_dst=
 for cf_rpath_src in $LDFLAGS
@@ -7072,7 +7569,7 @@
 			then
 				test -n "$verbose" && echo "	...Filter $cf_rpath_src ->$cf_rpath_tmp" 1>&6
 
-echo "${as_me:-configure}:7075: testing ...Filter $cf_rpath_src ->$cf_rpath_tmp ..." 1>&5
+echo "${as_me:-configure}:7572: testing ...Filter $cf_rpath_src ->$cf_rpath_tmp ..." 1>&5
 
 				EXTRA_LDFLAGS="$cf_rpath_tmp $EXTRA_LDFLAGS"
 			fi
@@ -7085,11 +7582,11 @@
 
 test -n "$verbose" && echo "	...checked LDFLAGS $LDFLAGS" 1>&6
 
-echo "${as_me:-configure}:7088: testing ...checked LDFLAGS $LDFLAGS ..." 1>&5
+echo "${as_me:-configure}:7585: testing ...checked LDFLAGS $LDFLAGS ..." 1>&5
 
 test -n "$verbose" && echo "	...checking LIBS $LIBS" 1>&6
 
-echo "${as_me:-configure}:7092: testing ...checking LIBS $LIBS ..." 1>&5
+echo "${as_me:-configure}:7589: testing ...checking LIBS $LIBS ..." 1>&5
 
 cf_rpath_dst=
 for cf_rpath_src in $LIBS
@@ -7126,7 +7623,7 @@
 			then
 				test -n "$verbose" && echo "	...Filter $cf_rpath_src ->$cf_rpath_tmp" 1>&6
 
-echo "${as_me:-configure}:7129: testing ...Filter $cf_rpath_src ->$cf_rpath_tmp ..." 1>&5
+echo "${as_me:-configure}:7626: testing ...Filter $cf_rpath_src ->$cf_rpath_tmp ..." 1>&5
 
 				EXTRA_LDFLAGS="$cf_rpath_tmp $EXTRA_LDFLAGS"
 			fi
@@ -7139,14 +7636,14 @@
 
 test -n "$verbose" && echo "	...checked LIBS $LIBS" 1>&6
 
-echo "${as_me:-configure}:7142: testing ...checked LIBS $LIBS ..." 1>&5
+echo "${as_me:-configure}:7639: testing ...checked LIBS $LIBS ..." 1>&5
 
 	test -n "$verbose" && echo "	...checked EXTRA_LDFLAGS $EXTRA_LDFLAGS" 1>&6
 
-echo "${as_me:-configure}:7146: testing ...checked EXTRA_LDFLAGS $EXTRA_LDFLAGS ..." 1>&5
+echo "${as_me:-configure}:7643: testing ...checked EXTRA_LDFLAGS $EXTRA_LDFLAGS ..." 1>&5
 
 else
-	echo "$as_me:7149: result: no" >&5
+	echo "$as_me:7646: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -7157,7 +7654,7 @@
 ###############################################################################
 
 ###	use option --with-extra-suffix to append suffix to headers and libraries
-echo "$as_me:7160: checking if you wish to append extra suffix to header/library paths" >&5
+echo "$as_me:7657: checking if you wish to append extra suffix to header/library paths" >&5
 echo $ECHO_N "checking if you wish to append extra suffix to header/library paths... $ECHO_C" >&6
 EXTRA_SUFFIX=
 
@@ -7176,11 +7673,11 @@
 	esac
 
 fi;
-echo "$as_me:7179: result: $EXTRA_SUFFIX" >&5
+echo "$as_me:7676: result: $EXTRA_SUFFIX" >&5
 echo "${ECHO_T}$EXTRA_SUFFIX" >&6
 
 ###	use option --disable-overwrite to leave out the link to -lcurses
-echo "$as_me:7183: checking if you wish to install ncurses overwriting curses" >&5
+echo "$as_me:7680: checking if you wish to install ncurses overwriting curses" >&5
 echo $ECHO_N "checking if you wish to install ncurses overwriting curses... $ECHO_C" >&6
 
 # Check whether --enable-overwrite or --disable-overwrite was given.
@@ -7190,10 +7687,10 @@
 else
   if test "$prefix" = "/usr" ; then with_overwrite=yes; else with_overwrite=no; fi
 fi;
-echo "$as_me:7193: result: $with_overwrite" >&5
+echo "$as_me:7690: result: $with_overwrite" >&5
 echo "${ECHO_T}$with_overwrite" >&6
 
-echo "$as_me:7196: checking if external terminfo-database is used" >&5
+echo "$as_me:7693: checking if external terminfo-database is used" >&5
 echo $ECHO_N "checking if external terminfo-database is used... $ECHO_C" >&6
 
 # Check whether --enable-database or --disable-database was given.
@@ -7203,7 +7700,7 @@
 else
   use_database=yes
 fi;
-echo "$as_me:7206: result: $use_database" >&5
+echo "$as_me:7703: result: $use_database" >&5
 echo "${ECHO_T}$use_database" >&6
 
 case $host_os in
@@ -7219,7 +7716,7 @@
 if test "$use_database" != no ; then
 	NCURSES_USE_DATABASE=1
 
-	echo "$as_me:7222: checking which terminfo source-file will be installed" >&5
+	echo "$as_me:7719: checking which terminfo source-file will be installed" >&5
 echo $ECHO_N "checking which terminfo source-file will be installed... $ECHO_C" >&6
 
 # Check whether --with-database or --without-database was given.
@@ -7227,10 +7724,10 @@
   withval="$with_database"
   TERMINFO_SRC=$withval
 fi;
-	echo "$as_me:7230: result: $TERMINFO_SRC" >&5
+	echo "$as_me:7727: result: $TERMINFO_SRC" >&5
 echo "${ECHO_T}$TERMINFO_SRC" >&6
 
-	echo "$as_me:7233: checking whether to use hashed database instead of directory/tree" >&5
+	echo "$as_me:7730: checking whether to use hashed database instead of directory/tree" >&5
 echo $ECHO_N "checking whether to use hashed database instead of directory/tree... $ECHO_C" >&6
 
 # Check whether --with-hashed-db or --without-hashed-db was given.
@@ -7240,13 +7737,13 @@
 else
   with_hashed_db=no
 fi;
-	echo "$as_me:7243: result: $with_hashed_db" >&5
+	echo "$as_me:7740: result: $with_hashed_db" >&5
 echo "${ECHO_T}$with_hashed_db" >&6
 else
 	with_hashed_db=no
 fi
 
-echo "$as_me:7249: checking for list of fallback descriptions" >&5
+echo "$as_me:7746: checking for list of fallback descriptions" >&5
 echo $ECHO_N "checking for list of fallback descriptions... $ECHO_C" >&6
 
 # Check whether --with-fallbacks or --without-fallbacks was given.
@@ -7256,11 +7753,11 @@
 else
   with_fallback=
 fi;
-echo "$as_me:7259: result: $with_fallback" >&5
+echo "$as_me:7756: result: $with_fallback" >&5
 echo "${ECHO_T}$with_fallback" >&6
 FALLBACK_LIST=`test "$with_fallback" != no && echo "$with_fallback" | sed -e 's/,/ /g'`
 
-echo "$as_me:7263: checking if you want modern xterm or antique" >&5
+echo "$as_me:7760: checking if you want modern xterm or antique" >&5
 echo $ECHO_N "checking if you want modern xterm or antique... $ECHO_C" >&6
 
 # Check whether --with-xterm-new or --without-xterm-new was given.
@@ -7274,11 +7771,11 @@
 (no) with_xterm_new=xterm-old;;
 (*)	 with_xterm_new=xterm-new;;
 esac
-echo "$as_me:7277: result: $with_xterm_new" >&5
+echo "$as_me:7774: result: $with_xterm_new" >&5
 echo "${ECHO_T}$with_xterm_new" >&6
 WHICH_XTERM=$with_xterm_new
 
-echo "$as_me:7281: checking if xterm backspace sends BS or DEL" >&5
+echo "$as_me:7778: checking if xterm backspace sends BS or DEL" >&5
 echo $ECHO_N "checking if xterm backspace sends BS or DEL... $ECHO_C" >&6
 
 # Check whether --with-xterm-kbs or --without-xterm-kbs was given.
@@ -7299,7 +7796,7 @@
 	with_xterm_kbs=$withval
 	;;
 esac
-echo "$as_me:7302: result: $with_xterm_kbs" >&5
+echo "$as_me:7799: result: $with_xterm_kbs" >&5
 echo "${ECHO_T}$with_xterm_kbs" >&6
 XTERM_KBS=$with_xterm_kbs
 
@@ -7309,7 +7806,7 @@
 	MAKE_TERMINFO="#"
 else
 
-echo "$as_me:7312: checking for list of terminfo directories" >&5
+echo "$as_me:7809: checking for list of terminfo directories" >&5
 echo $ECHO_N "checking for list of terminfo directories... $ECHO_C" >&6
 
 # Check whether --with-terminfo-dirs or --without-terminfo-dirs was given.
@@ -7349,7 +7846,7 @@
 	cf_src_path=`echo $cf_src_path | sed -e s%NONE%$cf_path_syntax%`
 	;;
 (*)
-	{ { echo "$as_me:7352: error: expected a pathname, not \"$cf_src_path\"" >&5
+	{ { echo "$as_me:7849: error: expected a pathname, not \"$cf_src_path\"" >&5
 echo "$as_me: error: expected a pathname, not \"$cf_src_path\"" >&2;}
    { (exit 1); exit 1; }; }
 	;;
@@ -7372,14 +7869,14 @@
 	;;
 esac
 
-echo "$as_me:7375: result: $TERMINFO_DIRS" >&5
+echo "$as_me:7872: result: $TERMINFO_DIRS" >&5
 echo "${ECHO_T}$TERMINFO_DIRS" >&6
 test -n "$TERMINFO_DIRS" &&
 cat >>confdefs.h <<EOF
 #define TERMINFO_DIRS "$TERMINFO_DIRS"
 EOF
 
-echo "$as_me:7382: checking for default terminfo directory" >&5
+echo "$as_me:7879: checking for default terminfo directory" >&5
 echo $ECHO_N "checking for default terminfo directory... $ECHO_C" >&6
 
 # Check whether --with-default-terminfo-dir or --without-default-terminfo-dir was given.
@@ -7415,7 +7912,7 @@
 	withval=`echo $withval | sed -e s%NONE%$cf_path_syntax%`
 	;;
 (*)
-	{ { echo "$as_me:7418: error: expected a pathname, not \"$withval\"" >&5
+	{ { echo "$as_me:7915: error: expected a pathname, not \"$withval\"" >&5
 echo "$as_me: error: expected a pathname, not \"$withval\"" >&2;}
    { (exit 1); exit 1; }; }
 	;;
@@ -7424,7 +7921,7 @@
 fi
 eval TERMINFO="$withval"
 
-echo "$as_me:7427: result: $TERMINFO" >&5
+echo "$as_me:7924: result: $TERMINFO" >&5
 echo "${ECHO_T}$TERMINFO" >&6
 
 cat >>confdefs.h <<EOF
@@ -7435,7 +7932,7 @@
 
 ###	use option --disable-big-core to make tic run on small machines
 ###	We need 4Mb, check if we can allocate 50% more than that.
-echo "$as_me:7438: checking if big-core option selected" >&5
+echo "$as_me:7935: checking if big-core option selected" >&5
 echo $ECHO_N "checking if big-core option selected... $ECHO_C" >&6
 
 # Check whether --enable-big-core or --disable-big-core was given.
@@ -7447,7 +7944,7 @@
   with_big_core=no
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7450 "configure"
+#line 7947 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -7461,15 +7958,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:7464: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7961: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7467: \$? = $ac_status" >&5
+  echo "$as_me:7964: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:7469: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7966: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7472: \$? = $ac_status" >&5
+  echo "$as_me:7969: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   with_big_core=yes
 else
@@ -7481,7 +7978,7 @@
 rm -f core core.* *.core conftest$ac_exeext conftest.$ac_objext conftest.$ac_ext
 fi
 fi;
-echo "$as_me:7484: result: $with_big_core" >&5
+echo "$as_me:7981: result: $with_big_core" >&5
 echo "${ECHO_T}$with_big_core" >&6
 test "x$with_big_core" = "xyes" &&
 cat >>confdefs.h <<\EOF
@@ -7491,7 +7988,7 @@
 ### ISO C only guarantees 512-char strings, we have tables which load faster
 ### when constructed using "big" strings.  More than the C compiler, the awk
 ### program is a limit on most vendor UNIX systems.  Check that we can build.
-echo "$as_me:7494: checking if big-strings option selected" >&5
+echo "$as_me:7991: checking if big-strings option selected" >&5
 echo $ECHO_N "checking if big-strings option selected... $ECHO_C" >&6
 
 # Check whether --enable-big-strings or --disable-big-strings was given.
@@ -7515,14 +8012,14 @@
 	esac
 
 fi;
-echo "$as_me:7518: result: $with_big_strings" >&5
+echo "$as_me:8015: result: $with_big_strings" >&5
 echo "${ECHO_T}$with_big_strings" >&6
 
 USE_BIG_STRINGS=0
 test "x$with_big_strings" = "xyes" && USE_BIG_STRINGS=1
 
 ###	use option --enable-termcap to compile in the termcap fallback support
-echo "$as_me:7525: checking if you want termcap-fallback support" >&5
+echo "$as_me:8022: checking if you want termcap-fallback support" >&5
 echo $ECHO_N "checking if you want termcap-fallback support... $ECHO_C" >&6
 
 # Check whether --enable-termcap or --disable-termcap was given.
@@ -7532,14 +8029,14 @@
 else
   with_termcap=no
 fi;
-echo "$as_me:7535: result: $with_termcap" >&5
+echo "$as_me:8032: result: $with_termcap" >&5
 echo "${ECHO_T}$with_termcap" >&6
 
 NCURSES_USE_TERMCAP=0
 if test "x$with_termcap" != "xyes" ; then
 	if test "$use_database" = no ; then
 		if test -z "$with_fallback" ; then
-			{ { echo "$as_me:7542: error: You have disabled the database w/o specifying fallbacks" >&5
+			{ { echo "$as_me:8039: error: You have disabled the database w/o specifying fallbacks" >&5
 echo "$as_me: error: You have disabled the database w/o specifying fallbacks" >&2;}
    { (exit 1); exit 1; }; }
 		fi
@@ -7552,13 +8049,13 @@
 else
 
 	if test "$with_ticlib" != no ; then
-		{ { echo "$as_me:7555: error: Options --with-ticlib and --enable-termcap cannot be combined" >&5
+		{ { echo "$as_me:8052: error: Options --with-ticlib and --enable-termcap cannot be combined" >&5
 echo "$as_me: error: Options --with-ticlib and --enable-termcap cannot be combined" >&2;}
    { (exit 1); exit 1; }; }
 	fi
 
 	NCURSES_USE_TERMCAP=1
-	echo "$as_me:7561: checking for list of termcap files" >&5
+	echo "$as_me:8058: checking for list of termcap files" >&5
 echo $ECHO_N "checking for list of termcap files... $ECHO_C" >&6
 
 # Check whether --with-termpath or --without-termpath was given.
@@ -7598,7 +8095,7 @@
 	cf_src_path=`echo $cf_src_path | sed -e s%NONE%$cf_path_syntax%`
 	;;
 (*)
-	{ { echo "$as_me:7601: error: expected a pathname, not \"$cf_src_path\"" >&5
+	{ { echo "$as_me:8098: error: expected a pathname, not \"$cf_src_path\"" >&5
 echo "$as_me: error: expected a pathname, not \"$cf_src_path\"" >&2;}
    { (exit 1); exit 1; }; }
 	;;
@@ -7621,7 +8118,7 @@
 	;;
 esac
 
-	echo "$as_me:7624: result: $TERMPATH" >&5
+	echo "$as_me:8121: result: $TERMPATH" >&5
 echo "${ECHO_T}$TERMPATH" >&6
 	test -n "$TERMPATH" &&
 cat >>confdefs.h <<EOF
@@ -7629,7 +8126,7 @@
 EOF
 
 	###	use option --enable-getcap to use a hacked getcap for reading termcaps
-	echo "$as_me:7632: checking if fast termcap-loader is needed" >&5
+	echo "$as_me:8129: checking if fast termcap-loader is needed" >&5
 echo $ECHO_N "checking if fast termcap-loader is needed... $ECHO_C" >&6
 
 # Check whether --enable-getcap or --disable-getcap was given.
@@ -7639,14 +8136,14 @@
 else
   with_getcap=no
 fi;
-	echo "$as_me:7642: result: $with_getcap" >&5
+	echo "$as_me:8139: result: $with_getcap" >&5
 echo "${ECHO_T}$with_getcap" >&6
 	test "x$with_getcap" = "xyes" &&
 cat >>confdefs.h <<\EOF
 #define USE_GETCAP 1
 EOF
 
-	echo "$as_me:7649: checking if translated termcaps will be cached in ~/.terminfo" >&5
+	echo "$as_me:8146: checking if translated termcaps will be cached in ~/.terminfo" >&5
 echo $ECHO_N "checking if translated termcaps will be cached in ~/.terminfo... $ECHO_C" >&6
 
 # Check whether --enable-getcap-cache or --disable-getcap-cache was given.
@@ -7656,7 +8153,7 @@
 else
   with_getcap_cache=no
 fi;
-	echo "$as_me:7659: result: $with_getcap_cache" >&5
+	echo "$as_me:8156: result: $with_getcap_cache" >&5
 echo "${ECHO_T}$with_getcap_cache" >&6
 	test "x$with_getcap_cache" = "xyes" &&
 cat >>confdefs.h <<\EOF
@@ -7666,7 +8163,7 @@
 fi
 
 ###   Use option --disable-home-terminfo to completely remove ~/.terminfo
-echo "$as_me:7669: checking if ~/.terminfo is wanted" >&5
+echo "$as_me:8166: checking if ~/.terminfo is wanted" >&5
 echo $ECHO_N "checking if ~/.terminfo is wanted... $ECHO_C" >&6
 
 # Check whether --enable-home-terminfo or --disable-home-terminfo was given.
@@ -7676,14 +8173,14 @@
 else
   with_home_terminfo=yes
 fi;
-echo "$as_me:7679: result: $with_home_terminfo" >&5
+echo "$as_me:8176: result: $with_home_terminfo" >&5
 echo "${ECHO_T}$with_home_terminfo" >&6
 test "x$with_home_terminfo" = "xyes" &&
 cat >>confdefs.h <<\EOF
 #define USE_HOME_TERMINFO 1
 EOF
 
-echo "$as_me:7686: checking if you want to use restricted environment when running as root" >&5
+echo "$as_me:8183: checking if you want to use restricted environment when running as root" >&5
 echo $ECHO_N "checking if you want to use restricted environment when running as root... $ECHO_C" >&6
 
 # Check whether --enable-root-environ or --disable-root-environ was given.
@@ -7693,7 +8190,7 @@
 else
   with_root_environ=yes
 fi;
-echo "$as_me:7696: result: $with_root_environ" >&5
+echo "$as_me:8193: result: $with_root_environ" >&5
 echo "${ECHO_T}$with_root_environ" >&6
 test "x$with_root_environ" = xyes &&
 cat >>confdefs.h <<\EOF
@@ -7708,23 +8205,23 @@
 
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:7711: checking for $ac_header" >&5
+echo "$as_me:8208: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7717 "configure"
+#line 8214 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:7721: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:8218: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:7727: \$? = $ac_status" >&5
+  echo "$as_me:8224: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -7743,7 +8240,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:7746: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:8243: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7758,13 +8255,13 @@
 	unlink
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7761: checking for $ac_func" >&5
+echo "$as_me:8258: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7767 "configure"
+#line 8264 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7795,16 +8292,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7798: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8295: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7801: \$? = $ac_status" >&5
+  echo "$as_me:8298: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7804: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8301: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7807: \$? = $ac_status" >&5
+  echo "$as_me:8304: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7814,7 +8311,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7817: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:8314: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7831,13 +8328,13 @@
 		symlink
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7834: checking for $ac_func" >&5
+echo "$as_me:8331: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7840 "configure"
+#line 8337 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7868,16 +8365,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7871: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8368: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7874: \$? = $ac_status" >&5
+  echo "$as_me:8371: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7877: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8374: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7880: \$? = $ac_status" >&5
+  echo "$as_me:8377: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7887,7 +8384,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7890: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:8387: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7898,7 +8395,7 @@
 done
 
 else
-	echo "$as_me:7901: checking if link/symlink functions work" >&5
+	echo "$as_me:8398: checking if link/symlink functions work" >&5
 echo $ECHO_N "checking if link/symlink functions work... $ECHO_C" >&6
 if test "${cf_cv_link_funcs+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -7911,7 +8408,7 @@
 			eval 'ac_cv_func_'$cf_func'=error'
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7914 "configure"
+#line 8411 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -7941,15 +8438,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:7944: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8441: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7947: \$? = $ac_status" >&5
+  echo "$as_me:8444: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:7949: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8446: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7952: \$? = $ac_status" >&5
+  echo "$as_me:8449: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 			cf_cv_link_funcs="$cf_cv_link_funcs $cf_func"
@@ -7967,7 +8464,7 @@
 		test -z "$cf_cv_link_funcs" && cf_cv_link_funcs=no
 
 fi
-echo "$as_me:7970: result: $cf_cv_link_funcs" >&5
+echo "$as_me:8467: result: $cf_cv_link_funcs" >&5
 echo "${ECHO_T}$cf_cv_link_funcs" >&6
 	test "$ac_cv_func_link"    = yes &&
 cat >>confdefs.h <<\EOF
@@ -7987,7 +8484,7 @@
 # soft links (symbolic links) are useful for some systems where hard links do
 # not work, or to make it simpler to copy terminfo trees around.
 if test "x$ac_cv_func_symlink" = xyes ; then
-	echo "$as_me:7990: checking if tic should use symbolic links" >&5
+	echo "$as_me:8487: checking if tic should use symbolic links" >&5
 echo $ECHO_N "checking if tic should use symbolic links... $ECHO_C" >&6
 
 # Check whether --enable-symlinks or --disable-symlinks was given.
@@ -7997,21 +8494,21 @@
 else
   with_symlinks=no
 fi;
-	echo "$as_me:8000: result: $with_symlinks" >&5
+	echo "$as_me:8497: result: $with_symlinks" >&5
 echo "${ECHO_T}$with_symlinks" >&6
 fi
 
 # If we have hard links and did not choose to use soft links instead, there is
 # no reason to make this choice optional - use the hard links.
 if test "$with_symlinks" = no ; then
-	echo "$as_me:8007: checking if tic should use hard links" >&5
+	echo "$as_me:8504: checking if tic should use hard links" >&5
 echo $ECHO_N "checking if tic should use hard links... $ECHO_C" >&6
 	if test "x$ac_cv_func_link" = xyes ; then
 		with_links=yes
 	else
 		with_links=no
 	fi
-	echo "$as_me:8014: result: $with_links" >&5
+	echo "$as_me:8511: result: $with_links" >&5
 echo "${ECHO_T}$with_links" >&6
 fi
 
@@ -8026,7 +8523,7 @@
 EOF
 
 ###   use option --enable-broken-linker to force on use of broken-linker support
-echo "$as_me:8029: checking if you want broken-linker support code" >&5
+echo "$as_me:8526: checking if you want broken-linker support code" >&5
 echo $ECHO_N "checking if you want broken-linker support code... $ECHO_C" >&6
 
 # Check whether --enable-broken_linker or --disable-broken_linker was given.
@@ -8036,7 +8533,7 @@
 else
   with_broken_linker=${BROKEN_LINKER:-no}
 fi;
-echo "$as_me:8039: result: $with_broken_linker" >&5
+echo "$as_me:8536: result: $with_broken_linker" >&5
 echo "${ECHO_T}$with_broken_linker" >&6
 
 BROKEN_LINKER=0
@@ -8058,14 +8555,14 @@
 		BROKEN_LINKER=1
 		test -n "$verbose" && echo "	cygwin linker is broken anyway" 1>&6
 
-echo "${as_me:-configure}:8061: testing cygwin linker is broken anyway ..." 1>&5
+echo "${as_me:-configure}:8558: testing cygwin linker is broken anyway ..." 1>&5
 
 		;;
 	esac
 fi
 
 ###   use option --enable-bsdpad to have tputs process BSD-style prefix padding
-echo "$as_me:8068: checking if tputs should process BSD-style prefix padding" >&5
+echo "$as_me:8565: checking if tputs should process BSD-style prefix padding" >&5
 echo $ECHO_N "checking if tputs should process BSD-style prefix padding... $ECHO_C" >&6
 
 # Check whether --enable-bsdpad or --disable-bsdpad was given.
@@ -8075,7 +8572,7 @@
 else
   with_bsdpad=no
 fi;
-echo "$as_me:8078: result: $with_bsdpad" >&5
+echo "$as_me:8575: result: $with_bsdpad" >&5
 echo "${ECHO_T}$with_bsdpad" >&6
 test "x$with_bsdpad" = xyes &&
 cat >>confdefs.h <<\EOF
@@ -8134,14 +8631,14 @@
 
 cf_gnu_xopen_source=$cf_XOPEN_SOURCE
 
-echo "$as_me:8137: checking if this is the GNU C library" >&5
+echo "$as_me:8634: checking if this is the GNU C library" >&5
 echo $ECHO_N "checking if this is the GNU C library... $ECHO_C" >&6
 if test "${cf_cv_gnu_library+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 8144 "configure"
+#line 8641 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 int
@@ -8158,16 +8655,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8161: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:8658: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8164: \$? = $ac_status" >&5
+  echo "$as_me:8661: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8167: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8664: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8170: \$? = $ac_status" >&5
+  echo "$as_me:8667: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_gnu_library=yes
 else
@@ -8178,14 +8675,14 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:8181: result: $cf_cv_gnu_library" >&5
+echo "$as_me:8678: result: $cf_cv_gnu_library" >&5
 echo "${ECHO_T}$cf_cv_gnu_library" >&6
 
 if test x$cf_cv_gnu_library = xyes; then
 
 	# With glibc 2.19 (13 years after this check was begun), _DEFAULT_SOURCE
 	# was changed to help a little...
-	echo "$as_me:8188: checking if _DEFAULT_SOURCE can be used as a basis" >&5
+	echo "$as_me:8685: checking if _DEFAULT_SOURCE can be used as a basis" >&5
 echo $ECHO_N "checking if _DEFAULT_SOURCE can be used as a basis... $ECHO_C" >&6
 if test "${cf_cv_gnu_library_219+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -8197,7 +8694,7 @@
 	CPPFLAGS="${CPPFLAGS}-D_DEFAULT_SOURCE"
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 8200 "configure"
+#line 8697 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 int
@@ -8214,16 +8711,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8217: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:8714: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8220: \$? = $ac_status" >&5
+  echo "$as_me:8717: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8223: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8720: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8226: \$? = $ac_status" >&5
+  echo "$as_me:8723: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_gnu_library_219=yes
 else
@@ -8235,12 +8732,12 @@
 		CPPFLAGS="$cf_save"
 
 fi
-echo "$as_me:8238: result: $cf_cv_gnu_library_219" >&5
+echo "$as_me:8735: result: $cf_cv_gnu_library_219" >&5
 echo "${ECHO_T}$cf_cv_gnu_library_219" >&6
 
 	if test "x$cf_cv_gnu_library_219" = xyes; then
 		cf_save="$CPPFLAGS"
-		echo "$as_me:8243: checking if _XOPEN_SOURCE=$cf_gnu_xopen_source works with _DEFAULT_SOURCE" >&5
+		echo "$as_me:8740: checking if _XOPEN_SOURCE=$cf_gnu_xopen_source works with _DEFAULT_SOURCE" >&5
 echo $ECHO_N "checking if _XOPEN_SOURCE=$cf_gnu_xopen_source works with _DEFAULT_SOURCE... $ECHO_C" >&6
 if test "${cf_cv_gnu_dftsrc_219+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -8345,7 +8842,7 @@
 fi
 
 			cat >conftest.$ac_ext <<_ACEOF
-#line 8348 "configure"
+#line 8845 "configure"
 #include "confdefs.h"
 
 				#include <limits.h>
@@ -8365,16 +8862,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8368: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:8865: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8371: \$? = $ac_status" >&5
+  echo "$as_me:8868: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8374: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8871: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8377: \$? = $ac_status" >&5
+  echo "$as_me:8874: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_gnu_dftsrc_219=yes
 else
@@ -8385,7 +8882,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:8388: result: $cf_cv_gnu_dftsrc_219" >&5
+echo "$as_me:8885: result: $cf_cv_gnu_dftsrc_219" >&5
 echo "${ECHO_T}$cf_cv_gnu_dftsrc_219" >&6
 		test "x$cf_cv_gnu_dftsrc_219" = "xyes" || CPPFLAGS="$cf_save"
 	else
@@ -8394,14 +8891,14 @@
 
 	if test "x$cf_cv_gnu_dftsrc_219" != xyes; then
 
-		echo "$as_me:8397: checking if we must define _GNU_SOURCE" >&5
+		echo "$as_me:8894: checking if we must define _GNU_SOURCE" >&5
 echo $ECHO_N "checking if we must define _GNU_SOURCE... $ECHO_C" >&6
 if test "${cf_cv_gnu_source+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 8404 "configure"
+#line 8901 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 int
@@ -8416,16 +8913,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8419: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:8916: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8422: \$? = $ac_status" >&5
+  echo "$as_me:8919: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8425: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8922: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8428: \$? = $ac_status" >&5
+  echo "$as_me:8925: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_gnu_source=no
 else
@@ -8532,7 +9029,7 @@
 fi
 
 			 cat >conftest.$ac_ext <<_ACEOF
-#line 8535 "configure"
+#line 9032 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 int
@@ -8547,16 +9044,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8550: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:9047: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8553: \$? = $ac_status" >&5
+  echo "$as_me:9050: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8556: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9053: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8559: \$? = $ac_status" >&5
+  echo "$as_me:9056: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_gnu_source=no
 else
@@ -8571,12 +9068,12 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:8574: result: $cf_cv_gnu_source" >&5
+echo "$as_me:9071: result: $cf_cv_gnu_source" >&5
 echo "${ECHO_T}$cf_cv_gnu_source" >&6
 
 		if test "$cf_cv_gnu_source" = yes
 		then
-		echo "$as_me:8579: checking if we should also define _DEFAULT_SOURCE" >&5
+		echo "$as_me:9076: checking if we should also define _DEFAULT_SOURCE" >&5
 echo $ECHO_N "checking if we should also define _DEFAULT_SOURCE... $ECHO_C" >&6
 if test "${cf_cv_default_source+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -8586,7 +9083,7 @@
 	CPPFLAGS="${CPPFLAGS}-D_GNU_SOURCE"
 
 			cat >conftest.$ac_ext <<_ACEOF
-#line 8589 "configure"
+#line 9086 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 int
@@ -8601,16 +9098,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8604: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:9101: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8607: \$? = $ac_status" >&5
+  echo "$as_me:9104: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8610: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9107: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8613: \$? = $ac_status" >&5
+  echo "$as_me:9110: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_default_source=no
 else
@@ -8621,7 +9118,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:8624: result: $cf_cv_default_source" >&5
+echo "$as_me:9121: result: $cf_cv_default_source" >&5
 echo "${ECHO_T}$cf_cv_default_source" >&6
 			if test "$cf_cv_default_source" = yes
 			then
@@ -8656,16 +9153,16 @@
 	sed	-e 's/-[UD]'"_POSIX_C_SOURCE"'\(=[^ 	]*\)\?[ 	]/ /g' \
 		-e 's/-[UD]'"_POSIX_C_SOURCE"'\(=[^ 	]*\)\?$//g'`
 
-echo "$as_me:8659: checking if we should define _POSIX_C_SOURCE" >&5
+echo "$as_me:9156: checking if we should define _POSIX_C_SOURCE" >&5
 echo $ECHO_N "checking if we should define _POSIX_C_SOURCE... $ECHO_C" >&6
 if test "${cf_cv_posix_c_source+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
-echo "${as_me:-configure}:8665: testing if the symbol is already defined go no further ..." 1>&5
+echo "${as_me:-configure}:9162: testing if the symbol is already defined go no further ..." 1>&5
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 8668 "configure"
+#line 9165 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 int
@@ -8680,16 +9177,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8683: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:9180: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8686: \$? = $ac_status" >&5
+  echo "$as_me:9183: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8689: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9186: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8692: \$? = $ac_status" >&5
+  echo "$as_me:9189: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_posix_c_source=no
 else
@@ -8710,7 +9207,7 @@
 	 esac
 	 if test "$cf_want_posix_source" = yes ; then
 		cat >conftest.$ac_ext <<_ACEOF
-#line 8713 "configure"
+#line 9210 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 int
@@ -8725,16 +9222,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8728: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:9225: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8731: \$? = $ac_status" >&5
+  echo "$as_me:9228: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8734: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9231: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8737: \$? = $ac_status" >&5
+  echo "$as_me:9234: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   :
 else
@@ -8745,7 +9242,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 	 fi
 
-echo "${as_me:-configure}:8748: testing ifdef from value $cf_POSIX_C_SOURCE ..." 1>&5
+echo "${as_me:-configure}:9245: testing ifdef from value $cf_POSIX_C_SOURCE ..." 1>&5
 
 	 CFLAGS="$cf_trim_CFLAGS"
 	 CPPFLAGS="$cf_trim_CPPFLAGS"
@@ -8753,10 +9250,10 @@
 	test -n "$CPPFLAGS" && CPPFLAGS="$CPPFLAGS "
 	CPPFLAGS="${CPPFLAGS}$cf_cv_posix_c_source"
 
-echo "${as_me:-configure}:8756: testing if the second compile does not leave our definition intact error ..." 1>&5
+echo "${as_me:-configure}:9253: testing if the second compile does not leave our definition intact error ..." 1>&5
 
 	 cat >conftest.$ac_ext <<_ACEOF
-#line 8759 "configure"
+#line 9256 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 int
@@ -8771,16 +9268,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8774: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:9271: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8777: \$? = $ac_status" >&5
+  echo "$as_me:9274: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8780: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9277: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8783: \$? = $ac_status" >&5
+  echo "$as_me:9280: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   :
 else
@@ -8796,7 +9293,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:8799: result: $cf_cv_posix_c_source" >&5
+echo "$as_me:9296: result: $cf_cv_posix_c_source" >&5
 echo "${ECHO_T}$cf_cv_posix_c_source" >&6
 
 if test "$cf_cv_posix_c_source" != no ; then
@@ -8934,14 +9431,14 @@
 	;;
 (*)
 
-echo "$as_me:8937: checking if we should define _XOPEN_SOURCE" >&5
+echo "$as_me:9434: checking if we should define _XOPEN_SOURCE" >&5
 echo $ECHO_N "checking if we should define _XOPEN_SOURCE... $ECHO_C" >&6
 if test "${cf_cv_xopen_source+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 8944 "configure"
+#line 9441 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -8960,16 +9457,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8963: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:9460: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8966: \$? = $ac_status" >&5
+  echo "$as_me:9463: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8969: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9466: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8972: \$? = $ac_status" >&5
+  echo "$as_me:9469: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_xopen_source=no
 else
@@ -8981,7 +9478,7 @@
 	CPPFLAGS="${CPPFLAGS}-D_XOPEN_SOURCE=$cf_XOPEN_SOURCE"
 
 	 cat >conftest.$ac_ext <<_ACEOF
-#line 8984 "configure"
+#line 9481 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -9000,16 +9497,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:9003: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:9500: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:9006: \$? = $ac_status" >&5
+  echo "$as_me:9503: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:9009: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9506: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9012: \$? = $ac_status" >&5
+  echo "$as_me:9509: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_xopen_source=no
 else
@@ -9024,7 +9521,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:9027: result: $cf_cv_xopen_source" >&5
+echo "$as_me:9524: result: $cf_cv_xopen_source" >&5
 echo "${ECHO_T}$cf_cv_xopen_source" >&6
 
 if test "$cf_cv_xopen_source" != no ; then
@@ -9152,16 +9649,16 @@
 	sed	-e 's/-[UD]'"_POSIX_C_SOURCE"'\(=[^ 	]*\)\?[ 	]/ /g' \
 		-e 's/-[UD]'"_POSIX_C_SOURCE"'\(=[^ 	]*\)\?$//g'`
 
-echo "$as_me:9155: checking if we should define _POSIX_C_SOURCE" >&5
+echo "$as_me:9652: checking if we should define _POSIX_C_SOURCE" >&5
 echo $ECHO_N "checking if we should define _POSIX_C_SOURCE... $ECHO_C" >&6
 if test "${cf_cv_posix_c_source+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
-echo "${as_me:-configure}:9161: testing if the symbol is already defined go no further ..." 1>&5
+echo "${as_me:-configure}:9658: testing if the symbol is already defined go no further ..." 1>&5
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 9164 "configure"
+#line 9661 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 int
@@ -9176,16 +9673,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:9179: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:9676: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:9182: \$? = $ac_status" >&5
+  echo "$as_me:9679: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:9185: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9682: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9188: \$? = $ac_status" >&5
+  echo "$as_me:9685: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_posix_c_source=no
 else
@@ -9206,7 +9703,7 @@
 	 esac
 	 if test "$cf_want_posix_source" = yes ; then
 		cat >conftest.$ac_ext <<_ACEOF
-#line 9209 "configure"
+#line 9706 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 int
@@ -9221,16 +9718,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:9224: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:9721: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:9227: \$? = $ac_status" >&5
+  echo "$as_me:9724: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:9230: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9727: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9233: \$? = $ac_status" >&5
+  echo "$as_me:9730: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   :
 else
@@ -9241,7 +9738,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 	 fi
 
-echo "${as_me:-configure}:9244: testing ifdef from value $cf_POSIX_C_SOURCE ..." 1>&5
+echo "${as_me:-configure}:9741: testing ifdef from value $cf_POSIX_C_SOURCE ..." 1>&5
 
 	 CFLAGS="$cf_trim_CFLAGS"
 	 CPPFLAGS="$cf_trim_CPPFLAGS"
@@ -9249,10 +9746,10 @@
 	test -n "$CPPFLAGS" && CPPFLAGS="$CPPFLAGS "
 	CPPFLAGS="${CPPFLAGS}$cf_cv_posix_c_source"
 
-echo "${as_me:-configure}:9252: testing if the second compile does not leave our definition intact error ..." 1>&5
+echo "${as_me:-configure}:9749: testing if the second compile does not leave our definition intact error ..." 1>&5
 
 	 cat >conftest.$ac_ext <<_ACEOF
-#line 9255 "configure"
+#line 9752 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 int
@@ -9267,16 +9764,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:9270: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:9767: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:9273: \$? = $ac_status" >&5
+  echo "$as_me:9770: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:9276: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9773: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9279: \$? = $ac_status" >&5
+  echo "$as_me:9776: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   :
 else
@@ -9292,7 +9789,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:9295: result: $cf_cv_posix_c_source" >&5
+echo "$as_me:9792: result: $cf_cv_posix_c_source" >&5
 echo "${ECHO_T}$cf_cv_posix_c_source" >&6
 
 if test "$cf_cv_posix_c_source" != no ; then
@@ -9484,7 +9981,7 @@
 if test -n "$cf_new_cflags" ; then
 	test -n "$verbose" && echo "	add to \$CFLAGS $cf_new_cflags" 1>&6
 
-echo "${as_me:-configure}:9487: testing add to \$CFLAGS $cf_new_cflags ..." 1>&5
+echo "${as_me:-configure}:9984: testing add to \$CFLAGS $cf_new_cflags ..." 1>&5
 
 	test -n "$CFLAGS" && CFLAGS="$CFLAGS "
 	CFLAGS="${CFLAGS}$cf_new_cflags"
@@ -9494,7 +9991,7 @@
 if test -n "$cf_new_cppflags" ; then
 	test -n "$verbose" && echo "	add to \$CPPFLAGS $cf_new_cppflags" 1>&6
 
-echo "${as_me:-configure}:9497: testing add to \$CPPFLAGS $cf_new_cppflags ..." 1>&5
+echo "${as_me:-configure}:9994: testing add to \$CPPFLAGS $cf_new_cppflags ..." 1>&5
 
 	test -n "$CPPFLAGS" && CPPFLAGS="$CPPFLAGS "
 	CPPFLAGS="${CPPFLAGS}$cf_new_cppflags"
@@ -9504,7 +10001,7 @@
 if test -n "$cf_new_extra_cppflags" ; then
 	test -n "$verbose" && echo "	add to \$EXTRA_CPPFLAGS $cf_new_extra_cppflags" 1>&6
 
-echo "${as_me:-configure}:9507: testing add to \$EXTRA_CPPFLAGS $cf_new_extra_cppflags ..." 1>&5
+echo "${as_me:-configure}:10004: testing add to \$EXTRA_CPPFLAGS $cf_new_extra_cppflags ..." 1>&5
 
 	test -n "$EXTRA_CPPFLAGS" && EXTRA_CPPFLAGS="$EXTRA_CPPFLAGS "
 	EXTRA_CPPFLAGS="${EXTRA_CPPFLAGS}$cf_new_extra_cppflags"
@@ -9514,10 +10011,10 @@
 fi
 
 if test -n "$cf_XOPEN_SOURCE" && test -z "$cf_cv_xopen_source" ; then
-	echo "$as_me:9517: checking if _XOPEN_SOURCE really is set" >&5
+	echo "$as_me:10014: checking if _XOPEN_SOURCE really is set" >&5
 echo $ECHO_N "checking if _XOPEN_SOURCE really is set... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 9520 "configure"
+#line 10017 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 int
@@ -9532,16 +10029,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:9535: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10032: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:9538: \$? = $ac_status" >&5
+  echo "$as_me:10035: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:9541: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10038: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9544: \$? = $ac_status" >&5
+  echo "$as_me:10041: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_XOPEN_SOURCE_set=yes
 else
@@ -9550,12 +10047,12 @@
 cf_XOPEN_SOURCE_set=no
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
-	echo "$as_me:9553: result: $cf_XOPEN_SOURCE_set" >&5
+	echo "$as_me:10050: result: $cf_XOPEN_SOURCE_set" >&5
 echo "${ECHO_T}$cf_XOPEN_SOURCE_set" >&6
 	if test $cf_XOPEN_SOURCE_set = yes
 	then
 		cat >conftest.$ac_ext <<_ACEOF
-#line 9558 "configure"
+#line 10055 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 int
@@ -9570,16 +10067,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:9573: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10070: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:9576: \$? = $ac_status" >&5
+  echo "$as_me:10073: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:9579: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10076: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9582: \$? = $ac_status" >&5
+  echo "$as_me:10079: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_XOPEN_SOURCE_set_ok=yes
 else
@@ -9590,19 +10087,19 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 		if test $cf_XOPEN_SOURCE_set_ok = no
 		then
-			{ echo "$as_me:9593: WARNING: _XOPEN_SOURCE is lower than requested" >&5
+			{ echo "$as_me:10090: WARNING: _XOPEN_SOURCE is lower than requested" >&5
 echo "$as_me: WARNING: _XOPEN_SOURCE is lower than requested" >&2;}
 		fi
 	else
 
-echo "$as_me:9598: checking if we should define _XOPEN_SOURCE" >&5
+echo "$as_me:10095: checking if we should define _XOPEN_SOURCE" >&5
 echo $ECHO_N "checking if we should define _XOPEN_SOURCE... $ECHO_C" >&6
 if test "${cf_cv_xopen_source+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 9605 "configure"
+#line 10102 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -9621,16 +10118,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:9624: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10121: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:9627: \$? = $ac_status" >&5
+  echo "$as_me:10124: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:9630: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10127: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9633: \$? = $ac_status" >&5
+  echo "$as_me:10130: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_xopen_source=no
 else
@@ -9642,7 +10139,7 @@
 	CPPFLAGS="${CPPFLAGS}-D_XOPEN_SOURCE=$cf_XOPEN_SOURCE"
 
 	 cat >conftest.$ac_ext <<_ACEOF
-#line 9645 "configure"
+#line 10142 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -9661,16 +10158,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:9664: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10161: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:9667: \$? = $ac_status" >&5
+  echo "$as_me:10164: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:9670: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10167: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9673: \$? = $ac_status" >&5
+  echo "$as_me:10170: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_xopen_source=no
 else
@@ -9685,7 +10182,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:9688: result: $cf_cv_xopen_source" >&5
+echo "$as_me:10185: result: $cf_cv_xopen_source" >&5
 echo "${ECHO_T}$cf_cv_xopen_source" >&6
 
 if test "$cf_cv_xopen_source" != no ; then
@@ -9807,14 +10304,14 @@
 
 # Work around breakage on OS X
 
-echo "$as_me:9810: checking if SIGWINCH is defined" >&5
+echo "$as_me:10307: checking if SIGWINCH is defined" >&5
 echo $ECHO_N "checking if SIGWINCH is defined... $ECHO_C" >&6
 if test "${cf_cv_define_sigwinch+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 9817 "configure"
+#line 10314 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -9829,23 +10326,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:9832: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10329: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:9835: \$? = $ac_status" >&5
+  echo "$as_me:10332: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:9838: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10335: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9841: \$? = $ac_status" >&5
+  echo "$as_me:10338: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_define_sigwinch=yes
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 cat >conftest.$ac_ext <<_ACEOF
-#line 9848 "configure"
+#line 10345 "configure"
 #include "confdefs.h"
 
 #undef _XOPEN_SOURCE
@@ -9863,16 +10360,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:9866: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10363: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:9869: \$? = $ac_status" >&5
+  echo "$as_me:10366: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:9872: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10369: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9875: \$? = $ac_status" >&5
+  echo "$as_me:10372: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_define_sigwinch=maybe
 else
@@ -9886,11 +10383,11 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:9889: result: $cf_cv_define_sigwinch" >&5
+echo "$as_me:10386: result: $cf_cv_define_sigwinch" >&5
 echo "${ECHO_T}$cf_cv_define_sigwinch" >&6
 
 if test "$cf_cv_define_sigwinch" = maybe ; then
-echo "$as_me:9893: checking for actual SIGWINCH definition" >&5
+echo "$as_me:10390: checking for actual SIGWINCH definition" >&5
 echo $ECHO_N "checking for actual SIGWINCH definition... $ECHO_C" >&6
 if test "${cf_cv_fixup_sigwinch+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9901,7 +10398,7 @@
 while test $cf_sigwinch != 1
 do
 	cat >conftest.$ac_ext <<_ACEOF
-#line 9904 "configure"
+#line 10401 "configure"
 #include "confdefs.h"
 
 #undef _XOPEN_SOURCE
@@ -9923,16 +10420,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:9926: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10423: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:9929: \$? = $ac_status" >&5
+  echo "$as_me:10426: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:9932: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10429: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9935: \$? = $ac_status" >&5
+  echo "$as_me:10432: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_fixup_sigwinch=$cf_sigwinch
 	 break
@@ -9946,7 +10443,7 @@
 done
 
 fi
-echo "$as_me:9949: result: $cf_cv_fixup_sigwinch" >&5
+echo "$as_me:10446: result: $cf_cv_fixup_sigwinch" >&5
 echo "${ECHO_T}$cf_cv_fixup_sigwinch" >&6
 
 	if test "$cf_cv_fixup_sigwinch" != unknown ; then
@@ -9956,13 +10453,13 @@
 
 # Checks for CODESET support.
 
-echo "$as_me:9959: checking for nl_langinfo and CODESET" >&5
+echo "$as_me:10456: checking for nl_langinfo and CODESET" >&5
 echo $ECHO_N "checking for nl_langinfo and CODESET... $ECHO_C" >&6
 if test "${am_cv_langinfo_codeset+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 9965 "configure"
+#line 10462 "configure"
 #include "confdefs.h"
 #include <langinfo.h>
 int
@@ -9974,16 +10471,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:9977: \"$ac_link\"") >&5
+if { (eval echo "$as_me:10474: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:9980: \$? = $ac_status" >&5
+  echo "$as_me:10477: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:9983: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10480: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9986: \$? = $ac_status" >&5
+  echo "$as_me:10483: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   am_cv_langinfo_codeset=yes
 else
@@ -9994,7 +10491,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:9997: result: $am_cv_langinfo_codeset" >&5
+echo "$as_me:10494: result: $am_cv_langinfo_codeset" >&5
 echo "${ECHO_T}$am_cv_langinfo_codeset" >&6
 	if test $am_cv_langinfo_codeset = yes; then
 
@@ -10008,7 +10505,7 @@
 NCURSES_OK_WCHAR_T=
 NCURSES_OK_WINT_T=
 
-echo "$as_me:10011: checking if you want wide-character code" >&5
+echo "$as_me:10508: checking if you want wide-character code" >&5
 echo $ECHO_N "checking if you want wide-character code... $ECHO_C" >&6
 
 # Check whether --enable-widec or --disable-widec was given.
@@ -10018,7 +10515,7 @@
 else
   with_widec=no
 fi;
-echo "$as_me:10021: result: $with_widec" >&5
+echo "$as_me:10518: result: $with_widec" >&5
 echo "${ECHO_T}$with_widec" >&6
 
 NCURSES_WCWIDTH_GRAPHICS=1
@@ -10042,23 +10539,23 @@
 
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:10045: checking for $ac_header" >&5
+echo "$as_me:10542: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10051 "configure"
+#line 10548 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:10055: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:10552: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:10061: \$? = $ac_status" >&5
+  echo "$as_me:10558: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -10077,7 +10574,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:10080: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:10577: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -10087,14 +10584,14 @@
 fi
 done
 
-echo "$as_me:10090: checking if wchar.h can be used as is" >&5
+echo "$as_me:10587: checking if wchar.h can be used as is" >&5
 echo $ECHO_N "checking if wchar.h can be used as is... $ECHO_C" >&6
 if test "${cf_cv_wchar_h_okay+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 10097 "configure"
+#line 10594 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -10116,16 +10613,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10119: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10616: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10122: \$? = $ac_status" >&5
+  echo "$as_me:10619: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10125: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10622: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10128: \$? = $ac_status" >&5
+  echo "$as_me:10625: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_wchar_h_okay=yes
 else
@@ -10135,16 +10632,16 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:10138: result: $cf_cv_wchar_h_okay" >&5
+echo "$as_me:10635: result: $cf_cv_wchar_h_okay" >&5
 echo "${ECHO_T}$cf_cv_wchar_h_okay" >&6
 
 if test $cf_cv_wchar_h_okay = no
 then
 
-echo "$as_me:10144: checking if we must define _XOPEN_SOURCE_EXTENDED" >&5
+echo "$as_me:10641: checking if we must define _XOPEN_SOURCE_EXTENDED" >&5
 echo $ECHO_N "checking if we must define _XOPEN_SOURCE_EXTENDED... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 10147 "configure"
+#line 10644 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 
@@ -10160,16 +10657,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10163: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10660: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10166: \$? = $ac_status" >&5
+  echo "$as_me:10663: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10169: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10666: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10172: \$? = $ac_status" >&5
+  echo "$as_me:10669: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_result=no
 else
@@ -10178,16 +10675,16 @@
 cf_result=yes
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
-echo "$as_me:10181: result: $cf_result" >&5
+echo "$as_me:10678: result: $cf_result" >&5
 echo "${ECHO_T}$cf_result" >&6
 
 if test "$cf_result" = yes ; then
 	CPPFLAGS="$CPPFLAGS -D_XOPEN_SOURCE_EXTENDED"
 elif test "x" != "x" ; then
-	echo "$as_me:10187: checking checking for compatible value versus " >&5
+	echo "$as_me:10684: checking checking for compatible value versus " >&5
 echo $ECHO_N "checking checking for compatible value versus ... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 10190 "configure"
+#line 10687 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 
@@ -10203,16 +10700,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10206: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10703: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10209: \$? = $ac_status" >&5
+  echo "$as_me:10706: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10212: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10709: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10215: \$? = $ac_status" >&5
+  echo "$as_me:10712: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_result=yes
 else
@@ -10221,7 +10718,7 @@
 cf_result=no
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
-	echo "$as_me:10224: result: $cf_result" >&5
+	echo "$as_me:10721: result: $cf_result" >&5
 echo "${ECHO_T}$cf_result" >&6
 	if test "$cf_result" = no ; then
 		# perhaps we can override it - try...
@@ -10231,7 +10728,7 @@
 
 fi
 
-echo "$as_me:10234: checking if wcwidth agrees graphics are single-width" >&5
+echo "$as_me:10731: checking if wcwidth agrees graphics are single-width" >&5
 echo $ECHO_N "checking if wcwidth agrees graphics are single-width... $ECHO_C" >&6
 if test "${cf_cv_wcwidth_graphics+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -10302,7 +10799,7 @@
   cf_cv_wcwidth_graphics=unknown
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10305 "configure"
+#line 10802 "configure"
 #include "confdefs.h"
 
 #include <locale.h>
@@ -10346,15 +10843,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:10349: \"$ac_link\"") >&5
+if { (eval echo "$as_me:10846: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:10352: \$? = $ac_status" >&5
+  echo "$as_me:10849: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:10354: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10851: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10357: \$? = $ac_status" >&5
+  echo "$as_me:10854: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_wcwidth_graphics=yes
 else
@@ -10367,7 +10864,7 @@
 fi
 
 fi
-echo "$as_me:10370: result: $cf_cv_wcwidth_graphics" >&5
+echo "$as_me:10867: result: $cf_cv_wcwidth_graphics" >&5
 echo "${ECHO_T}$cf_cv_wcwidth_graphics" >&6
 
 	test "$cf_cv_wcwidth_graphics" = no && NCURSES_WCWIDTH_GRAPHICS=0
@@ -10378,13 +10875,13 @@
 for ac_func in putwc btowc wctob mbtowc wctomb mblen mbrlen mbrtowc wcsrtombs mbsrtowcs wcstombs mbstowcs
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:10381: checking for $ac_func" >&5
+echo "$as_me:10878: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10387 "configure"
+#line 10884 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -10415,16 +10912,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:10418: \"$ac_link\"") >&5
+if { (eval echo "$as_me:10915: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:10421: \$? = $ac_status" >&5
+  echo "$as_me:10918: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:10424: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10921: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10427: \$? = $ac_status" >&5
+  echo "$as_me:10924: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -10434,7 +10931,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:10437: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:10934: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -10446,7 +10943,7 @@
 
 	if test "x$ac_cv_func_putwc" != xyes ; then
 
-echo "$as_me:10449: checking for multibyte character support" >&5
+echo "$as_me:10946: checking for multibyte character support" >&5
 echo $ECHO_N "checking for multibyte character support... $ECHO_C" >&6
 if test "${cf_cv_utf8_lib+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -10454,7 +10951,7 @@
 
 	cf_save_LIBS="$LIBS"
 	cat >conftest.$ac_ext <<_ACEOF
-#line 10457 "configure"
+#line 10954 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -10467,16 +10964,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:10470: \"$ac_link\"") >&5
+if { (eval echo "$as_me:10967: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:10473: \$? = $ac_status" >&5
+  echo "$as_me:10970: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:10476: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10973: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10479: \$? = $ac_status" >&5
+  echo "$as_me:10976: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_utf8_lib=yes
 else
@@ -10488,12 +10985,12 @@
 cf_cv_header_path_utf8=
 cf_cv_library_path_utf8=
 
-echo "${as_me:-configure}:10491: testing Starting FIND_LINKAGE(utf8,) ..." 1>&5
+echo "${as_me:-configure}:10988: testing Starting FIND_LINKAGE(utf8,) ..." 1>&5
 
 cf_save_LIBS="$LIBS"
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 10496 "configure"
+#line 10993 "configure"
 #include "confdefs.h"
 
 #include <libutf8.h>
@@ -10506,16 +11003,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:10509: \"$ac_link\"") >&5
+if { (eval echo "$as_me:11006: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:10512: \$? = $ac_status" >&5
+  echo "$as_me:11009: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:10515: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11012: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10518: \$? = $ac_status" >&5
+  echo "$as_me:11015: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 	cf_cv_find_linkage_utf8=yes
@@ -10529,7 +11026,7 @@
 LIBS="-lutf8  $cf_save_LIBS"
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 10532 "configure"
+#line 11029 "configure"
 #include "confdefs.h"
 
 #include <libutf8.h>
@@ -10542,16 +11039,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:10545: \"$ac_link\"") >&5
+if { (eval echo "$as_me:11042: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:10548: \$? = $ac_status" >&5
+  echo "$as_me:11045: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:10551: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11048: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10554: \$? = $ac_status" >&5
+  echo "$as_me:11051: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 	cf_cv_find_linkage_utf8=yes
@@ -10568,9 +11065,9 @@
 
 	test -n "$verbose" && echo "	find linkage for utf8 library" 1>&6
 
-echo "${as_me:-configure}:10571: testing find linkage for utf8 library ..." 1>&5
+echo "${as_me:-configure}:11068: testing find linkage for utf8 library ..." 1>&5
 
-echo "${as_me:-configure}:10573: testing Searching for headers in FIND_LINKAGE(utf8,) ..." 1>&5
+echo "${as_me:-configure}:11070: testing Searching for headers in FIND_LINKAGE(utf8,) ..." 1>&5
 
 	cf_save_CPPFLAGS="$CPPFLAGS"
 	cf_test_CPPFLAGS="$CPPFLAGS"
@@ -10661,7 +11158,7 @@
 		if test -d $cf_cv_header_path_utf8 ; then
 			test -n "$verbose" && echo "	... testing $cf_cv_header_path_utf8" 1>&6
 
-echo "${as_me:-configure}:10664: testing ... testing $cf_cv_header_path_utf8 ..." 1>&5
+echo "${as_me:-configure}:11161: testing ... testing $cf_cv_header_path_utf8 ..." 1>&5
 
 			CPPFLAGS="$cf_save_CPPFLAGS"
 
@@ -10669,7 +11166,7 @@
 	CPPFLAGS="${CPPFLAGS}-I$cf_cv_header_path_utf8"
 
 			cat >conftest.$ac_ext <<_ACEOF
-#line 10672 "configure"
+#line 11169 "configure"
 #include "confdefs.h"
 
 #include <libutf8.h>
@@ -10682,21 +11179,21 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10685: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11182: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10688: \$? = $ac_status" >&5
+  echo "$as_me:11185: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10691: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11188: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10694: \$? = $ac_status" >&5
+  echo "$as_me:11191: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 				test -n "$verbose" && echo "	... found utf8 headers in $cf_cv_header_path_utf8" 1>&6
 
-echo "${as_me:-configure}:10699: testing ... found utf8 headers in $cf_cv_header_path_utf8 ..." 1>&5
+echo "${as_me:-configure}:11196: testing ... found utf8 headers in $cf_cv_header_path_utf8 ..." 1>&5
 
 				cf_cv_find_linkage_utf8=maybe
 				cf_test_CPPFLAGS="$CPPFLAGS"
@@ -10714,7 +11211,7 @@
 
 	if test "$cf_cv_find_linkage_utf8" = maybe ; then
 
-echo "${as_me:-configure}:10717: testing Searching for utf8 library in FIND_LINKAGE(utf8,) ..." 1>&5
+echo "${as_me:-configure}:11214: testing Searching for utf8 library in FIND_LINKAGE(utf8,) ..." 1>&5
 
 		cf_save_LIBS="$LIBS"
 		cf_save_LDFLAGS="$LDFLAGS"
@@ -10789,13 +11286,13 @@
 				if test -d $cf_cv_library_path_utf8 ; then
 					test -n "$verbose" && echo "	... testing $cf_cv_library_path_utf8" 1>&6
 
-echo "${as_me:-configure}:10792: testing ... testing $cf_cv_library_path_utf8 ..." 1>&5
+echo "${as_me:-configure}:11289: testing ... testing $cf_cv_library_path_utf8 ..." 1>&5
 
 					CPPFLAGS="$cf_test_CPPFLAGS"
 					LIBS="-lutf8  $cf_save_LIBS"
 					LDFLAGS="$cf_save_LDFLAGS -L$cf_cv_library_path_utf8"
 					cat >conftest.$ac_ext <<_ACEOF
-#line 10798 "configure"
+#line 11295 "configure"
 #include "confdefs.h"
 
 #include <libutf8.h>
@@ -10808,21 +11305,21 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:10811: \"$ac_link\"") >&5
+if { (eval echo "$as_me:11308: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:10814: \$? = $ac_status" >&5
+  echo "$as_me:11311: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:10817: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11314: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10820: \$? = $ac_status" >&5
+  echo "$as_me:11317: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 					test -n "$verbose" && echo "	... found utf8 library in $cf_cv_library_path_utf8" 1>&6
 
-echo "${as_me:-configure}:10825: testing ... found utf8 library in $cf_cv_library_path_utf8 ..." 1>&5
+echo "${as_me:-configure}:11322: testing ... found utf8 library in $cf_cv_library_path_utf8 ..." 1>&5
 
 					cf_cv_find_linkage_utf8=yes
 					cf_cv_library_file_utf8="-lutf8"
@@ -10864,7 +11361,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:10867: result: $cf_cv_utf8_lib" >&5
+echo "$as_me:11364: result: $cf_cv_utf8_lib" >&5
 echo "${ECHO_T}$cf_cv_utf8_lib" >&6
 
 # HAVE_LIBUTF8_H is used by ncurses if curses.h is shared between
@@ -10902,7 +11399,7 @@
 	CPPFLAGS="${CPPFLAGS}-I$cf_add_incdir"
 
 			  cat >conftest.$ac_ext <<_ACEOF
-#line 10905 "configure"
+#line 11402 "configure"
 #include "confdefs.h"
 #include <stdio.h>
 int
@@ -10914,16 +11411,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10917: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11414: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10920: \$? = $ac_status" >&5
+  echo "$as_me:11417: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10923: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11420: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10926: \$? = $ac_status" >&5
+  echo "$as_me:11423: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   :
 else
@@ -10940,7 +11437,7 @@
 		if test "$cf_have_incdir" = no ; then
 		  test -n "$verbose" && echo "	adding $cf_add_incdir to include-path" 1>&6
 
-echo "${as_me:-configure}:10943: testing adding $cf_add_incdir to include-path ..." 1>&5
+echo "${as_me:-configure}:11440: testing adding $cf_add_incdir to include-path ..." 1>&5
 
 		  CPPFLAGS="$CPPFLAGS -I$cf_add_incdir"
 
@@ -10976,7 +11473,7 @@
 			if test "$cf_have_libdir" = no ; then
 				test -n "$verbose" && echo "	adding $cf_add_libdir to library-path" 1>&6
 
-echo "${as_me:-configure}:10979: testing adding $cf_add_libdir to library-path ..." 1>&5
+echo "${as_me:-configure}:11476: testing adding $cf_add_libdir to library-path ..." 1>&5
 
 				LDFLAGS="-L$cf_add_libdir $LDFLAGS"
 			fi
@@ -11008,14 +11505,14 @@
 	fi
 
 # This is needed on Tru64 5.0 to declare mbstate_t
-echo "$as_me:11011: checking if we must include wchar.h to declare mbstate_t" >&5
+echo "$as_me:11508: checking if we must include wchar.h to declare mbstate_t" >&5
 echo $ECHO_N "checking if we must include wchar.h to declare mbstate_t... $ECHO_C" >&6
 if test "${cf_cv_mbstate_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 11018 "configure"
+#line 11515 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -11033,23 +11530,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11036: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11533: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11039: \$? = $ac_status" >&5
+  echo "$as_me:11536: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11042: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11539: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11045: \$? = $ac_status" >&5
+  echo "$as_me:11542: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_mbstate_t=no
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 cat >conftest.$ac_ext <<_ACEOF
-#line 11052 "configure"
+#line 11549 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -11068,16 +11565,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11071: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11568: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11074: \$? = $ac_status" >&5
+  echo "$as_me:11571: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11077: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11574: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11080: \$? = $ac_status" >&5
+  echo "$as_me:11577: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_mbstate_t=yes
 else
@@ -11089,7 +11586,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:11092: result: $cf_cv_mbstate_t" >&5
+echo "$as_me:11589: result: $cf_cv_mbstate_t" >&5
 echo "${ECHO_T}$cf_cv_mbstate_t" >&6
 
 if test "$cf_cv_mbstate_t" = yes ; then
@@ -11107,14 +11604,14 @@
 fi
 
 # This is needed on Tru64 5.0 to declare wchar_t
-echo "$as_me:11110: checking if we must include wchar.h to declare wchar_t" >&5
+echo "$as_me:11607: checking if we must include wchar.h to declare wchar_t" >&5
 echo $ECHO_N "checking if we must include wchar.h to declare wchar_t... $ECHO_C" >&6
 if test "${cf_cv_wchar_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 11117 "configure"
+#line 11614 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -11132,23 +11629,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11135: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11632: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11138: \$? = $ac_status" >&5
+  echo "$as_me:11635: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11141: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11638: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11144: \$? = $ac_status" >&5
+  echo "$as_me:11641: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_wchar_t=no
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 cat >conftest.$ac_ext <<_ACEOF
-#line 11151 "configure"
+#line 11648 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -11167,16 +11664,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11170: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11667: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11173: \$? = $ac_status" >&5
+  echo "$as_me:11670: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11176: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11673: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11179: \$? = $ac_status" >&5
+  echo "$as_me:11676: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_wchar_t=yes
 else
@@ -11188,7 +11685,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:11191: result: $cf_cv_wchar_t" >&5
+echo "$as_me:11688: result: $cf_cv_wchar_t" >&5
 echo "${ECHO_T}$cf_cv_wchar_t" >&6
 
 if test "$cf_cv_wchar_t" = yes ; then
@@ -11211,14 +11708,14 @@
 fi
 
 # This is needed on Tru64 5.0 to declare wint_t
-echo "$as_me:11214: checking if we must include wchar.h to declare wint_t" >&5
+echo "$as_me:11711: checking if we must include wchar.h to declare wint_t" >&5
 echo $ECHO_N "checking if we must include wchar.h to declare wint_t... $ECHO_C" >&6
 if test "${cf_cv_wint_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 11221 "configure"
+#line 11718 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -11236,23 +11733,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11239: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11736: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11242: \$? = $ac_status" >&5
+  echo "$as_me:11739: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11245: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11742: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11248: \$? = $ac_status" >&5
+  echo "$as_me:11745: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_wint_t=no
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 cat >conftest.$ac_ext <<_ACEOF
-#line 11255 "configure"
+#line 11752 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -11271,16 +11768,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11274: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11771: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11277: \$? = $ac_status" >&5
+  echo "$as_me:11774: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11280: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11777: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11283: \$? = $ac_status" >&5
+  echo "$as_me:11780: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_wint_t=yes
 else
@@ -11292,7 +11789,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:11295: result: $cf_cv_wint_t" >&5
+echo "$as_me:11792: result: $cf_cv_wint_t" >&5
 echo "${ECHO_T}$cf_cv_wint_t" >&6
 
 if test "$cf_cv_wint_t" = yes ; then
@@ -11324,7 +11821,7 @@
 fi
 
 ###   use option --disable-lp64 to allow long chtype
-echo "$as_me:11327: checking whether to enable _LP64 definition in curses.h" >&5
+echo "$as_me:11824: checking whether to enable _LP64 definition in curses.h" >&5
 echo $ECHO_N "checking whether to enable _LP64 definition in curses.h... $ECHO_C" >&6
 
 # Check whether --enable-lp64 or --disable-lp64 was given.
@@ -11334,7 +11831,7 @@
 else
   with_lp64=$cf_dft_with_lp64
 fi;
-echo "$as_me:11337: result: $with_lp64" >&5
+echo "$as_me:11834: result: $with_lp64" >&5
 echo "${ECHO_T}$with_lp64" >&6
 
 if test "x$with_lp64" = xyes ; then
@@ -11350,7 +11847,7 @@
 fi;
 if test "$enable_largefile" != no; then
 
-  echo "$as_me:11353: checking for special C compiler options needed for large files" >&5
+  echo "$as_me:11850: checking for special C compiler options needed for large files" >&5
 echo $ECHO_N "checking for special C compiler options needed for large files... $ECHO_C" >&6
 if test "${ac_cv_sys_largefile_CC+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -11362,7 +11859,7 @@
      	 # IRIX 6.2 and later do not support large files by default,
      	 # so use the C compiler's -n32 option if that helps.
          cat >conftest.$ac_ext <<_ACEOF
-#line 11365 "configure"
+#line 11862 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
  /* Check that off_t can represent 2**63 - 1 correctly.
@@ -11382,16 +11879,16 @@
 }
 _ACEOF
      	 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11385: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11882: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11388: \$? = $ac_status" >&5
+  echo "$as_me:11885: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11391: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11888: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11394: \$? = $ac_status" >&5
+  echo "$as_me:11891: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   break
 else
@@ -11401,16 +11898,16 @@
 rm -f conftest.$ac_objext
      	 CC="$CC -n32"
      	 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11404: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11901: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11407: \$? = $ac_status" >&5
+  echo "$as_me:11904: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11410: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11907: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11413: \$? = $ac_status" >&5
+  echo "$as_me:11910: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sys_largefile_CC=' -n32'; break
 else
@@ -11424,13 +11921,13 @@
        rm -f conftest.$ac_ext
     fi
 fi
-echo "$as_me:11427: result: $ac_cv_sys_largefile_CC" >&5
+echo "$as_me:11924: result: $ac_cv_sys_largefile_CC" >&5
 echo "${ECHO_T}$ac_cv_sys_largefile_CC" >&6
   if test "$ac_cv_sys_largefile_CC" != no; then
     CC=$CC$ac_cv_sys_largefile_CC
   fi
 
-  echo "$as_me:11433: checking for _FILE_OFFSET_BITS value needed for large files" >&5
+  echo "$as_me:11930: checking for _FILE_OFFSET_BITS value needed for large files" >&5
 echo $ECHO_N "checking for _FILE_OFFSET_BITS value needed for large files... $ECHO_C" >&6
 if test "${ac_cv_sys_file_offset_bits+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -11438,7 +11935,7 @@
   while :; do
   ac_cv_sys_file_offset_bits=no
   cat >conftest.$ac_ext <<_ACEOF
-#line 11441 "configure"
+#line 11938 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
  /* Check that off_t can represent 2**63 - 1 correctly.
@@ -11458,16 +11955,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11461: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11958: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11464: \$? = $ac_status" >&5
+  echo "$as_me:11961: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11467: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11964: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11470: \$? = $ac_status" >&5
+  echo "$as_me:11967: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   break
 else
@@ -11476,7 +11973,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
   cat >conftest.$ac_ext <<_ACEOF
-#line 11479 "configure"
+#line 11976 "configure"
 #include "confdefs.h"
 #define _FILE_OFFSET_BITS 64
 #include <sys/types.h>
@@ -11497,16 +11994,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11500: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11997: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11503: \$? = $ac_status" >&5
+  echo "$as_me:12000: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11506: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12003: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11509: \$? = $ac_status" >&5
+  echo "$as_me:12006: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sys_file_offset_bits=64; break
 else
@@ -11517,7 +12014,7 @@
   break
 done
 fi
-echo "$as_me:11520: result: $ac_cv_sys_file_offset_bits" >&5
+echo "$as_me:12017: result: $ac_cv_sys_file_offset_bits" >&5
 echo "${ECHO_T}$ac_cv_sys_file_offset_bits" >&6
 if test "$ac_cv_sys_file_offset_bits" != no; then
 
@@ -11527,7 +12024,7 @@
 
 fi
 rm -rf conftest*
-  echo "$as_me:11530: checking for _LARGE_FILES value needed for large files" >&5
+  echo "$as_me:12027: checking for _LARGE_FILES value needed for large files" >&5
 echo $ECHO_N "checking for _LARGE_FILES value needed for large files... $ECHO_C" >&6
 if test "${ac_cv_sys_large_files+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -11535,7 +12032,7 @@
   while :; do
   ac_cv_sys_large_files=no
   cat >conftest.$ac_ext <<_ACEOF
-#line 11538 "configure"
+#line 12035 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
  /* Check that off_t can represent 2**63 - 1 correctly.
@@ -11555,16 +12052,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11558: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12055: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11561: \$? = $ac_status" >&5
+  echo "$as_me:12058: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11564: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12061: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11567: \$? = $ac_status" >&5
+  echo "$as_me:12064: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   break
 else
@@ -11573,7 +12070,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
   cat >conftest.$ac_ext <<_ACEOF
-#line 11576 "configure"
+#line 12073 "configure"
 #include "confdefs.h"
 #define _LARGE_FILES 1
 #include <sys/types.h>
@@ -11594,16 +12091,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11597: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12094: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11600: \$? = $ac_status" >&5
+  echo "$as_me:12097: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11603: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12100: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11606: \$? = $ac_status" >&5
+  echo "$as_me:12103: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sys_large_files=1; break
 else
@@ -11614,7 +12111,7 @@
   break
 done
 fi
-echo "$as_me:11617: result: $ac_cv_sys_large_files" >&5
+echo "$as_me:12114: result: $ac_cv_sys_large_files" >&5
 echo "${ECHO_T}$ac_cv_sys_large_files" >&6
 if test "$ac_cv_sys_large_files" != no; then
 
@@ -11627,7 +12124,7 @@
 fi
 
 	if test "$enable_largefile" != no ; then
-	echo "$as_me:11630: checking for _LARGEFILE_SOURCE value needed for large files" >&5
+	echo "$as_me:12127: checking for _LARGEFILE_SOURCE value needed for large files" >&5
 echo $ECHO_N "checking for _LARGEFILE_SOURCE value needed for large files... $ECHO_C" >&6
 if test "${ac_cv_sys_largefile_source+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -11635,7 +12132,7 @@
   while :; do
   ac_cv_sys_largefile_source=no
   cat >conftest.$ac_ext <<_ACEOF
-#line 11638 "configure"
+#line 12135 "configure"
 #include "confdefs.h"
 #include <stdio.h>
 int
@@ -11647,16 +12144,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11650: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12147: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11653: \$? = $ac_status" >&5
+  echo "$as_me:12150: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11656: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12153: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11659: \$? = $ac_status" >&5
+  echo "$as_me:12156: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   break
 else
@@ -11665,7 +12162,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
   cat >conftest.$ac_ext <<_ACEOF
-#line 11668 "configure"
+#line 12165 "configure"
 #include "confdefs.h"
 #define _LARGEFILE_SOURCE 1
 #include <stdio.h>
@@ -11678,16 +12175,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11681: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12178: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11684: \$? = $ac_status" >&5
+  echo "$as_me:12181: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11687: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12184: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11690: \$? = $ac_status" >&5
+  echo "$as_me:12187: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sys_largefile_source=1; break
 else
@@ -11698,7 +12195,7 @@
   break
 done
 fi
-echo "$as_me:11701: result: $ac_cv_sys_largefile_source" >&5
+echo "$as_me:12198: result: $ac_cv_sys_largefile_source" >&5
 echo "${ECHO_T}$ac_cv_sys_largefile_source" >&6
 if test "$ac_cv_sys_largefile_source" != no; then
 
@@ -11712,13 +12209,13 @@
 # We used to try defining _XOPEN_SOURCE=500 too, to work around a bug
 # in glibc 2.1.3, but that breaks too many other things.
 # If you want fseeko and ftello with glibc, upgrade to a fixed glibc.
-echo "$as_me:11715: checking for fseeko" >&5
+echo "$as_me:12212: checking for fseeko" >&5
 echo $ECHO_N "checking for fseeko... $ECHO_C" >&6
 if test "${ac_cv_func_fseeko+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 11721 "configure"
+#line 12218 "configure"
 #include "confdefs.h"
 #include <stdio.h>
 int
@@ -11730,16 +12227,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:11733: \"$ac_link\"") >&5
+if { (eval echo "$as_me:12230: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:11736: \$? = $ac_status" >&5
+  echo "$as_me:12233: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:11739: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12236: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11742: \$? = $ac_status" >&5
+  echo "$as_me:12239: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_fseeko=yes
 else
@@ -11749,7 +12246,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:11752: result: $ac_cv_func_fseeko" >&5
+echo "$as_me:12249: result: $ac_cv_func_fseeko" >&5
 echo "${ECHO_T}$ac_cv_func_fseeko" >&6
 if test $ac_cv_func_fseeko = yes; then
 
@@ -11788,14 +12285,14 @@
 
 	fi
 
-	echo "$as_me:11791: checking whether to use struct dirent64" >&5
+	echo "$as_me:12288: checking whether to use struct dirent64" >&5
 echo $ECHO_N "checking whether to use struct dirent64... $ECHO_C" >&6
 if test "${cf_cv_struct_dirent64+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 11798 "configure"
+#line 12295 "configure"
 #include "confdefs.h"
 
 #pragma GCC diagnostic error "-Wincompatible-pointer-types"
@@ -11817,16 +12314,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11820: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12317: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11823: \$? = $ac_status" >&5
+  echo "$as_me:12320: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11826: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12323: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11829: \$? = $ac_status" >&5
+  echo "$as_me:12326: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_struct_dirent64=yes
 else
@@ -11837,7 +12334,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11840: result: $cf_cv_struct_dirent64" >&5
+echo "$as_me:12337: result: $cf_cv_struct_dirent64" >&5
 echo "${ECHO_T}$cf_cv_struct_dirent64" >&6
 	test "$cf_cv_struct_dirent64" = yes &&
 cat >>confdefs.h <<\EOF
@@ -11847,7 +12344,7 @@
 	fi
 
 ###   use option --disable-tparm-varargs to make tparm() conform to X/Open
-echo "$as_me:11850: checking if you want tparm not to use X/Open fixed-parameter list" >&5
+echo "$as_me:12347: checking if you want tparm not to use X/Open fixed-parameter list" >&5
 echo $ECHO_N "checking if you want tparm not to use X/Open fixed-parameter list... $ECHO_C" >&6
 
 # Check whether --enable-tparm-varargs or --disable-tparm-varargs was given.
@@ -11857,14 +12354,14 @@
 else
   with_tparm_varargs=yes
 fi;
-echo "$as_me:11860: result: $with_tparm_varargs" >&5
+echo "$as_me:12357: result: $with_tparm_varargs" >&5
 echo "${ECHO_T}$with_tparm_varargs" >&6
 NCURSES_TPARM_VARARGS=0
 test "x$with_tparm_varargs" = xyes && NCURSES_TPARM_VARARGS=1
 
 ###   use option --disable-tic-depends to make libtic not explicitly depend on ncurses/ncursesw
 if test "$with_ticlib" != no ; then
-echo "$as_me:11867: checking if you want tic library to use explicit dependency on ncurses$LIB_SUFFIX library" >&5
+echo "$as_me:12364: checking if you want tic library to use explicit dependency on ncurses$LIB_SUFFIX library" >&5
 echo $ECHO_N "checking if you want tic library to use explicit dependency on ncurses$LIB_SUFFIX library... $ECHO_C" >&6
 
 # Check whether --enable-tic-depends or --disable-tic-depends was given.
@@ -11874,14 +12371,14 @@
 else
   with_tic_depends=yes
 fi;
-echo "$as_me:11877: result: $with_tic_depends" >&5
+echo "$as_me:12374: result: $with_tic_depends" >&5
 echo "${ECHO_T}$with_tic_depends" >&6
 else
 	with_tic_depends=no
 fi
 
 ###   use option --disable-wattr-macros to suppress wattr* macros from curses.h
-echo "$as_me:11884: checking if you want to suppress wattr* macros to help with ncurses5/ncurses6 transition" >&5
+echo "$as_me:12381: checking if you want to suppress wattr* macros to help with ncurses5/ncurses6 transition" >&5
 echo $ECHO_N "checking if you want to suppress wattr* macros to help with ncurses5/ncurses6 transition... $ECHO_C" >&6
 
 # Check whether --enable-wattr-macros or --disable-wattr-macros was given.
@@ -11893,15 +12390,15 @@
 fi;
 if [ "x$with_wattr_macros" != xyes ]; then
 	NCURSES_WATTR_MACROS=0
-	echo "$as_me:11896: result: yes" >&5
+	echo "$as_me:12393: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
 	NCURSES_WATTR_MACROS=1
-	echo "$as_me:11900: result: no" >&5
+	echo "$as_me:12397: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
-echo "$as_me:11904: checking for X11 rgb file" >&5
+echo "$as_me:12401: checking for X11 rgb file" >&5
 echo $ECHO_N "checking for X11 rgb file... $ECHO_C" >&6
 
 # Check whether --with-x11-rgb or --without-x11-rgb was given.
@@ -11965,7 +12462,7 @@
 	cf_path=`echo $cf_path | sed -e s%NONE%$cf_path_syntax%`
 	;;
 (*)
-	{ { echo "$as_me:11968: error: expected a pathname, not \"$cf_path\"" >&5
+	{ { echo "$as_me:12465: error: expected a pathname, not \"$cf_path\"" >&5
 echo "$as_me: error: expected a pathname, not \"$cf_path\"" >&2;}
    { (exit 1); exit 1; }; }
 	;;
@@ -11973,7 +12470,7 @@
 
 fi
 
-echo "$as_me:11976: result: $RGB_PATH" >&5
+echo "$as_me:12473: result: $RGB_PATH" >&5
 echo "${ECHO_T}$RGB_PATH" >&6
 
 cat >>confdefs.h <<EOF
@@ -11987,7 +12484,7 @@
 fi
 
 ###   use option --with-bool to override bool's type
-echo "$as_me:11990: checking for type of bool" >&5
+echo "$as_me:12487: checking for type of bool" >&5
 echo $ECHO_N "checking for type of bool... $ECHO_C" >&6
 
 # Check whether --with-bool or --without-bool was given.
@@ -11997,10 +12494,10 @@
 else
   NCURSES_BOOL=auto
 fi;
-echo "$as_me:12000: result: $NCURSES_BOOL" >&5
+echo "$as_me:12497: result: $NCURSES_BOOL" >&5
 echo "${ECHO_T}$NCURSES_BOOL" >&6
 
-echo "$as_me:12003: checking for alternate terminal capabilities file" >&5
+echo "$as_me:12500: checking for alternate terminal capabilities file" >&5
 echo $ECHO_N "checking for alternate terminal capabilities file... $ECHO_C" >&6
 
 # Check whether --with-caps or --without-caps was given.
@@ -12011,11 +12508,11 @@
   TERMINFO_CAPS=Caps
 fi;
 test -f "${srcdir}/include/${TERMINFO_CAPS}" || TERMINFO_CAPS=Caps
-echo "$as_me:12014: result: $TERMINFO_CAPS" >&5
+echo "$as_me:12511: result: $TERMINFO_CAPS" >&5
 echo "${ECHO_T}$TERMINFO_CAPS" >&6
 
 ###   use option --with-chtype to override chtype's type
-echo "$as_me:12018: checking for type of chtype" >&5
+echo "$as_me:12515: checking for type of chtype" >&5
 echo $ECHO_N "checking for type of chtype... $ECHO_C" >&6
 
 # Check whether --with-chtype or --without-chtype was given.
@@ -12025,11 +12522,11 @@
 else
   NCURSES_CHTYPE=$cf_dft_chtype
 fi;
-echo "$as_me:12028: result: $NCURSES_CHTYPE" >&5
+echo "$as_me:12525: result: $NCURSES_CHTYPE" >&5
 echo "${ECHO_T}$NCURSES_CHTYPE" >&6
 
 ###   use option --with-ospeed to override ospeed's type
-echo "$as_me:12032: checking for type of ospeed" >&5
+echo "$as_me:12529: checking for type of ospeed" >&5
 echo $ECHO_N "checking for type of ospeed... $ECHO_C" >&6
 
 # Check whether --with-ospeed or --without-ospeed was given.
@@ -12039,11 +12536,11 @@
 else
   NCURSES_OSPEED=short
 fi;
-echo "$as_me:12042: result: $NCURSES_OSPEED" >&5
+echo "$as_me:12539: result: $NCURSES_OSPEED" >&5
 echo "${ECHO_T}$NCURSES_OSPEED" >&6
 
 ###   use option --with-mmask-t to override mmask_t's type
-echo "$as_me:12046: checking for type of mmask_t" >&5
+echo "$as_me:12543: checking for type of mmask_t" >&5
 echo $ECHO_N "checking for type of mmask_t... $ECHO_C" >&6
 
 # Check whether --with-mmask-t or --without-mmask-t was given.
@@ -12053,11 +12550,11 @@
 else
   NCURSES_MMASK_T=$cf_dft_mmask_t
 fi;
-echo "$as_me:12056: result: $NCURSES_MMASK_T" >&5
+echo "$as_me:12553: result: $NCURSES_MMASK_T" >&5
 echo "${ECHO_T}$NCURSES_MMASK_T" >&6
 
 ###   use option --with-ccharw-max to override CCHARW_MAX size
-echo "$as_me:12060: checking for size CCHARW_MAX" >&5
+echo "$as_me:12557: checking for size CCHARW_MAX" >&5
 echo $ECHO_N "checking for size CCHARW_MAX... $ECHO_C" >&6
 
 # Check whether --with-ccharw-max or --without-ccharw-max was given.
@@ -12067,16 +12564,16 @@
 else
   NCURSES_CCHARW_MAX=5
 fi;
-echo "$as_me:12070: result: $NCURSES_CCHARW_MAX" >&5
+echo "$as_me:12567: result: $NCURSES_CCHARW_MAX" >&5
 echo "${ECHO_T}$NCURSES_CCHARW_MAX" >&6
 
-echo "$as_me:12073: checking for ANSI C header files" >&5
+echo "$as_me:12570: checking for ANSI C header files" >&5
 echo $ECHO_N "checking for ANSI C header files... $ECHO_C" >&6
 if test "${ac_cv_header_stdc+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 12079 "configure"
+#line 12576 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 #include <stdarg.h>
@@ -12084,13 +12581,13 @@
 #include <float.h>
 
 _ACEOF
-if { (eval echo "$as_me:12087: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:12584: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:12093: \$? = $ac_status" >&5
+  echo "$as_me:12590: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -12112,7 +12609,7 @@
 if test $ac_cv_header_stdc = yes; then
   # SunOS 4.x string.h does not declare mem*, contrary to ANSI.
   cat >conftest.$ac_ext <<_ACEOF
-#line 12115 "configure"
+#line 12612 "configure"
 #include "confdefs.h"
 #include <string.h>
 
@@ -12130,7 +12627,7 @@
 if test $ac_cv_header_stdc = yes; then
   # ISC 2.0.2 stdlib.h does not declare free, contrary to ANSI.
   cat >conftest.$ac_ext <<_ACEOF
-#line 12133 "configure"
+#line 12630 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 
@@ -12151,7 +12648,7 @@
   :
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 12154 "configure"
+#line 12651 "configure"
 #include "confdefs.h"
 #include <ctype.h>
 #if ((' ' & 0x0FF) == 0x020)
@@ -12177,15 +12674,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:12180: \"$ac_link\"") >&5
+if { (eval echo "$as_me:12677: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:12183: \$? = $ac_status" >&5
+  echo "$as_me:12680: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:12185: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12682: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12188: \$? = $ac_status" >&5
+  echo "$as_me:12685: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   :
 else
@@ -12198,7 +12695,7 @@
 fi
 fi
 fi
-echo "$as_me:12201: result: $ac_cv_header_stdc" >&5
+echo "$as_me:12698: result: $ac_cv_header_stdc" >&5
 echo "${ECHO_T}$ac_cv_header_stdc" >&6
 if test $ac_cv_header_stdc = yes; then
 
@@ -12214,28 +12711,28 @@
                   inttypes.h stdint.h unistd.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:12217: checking for $ac_header" >&5
+echo "$as_me:12714: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 12223 "configure"
+#line 12720 "configure"
 #include "confdefs.h"
 $ac_includes_default
 #include <$ac_header>
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12229: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12726: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12232: \$? = $ac_status" >&5
+  echo "$as_me:12729: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12235: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12732: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12238: \$? = $ac_status" >&5
+  echo "$as_me:12735: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_Header=yes"
 else
@@ -12245,7 +12742,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:12248: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:12745: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -12255,13 +12752,13 @@
 fi
 done
 
-echo "$as_me:12258: checking for signed char" >&5
+echo "$as_me:12755: checking for signed char" >&5
 echo $ECHO_N "checking for signed char... $ECHO_C" >&6
 if test "${ac_cv_type_signed_char+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 12264 "configure"
+#line 12761 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -12276,16 +12773,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12279: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12776: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12282: \$? = $ac_status" >&5
+  echo "$as_me:12779: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12285: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12782: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12288: \$? = $ac_status" >&5
+  echo "$as_me:12785: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_signed_char=yes
 else
@@ -12295,10 +12792,10 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:12298: result: $ac_cv_type_signed_char" >&5
+echo "$as_me:12795: result: $ac_cv_type_signed_char" >&5
 echo "${ECHO_T}$ac_cv_type_signed_char" >&6
 
-echo "$as_me:12301: checking size of signed char" >&5
+echo "$as_me:12798: checking size of signed char" >&5
 echo $ECHO_N "checking size of signed char... $ECHO_C" >&6
 if test "${ac_cv_sizeof_signed_char+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -12307,7 +12804,7 @@
   if test "$cross_compiling" = yes; then
   # Depending upon the size, compute the lo and hi bounds.
 cat >conftest.$ac_ext <<_ACEOF
-#line 12310 "configure"
+#line 12807 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -12319,21 +12816,21 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12322: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12819: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12325: \$? = $ac_status" >&5
+  echo "$as_me:12822: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12328: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12825: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12331: \$? = $ac_status" >&5
+  echo "$as_me:12828: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=0 ac_mid=0
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 12336 "configure"
+#line 12833 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -12345,16 +12842,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12348: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12845: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12351: \$? = $ac_status" >&5
+  echo "$as_me:12848: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12354: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12851: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12357: \$? = $ac_status" >&5
+  echo "$as_me:12854: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid; break
 else
@@ -12370,7 +12867,7 @@
 ac_hi=-1 ac_mid=-1
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 12373 "configure"
+#line 12870 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -12382,16 +12879,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12385: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12882: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12388: \$? = $ac_status" >&5
+  echo "$as_me:12885: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12391: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12888: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12394: \$? = $ac_status" >&5
+  echo "$as_me:12891: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=$ac_mid; break
 else
@@ -12407,7 +12904,7 @@
 while test "x$ac_lo" != "x$ac_hi"; do
   ac_mid=`expr '(' $ac_hi - $ac_lo ')' / 2 + $ac_lo`
   cat >conftest.$ac_ext <<_ACEOF
-#line 12410 "configure"
+#line 12907 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -12419,16 +12916,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12422: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12919: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12425: \$? = $ac_status" >&5
+  echo "$as_me:12922: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12428: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12925: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12431: \$? = $ac_status" >&5
+  echo "$as_me:12928: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid
 else
@@ -12441,12 +12938,12 @@
 ac_cv_sizeof_signed_char=$ac_lo
 else
   if test "$cross_compiling" = yes; then
-  { { echo "$as_me:12444: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:12941: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 12449 "configure"
+#line 12946 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -12462,15 +12959,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:12465: \"$ac_link\"") >&5
+if { (eval echo "$as_me:12962: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:12468: \$? = $ac_status" >&5
+  echo "$as_me:12965: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:12470: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12967: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12473: \$? = $ac_status" >&5
+  echo "$as_me:12970: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sizeof_signed_char=`cat conftest.val`
 else
@@ -12486,7 +12983,7 @@
   ac_cv_sizeof_signed_char=0
 fi
 fi
-echo "$as_me:12489: result: $ac_cv_sizeof_signed_char" >&5
+echo "$as_me:12986: result: $ac_cv_sizeof_signed_char" >&5
 echo "${ECHO_T}$ac_cv_sizeof_signed_char" >&6
 cat >>confdefs.h <<EOF
 #define SIZEOF_SIGNED_CHAR $ac_cv_sizeof_signed_char
@@ -12497,7 +12994,7 @@
 else
 	NCURSES_SBOOL="char"
 fi
-echo "$as_me:12500: checking if you want to use signed Boolean array in term.h" >&5
+echo "$as_me:12997: checking if you want to use signed Boolean array in term.h" >&5
 echo $ECHO_N "checking if you want to use signed Boolean array in term.h... $ECHO_C" >&6
 
 # Check whether --enable-signed-char or --disable-signed-char was given.
@@ -12507,12 +13004,12 @@
 else
   with_signed_char=no
 fi;
-echo "$as_me:12510: result: $with_signed_char" >&5
+echo "$as_me:13007: result: $with_signed_char" >&5
 echo "${ECHO_T}$with_signed_char" >&6
 test "x$with_signed_char" != xyes && NCURSES_SBOOL="char"
 
 ###   use option --with-tparm-arg to override tparm's argument type
-echo "$as_me:12515: checking for type of tparm args" >&5
+echo "$as_me:13012: checking for type of tparm args" >&5
 echo $ECHO_N "checking for type of tparm args... $ECHO_C" >&6
 
 # Check whether --with-tparm-arg or --without-tparm-arg was given.
@@ -12522,11 +13019,11 @@
 else
   NCURSES_TPARM_ARG=$cf_dft_tparm_arg
 fi;
-echo "$as_me:12525: result: $NCURSES_TPARM_ARG" >&5
+echo "$as_me:13022: result: $NCURSES_TPARM_ARG" >&5
 echo "${ECHO_T}$NCURSES_TPARM_ARG" >&6
 
 ### Enable compiling-in rcs id's
-echo "$as_me:12529: checking if RCS identifiers should be compiled-in" >&5
+echo "$as_me:13026: checking if RCS identifiers should be compiled-in" >&5
 echo $ECHO_N "checking if RCS identifiers should be compiled-in... $ECHO_C" >&6
 
 # Check whether --with-rcs-ids or --without-rcs-ids was given.
@@ -12536,7 +13033,7 @@
 else
   with_rcs_ids=no
 fi;
-echo "$as_me:12539: result: $with_rcs_ids" >&5
+echo "$as_me:13036: result: $with_rcs_ids" >&5
 echo "${ECHO_T}$with_rcs_ids" >&6
 test "x$with_rcs_ids" = xyes &&
 cat >>confdefs.h <<\EOF
@@ -12545,7 +13042,7 @@
 
 ###############################################################################
 
-echo "$as_me:12548: checking format of man-pages" >&5
+echo "$as_me:13045: checking format of man-pages" >&5
 echo $ECHO_N "checking format of man-pages... $ECHO_C" >&6
 
 # Check whether --with-manpage-format or --without-manpage-format was given.
@@ -12634,14 +13131,14 @@
 	;;
 esac
 
-echo "$as_me:12637: result: $MANPAGE_FORMAT" >&5
+echo "$as_me:13134: result: $MANPAGE_FORMAT" >&5
 echo "${ECHO_T}$MANPAGE_FORMAT" >&6
 if test -n "$cf_unknown" ; then
-	{ echo "$as_me:12640: WARNING: Unexpected manpage-format $cf_unknown" >&5
+	{ echo "$as_me:13137: WARNING: Unexpected manpage-format $cf_unknown" >&5
 echo "$as_me: WARNING: Unexpected manpage-format $cf_unknown" >&2;}
 fi
 
-echo "$as_me:12644: checking for manpage renaming" >&5
+echo "$as_me:13141: checking for manpage renaming" >&5
 echo $ECHO_N "checking for manpage renaming... $ECHO_C" >&6
 
 # Check whether --with-manpage-renames or --without-manpage-renames was given.
@@ -12669,7 +13166,7 @@
 	if test -f $srcdir/man/$MANPAGE_RENAMES ; then
 		MANPAGE_RENAMES=`cd $srcdir/man && pwd`/$MANPAGE_RENAMES
 	elif test ! -f $MANPAGE_RENAMES ; then
-		{ { echo "$as_me:12672: error: not a filename: $MANPAGE_RENAMES" >&5
+		{ { echo "$as_me:13169: error: not a filename: $MANPAGE_RENAMES" >&5
 echo "$as_me: error: not a filename: $MANPAGE_RENAMES" >&2;}
    { (exit 1); exit 1; }; }
 	fi
@@ -12683,10 +13180,10 @@
 	fi
 fi
 
-echo "$as_me:12686: result: $MANPAGE_RENAMES" >&5
+echo "$as_me:13183: result: $MANPAGE_RENAMES" >&5
 echo "${ECHO_T}$MANPAGE_RENAMES" >&6
 
-echo "$as_me:12689: checking if manpage aliases will be installed" >&5
+echo "$as_me:13186: checking if manpage aliases will be installed" >&5
 echo $ECHO_N "checking if manpage aliases will be installed... $ECHO_C" >&6
 
 # Check whether --with-manpage-aliases or --without-manpage-aliases was given.
@@ -12697,7 +13194,7 @@
   MANPAGE_ALIASES=yes
 fi;
 
-echo "$as_me:12700: result: $MANPAGE_ALIASES" >&5
+echo "$as_me:13197: result: $MANPAGE_ALIASES" >&5
 echo "${ECHO_T}$MANPAGE_ALIASES" >&6
 
 case "x$LN_S" in
@@ -12711,7 +13208,7 @@
 
 MANPAGE_SYMLINKS=no
 if test "$MANPAGE_ALIASES" = yes ; then
-echo "$as_me:12714: checking if manpage symlinks should be used" >&5
+echo "$as_me:13211: checking if manpage symlinks should be used" >&5
 echo $ECHO_N "checking if manpage symlinks should be used... $ECHO_C" >&6
 
 # Check whether --with-manpage-symlinks or --without-manpage-symlinks was given.
@@ -12724,17 +13221,17 @@
 
 if test "$$cf_use_symlinks" = no; then
 if test "$MANPAGE_SYMLINKS" = yes ; then
-	{ echo "$as_me:12727: WARNING: cannot make symlinks" >&5
+	{ echo "$as_me:13224: WARNING: cannot make symlinks" >&5
 echo "$as_me: WARNING: cannot make symlinks" >&2;}
 	MANPAGE_SYMLINKS=no
 fi
 fi
 
-echo "$as_me:12733: result: $MANPAGE_SYMLINKS" >&5
+echo "$as_me:13230: result: $MANPAGE_SYMLINKS" >&5
 echo "${ECHO_T}$MANPAGE_SYMLINKS" >&6
 fi
 
-echo "$as_me:12737: checking for manpage tbl" >&5
+echo "$as_me:13234: checking for manpage tbl" >&5
 echo $ECHO_N "checking for manpage tbl... $ECHO_C" >&6
 
 # Check whether --with-manpage-tbl or --without-manpage-tbl was given.
@@ -12745,7 +13242,7 @@
   MANPAGE_TBL=no
 fi;
 
-echo "$as_me:12748: result: $MANPAGE_TBL" >&5
+echo "$as_me:13245: result: $MANPAGE_TBL" >&5
 echo "${ECHO_T}$MANPAGE_TBL" >&6
 
 if test "$prefix" = "NONE" ; then
@@ -13078,7 +13575,7 @@
 ###############################################################################
 
 ### Note that some functions (such as const) are normally disabled anyway.
-echo "$as_me:13081: checking if you want to build with function extensions" >&5
+echo "$as_me:13578: checking if you want to build with function extensions" >&5
 echo $ECHO_N "checking if you want to build with function extensions... $ECHO_C" >&6
 
 # Check whether --enable-ext-funcs or --disable-ext-funcs was given.
@@ -13088,7 +13585,7 @@
 else
   with_ext_funcs=yes
 fi;
-echo "$as_me:13091: result: $with_ext_funcs" >&5
+echo "$as_me:13588: result: $with_ext_funcs" >&5
 echo "${ECHO_T}$with_ext_funcs" >&6
 if test "x$with_ext_funcs" = xyes ; then
 	NCURSES_EXT_FUNCS=1
@@ -13148,7 +13645,7 @@
 	GENERATED_EXT_FUNCS=
 fi
 
-echo "$as_me:13151: checking if you want to build with SCREEN extensions" >&5
+echo "$as_me:13648: checking if you want to build with SCREEN extensions" >&5
 echo $ECHO_N "checking if you want to build with SCREEN extensions... $ECHO_C" >&6
 
 # Check whether --enable-sp-funcs or --disable-sp-funcs was given.
@@ -13158,7 +13655,7 @@
 else
   with_sp_funcs=$cf_dft_ext_spfuncs
 fi;
-echo "$as_me:13161: result: $with_sp_funcs" >&5
+echo "$as_me:13658: result: $with_sp_funcs" >&5
 echo "${ECHO_T}$with_sp_funcs" >&6
 if test "x$with_sp_funcs" = xyes ; then
 	NCURSES_SP_FUNCS=1
@@ -13177,7 +13674,7 @@
 	GENERATED_SP_FUNCS=
 fi
 
-echo "$as_me:13180: checking if you want to build with terminal-driver" >&5
+echo "$as_me:13677: checking if you want to build with terminal-driver" >&5
 echo $ECHO_N "checking if you want to build with terminal-driver... $ECHO_C" >&6
 
 # Check whether --enable-term-driver or --disable-term-driver was given.
@@ -13187,7 +13684,7 @@
 else
   with_term_driver=no
 fi;
-echo "$as_me:13190: result: $with_term_driver" >&5
+echo "$as_me:13687: result: $with_term_driver" >&5
 echo "${ECHO_T}$with_term_driver" >&6
 if test "x$with_term_driver" = xyes ; then
 
@@ -13196,19 +13693,19 @@
 EOF
 
 	if test "x$with_termlib" != xno ; then
-		{ { echo "$as_me:13199: error: The term-driver option conflicts with the termlib option" >&5
+		{ { echo "$as_me:13696: error: The term-driver option conflicts with the termlib option" >&5
 echo "$as_me: error: The term-driver option conflicts with the termlib option" >&2;}
    { (exit 1); exit 1; }; }
 	fi
 	if test "x$with_sp_funcs" != xyes ; then
-		{ { echo "$as_me:13204: error: The term-driver option relies upon sp-funcs" >&5
+		{ { echo "$as_me:13701: error: The term-driver option relies upon sp-funcs" >&5
 echo "$as_me: error: The term-driver option relies upon sp-funcs" >&2;}
    { (exit 1); exit 1; }; }
 	fi
 fi
 
 ###   use option --enable-const to turn on use of const beyond that in XSI.
-echo "$as_me:13211: checking for extended use of const keyword" >&5
+echo "$as_me:13708: checking for extended use of const keyword" >&5
 echo $ECHO_N "checking for extended use of const keyword... $ECHO_C" >&6
 
 # Check whether --enable-const or --disable-const was given.
@@ -13218,7 +13715,7 @@
 else
   with_ext_const=$cf_dft_ext_const
 fi;
-echo "$as_me:13221: result: $with_ext_const" >&5
+echo "$as_me:13718: result: $with_ext_const" >&5
 echo "${ECHO_T}$with_ext_const" >&6
 NCURSES_CONST='/*nothing*/'
 if test "x$with_ext_const" = xyes ; then
@@ -13226,7 +13723,7 @@
 fi
 
 ###   use option --enable-ext-colors to turn on use of colors beyond 16.
-echo "$as_me:13229: checking if you want to use extended colors" >&5
+echo "$as_me:13726: checking if you want to use extended colors" >&5
 echo $ECHO_N "checking if you want to use extended colors... $ECHO_C" >&6
 
 # Check whether --enable-ext-colors or --disable-ext-colors was given.
@@ -13236,12 +13733,12 @@
 else
   with_ext_colors=$cf_dft_ext_colors
 fi;
-echo "$as_me:13239: result: $with_ext_colors" >&5
+echo "$as_me:13736: result: $with_ext_colors" >&5
 echo "${ECHO_T}$with_ext_colors" >&6
 NCURSES_EXT_COLORS=0
 if test "x$with_ext_colors" = xyes ; then
 	if test "x$with_widec" != xyes ; then
-		{ echo "$as_me:13244: WARNING: This option applies only to wide-character library" >&5
+		{ echo "$as_me:13741: WARNING: This option applies only to wide-character library" >&5
 echo "$as_me: WARNING: This option applies only to wide-character library" >&2;}
 	else
 		# cannot be ABI 5 since it changes sizeof(cchar_t)
@@ -13251,7 +13748,7 @@
 	(5.*)
 		cf_cv_rel_version=6.0
 		cf_cv_abi_version=6
-		{ echo "$as_me:13254: WARNING: overriding ABI version to $cf_cv_abi_version" >&5
+		{ echo "$as_me:13751: WARNING: overriding ABI version to $cf_cv_abi_version" >&5
 echo "$as_me: WARNING: overriding ABI version to $cf_cv_abi_version" >&2;}
 		;;
 	esac
@@ -13279,7 +13776,7 @@
 fi
 
 ###   use option --enable-ext-mouse to modify coding to support 5-button mice
-echo "$as_me:13282: checking if you want to use extended mouse encoding" >&5
+echo "$as_me:13779: checking if you want to use extended mouse encoding" >&5
 echo $ECHO_N "checking if you want to use extended mouse encoding... $ECHO_C" >&6
 
 # Check whether --enable-ext-mouse or --disable-ext-mouse was given.
@@ -13289,7 +13786,7 @@
 else
   with_ext_mouse=$cf_dft_ext_mouse
 fi;
-echo "$as_me:13292: result: $with_ext_mouse" >&5
+echo "$as_me:13789: result: $with_ext_mouse" >&5
 echo "${ECHO_T}$with_ext_mouse" >&6
 NCURSES_MOUSE_VERSION=1
 if test "x$with_ext_mouse" = xyes ; then
@@ -13300,7 +13797,7 @@
 	(5.*)
 		cf_cv_rel_version=6.0
 		cf_cv_abi_version=6
-		{ echo "$as_me:13303: WARNING: overriding ABI version to $cf_cv_abi_version" >&5
+		{ echo "$as_me:13800: WARNING: overriding ABI version to $cf_cv_abi_version" >&5
 echo "$as_me: WARNING: overriding ABI version to $cf_cv_abi_version" >&2;}
 		;;
 	esac
@@ -13309,7 +13806,7 @@
 fi
 
 ###   use option --enable-ext-putwin to turn on extended screendumps
-echo "$as_me:13312: checking if you want to use extended putwin/screendump" >&5
+echo "$as_me:13809: checking if you want to use extended putwin/screendump" >&5
 echo $ECHO_N "checking if you want to use extended putwin/screendump... $ECHO_C" >&6
 
 # Check whether --enable-ext-putwin or --disable-ext-putwin was given.
@@ -13319,7 +13816,7 @@
 else
   with_ext_putwin=$cf_dft_ext_putwin
 fi;
-echo "$as_me:13322: result: $with_ext_putwin" >&5
+echo "$as_me:13819: result: $with_ext_putwin" >&5
 echo "${ECHO_T}$with_ext_putwin" >&6
 if test "x$with_ext_putwin" = xyes ; then
 
@@ -13329,7 +13826,7 @@
 
 fi
 
-echo "$as_me:13332: checking if you want \$NCURSES_NO_PADDING code" >&5
+echo "$as_me:13829: checking if you want \$NCURSES_NO_PADDING code" >&5
 echo $ECHO_N "checking if you want \$NCURSES_NO_PADDING code... $ECHO_C" >&6
 
 # Check whether --enable-no-padding or --disable-no-padding was given.
@@ -13339,7 +13836,7 @@
 else
   with_no_padding=$with_ext_funcs
 fi;
-echo "$as_me:13342: result: $with_no_padding" >&5
+echo "$as_me:13839: result: $with_no_padding" >&5
 echo "${ECHO_T}$with_no_padding" >&6
 test "x$with_no_padding" = xyes &&
 cat >>confdefs.h <<\EOF
@@ -13347,7 +13844,7 @@
 EOF
 
 ###   use option --enable-sigwinch to turn on use of SIGWINCH logic
-echo "$as_me:13350: checking if you want SIGWINCH handler" >&5
+echo "$as_me:13847: checking if you want SIGWINCH handler" >&5
 echo $ECHO_N "checking if you want SIGWINCH handler... $ECHO_C" >&6
 
 # Check whether --enable-sigwinch or --disable-sigwinch was given.
@@ -13357,7 +13854,7 @@
 else
   with_sigwinch=$with_ext_funcs
 fi;
-echo "$as_me:13360: result: $with_sigwinch" >&5
+echo "$as_me:13857: result: $with_sigwinch" >&5
 echo "${ECHO_T}$with_sigwinch" >&6
 test "x$with_sigwinch" = xyes &&
 cat >>confdefs.h <<\EOF
@@ -13365,7 +13862,7 @@
 EOF
 
 ###   use option --enable-tcap-names to allow user to define new capabilities
-echo "$as_me:13368: checking if you want user-definable terminal capabilities like termcap" >&5
+echo "$as_me:13865: checking if you want user-definable terminal capabilities like termcap" >&5
 echo $ECHO_N "checking if you want user-definable terminal capabilities like termcap... $ECHO_C" >&6
 
 # Check whether --enable-tcap-names or --disable-tcap-names was given.
@@ -13375,14 +13872,14 @@
 else
   with_tcap_names=$with_ext_funcs
 fi;
-echo "$as_me:13378: result: $with_tcap_names" >&5
+echo "$as_me:13875: result: $with_tcap_names" >&5
 echo "${ECHO_T}$with_tcap_names" >&6
 NCURSES_XNAMES=0
 test "x$with_tcap_names" = xyes && NCURSES_XNAMES=1
 
 ##############################################################################
 
-echo "$as_me:13385: checking if you want to link with the pthread library" >&5
+echo "$as_me:13882: checking if you want to link with the pthread library" >&5
 echo $ECHO_N "checking if you want to link with the pthread library... $ECHO_C" >&6
 
 # Check whether --with-pthread or --without-pthread was given.
@@ -13392,27 +13889,27 @@
 else
   with_pthread=no
 fi;
-echo "$as_me:13395: result: $with_pthread" >&5
+echo "$as_me:13892: result: $with_pthread" >&5
 echo "${ECHO_T}$with_pthread" >&6
 
 if test "$with_pthread" != no ; then
-	echo "$as_me:13399: checking for pthread.h" >&5
+	echo "$as_me:13896: checking for pthread.h" >&5
 echo $ECHO_N "checking for pthread.h... $ECHO_C" >&6
 if test "${ac_cv_header_pthread_h+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 13405 "configure"
+#line 13902 "configure"
 #include "confdefs.h"
 #include <pthread.h>
 _ACEOF
-if { (eval echo "$as_me:13409: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:13906: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:13415: \$? = $ac_status" >&5
+  echo "$as_me:13912: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -13431,7 +13928,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:13434: result: $ac_cv_header_pthread_h" >&5
+echo "$as_me:13931: result: $ac_cv_header_pthread_h" >&5
 echo "${ECHO_T}$ac_cv_header_pthread_h" >&6
 if test $ac_cv_header_pthread_h = yes; then
 
@@ -13441,7 +13938,7 @@
 
 	for cf_lib_pthread in pthread c_r
 	do
-	    echo "$as_me:13444: checking if we can link with the $cf_lib_pthread library" >&5
+	    echo "$as_me:13941: checking if we can link with the $cf_lib_pthread library" >&5
 echo $ECHO_N "checking if we can link with the $cf_lib_pthread library... $ECHO_C" >&6
 	    cf_save_LIBS="$LIBS"
 
@@ -13462,7 +13959,7 @@
 LIBS="$cf_add_libs"
 
 	    cat >conftest.$ac_ext <<_ACEOF
-#line 13465 "configure"
+#line 13962 "configure"
 #include "confdefs.h"
 
 #include <pthread.h>
@@ -13479,16 +13976,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:13482: \"$ac_link\"") >&5
+if { (eval echo "$as_me:13979: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13485: \$? = $ac_status" >&5
+  echo "$as_me:13982: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:13488: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13985: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13491: \$? = $ac_status" >&5
+  echo "$as_me:13988: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   with_pthread=yes
 else
@@ -13498,7 +13995,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 	    LIBS="$cf_save_LIBS"
-	    echo "$as_me:13501: result: $with_pthread" >&5
+	    echo "$as_me:13998: result: $with_pthread" >&5
 echo "${ECHO_T}$with_pthread" >&6
 	    test "$with_pthread" = yes && break
 	done
@@ -13526,7 +14023,7 @@
 EOF
 
 	else
-	    { { echo "$as_me:13529: error: Cannot link with pthread library" >&5
+	    { { echo "$as_me:14026: error: Cannot link with pthread library" >&5
 echo "$as_me: error: Cannot link with pthread library" >&2;}
    { (exit 1); exit 1; }; }
 	fi
@@ -13536,13 +14033,13 @@
 fi
 
 if test "x$with_pthread" != xno; then
-	echo "$as_me:13539: checking for pthread_kill" >&5
+	echo "$as_me:14036: checking for pthread_kill" >&5
 echo $ECHO_N "checking for pthread_kill... $ECHO_C" >&6
 if test "${ac_cv_func_pthread_kill+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 13545 "configure"
+#line 14042 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char pthread_kill (); below.  */
@@ -13573,16 +14070,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:13576: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14073: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13579: \$? = $ac_status" >&5
+  echo "$as_me:14076: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:13582: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14079: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13585: \$? = $ac_status" >&5
+  echo "$as_me:14082: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_pthread_kill=yes
 else
@@ -13592,11 +14089,11 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:13595: result: $ac_cv_func_pthread_kill" >&5
+echo "$as_me:14092: result: $ac_cv_func_pthread_kill" >&5
 echo "${ECHO_T}$ac_cv_func_pthread_kill" >&6
 if test $ac_cv_func_pthread_kill = yes; then
 
-		echo "$as_me:13599: checking if you want to allow EINTR in wgetch with pthreads" >&5
+		echo "$as_me:14096: checking if you want to allow EINTR in wgetch with pthreads" >&5
 echo $ECHO_N "checking if you want to allow EINTR in wgetch with pthreads... $ECHO_C" >&6
 
 # Check whether --enable-pthreads-eintr or --disable-pthreads-eintr was given.
@@ -13606,7 +14103,7 @@
 else
   use_pthreads_eintr=no
 fi;
-		echo "$as_me:13609: result: $use_pthreads_eintr" >&5
+		echo "$as_me:14106: result: $use_pthreads_eintr" >&5
 echo "${ECHO_T}$use_pthreads_eintr" >&6
 		if test "x$use_pthreads_eintr" = xyes ; then
 
@@ -13617,7 +14114,7 @@
 		fi
 fi
 
-	echo "$as_me:13620: checking if you want to use weak-symbols for pthreads" >&5
+	echo "$as_me:14117: checking if you want to use weak-symbols for pthreads" >&5
 echo $ECHO_N "checking if you want to use weak-symbols for pthreads... $ECHO_C" >&6
 
 # Check whether --enable-weak-symbols or --disable-weak-symbols was given.
@@ -13627,18 +14124,18 @@
 else
   use_weak_symbols=no
 fi;
-	echo "$as_me:13630: result: $use_weak_symbols" >&5
+	echo "$as_me:14127: result: $use_weak_symbols" >&5
 echo "${ECHO_T}$use_weak_symbols" >&6
 	if test "x$use_weak_symbols" = xyes ; then
 
-echo "$as_me:13634: checking if $CC supports weak symbols" >&5
+echo "$as_me:14131: checking if $CC supports weak symbols" >&5
 echo $ECHO_N "checking if $CC supports weak symbols... $ECHO_C" >&6
 if test "${cf_cv_weak_symbols+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 13641 "configure"
+#line 14138 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -13664,16 +14161,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:13667: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:14164: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:13670: \$? = $ac_status" >&5
+  echo "$as_me:14167: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:13673: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14170: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13676: \$? = $ac_status" >&5
+  echo "$as_me:14173: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_weak_symbols=yes
 else
@@ -13684,7 +14181,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:13687: result: $cf_cv_weak_symbols" >&5
+echo "$as_me:14184: result: $cf_cv_weak_symbols" >&5
 echo "${ECHO_T}$cf_cv_weak_symbols" >&6
 
 	else
@@ -13734,7 +14231,7 @@
 # opaque outside of that, so there is no --enable-opaque option.  We can use
 # this option without --with-pthreads, but this will be always set for
 # pthreads.
-echo "$as_me:13737: checking if you want reentrant code" >&5
+echo "$as_me:14234: checking if you want reentrant code" >&5
 echo $ECHO_N "checking if you want reentrant code... $ECHO_C" >&6
 
 # Check whether --enable-reentrant or --disable-reentrant was given.
@@ -13744,7 +14241,7 @@
 else
   with_reentrant=no
 fi;
-echo "$as_me:13747: result: $with_reentrant" >&5
+echo "$as_me:14244: result: $with_reentrant" >&5
 echo "${ECHO_T}$with_reentrant" >&6
 if test "x$with_reentrant" = xyes ; then
 	cf_cv_enable_reentrant=1
@@ -13832,7 +14329,7 @@
 	(5.*)
 		cf_cv_rel_version=6.0
 		cf_cv_abi_version=6
-		{ echo "$as_me:13835: WARNING: overriding ABI version to $cf_cv_abi_version" >&5
+		{ echo "$as_me:14332: WARNING: overriding ABI version to $cf_cv_abi_version" >&5
 echo "$as_me: WARNING: overriding ABI version to $cf_cv_abi_version" >&2;}
 		;;
 	esac
@@ -13844,7 +14341,7 @@
 	NCURSES_SIZE_T=short
 fi
 
-echo "$as_me:13847: checking if you want opaque curses-library structures" >&5
+echo "$as_me:14344: checking if you want opaque curses-library structures" >&5
 echo $ECHO_N "checking if you want opaque curses-library structures... $ECHO_C" >&6
 
 # Check whether --enable-opaque-curses or --disable-opaque-curses was given.
@@ -13866,16 +14363,16 @@
 	 test "$cf_cv_enable_reentrant" = 1 || enable_opaque_curses=no
 
 fi;
-echo "$as_me:13869: result: $enable_opaque_curses" >&5
+echo "$as_me:14366: result: $enable_opaque_curses" >&5
 echo "${ECHO_T}$enable_opaque_curses" >&6
 
 test "$cf_cv_enable_reentrant" = 1 && \
 test "$enable_opaque_curses" = no && \
-{ { echo "$as_me:13874: error: reentrant configuration requires opaque library" >&5
+{ { echo "$as_me:14371: error: reentrant configuration requires opaque library" >&5
 echo "$as_me: error: reentrant configuration requires opaque library" >&2;}
    { (exit 1); exit 1; }; }
 
-echo "$as_me:13878: checking if you want opaque form-library structures" >&5
+echo "$as_me:14375: checking if you want opaque form-library structures" >&5
 echo $ECHO_N "checking if you want opaque form-library structures... $ECHO_C" >&6
 
 # Check whether --enable-opaque-form or --disable-opaque-form was given.
@@ -13885,10 +14382,10 @@
 else
   enable_opaque_form=no
 fi;
-echo "$as_me:13888: result: $enable_opaque_form" >&5
+echo "$as_me:14385: result: $enable_opaque_form" >&5
 echo "${ECHO_T}$enable_opaque_form" >&6
 
-echo "$as_me:13891: checking if you want opaque menu-library structures" >&5
+echo "$as_me:14388: checking if you want opaque menu-library structures" >&5
 echo $ECHO_N "checking if you want opaque menu-library structures... $ECHO_C" >&6
 
 # Check whether --enable-opaque-menu or --disable-opaque-menu was given.
@@ -13898,10 +14395,10 @@
 else
   enable_opaque_menu=no
 fi;
-echo "$as_me:13901: result: $enable_opaque_menu" >&5
+echo "$as_me:14398: result: $enable_opaque_menu" >&5
 echo "${ECHO_T}$enable_opaque_menu" >&6
 
-echo "$as_me:13904: checking if you want opaque panel-library structures" >&5
+echo "$as_me:14401: checking if you want opaque panel-library structures" >&5
 echo $ECHO_N "checking if you want opaque panel-library structures... $ECHO_C" >&6
 
 # Check whether --enable-opaque-panel or --disable-opaque-panel was given.
@@ -13911,7 +14408,7 @@
 else
   enable_opaque_panel=no
 fi;
-echo "$as_me:13914: result: $enable_opaque_panel" >&5
+echo "$as_me:14411: result: $enable_opaque_panel" >&5
 echo "${ECHO_T}$enable_opaque_panel" >&6
 
 NCURSES_OPAQUE=0;		test "$enable_opaque_curses" = yes && NCURSES_OPAQUE=1
@@ -13921,7 +14418,7 @@
 
 ### Allow using a different wrap-prefix
 if test "$cf_cv_enable_reentrant" != 0 || test "$BROKEN_LINKER" = 1 ; then
-	echo "$as_me:13924: checking for prefix used to wrap public variables" >&5
+	echo "$as_me:14421: checking for prefix used to wrap public variables" >&5
 echo $ECHO_N "checking for prefix used to wrap public variables... $ECHO_C" >&6
 
 # Check whether --with-wrap-prefix or --without-wrap-prefix was given.
@@ -13931,7 +14428,7 @@
 else
   NCURSES_WRAP_PREFIX=_nc_
 fi;
-	echo "$as_me:13934: result: $NCURSES_WRAP_PREFIX" >&5
+	echo "$as_me:14431: result: $NCURSES_WRAP_PREFIX" >&5
 echo "${ECHO_T}$NCURSES_WRAP_PREFIX" >&6
 else
 	NCURSES_WRAP_PREFIX=_nc_
@@ -13944,7 +14441,7 @@
 ###############################################################################
 # These options are relatively safe to experiment with.
 
-echo "$as_me:13947: checking if you want all development code" >&5
+echo "$as_me:14444: checking if you want all development code" >&5
 echo $ECHO_N "checking if you want all development code... $ECHO_C" >&6
 
 # Check whether --with-develop or --without-develop was given.
@@ -13954,11 +14451,11 @@
 else
   with_develop=no
 fi;
-echo "$as_me:13957: result: $with_develop" >&5
+echo "$as_me:14454: result: $with_develop" >&5
 echo "${ECHO_T}$with_develop" >&6
 
 ###   use option --enable-hard-tabs to turn on use of hard-tabs optimize
-echo "$as_me:13961: checking if you want hard-tabs code" >&5
+echo "$as_me:14458: checking if you want hard-tabs code" >&5
 echo $ECHO_N "checking if you want hard-tabs code... $ECHO_C" >&6
 
 # Check whether --enable-hard-tabs or --disable-hard-tabs was given.
@@ -13968,7 +14465,7 @@
 else
   enable_hard_tabs=$with_develop
 fi;
-echo "$as_me:13971: result: $enable_hard_tabs" >&5
+echo "$as_me:14468: result: $enable_hard_tabs" >&5
 echo "${ECHO_T}$enable_hard_tabs" >&6
 test "x$enable_hard_tabs" = xyes &&
 cat >>confdefs.h <<\EOF
@@ -13976,7 +14473,7 @@
 EOF
 
 ###   use option --enable-xmc-glitch to turn on use of magic-cookie optimize
-echo "$as_me:13979: checking if you want limited support for xmc" >&5
+echo "$as_me:14476: checking if you want limited support for xmc" >&5
 echo $ECHO_N "checking if you want limited support for xmc... $ECHO_C" >&6
 
 # Check whether --enable-xmc-glitch or --disable-xmc-glitch was given.
@@ -13986,7 +14483,7 @@
 else
   enable_xmc_glitch=$with_develop
 fi;
-echo "$as_me:13989: result: $enable_xmc_glitch" >&5
+echo "$as_me:14486: result: $enable_xmc_glitch" >&5
 echo "${ECHO_T}$enable_xmc_glitch" >&6
 test "x$enable_xmc_glitch" = xyes &&
 cat >>confdefs.h <<\EOF
@@ -13996,7 +14493,7 @@
 ###############################################################################
 # These are just experimental, probably should not be in a package:
 
-echo "$as_me:13999: checking if you do not want to assume colors are white-on-black" >&5
+echo "$as_me:14496: checking if you do not want to assume colors are white-on-black" >&5
 echo $ECHO_N "checking if you do not want to assume colors are white-on-black... $ECHO_C" >&6
 
 # Check whether --enable-assumed-color or --disable-assumed-color was given.
@@ -14006,7 +14503,7 @@
 else
   with_assumed_color=yes
 fi;
-echo "$as_me:14009: result: $with_assumed_color" >&5
+echo "$as_me:14506: result: $with_assumed_color" >&5
 echo "${ECHO_T}$with_assumed_color" >&6
 test "x$with_assumed_color" = xyes &&
 cat >>confdefs.h <<\EOF
@@ -14014,7 +14511,7 @@
 EOF
 
 ###   use option --enable-hashmap to turn on use of hashmap scrolling logic
-echo "$as_me:14017: checking if you want hashmap scrolling-optimization code" >&5
+echo "$as_me:14514: checking if you want hashmap scrolling-optimization code" >&5
 echo $ECHO_N "checking if you want hashmap scrolling-optimization code... $ECHO_C" >&6
 
 # Check whether --enable-hashmap or --disable-hashmap was given.
@@ -14024,7 +14521,7 @@
 else
   with_hashmap=yes
 fi;
-echo "$as_me:14027: result: $with_hashmap" >&5
+echo "$as_me:14524: result: $with_hashmap" >&5
 echo "${ECHO_T}$with_hashmap" >&6
 test "x$with_hashmap" = xyes &&
 cat >>confdefs.h <<\EOF
@@ -14032,7 +14529,7 @@
 EOF
 
 ###   use option --enable-colorfgbg to turn on use of $COLORFGBG environment
-echo "$as_me:14035: checking if you want colorfgbg code" >&5
+echo "$as_me:14532: checking if you want colorfgbg code" >&5
 echo $ECHO_N "checking if you want colorfgbg code... $ECHO_C" >&6
 
 # Check whether --enable-colorfgbg or --disable-colorfgbg was given.
@@ -14042,7 +14539,7 @@
 else
   with_colorfgbg=no
 fi;
-echo "$as_me:14045: result: $with_colorfgbg" >&5
+echo "$as_me:14542: result: $with_colorfgbg" >&5
 echo "${ECHO_T}$with_colorfgbg" >&6
 test "x$with_colorfgbg" = xyes &&
 cat >>confdefs.h <<\EOF
@@ -14050,7 +14547,7 @@
 EOF
 
 ###   use option --enable-interop to turn on use of bindings used for interop
-echo "$as_me:14053: checking if you want interop bindings" >&5
+echo "$as_me:14550: checking if you want interop bindings" >&5
 echo $ECHO_N "checking if you want interop bindings... $ECHO_C" >&6
 
 # Check whether --enable-interop or --disable-interop was given.
@@ -14060,13 +14557,13 @@
 else
   with_exp_interop=$cf_dft_interop
 fi;
-echo "$as_me:14063: result: $with_exp_interop" >&5
+echo "$as_me:14560: result: $with_exp_interop" >&5
 echo "${ECHO_T}$with_exp_interop" >&6
 
 NCURSES_INTEROP_FUNCS=0
 test "x$with_exp_interop" = xyes && NCURSES_INTEROP_FUNCS=1
 
-echo "$as_me:14069: checking if you want experimental safe-sprintf code" >&5
+echo "$as_me:14566: checking if you want experimental safe-sprintf code" >&5
 echo $ECHO_N "checking if you want experimental safe-sprintf code... $ECHO_C" >&6
 
 # Check whether --enable-safe-sprintf or --disable-safe-sprintf was given.
@@ -14076,13 +14573,13 @@
 else
   with_safe_sprintf=no
 fi;
-echo "$as_me:14079: result: $with_safe_sprintf" >&5
+echo "$as_me:14576: result: $with_safe_sprintf" >&5
 echo "${ECHO_T}$with_safe_sprintf" >&6
 
 ###   use option --disable-scroll-hints to turn off use of scroll-hints scrolling logic
 # when hashmap is used scroll hints are useless
 if test "$with_hashmap" = no ; then
-echo "$as_me:14085: checking if you want to experiment without scrolling-hints code" >&5
+echo "$as_me:14582: checking if you want to experiment without scrolling-hints code" >&5
 echo $ECHO_N "checking if you want to experiment without scrolling-hints code... $ECHO_C" >&6
 
 # Check whether --enable-scroll-hints or --disable-scroll-hints was given.
@@ -14092,7 +14589,7 @@
 else
   with_scroll_hints=yes
 fi;
-echo "$as_me:14095: result: $with_scroll_hints" >&5
+echo "$as_me:14592: result: $with_scroll_hints" >&5
 echo "${ECHO_T}$with_scroll_hints" >&6
 test "x$with_scroll_hints" = xyes &&
 cat >>confdefs.h <<\EOF
@@ -14101,7 +14598,7 @@
 
 fi
 
-echo "$as_me:14104: checking if you want wgetch-events code" >&5
+echo "$as_me:14601: checking if you want wgetch-events code" >&5
 echo $ECHO_N "checking if you want wgetch-events code... $ECHO_C" >&6
 
 # Check whether --enable-wgetch-events or --disable-wgetch-events was given.
@@ -14111,7 +14608,7 @@
 else
   with_wgetch_events=no
 fi;
-echo "$as_me:14114: result: $with_wgetch_events" >&5
+echo "$as_me:14611: result: $with_wgetch_events" >&5
 echo "${ECHO_T}$with_wgetch_events" >&6
 test "x$with_wgetch_events" = xyes &&
 cat >>confdefs.h <<\EOF
@@ -14122,7 +14619,7 @@
 
 ###	use option --disable-echo to suppress full display compiling commands
 
-echo "$as_me:14125: checking if you want to see long compiling messages" >&5
+echo "$as_me:14622: checking if you want to see long compiling messages" >&5
 echo $ECHO_N "checking if you want to see long compiling messages... $ECHO_C" >&6
 
 # Check whether --enable-echo or --disable-echo was given.
@@ -14156,7 +14653,7 @@
 	ECHO_CC=''
 
 fi;
-echo "$as_me:14159: result: $enableval" >&5
+echo "$as_me:14656: result: $enableval" >&5
 echo "${ECHO_T}$enableval" >&6
 
 if test "x$enable_echo" = xyes; then
@@ -14169,7 +14666,7 @@
 
 # --disable-stripping is used for debugging
 
-echo "$as_me:14172: checking if you want to install stripped executables" >&5
+echo "$as_me:14669: checking if you want to install stripped executables" >&5
 echo $ECHO_N "checking if you want to install stripped executables... $ECHO_C" >&6
 
 # Check whether --enable-stripping or --disable-stripping was given.
@@ -14186,7 +14683,7 @@
 	with_stripping=yes
 
 fi;
-echo "$as_me:14189: result: $with_stripping" >&5
+echo "$as_me:14686: result: $with_stripping" >&5
 echo "${ECHO_T}$with_stripping" >&6
 
 if test "$with_stripping" = yes
@@ -14196,7 +14693,7 @@
 	INSTALL_OPT_S=
 fi
 
-echo "$as_me:14199: checking if install needs to be told about ownership" >&5
+echo "$as_me:14696: checking if install needs to be told about ownership" >&5
 echo $ECHO_N "checking if install needs to be told about ownership... $ECHO_C" >&6
 case `$ac_config_guess` in
 (*minix)
@@ -14207,7 +14704,7 @@
 	;;
 esac
 
-echo "$as_me:14210: result: $with_install_o" >&5
+echo "$as_me:14707: result: $with_install_o" >&5
 echo "${ECHO_T}$with_install_o" >&6
 if test "x$with_install_o" = xyes
 then
@@ -14217,7 +14714,7 @@
 fi
 
 ###	use option --enable-warnings to turn on all gcc warnings
-echo "$as_me:14220: checking if you want to see compiler warnings" >&5
+echo "$as_me:14717: checking if you want to see compiler warnings" >&5
 echo $ECHO_N "checking if you want to see compiler warnings... $ECHO_C" >&6
 
 # Check whether --enable-warnings or --disable-warnings was given.
@@ -14225,7 +14722,7 @@
   enableval="$enable_warnings"
   with_warnings=$enableval
 fi;
-echo "$as_me:14228: result: $with_warnings" >&5
+echo "$as_me:14725: result: $with_warnings" >&5
 echo "${ECHO_T}$with_warnings" >&6
 
 if test "x$with_warnings" = "xyes"; then
@@ -14237,12 +14734,12 @@
 if test "$GCC" = yes ; then
 	case $host_os in
 	(linux*|gnu*)
-		echo "$as_me:14240: checking if this is really Intel C compiler" >&5
+		echo "$as_me:14737: checking if this is really Intel C compiler" >&5
 echo $ECHO_N "checking if this is really Intel C compiler... $ECHO_C" >&6
 		cf_save_CFLAGS="$CFLAGS"
 		CFLAGS="$CFLAGS -no-gcc"
 		cat >conftest.$ac_ext <<_ACEOF
-#line 14245 "configure"
+#line 14742 "configure"
 #include "confdefs.h"
 
 int
@@ -14259,16 +14756,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:14262: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:14759: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:14265: \$? = $ac_status" >&5
+  echo "$as_me:14762: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:14268: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14765: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14271: \$? = $ac_status" >&5
+  echo "$as_me:14768: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   INTEL_COMPILER=yes
 cf_save_CFLAGS="$cf_save_CFLAGS -we147"
@@ -14279,7 +14776,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 		CFLAGS="$cf_save_CFLAGS"
-		echo "$as_me:14282: result: $INTEL_COMPILER" >&5
+		echo "$as_me:14779: result: $INTEL_COMPILER" >&5
 echo "${ECHO_T}$INTEL_COMPILER" >&6
 		;;
 	esac
@@ -14288,12 +14785,12 @@
 CLANG_COMPILER=no
 
 if test "$GCC" = yes ; then
-	echo "$as_me:14291: checking if this is really Clang C compiler" >&5
+	echo "$as_me:14788: checking if this is really Clang C compiler" >&5
 echo $ECHO_N "checking if this is really Clang C compiler... $ECHO_C" >&6
 	cf_save_CFLAGS="$CFLAGS"
 	CFLAGS="$CFLAGS -Qunused-arguments"
 	cat >conftest.$ac_ext <<_ACEOF
-#line 14296 "configure"
+#line 14793 "configure"
 #include "confdefs.h"
 
 int
@@ -14310,16 +14807,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:14313: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:14810: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:14316: \$? = $ac_status" >&5
+  echo "$as_me:14813: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:14319: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14816: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14322: \$? = $ac_status" >&5
+  echo "$as_me:14819: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   CLANG_COMPILER=yes
 cf_save_CFLAGS="$cf_save_CFLAGS -Qunused-arguments"
@@ -14330,12 +14827,12 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 	CFLAGS="$cf_save_CFLAGS"
-	echo "$as_me:14333: result: $CLANG_COMPILER" >&5
+	echo "$as_me:14830: result: $CLANG_COMPILER" >&5
 echo "${ECHO_T}$CLANG_COMPILER" >&6
 fi
 
 cat > conftest.$ac_ext <<EOF
-#line 14338 "${as_me:-configure}"
+#line 14835 "${as_me:-configure}"
 int main(int argc, char *argv[]) { return (argv[argc-1] == 0) ; }
 EOF
 
@@ -14352,7 +14849,7 @@
 # remark #981: operands are evaluated in unspecified order
 # warning #279: controlling expression is constant
 
-	{ echo "$as_me:14355: checking for $CC warning options..." >&5
+	{ echo "$as_me:14852: checking for $CC warning options..." >&5
 echo "$as_me: checking for $CC warning options..." >&6;}
 	cf_save_CFLAGS="$CFLAGS"
 	EXTRA_CFLAGS="-Wall"
@@ -14368,12 +14865,12 @@
 		wd981
 	do
 		CFLAGS="$cf_save_CFLAGS $EXTRA_CFLAGS -$cf_opt"
-		if { (eval echo "$as_me:14371: \"$ac_compile\"") >&5
+		if { (eval echo "$as_me:14868: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:14374: \$? = $ac_status" >&5
+  echo "$as_me:14871: \$? = $ac_status" >&5
   (exit $ac_status); }; then
-			test -n "$verbose" && echo "$as_me:14376: result: ... -$cf_opt" >&5
+			test -n "$verbose" && echo "$as_me:14873: result: ... -$cf_opt" >&5
 echo "${ECHO_T}... -$cf_opt" >&6
 			EXTRA_CFLAGS="$EXTRA_CFLAGS -$cf_opt"
 		fi
@@ -14382,7 +14879,7 @@
 
 elif test "$GCC" = yes
 then
-	{ echo "$as_me:14385: checking for $CC warning options..." >&5
+	{ echo "$as_me:14882: checking for $CC warning options..." >&5
 echo "$as_me: checking for $CC warning options..." >&6;}
 	cf_save_CFLAGS="$CFLAGS"
 	EXTRA_CFLAGS=
@@ -14406,12 +14903,12 @@
 		Wundef $cf_gcc_warnings $cf_warn_CONST Wno-unknown-pragmas Wswitch-enum
 	do
 		CFLAGS="$cf_save_CFLAGS $EXTRA_CFLAGS -$cf_opt"
-		if { (eval echo "$as_me:14409: \"$ac_compile\"") >&5
+		if { (eval echo "$as_me:14906: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:14412: \$? = $ac_status" >&5
+  echo "$as_me:14909: \$? = $ac_status" >&5
   (exit $ac_status); }; then
-			test -n "$verbose" && echo "$as_me:14414: result: ... -$cf_opt" >&5
+			test -n "$verbose" && echo "$as_me:14911: result: ... -$cf_opt" >&5
 echo "${ECHO_T}... -$cf_opt" >&6
 			case $cf_opt in
 			(Wcast-qual)
@@ -14425,7 +14922,7 @@
 				([34].*)
 					test -n "$verbose" && echo "	feature is broken in gcc $GCC_VERSION" 1>&6
 
-echo "${as_me:-configure}:14428: testing feature is broken in gcc $GCC_VERSION ..." 1>&5
+echo "${as_me:-configure}:14925: testing feature is broken in gcc $GCC_VERSION ..." 1>&5
 
 					continue;;
 				esac
@@ -14435,7 +14932,7 @@
 				([12].*)
 					test -n "$verbose" && echo "	feature is broken in gcc $GCC_VERSION" 1>&6
 
-echo "${as_me:-configure}:14438: testing feature is broken in gcc $GCC_VERSION ..." 1>&5
+echo "${as_me:-configure}:14935: testing feature is broken in gcc $GCC_VERSION ..." 1>&5
 
 					continue;;
 				esac
@@ -14455,12 +14952,12 @@
 if test "$GCC" = yes ; then
 	case $host_os in
 	(linux*|gnu*)
-		echo "$as_me:14458: checking if this is really Intel C++ compiler" >&5
+		echo "$as_me:14955: checking if this is really Intel C++ compiler" >&5
 echo $ECHO_N "checking if this is really Intel C++ compiler... $ECHO_C" >&6
 		cf_save_CFLAGS="$CXXFLAGS"
 		CXXFLAGS="$CXXFLAGS -no-gcc"
 		cat >conftest.$ac_ext <<_ACEOF
-#line 14463 "configure"
+#line 14960 "configure"
 #include "confdefs.h"
 
 int
@@ -14477,16 +14974,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:14480: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:14977: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:14483: \$? = $ac_status" >&5
+  echo "$as_me:14980: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:14486: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14983: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14489: \$? = $ac_status" >&5
+  echo "$as_me:14986: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   INTEL_CPLUSPLUS=yes
 cf_save_CFLAGS="$cf_save_CFLAGS -we147"
@@ -14497,7 +14994,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 		CXXFLAGS="$cf_save_CFLAGS"
-		echo "$as_me:14500: result: $INTEL_CPLUSPLUS" >&5
+		echo "$as_me:14997: result: $INTEL_CPLUSPLUS" >&5
 echo "${ECHO_T}$INTEL_CPLUSPLUS" >&6
 		;;
 	esac
@@ -14506,12 +15003,12 @@
 CLANG_CPLUSPLUS=no
 
 if test "$GCC" = yes ; then
-	echo "$as_me:14509: checking if this is really Clang C++ compiler" >&5
+	echo "$as_me:15006: checking if this is really Clang C++ compiler" >&5
 echo $ECHO_N "checking if this is really Clang C++ compiler... $ECHO_C" >&6
 	cf_save_CFLAGS="$CXXFLAGS"
 	CXXFLAGS="$CXXFLAGS -Qunused-arguments"
 	cat >conftest.$ac_ext <<_ACEOF
-#line 14514 "configure"
+#line 15011 "configure"
 #include "confdefs.h"
 
 int
@@ -14528,16 +15025,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:14531: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:15028: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:14534: \$? = $ac_status" >&5
+  echo "$as_me:15031: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:14537: \"$ac_try\"") >&5
+  { (eval echo "$as_me:15034: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14540: \$? = $ac_status" >&5
+  echo "$as_me:15037: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   CLANG_CPLUSPLUS=yes
 cf_save_CFLAGS="$cf_save_CFLAGS -Qunused-arguments"
@@ -14548,7 +15045,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 	CXXFLAGS="$cf_save_CFLAGS"
-	echo "$as_me:14551: result: $CLANG_CPLUSPLUS" >&5
+	echo "$as_me:15048: result: $CLANG_CPLUSPLUS" >&5
 echo "${ECHO_T}$CLANG_CPLUSPLUS" >&6
 fi
 
@@ -14560,7 +15057,7 @@
 ac_main_return=return
 
 cat > conftest.$ac_ext <<EOF
-#line 14563 "configure"
+#line 15060 "configure"
 int main(int argc, char *argv[]) { return (argv[argc-1] == 0) ; }
 EOF
 
@@ -14578,7 +15075,7 @@
 # remark #981: operands are evaluated in unspecified order
 # warning #269: invalid format string conversion
 
-	{ echo "$as_me:14581: checking for $CC warning options..." >&5
+	{ echo "$as_me:15078: checking for $CC warning options..." >&5
 echo "$as_me: checking for $CC warning options..." >&6;}
 	cf_save_CXXFLAGS="$CXXFLAGS"
 	EXTRA_CXXFLAGS="-Wall"
@@ -14595,12 +15092,12 @@
 		wd981
 	do
 		CXXFLAGS="$cf_save_CXXFLAGS $EXTRA_CXXFLAGS -$cf_opt"
-		if { (eval echo "$as_me:14598: \"$ac_compile\"") >&5
+		if { (eval echo "$as_me:15095: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:14601: \$? = $ac_status" >&5
+  echo "$as_me:15098: \$? = $ac_status" >&5
   (exit $ac_status); }; then
-			test -n "$verbose" && echo "$as_me:14603: result: ... -$cf_opt" >&5
+			test -n "$verbose" && echo "$as_me:15100: result: ... -$cf_opt" >&5
 echo "${ECHO_T}... -$cf_opt" >&6
 			EXTRA_CXXFLAGS="$EXTRA_CXXFLAGS -$cf_opt"
 		fi
@@ -14609,7 +15106,7 @@
 
 elif test "$GXX" = yes
 then
-	{ echo "$as_me:14612: checking for $CXX warning options..." >&5
+	{ echo "$as_me:15109: checking for $CXX warning options..." >&5
 echo "$as_me: checking for $CXX warning options..." >&6;}
 	cf_save_CXXFLAGS="$CXXFLAGS"
 	EXTRA_CXXFLAGS="-W -Wall"
@@ -14639,16 +15136,16 @@
 		Wundef $cf_gxx_extra_warnings Wno-unused
 	do
 		CXXFLAGS="$cf_save_CXXFLAGS $EXTRA_CXXFLAGS -Werror -$cf_opt"
-		if { (eval echo "$as_me:14642: \"$ac_compile\"") >&5
+		if { (eval echo "$as_me:15139: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:14645: \$? = $ac_status" >&5
+  echo "$as_me:15142: \$? = $ac_status" >&5
   (exit $ac_status); }; then
-			test -n "$verbose" && echo "$as_me:14647: result: ... -$cf_opt" >&5
+			test -n "$verbose" && echo "$as_me:15144: result: ... -$cf_opt" >&5
 echo "${ECHO_T}... -$cf_opt" >&6
 			EXTRA_CXXFLAGS="$EXTRA_CXXFLAGS -$cf_opt"
 		else
-			test -n "$verbose" && echo "$as_me:14651: result: ... no -$cf_opt" >&5
+			test -n "$verbose" && echo "$as_me:15148: result: ... no -$cf_opt" >&5
 echo "${ECHO_T}... no -$cf_opt" >&6
 		fi
 	done
@@ -14684,10 +15181,10 @@
 EOF
 if test "$GCC" = yes
 then
-	{ echo "$as_me:14687: checking for $CC __attribute__ directives..." >&5
+	{ echo "$as_me:15184: checking for $CC __attribute__ directives..." >&5
 echo "$as_me: checking for $CC __attribute__ directives..." >&6;}
 cat > conftest.$ac_ext <<EOF
-#line 14690 "${as_me:-configure}"
+#line 15187 "${as_me:-configure}"
 #include "confdefs.h"
 #include "conftest.h"
 #include "conftest.i"
@@ -14736,12 +15233,12 @@
 			;;
 		esac
 
-		if { (eval echo "$as_me:14739: \"$ac_compile\"") >&5
+		if { (eval echo "$as_me:15236: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:14742: \$? = $ac_status" >&5
+  echo "$as_me:15239: \$? = $ac_status" >&5
   (exit $ac_status); }; then
-			test -n "$verbose" && echo "$as_me:14744: result: ... $cf_attribute" >&5
+			test -n "$verbose" && echo "$as_me:15241: result: ... $cf_attribute" >&5
 echo "${ECHO_T}... $cf_attribute" >&6
 			cat conftest.h >>confdefs.h
 			case $cf_attribute in
@@ -14800,7 +15297,7 @@
 rm -rf conftest*
 fi
 
-echo "$as_me:14803: checking if you want to work around bogus compiler/loader warnings" >&5
+echo "$as_me:15300: checking if you want to work around bogus compiler/loader warnings" >&5
 echo $ECHO_N "checking if you want to work around bogus compiler/loader warnings... $ECHO_C" >&6
 
 # Check whether --enable-string-hacks or --disable-string-hacks was given.
@@ -14810,7 +15307,7 @@
 else
   with_string_hacks=no
 fi;
-echo "$as_me:14813: result: $with_string_hacks" >&5
+echo "$as_me:15310: result: $with_string_hacks" >&5
 echo "${ECHO_T}$with_string_hacks" >&6
 
 if test "x$with_string_hacks" = "xyes"; then
@@ -14819,15 +15316,15 @@
 #define USE_STRING_HACKS 1
 EOF
 
-	{ echo "$as_me:14822: WARNING: enabling string-hacks to work around bogus compiler/loader warnings" >&5
+	{ echo "$as_me:15319: WARNING: enabling string-hacks to work around bogus compiler/loader warnings" >&5
 echo "$as_me: WARNING: enabling string-hacks to work around bogus compiler/loader warnings" >&2;}
-	echo "$as_me:14824: checking for strlcat" >&5
+	echo "$as_me:15321: checking for strlcat" >&5
 echo $ECHO_N "checking for strlcat... $ECHO_C" >&6
 if test "${ac_cv_func_strlcat+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 14830 "configure"
+#line 15327 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char strlcat (); below.  */
@@ -14858,16 +15355,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14861: \"$ac_link\"") >&5
+if { (eval echo "$as_me:15358: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14864: \$? = $ac_status" >&5
+  echo "$as_me:15361: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14867: \"$ac_try\"") >&5
+  { (eval echo "$as_me:15364: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14870: \$? = $ac_status" >&5
+  echo "$as_me:15367: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_strlcat=yes
 else
@@ -14877,7 +15374,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:14880: result: $ac_cv_func_strlcat" >&5
+echo "$as_me:15377: result: $ac_cv_func_strlcat" >&5
 echo "${ECHO_T}$ac_cv_func_strlcat" >&6
 if test $ac_cv_func_strlcat = yes; then
 
@@ -14887,7 +15384,7 @@
 
 else
 
-		echo "$as_me:14890: checking for strlcat in -lbsd" >&5
+		echo "$as_me:15387: checking for strlcat in -lbsd" >&5
 echo $ECHO_N "checking for strlcat in -lbsd... $ECHO_C" >&6
 if test "${ac_cv_lib_bsd_strlcat+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14895,7 +15392,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lbsd  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 14898 "configure"
+#line 15395 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14914,16 +15411,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14917: \"$ac_link\"") >&5
+if { (eval echo "$as_me:15414: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14920: \$? = $ac_status" >&5
+  echo "$as_me:15417: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14923: \"$ac_try\"") >&5
+  { (eval echo "$as_me:15420: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14926: \$? = $ac_status" >&5
+  echo "$as_me:15423: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_bsd_strlcat=yes
 else
@@ -14934,7 +15431,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:14937: result: $ac_cv_lib_bsd_strlcat" >&5
+echo "$as_me:15434: result: $ac_cv_lib_bsd_strlcat" >&5
 echo "${ECHO_T}$ac_cv_lib_bsd_strlcat" >&6
 if test $ac_cv_lib_bsd_strlcat = yes; then
 
@@ -14957,23 +15454,23 @@
 for ac_header in bsd/string.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:14960: checking for $ac_header" >&5
+echo "$as_me:15457: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 14966 "configure"
+#line 15463 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:14970: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:15467: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:14976: \$? = $ac_status" >&5
+  echo "$as_me:15473: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -14992,7 +15489,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:14995: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:15492: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -15013,13 +15510,13 @@
 for ac_func in strlcpy snprintf
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:15016: checking for $ac_func" >&5
+echo "$as_me:15513: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 15022 "configure"
+#line 15519 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -15050,16 +15547,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:15053: \"$ac_link\"") >&5
+if { (eval echo "$as_me:15550: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:15056: \$? = $ac_status" >&5
+  echo "$as_me:15553: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:15059: \"$ac_try\"") >&5
+  { (eval echo "$as_me:15556: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:15062: \$? = $ac_status" >&5
+  echo "$as_me:15559: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -15069,7 +15566,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:15072: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:15569: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -15082,7 +15579,7 @@
 fi
 
 ###	use option --enable-assertions to turn on generation of assertion code
-echo "$as_me:15085: checking if you want to enable runtime assertions" >&5
+echo "$as_me:15582: checking if you want to enable runtime assertions" >&5
 echo $ECHO_N "checking if you want to enable runtime assertions... $ECHO_C" >&6
 
 # Check whether --enable-assertions or --disable-assertions was given.
@@ -15092,7 +15589,7 @@
 else
   with_assertions=no
 fi;
-echo "$as_me:15095: result: $with_assertions" >&5
+echo "$as_me:15592: result: $with_assertions" >&5
 echo "${ECHO_T}$with_assertions" >&6
 if test -n "$GCC"
 then
@@ -15108,7 +15605,7 @@
 
 ###	use option --disable-leaks to suppress "permanent" leaks, for testing
 
-echo "$as_me:15111: checking if you want to use dmalloc for testing" >&5
+echo "$as_me:15608: checking if you want to use dmalloc for testing" >&5
 echo $ECHO_N "checking if you want to use dmalloc for testing... $ECHO_C" >&6
 
 # Check whether --with-dmalloc or --without-dmalloc was given.
@@ -15125,7 +15622,7 @@
 else
   with_dmalloc=
 fi;
-echo "$as_me:15128: result: ${with_dmalloc:-no}" >&5
+echo "$as_me:15625: result: ${with_dmalloc:-no}" >&5
 echo "${ECHO_T}${with_dmalloc:-no}" >&6
 
 case .$with_cflags in
@@ -15239,23 +15736,23 @@
 esac
 
 if test "$with_dmalloc" = yes ; then
-	echo "$as_me:15242: checking for dmalloc.h" >&5
+	echo "$as_me:15739: checking for dmalloc.h" >&5
 echo $ECHO_N "checking for dmalloc.h... $ECHO_C" >&6
 if test "${ac_cv_header_dmalloc_h+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 15248 "configure"
+#line 15745 "configure"
 #include "confdefs.h"
 #include <dmalloc.h>
 _ACEOF
-if { (eval echo "$as_me:15252: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:15749: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:15258: \$? = $ac_status" >&5
+  echo "$as_me:15755: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -15274,11 +15771,11 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:15277: result: $ac_cv_header_dmalloc_h" >&5
+echo "$as_me:15774: result: $ac_cv_header_dmalloc_h" >&5
 echo "${ECHO_T}$ac_cv_header_dmalloc_h" >&6
 if test $ac_cv_header_dmalloc_h = yes; then
 
-echo "$as_me:15281: checking for dmalloc_debug in -ldmalloc" >&5
+echo "$as_me:15778: checking for dmalloc_debug in -ldmalloc" >&5
 echo $ECHO_N "checking for dmalloc_debug in -ldmalloc... $ECHO_C" >&6
 if test "${ac_cv_lib_dmalloc_dmalloc_debug+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -15286,7 +15783,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-ldmalloc  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 15289 "configure"
+#line 15786 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -15305,16 +15802,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:15308: \"$ac_link\"") >&5
+if { (eval echo "$as_me:15805: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:15311: \$? = $ac_status" >&5
+  echo "$as_me:15808: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:15314: \"$ac_try\"") >&5
+  { (eval echo "$as_me:15811: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:15317: \$? = $ac_status" >&5
+  echo "$as_me:15814: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_dmalloc_dmalloc_debug=yes
 else
@@ -15325,7 +15822,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:15328: result: $ac_cv_lib_dmalloc_dmalloc_debug" >&5
+echo "$as_me:15825: result: $ac_cv_lib_dmalloc_dmalloc_debug" >&5
 echo "${ECHO_T}$ac_cv_lib_dmalloc_dmalloc_debug" >&6
 if test $ac_cv_lib_dmalloc_dmalloc_debug = yes; then
   cat >>confdefs.h <<EOF
@@ -15340,7 +15837,7 @@
 
 fi
 
-echo "$as_me:15343: checking if you want to use dbmalloc for testing" >&5
+echo "$as_me:15840: checking if you want to use dbmalloc for testing" >&5
 echo $ECHO_N "checking if you want to use dbmalloc for testing... $ECHO_C" >&6
 
 # Check whether --with-dbmalloc or --without-dbmalloc was given.
@@ -15357,7 +15854,7 @@
 else
   with_dbmalloc=
 fi;
-echo "$as_me:15360: result: ${with_dbmalloc:-no}" >&5
+echo "$as_me:15857: result: ${with_dbmalloc:-no}" >&5
 echo "${ECHO_T}${with_dbmalloc:-no}" >&6
 
 case .$with_cflags in
@@ -15471,23 +15968,23 @@
 esac
 
 if test "$with_dbmalloc" = yes ; then
-	echo "$as_me:15474: checking for dbmalloc.h" >&5
+	echo "$as_me:15971: checking for dbmalloc.h" >&5
 echo $ECHO_N "checking for dbmalloc.h... $ECHO_C" >&6
 if test "${ac_cv_header_dbmalloc_h+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 15480 "configure"
+#line 15977 "configure"
 #include "confdefs.h"
 #include <dbmalloc.h>
 _ACEOF
-if { (eval echo "$as_me:15484: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:15981: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:15490: \$? = $ac_status" >&5
+  echo "$as_me:15987: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -15506,11 +16003,11 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:15509: result: $ac_cv_header_dbmalloc_h" >&5
+echo "$as_me:16006: result: $ac_cv_header_dbmalloc_h" >&5
 echo "${ECHO_T}$ac_cv_header_dbmalloc_h" >&6
 if test $ac_cv_header_dbmalloc_h = yes; then
 
-echo "$as_me:15513: checking for debug_malloc in -ldbmalloc" >&5
+echo "$as_me:16010: checking for debug_malloc in -ldbmalloc" >&5
 echo $ECHO_N "checking for debug_malloc in -ldbmalloc... $ECHO_C" >&6
 if test "${ac_cv_lib_dbmalloc_debug_malloc+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -15518,7 +16015,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-ldbmalloc  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 15521 "configure"
+#line 16018 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -15537,16 +16034,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:15540: \"$ac_link\"") >&5
+if { (eval echo "$as_me:16037: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:15543: \$? = $ac_status" >&5
+  echo "$as_me:16040: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:15546: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16043: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:15549: \$? = $ac_status" >&5
+  echo "$as_me:16046: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_dbmalloc_debug_malloc=yes
 else
@@ -15557,7 +16054,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:15560: result: $ac_cv_lib_dbmalloc_debug_malloc" >&5
+echo "$as_me:16057: result: $ac_cv_lib_dbmalloc_debug_malloc" >&5
 echo "${ECHO_T}$ac_cv_lib_dbmalloc_debug_malloc" >&6
 if test $ac_cv_lib_dbmalloc_debug_malloc = yes; then
   cat >>confdefs.h <<EOF
@@ -15572,7 +16069,7 @@
 
 fi
 
-echo "$as_me:15575: checking if you want to use valgrind for testing" >&5
+echo "$as_me:16072: checking if you want to use valgrind for testing" >&5
 echo $ECHO_N "checking if you want to use valgrind for testing... $ECHO_C" >&6
 
 # Check whether --with-valgrind or --without-valgrind was given.
@@ -15589,7 +16086,7 @@
 else
   with_valgrind=
 fi;
-echo "$as_me:15592: result: ${with_valgrind:-no}" >&5
+echo "$as_me:16089: result: ${with_valgrind:-no}" >&5
 echo "${ECHO_T}${with_valgrind:-no}" >&6
 
 case .$with_cflags in
@@ -15702,7 +16199,7 @@
 	;;
 esac
 
-echo "$as_me:15705: checking if you want to perform memory-leak testing" >&5
+echo "$as_me:16202: checking if you want to perform memory-leak testing" >&5
 echo $ECHO_N "checking if you want to perform memory-leak testing... $ECHO_C" >&6
 
 # Check whether --enable-leaks or --disable-leaks was given.
@@ -15712,7 +16209,7 @@
 else
   : ${with_no_leaks:=no}
 fi;
-echo "$as_me:15715: result: $with_no_leaks" >&5
+echo "$as_me:16212: result: $with_no_leaks" >&5
 echo "${ECHO_T}$with_no_leaks" >&6
 
 if test "$with_no_leaks" = yes ; then
@@ -15764,7 +16261,7 @@
 	;;
 esac
 
-echo "$as_me:15767: checking whether to add trace feature to all models" >&5
+echo "$as_me:16264: checking whether to add trace feature to all models" >&5
 echo $ECHO_N "checking whether to add trace feature to all models... $ECHO_C" >&6
 
 # Check whether --with-trace or --without-trace was given.
@@ -15774,7 +16271,7 @@
 else
   cf_with_trace=$cf_all_traces
 fi;
-echo "$as_me:15777: result: $cf_with_trace" >&5
+echo "$as_me:16274: result: $cf_with_trace" >&5
 echo "${ECHO_T}$cf_with_trace" >&6
 
 if test "x$cf_with_trace" = xyes ; then
@@ -15888,7 +16385,7 @@
 	ADA_TRACE=FALSE
 fi
 
-echo "$as_me:15891: checking if we want to use GNAT projects" >&5
+echo "$as_me:16388: checking if we want to use GNAT projects" >&5
 echo $ECHO_N "checking if we want to use GNAT projects... $ECHO_C" >&6
 
 # Check whether --enable-gnat-projects or --disable-gnat-projects was given.
@@ -15905,7 +16402,7 @@
 	enable_gnat_projects=yes
 
 fi;
-echo "$as_me:15908: result: $enable_gnat_projects" >&5
+echo "$as_me:16405: result: $enable_gnat_projects" >&5
 echo "${ECHO_T}$enable_gnat_projects" >&6
 
 ###	Checks for libraries.
@@ -15915,13 +16412,13 @@
 	LIBS=" -lpsapi $LIBS"
 	;;
 (*)
-echo "$as_me:15918: checking for gettimeofday" >&5
+echo "$as_me:16415: checking for gettimeofday" >&5
 echo $ECHO_N "checking for gettimeofday... $ECHO_C" >&6
 if test "${ac_cv_func_gettimeofday+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 15924 "configure"
+#line 16421 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char gettimeofday (); below.  */
@@ -15952,16 +16449,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:15955: \"$ac_link\"") >&5
+if { (eval echo "$as_me:16452: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:15958: \$? = $ac_status" >&5
+  echo "$as_me:16455: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:15961: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16458: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:15964: \$? = $ac_status" >&5
+  echo "$as_me:16461: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_gettimeofday=yes
 else
@@ -15971,7 +16468,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:15974: result: $ac_cv_func_gettimeofday" >&5
+echo "$as_me:16471: result: $ac_cv_func_gettimeofday" >&5
 echo "${ECHO_T}$ac_cv_func_gettimeofday" >&6
 if test $ac_cv_func_gettimeofday = yes; then
 
@@ -15981,7 +16478,7 @@
 
 else
 
-echo "$as_me:15984: checking for gettimeofday in -lbsd" >&5
+echo "$as_me:16481: checking for gettimeofday in -lbsd" >&5
 echo $ECHO_N "checking for gettimeofday in -lbsd... $ECHO_C" >&6
 if test "${ac_cv_lib_bsd_gettimeofday+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -15989,7 +16486,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lbsd  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 15992 "configure"
+#line 16489 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -16008,16 +16505,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:16011: \"$ac_link\"") >&5
+if { (eval echo "$as_me:16508: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:16014: \$? = $ac_status" >&5
+  echo "$as_me:16511: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:16017: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16514: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16020: \$? = $ac_status" >&5
+  echo "$as_me:16517: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_bsd_gettimeofday=yes
 else
@@ -16028,7 +16525,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:16031: result: $ac_cv_lib_bsd_gettimeofday" >&5
+echo "$as_me:16528: result: $ac_cv_lib_bsd_gettimeofday" >&5
 echo "${ECHO_T}$ac_cv_lib_bsd_gettimeofday" >&6
 if test $ac_cv_lib_bsd_gettimeofday = yes; then
 
@@ -16058,14 +16555,14 @@
 	;;
 esac
 
-echo "$as_me:16061: checking if -lm needed for math functions" >&5
+echo "$as_me:16558: checking if -lm needed for math functions" >&5
 echo $ECHO_N "checking if -lm needed for math functions... $ECHO_C" >&6
 if test "${cf_cv_need_libm+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 16068 "configure"
+#line 16565 "configure"
 #include "confdefs.h"
 
 	#include <stdio.h>
@@ -16081,16 +16578,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:16084: \"$ac_link\"") >&5
+if { (eval echo "$as_me:16581: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:16087: \$? = $ac_status" >&5
+  echo "$as_me:16584: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:16090: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16587: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16093: \$? = $ac_status" >&5
+  echo "$as_me:16590: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_need_libm=no
 else
@@ -16100,7 +16597,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:16103: result: $cf_cv_need_libm" >&5
+echo "$as_me:16600: result: $cf_cv_need_libm" >&5
 echo "${ECHO_T}$cf_cv_need_libm" >&6
 if test "$cf_cv_need_libm" = yes
 then
@@ -16108,13 +16605,13 @@
 fi
 
 ###	Checks for header files.
-echo "$as_me:16111: checking for ANSI C header files" >&5
+echo "$as_me:16608: checking for ANSI C header files" >&5
 echo $ECHO_N "checking for ANSI C header files... $ECHO_C" >&6
 if test "${ac_cv_header_stdc+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 16117 "configure"
+#line 16614 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 #include <stdarg.h>
@@ -16122,13 +16619,13 @@
 #include <float.h>
 
 _ACEOF
-if { (eval echo "$as_me:16125: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:16622: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:16131: \$? = $ac_status" >&5
+  echo "$as_me:16628: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -16150,7 +16647,7 @@
 if test $ac_cv_header_stdc = yes; then
   # SunOS 4.x string.h does not declare mem*, contrary to ANSI.
   cat >conftest.$ac_ext <<_ACEOF
-#line 16153 "configure"
+#line 16650 "configure"
 #include "confdefs.h"
 #include <string.h>
 
@@ -16168,7 +16665,7 @@
 if test $ac_cv_header_stdc = yes; then
   # ISC 2.0.2 stdlib.h does not declare free, contrary to ANSI.
   cat >conftest.$ac_ext <<_ACEOF
-#line 16171 "configure"
+#line 16668 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 
@@ -16189,7 +16686,7 @@
   :
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 16192 "configure"
+#line 16689 "configure"
 #include "confdefs.h"
 #include <ctype.h>
 #if ((' ' & 0x0FF) == 0x020)
@@ -16215,15 +16712,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:16218: \"$ac_link\"") >&5
+if { (eval echo "$as_me:16715: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:16221: \$? = $ac_status" >&5
+  echo "$as_me:16718: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:16223: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16720: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16226: \$? = $ac_status" >&5
+  echo "$as_me:16723: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   :
 else
@@ -16236,7 +16733,7 @@
 fi
 fi
 fi
-echo "$as_me:16239: result: $ac_cv_header_stdc" >&5
+echo "$as_me:16736: result: $ac_cv_header_stdc" >&5
 echo "${ECHO_T}$ac_cv_header_stdc" >&6
 if test $ac_cv_header_stdc = yes; then
 
@@ -16249,13 +16746,13 @@
 ac_header_dirent=no
 for ac_hdr in dirent.h sys/ndir.h sys/dir.h ndir.h; do
   as_ac_Header=`echo "ac_cv_header_dirent_$ac_hdr" | $as_tr_sh`
-echo "$as_me:16252: checking for $ac_hdr that defines DIR" >&5
+echo "$as_me:16749: checking for $ac_hdr that defines DIR" >&5
 echo $ECHO_N "checking for $ac_hdr that defines DIR... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 16258 "configure"
+#line 16755 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <$ac_hdr>
@@ -16270,16 +16767,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:16273: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:16770: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:16276: \$? = $ac_status" >&5
+  echo "$as_me:16773: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:16279: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16776: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16282: \$? = $ac_status" >&5
+  echo "$as_me:16779: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_Header=yes"
 else
@@ -16289,7 +16786,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:16292: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:16789: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -16302,7 +16799,7 @@
 done
 # Two versions of opendir et al. are in -ldir and -lx on SCO Xenix.
 if test $ac_header_dirent = dirent.h; then
-  echo "$as_me:16305: checking for opendir in -ldir" >&5
+  echo "$as_me:16802: checking for opendir in -ldir" >&5
 echo $ECHO_N "checking for opendir in -ldir... $ECHO_C" >&6
 if test "${ac_cv_lib_dir_opendir+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -16310,7 +16807,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-ldir  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 16313 "configure"
+#line 16810 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -16329,16 +16826,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:16332: \"$ac_link\"") >&5
+if { (eval echo "$as_me:16829: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:16335: \$? = $ac_status" >&5
+  echo "$as_me:16832: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:16338: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16835: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16341: \$? = $ac_status" >&5
+  echo "$as_me:16838: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_dir_opendir=yes
 else
@@ -16349,14 +16846,14 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:16352: result: $ac_cv_lib_dir_opendir" >&5
+echo "$as_me:16849: result: $ac_cv_lib_dir_opendir" >&5
 echo "${ECHO_T}$ac_cv_lib_dir_opendir" >&6
 if test $ac_cv_lib_dir_opendir = yes; then
   LIBS="$LIBS -ldir"
 fi
 
 else
-  echo "$as_me:16359: checking for opendir in -lx" >&5
+  echo "$as_me:16856: checking for opendir in -lx" >&5
 echo $ECHO_N "checking for opendir in -lx... $ECHO_C" >&6
 if test "${ac_cv_lib_x_opendir+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -16364,7 +16861,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lx  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 16367 "configure"
+#line 16864 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -16383,16 +16880,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:16386: \"$ac_link\"") >&5
+if { (eval echo "$as_me:16883: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:16389: \$? = $ac_status" >&5
+  echo "$as_me:16886: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:16392: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16889: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16395: \$? = $ac_status" >&5
+  echo "$as_me:16892: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_x_opendir=yes
 else
@@ -16403,7 +16900,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:16406: result: $ac_cv_lib_x_opendir" >&5
+echo "$as_me:16903: result: $ac_cv_lib_x_opendir" >&5
 echo "${ECHO_T}$ac_cv_lib_x_opendir" >&6
 if test $ac_cv_lib_x_opendir = yes; then
   LIBS="$LIBS -lx"
@@ -16411,13 +16908,13 @@
 
 fi
 
-echo "$as_me:16414: checking whether time.h and sys/time.h may both be included" >&5
+echo "$as_me:16911: checking whether time.h and sys/time.h may both be included" >&5
 echo $ECHO_N "checking whether time.h and sys/time.h may both be included... $ECHO_C" >&6
 if test "${ac_cv_header_time+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 16420 "configure"
+#line 16917 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <sys/time.h>
@@ -16433,16 +16930,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:16436: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:16933: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:16439: \$? = $ac_status" >&5
+  echo "$as_me:16936: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:16442: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16939: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16445: \$? = $ac_status" >&5
+  echo "$as_me:16942: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_header_time=yes
 else
@@ -16452,7 +16949,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:16455: result: $ac_cv_header_time" >&5
+echo "$as_me:16952: result: $ac_cv_header_time" >&5
 echo "${ECHO_T}$ac_cv_header_time" >&6
 if test $ac_cv_header_time = yes; then
 
@@ -16471,13 +16968,13 @@
 	;;
 esac
 
-echo "$as_me:16474: checking for regcomp" >&5
+echo "$as_me:16971: checking for regcomp" >&5
 echo $ECHO_N "checking for regcomp... $ECHO_C" >&6
 if test "${ac_cv_func_regcomp+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 16480 "configure"
+#line 16977 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char regcomp (); below.  */
@@ -16508,16 +17005,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:16511: \"$ac_link\"") >&5
+if { (eval echo "$as_me:17008: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:16514: \$? = $ac_status" >&5
+  echo "$as_me:17011: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:16517: \"$ac_try\"") >&5
+  { (eval echo "$as_me:17014: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16520: \$? = $ac_status" >&5
+  echo "$as_me:17017: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_regcomp=yes
 else
@@ -16527,7 +17024,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:16530: result: $ac_cv_func_regcomp" >&5
+echo "$as_me:17027: result: $ac_cv_func_regcomp" >&5
 echo "${ECHO_T}$ac_cv_func_regcomp" >&6
 if test $ac_cv_func_regcomp = yes; then
   cf_regex_func=regcomp
@@ -16536,7 +17033,7 @@
 	for cf_regex_lib in $cf_regex_libs
 	do
 		as_ac_Lib=`echo "ac_cv_lib_$cf_regex_lib''_regcomp" | $as_tr_sh`
-echo "$as_me:16539: checking for regcomp in -l$cf_regex_lib" >&5
+echo "$as_me:17036: checking for regcomp in -l$cf_regex_lib" >&5
 echo $ECHO_N "checking for regcomp in -l$cf_regex_lib... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Lib+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -16544,7 +17041,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-l$cf_regex_lib  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 16547 "configure"
+#line 17044 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -16563,16 +17060,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:16566: \"$ac_link\"") >&5
+if { (eval echo "$as_me:17063: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:16569: \$? = $ac_status" >&5
+  echo "$as_me:17066: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:16572: \"$ac_try\"") >&5
+  { (eval echo "$as_me:17069: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16575: \$? = $ac_status" >&5
+  echo "$as_me:17072: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_Lib=yes"
 else
@@ -16583,7 +17080,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:16586: result: `eval echo '${'$as_ac_Lib'}'`" >&5
+echo "$as_me:17083: result: `eval echo '${'$as_ac_Lib'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Lib'}'`" >&6
 if test `eval echo '${'$as_ac_Lib'}'` = yes; then
 
@@ -16612,13 +17109,13 @@
 fi
 
 if test "$cf_regex_func" = no ; then
-	echo "$as_me:16615: checking for compile" >&5
+	echo "$as_me:17112: checking for compile" >&5
 echo $ECHO_N "checking for compile... $ECHO_C" >&6
 if test "${ac_cv_func_compile+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 16621 "configure"
+#line 17118 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char compile (); below.  */
@@ -16649,16 +17146,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:16652: \"$ac_link\"") >&5
+if { (eval echo "$as_me:17149: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:16655: \$? = $ac_status" >&5
+  echo "$as_me:17152: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:16658: \"$ac_try\"") >&5
+  { (eval echo "$as_me:17155: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16661: \$? = $ac_status" >&5
+  echo "$as_me:17158: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_compile=yes
 else
@@ -16668,13 +17165,13 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:16671: result: $ac_cv_func_compile" >&5
+echo "$as_me:17168: result: $ac_cv_func_compile" >&5
 echo "${ECHO_T}$ac_cv_func_compile" >&6
 if test $ac_cv_func_compile = yes; then
   cf_regex_func=compile
 else
 
-		echo "$as_me:16677: checking for compile in -lgen" >&5
+		echo "$as_me:17174: checking for compile in -lgen" >&5
 echo $ECHO_N "checking for compile in -lgen... $ECHO_C" >&6
 if test "${ac_cv_lib_gen_compile+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -16682,7 +17179,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lgen  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 16685 "configure"
+#line 17182 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -16701,16 +17198,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:16704: \"$ac_link\"") >&5
+if { (eval echo "$as_me:17201: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:16707: \$? = $ac_status" >&5
+  echo "$as_me:17204: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:16710: \"$ac_try\"") >&5
+  { (eval echo "$as_me:17207: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16713: \$? = $ac_status" >&5
+  echo "$as_me:17210: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_gen_compile=yes
 else
@@ -16721,7 +17218,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:16724: result: $ac_cv_lib_gen_compile" >&5
+echo "$as_me:17221: result: $ac_cv_lib_gen_compile" >&5
 echo "${ECHO_T}$ac_cv_lib_gen_compile" >&6
 if test $ac_cv_lib_gen_compile = yes; then
 
@@ -16749,11 +17246,11 @@
 fi
 
 if test "$cf_regex_func" = no ; then
-	{ echo "$as_me:16752: WARNING: cannot find regular expression library" >&5
+	{ echo "$as_me:17249: WARNING: cannot find regular expression library" >&5
 echo "$as_me: WARNING: cannot find regular expression library" >&2;}
 fi
 
-echo "$as_me:16756: checking for regular-expression headers" >&5
+echo "$as_me:17253: checking for regular-expression headers" >&5
 echo $ECHO_N "checking for regular-expression headers... $ECHO_C" >&6
 if test "${cf_cv_regex_hdrs+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -16765,7 +17262,7 @@
 	for cf_regex_hdr in regexp.h regexpr.h
 	do
 		cat >conftest.$ac_ext <<_ACEOF
-#line 16768 "configure"
+#line 17265 "configure"
 #include "confdefs.h"
 #include <$cf_regex_hdr>
 int
@@ -16780,16 +17277,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:16783: \"$ac_link\"") >&5
+if { (eval echo "$as_me:17280: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:16786: \$? = $ac_status" >&5
+  echo "$as_me:17283: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:16789: \"$ac_try\"") >&5
+  { (eval echo "$as_me:17286: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16792: \$? = $ac_status" >&5
+  echo "$as_me:17289: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 			cf_cv_regex_hdrs=$cf_regex_hdr
@@ -16806,7 +17303,7 @@
 	for cf_regex_hdr in regex.h
 	do
 		cat >conftest.$ac_ext <<_ACEOF
-#line 16809 "configure"
+#line 17306 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <$cf_regex_hdr>
@@ -16824,16 +17321,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:16827: \"$ac_link\"") >&5
+if { (eval echo "$as_me:17324: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:16830: \$? = $ac_status" >&5
+  echo "$as_me:17327: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:16833: \"$ac_try\"") >&5
+  { (eval echo "$as_me:17330: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16836: \$? = $ac_status" >&5
+  echo "$as_me:17333: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 			cf_cv_regex_hdrs=$cf_regex_hdr
@@ -16849,11 +17346,11 @@
 esac
 
 fi
-echo "$as_me:16852: result: $cf_cv_regex_hdrs" >&5
+echo "$as_me:17349: result: $cf_cv_regex_hdrs" >&5
 echo "${ECHO_T}$cf_cv_regex_hdrs" >&6
 
 case $cf_cv_regex_hdrs in
-	(no)		{ echo "$as_me:16856: WARNING: no regular expression header found" >&5
+	(no)		{ echo "$as_me:17353: WARNING: no regular expression header found" >&5
 echo "$as_me: WARNING: no regular expression header found" >&2;} ;;
 	(regex.h)
 cat >>confdefs.h <<\EOF
@@ -16892,23 +17389,23 @@
 
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:16895: checking for $ac_header" >&5
+echo "$as_me:17392: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 16901 "configure"
+#line 17398 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:16905: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:17402: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:16911: \$? = $ac_status" >&5
+  echo "$as_me:17408: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -16927,7 +17424,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:16930: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:17427: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -16940,23 +17437,23 @@
 for ac_header in unistd.h getopt.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:16943: checking for $ac_header" >&5
+echo "$as_me:17440: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 16949 "configure"
+#line 17446 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:16953: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:17450: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:16959: \$? = $ac_status" >&5
+  echo "$as_me:17456: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -16975,7 +17472,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:16978: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:17475: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -16985,7 +17482,7 @@
 fi
 done
 
-echo "$as_me:16988: checking for header declaring getopt variables" >&5
+echo "$as_me:17485: checking for header declaring getopt variables" >&5
 echo $ECHO_N "checking for header declaring getopt variables... $ECHO_C" >&6
 if test "${cf_cv_getopt_header+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -16995,7 +17492,7 @@
 for cf_header in stdio.h stdlib.h unistd.h getopt.h
 do
 cat >conftest.$ac_ext <<_ACEOF
-#line 16998 "configure"
+#line 17495 "configure"
 #include "confdefs.h"
 
 #include <$cf_header>
@@ -17008,16 +17505,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:17011: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:17508: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:17014: \$? = $ac_status" >&5
+  echo "$as_me:17511: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:17017: \"$ac_try\"") >&5
+  { (eval echo "$as_me:17514: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:17020: \$? = $ac_status" >&5
+  echo "$as_me:17517: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_getopt_header=$cf_header
  break
@@ -17029,7 +17526,7 @@
 done
 
 fi
-echo "$as_me:17032: result: $cf_cv_getopt_header" >&5
+echo "$as_me:17529: result: $cf_cv_getopt_header" >&5
 echo "${ECHO_T}$cf_cv_getopt_header" >&6
 if test $cf_cv_getopt_header != none ; then
 
@@ -17050,7 +17547,7 @@
 # Note: even non-Posix ISC needs <sys/bsdtypes.h> to declare fd_set
 if test "x$ISC" = xyes ; then
 
-echo "$as_me:17053: checking for main in -lcposix" >&5
+echo "$as_me:17550: checking for main in -lcposix" >&5
 echo $ECHO_N "checking for main in -lcposix... $ECHO_C" >&6
 if test "${ac_cv_lib_cposix_main+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -17058,7 +17555,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lcposix  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 17061 "configure"
+#line 17558 "configure"
 #include "confdefs.h"
 
 int
@@ -17070,16 +17567,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:17073: \"$ac_link\"") >&5
+if { (eval echo "$as_me:17570: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:17076: \$? = $ac_status" >&5
+  echo "$as_me:17573: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:17079: \"$ac_try\"") >&5
+  { (eval echo "$as_me:17576: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:17082: \$? = $ac_status" >&5
+  echo "$as_me:17579: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_cposix_main=yes
 else
@@ -17090,7 +17587,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:17093: result: $ac_cv_lib_cposix_main" >&5
+echo "$as_me:17590: result: $ac_cv_lib_cposix_main" >&5
 echo "${ECHO_T}$ac_cv_lib_cposix_main" >&6
 if test $ac_cv_lib_cposix_main = yes; then
   cat >>confdefs.h <<EOF
@@ -17101,7 +17598,7 @@
 
 fi
 
-	echo "$as_me:17104: checking for bzero in -linet" >&5
+	echo "$as_me:17601: checking for bzero in -linet" >&5
 echo $ECHO_N "checking for bzero in -linet... $ECHO_C" >&6
 if test "${ac_cv_lib_inet_bzero+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -17109,7 +17606,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-linet  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 17112 "configure"
+#line 17609 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -17128,16 +17625,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:17131: \"$ac_link\"") >&5
+if { (eval echo "$as_me:17628: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:17134: \$? = $ac_status" >&5
+  echo "$as_me:17631: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:17137: \"$ac_try\"") >&5
+  { (eval echo "$as_me:17634: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:17140: \$? = $ac_status" >&5
+  echo "$as_me:17637: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_inet_bzero=yes
 else
@@ -17148,7 +17645,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:17151: result: $ac_cv_lib_inet_bzero" >&5
+echo "$as_me:17648: result: $ac_cv_lib_inet_bzero" >&5
 echo "${ECHO_T}$ac_cv_lib_inet_bzero" >&6
 if test $ac_cv_lib_inet_bzero = yes; then
 
@@ -17171,14 +17668,14 @@
 fi
 fi
 
-echo "$as_me:17174: checking if sys/time.h works with sys/select.h" >&5
+echo "$as_me:17671: checking if sys/time.h works with sys/select.h" >&5
 echo $ECHO_N "checking if sys/time.h works with sys/select.h... $ECHO_C" >&6
 if test "${cf_cv_sys_time_select+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 17181 "configure"
+#line 17678 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -17198,16 +17695,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:17201: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:17698: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:17204: \$? = $ac_status" >&5
+  echo "$as_me:17701: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:17207: \"$ac_try\"") >&5
+  { (eval echo "$as_me:17704: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:17210: \$? = $ac_status" >&5
+  echo "$as_me:17707: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_sys_time_select=yes
 else
@@ -17219,7 +17716,7 @@
 
 fi
 
-echo "$as_me:17222: result: $cf_cv_sys_time_select" >&5
+echo "$as_me:17719: result: $cf_cv_sys_time_select" >&5
 echo "${ECHO_T}$cf_cv_sys_time_select" >&6
 test "$cf_cv_sys_time_select" = yes &&
 cat >>confdefs.h <<\EOF
@@ -17234,13 +17731,13 @@
 ac_compiler_gnu=$ac_cv_c_compiler_gnu
 ac_main_return=return
 
-echo "$as_me:17237: checking for an ANSI C-conforming const" >&5
+echo "$as_me:17734: checking for an ANSI C-conforming const" >&5
 echo $ECHO_N "checking for an ANSI C-conforming const... $ECHO_C" >&6
 if test "${ac_cv_c_const+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 17243 "configure"
+#line 17740 "configure"
 #include "confdefs.h"
 
 int
@@ -17298,16 +17795,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:17301: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:17798: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:17304: \$? = $ac_status" >&5
+  echo "$as_me:17801: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:17307: \"$ac_try\"") >&5
+  { (eval echo "$as_me:17804: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:17310: \$? = $ac_status" >&5
+  echo "$as_me:17807: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_c_const=yes
 else
@@ -17317,7 +17814,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:17320: result: $ac_cv_c_const" >&5
+echo "$as_me:17817: result: $ac_cv_c_const" >&5
 echo "${ECHO_T}$ac_cv_c_const" >&6
 if test $ac_cv_c_const = no; then
 
@@ -17327,7 +17824,7 @@
 
 fi
 
-echo "$as_me:17330: checking for inline" >&5
+echo "$as_me:17827: checking for inline" >&5
 echo $ECHO_N "checking for inline... $ECHO_C" >&6
 if test "${ac_cv_c_inline+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -17335,7 +17832,7 @@
   ac_cv_c_inline=no
 for ac_kw in inline __inline__ __inline; do
   cat >conftest.$ac_ext <<_ACEOF
-#line 17338 "configure"
+#line 17835 "configure"
 #include "confdefs.h"
 #ifndef __cplusplus
 static $ac_kw int static_foo () {return 0; }
@@ -17344,16 +17841,16 @@
 
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:17347: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:17844: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:17350: \$? = $ac_status" >&5
+  echo "$as_me:17847: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:17353: \"$ac_try\"") >&5
+  { (eval echo "$as_me:17850: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:17356: \$? = $ac_status" >&5
+  echo "$as_me:17853: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_c_inline=$ac_kw; break
 else
@@ -17364,7 +17861,7 @@
 done
 
 fi
-echo "$as_me:17367: result: $ac_cv_c_inline" >&5
+echo "$as_me:17864: result: $ac_cv_c_inline" >&5
 echo "${ECHO_T}$ac_cv_c_inline" >&6
 case $ac_cv_c_inline in
   inline | yes) ;;
@@ -17390,7 +17887,7 @@
 		:
 	elif test "$GCC" = yes
 	then
-		echo "$as_me:17393: checking if $CC supports options to tune inlining" >&5
+		echo "$as_me:17890: checking if $CC supports options to tune inlining" >&5
 echo $ECHO_N "checking if $CC supports options to tune inlining... $ECHO_C" >&6
 if test "${cf_cv_gcc_inline+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -17399,7 +17896,7 @@
 		cf_save_CFLAGS=$CFLAGS
 		CFLAGS="$CFLAGS --param max-inline-insns-single=1200"
 		cat >conftest.$ac_ext <<_ACEOF
-#line 17402 "configure"
+#line 17899 "configure"
 #include "confdefs.h"
 inline int foo(void) { return 1; }
 int
@@ -17411,16 +17908,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:17414: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:17911: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:17417: \$? = $ac_status" >&5
+  echo "$as_me:17914: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:17420: \"$ac_try\"") >&5
+  { (eval echo "$as_me:17917: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:17423: \$? = $ac_status" >&5
+  echo "$as_me:17920: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_gcc_inline=yes
 else
@@ -17432,7 +17929,7 @@
 		CFLAGS=$cf_save_CFLAGS
 
 fi
-echo "$as_me:17435: result: $cf_cv_gcc_inline" >&5
+echo "$as_me:17932: result: $cf_cv_gcc_inline" >&5
 echo "${ECHO_T}$cf_cv_gcc_inline" >&6
 		if test "$cf_cv_gcc_inline" = yes ; then
 
@@ -17538,7 +18035,7 @@
 	fi
 fi
 
-echo "$as_me:17541: checking for signal global datatype" >&5
+echo "$as_me:18038: checking for signal global datatype" >&5
 echo $ECHO_N "checking for signal global datatype... $ECHO_C" >&6
 if test "${cf_cv_sig_atomic_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -17550,7 +18047,7 @@
 		"int"
 	do
 	cat >conftest.$ac_ext <<_ACEOF
-#line 17553 "configure"
+#line 18050 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -17573,16 +18070,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:17576: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:18073: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:17579: \$? = $ac_status" >&5
+  echo "$as_me:18076: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:17582: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18079: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:17585: \$? = $ac_status" >&5
+  echo "$as_me:18082: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_sig_atomic_t=$cf_type
 else
@@ -17596,7 +18093,7 @@
 
 fi
 
-echo "$as_me:17599: result: $cf_cv_sig_atomic_t" >&5
+echo "$as_me:18096: result: $cf_cv_sig_atomic_t" >&5
 echo "${ECHO_T}$cf_cv_sig_atomic_t" >&6
 test "$cf_cv_sig_atomic_t" != no &&
 cat >>confdefs.h <<EOF
@@ -17605,7 +18102,7 @@
 
 if test $NCURSES_CHTYPE = auto ; then
 
-echo "$as_me:17608: checking for type of chtype" >&5
+echo "$as_me:18105: checking for type of chtype" >&5
 echo $ECHO_N "checking for type of chtype... $ECHO_C" >&6
 if test "${cf_cv_typeof_chtype+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -17615,7 +18112,7 @@
   cf_cv_typeof_chtype=long
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 17618 "configure"
+#line 18115 "configure"
 #include "confdefs.h"
 
 #define WANT_BITS 31
@@ -17650,15 +18147,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:17653: \"$ac_link\"") >&5
+if { (eval echo "$as_me:18150: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:17656: \$? = $ac_status" >&5
+  echo "$as_me:18153: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:17658: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18155: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:17661: \$? = $ac_status" >&5
+  echo "$as_me:18158: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_typeof_chtype=`cat cf_test.out`
 else
@@ -17673,7 +18170,7 @@
 
 fi
 
-echo "$as_me:17676: result: $cf_cv_typeof_chtype" >&5
+echo "$as_me:18173: result: $cf_cv_typeof_chtype" >&5
 echo "${ECHO_T}$cf_cv_typeof_chtype" >&6
 
 cat >>confdefs.h <<EOF
@@ -17685,14 +18182,14 @@
 fi
 test "$cf_cv_typeof_chtype" = unsigned && cf_cv_typeof_chtype=""
 
-echo "$as_me:17688: checking if unsigned literals are legal" >&5
+echo "$as_me:18185: checking if unsigned literals are legal" >&5
 echo $ECHO_N "checking if unsigned literals are legal... $ECHO_C" >&6
 if test "${cf_cv_unsigned_literals+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 17695 "configure"
+#line 18192 "configure"
 #include "confdefs.h"
 
 int
@@ -17704,16 +18201,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:17707: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:18204: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:17710: \$? = $ac_status" >&5
+  echo "$as_me:18207: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:17713: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18210: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:17716: \$? = $ac_status" >&5
+  echo "$as_me:18213: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_unsigned_literals=yes
 else
@@ -17725,7 +18222,7 @@
 
 fi
 
-echo "$as_me:17728: result: $cf_cv_unsigned_literals" >&5
+echo "$as_me:18225: result: $cf_cv_unsigned_literals" >&5
 echo "${ECHO_T}$cf_cv_unsigned_literals" >&6
 
 cf_cv_1UL="1"
@@ -17741,14 +18238,14 @@
 
 ###	Checks for external-data
 
-echo "$as_me:17744: checking if external errno is declared" >&5
+echo "$as_me:18241: checking if external errno is declared" >&5
 echo $ECHO_N "checking if external errno is declared... $ECHO_C" >&6
 if test "${cf_cv_dcl_errno+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 17751 "configure"
+#line 18248 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_STDLIB_H
@@ -17766,16 +18263,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:17769: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:18266: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:17772: \$? = $ac_status" >&5
+  echo "$as_me:18269: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:17775: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18272: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:17778: \$? = $ac_status" >&5
+  echo "$as_me:18275: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_dcl_errno=yes
 else
@@ -17786,7 +18283,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:17789: result: $cf_cv_dcl_errno" >&5
+echo "$as_me:18286: result: $cf_cv_dcl_errno" >&5
 echo "${ECHO_T}$cf_cv_dcl_errno" >&6
 
 if test "$cf_cv_dcl_errno" = no ; then
@@ -17801,14 +18298,14 @@
 
 # It's possible (for near-UNIX clones) that the data doesn't exist
 
-echo "$as_me:17804: checking if external errno exists" >&5
+echo "$as_me:18301: checking if external errno exists" >&5
 echo $ECHO_N "checking if external errno exists... $ECHO_C" >&6
 if test "${cf_cv_have_errno+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 17811 "configure"
+#line 18308 "configure"
 #include "confdefs.h"
 
 #undef errno
@@ -17823,16 +18320,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:17826: \"$ac_link\"") >&5
+if { (eval echo "$as_me:18323: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:17829: \$? = $ac_status" >&5
+  echo "$as_me:18326: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:17832: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18329: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:17835: \$? = $ac_status" >&5
+  echo "$as_me:18332: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_have_errno=yes
 else
@@ -17843,7 +18340,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:17846: result: $cf_cv_have_errno" >&5
+echo "$as_me:18343: result: $cf_cv_have_errno" >&5
 echo "${ECHO_T}$cf_cv_have_errno" >&6
 
 if test "$cf_cv_have_errno" = yes ; then
@@ -17856,7 +18353,7 @@
 
 fi
 
-echo "$as_me:17859: checking if data-only library module links" >&5
+echo "$as_me:18356: checking if data-only library module links" >&5
 echo $ECHO_N "checking if data-only library module links... $ECHO_C" >&6
 if test "${cf_cv_link_dataonly+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -17864,20 +18361,20 @@
 
 	rm -f conftest.a
 	cat >conftest.$ac_ext <<EOF
-#line 17867 "configure"
+#line 18364 "configure"
 int	testdata[3] = { 123, 456, 789 };
 EOF
-	if { (eval echo "$as_me:17870: \"$ac_compile\"") >&5
+	if { (eval echo "$as_me:18367: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:17873: \$? = $ac_status" >&5
+  echo "$as_me:18370: \$? = $ac_status" >&5
   (exit $ac_status); } ; then
 		mv conftest.o data.o && \
 		( $AR $ARFLAGS conftest.a data.o ) 2>&5 1>/dev/null
 	fi
 	rm -f conftest.$ac_ext data.o
 	cat >conftest.$ac_ext <<EOF
-#line 17880 "configure"
+#line 18377 "configure"
 int	testfunc(void)
 {
 #if defined(NeXT)
@@ -17890,10 +18387,10 @@
 #endif
 }
 EOF
-	if { (eval echo "$as_me:17893: \"$ac_compile\"") >&5
+	if { (eval echo "$as_me:18390: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:17896: \$? = $ac_status" >&5
+  echo "$as_me:18393: \$? = $ac_status" >&5
   (exit $ac_status); }; then
 		mv conftest.o func.o && \
 		( $AR $ARFLAGS conftest.a func.o ) 2>&5 1>/dev/null
@@ -17906,7 +18403,7 @@
   cf_cv_link_dataonly=unknown
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 17909 "configure"
+#line 18406 "configure"
 #include "confdefs.h"
 
 	int main(void)
@@ -17917,15 +18414,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:17920: \"$ac_link\"") >&5
+if { (eval echo "$as_me:18417: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:17923: \$? = $ac_status" >&5
+  echo "$as_me:18420: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:17925: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18422: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:17928: \$? = $ac_status" >&5
+  echo "$as_me:18425: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_link_dataonly=yes
 else
@@ -17940,7 +18437,7 @@
 
 fi
 
-echo "$as_me:17943: result: $cf_cv_link_dataonly" >&5
+echo "$as_me:18440: result: $cf_cv_link_dataonly" >&5
 echo "${ECHO_T}$cf_cv_link_dataonly" >&6
 
 if test "$cf_cv_link_dataonly" = no ; then
@@ -17981,13 +18478,13 @@
 
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:17984: checking for $ac_func" >&5
+echo "$as_me:18481: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 17990 "configure"
+#line 18487 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -18018,16 +18515,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:18021: \"$ac_link\"") >&5
+if { (eval echo "$as_me:18518: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:18024: \$? = $ac_status" >&5
+  echo "$as_me:18521: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:18027: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18524: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18030: \$? = $ac_status" >&5
+  echo "$as_me:18527: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -18037,7 +18534,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:18040: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:18537: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -18049,7 +18546,7 @@
 
 if test "x$ac_cv_func_getopt" = xno && \
    test "x$cf_with_progs$cf_with_tests" != xnono; then
-	{ { echo "$as_me:18052: error: getopt is required for building programs" >&5
+	{ { echo "$as_me:18549: error: getopt is required for building programs" >&5
 echo "$as_me: error: getopt is required for building programs" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -18058,7 +18555,7 @@
 then
 	if test "x$ac_cv_func_vsnprintf" = xyes
 	then
-		{ echo "$as_me:18061: WARNING: will use vsnprintf instead of safe-sprintf option" >&5
+		{ echo "$as_me:18558: WARNING: will use vsnprintf instead of safe-sprintf option" >&5
 echo "$as_me: WARNING: will use vsnprintf instead of safe-sprintf option" >&2;}
 	else
 
@@ -18071,14 +18568,14 @@
 
 if test "x$with_getcap" = "xyes" ; then
 
-echo "$as_me:18074: checking for terminal-capability database functions" >&5
+echo "$as_me:18571: checking for terminal-capability database functions" >&5
 echo $ECHO_N "checking for terminal-capability database functions... $ECHO_C" >&6
 if test "${cf_cv_cgetent+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 18081 "configure"
+#line 18578 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -18098,16 +18595,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:18101: \"$ac_link\"") >&5
+if { (eval echo "$as_me:18598: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:18104: \$? = $ac_status" >&5
+  echo "$as_me:18601: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:18107: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18604: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18110: \$? = $ac_status" >&5
+  echo "$as_me:18607: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_cgetent=yes
 else
@@ -18118,7 +18615,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:18121: result: $cf_cv_cgetent" >&5
+echo "$as_me:18618: result: $cf_cv_cgetent" >&5
 echo "${ECHO_T}$cf_cv_cgetent" >&6
 
 if test "$cf_cv_cgetent" = yes
@@ -18128,14 +18625,14 @@
 #define HAVE_BSD_CGETENT 1
 EOF
 
-echo "$as_me:18131: checking if cgetent uses const parameter" >&5
+echo "$as_me:18628: checking if cgetent uses const parameter" >&5
 echo $ECHO_N "checking if cgetent uses const parameter... $ECHO_C" >&6
 if test "${cf_cv_cgetent_const+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 18138 "configure"
+#line 18635 "configure"
 #include "confdefs.h"
 
 #pragma GCC diagnostic error "-Wincompatible-pointer-types-discards-qualifiers"
@@ -18158,16 +18655,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:18161: \"$ac_link\"") >&5
+if { (eval echo "$as_me:18658: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:18164: \$? = $ac_status" >&5
+  echo "$as_me:18661: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:18167: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18664: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18170: \$? = $ac_status" >&5
+  echo "$as_me:18667: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_cgetent_const=yes
 else
@@ -18178,7 +18675,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:18181: result: $cf_cv_cgetent_const" >&5
+echo "$as_me:18678: result: $cf_cv_cgetent_const" >&5
 echo "${ECHO_T}$cf_cv_cgetent_const" >&6
 	if test "$cf_cv_cgetent_const" = yes
 	then
@@ -18192,14 +18689,14 @@
 
 fi
 
-echo "$as_me:18195: checking for isascii" >&5
+echo "$as_me:18692: checking for isascii" >&5
 echo $ECHO_N "checking for isascii... $ECHO_C" >&6
 if test "${cf_cv_have_isascii+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 18202 "configure"
+#line 18699 "configure"
 #include "confdefs.h"
 #include <ctype.h>
 int
@@ -18211,16 +18708,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:18214: \"$ac_link\"") >&5
+if { (eval echo "$as_me:18711: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:18217: \$? = $ac_status" >&5
+  echo "$as_me:18714: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:18220: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18717: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18223: \$? = $ac_status" >&5
+  echo "$as_me:18720: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_have_isascii=yes
 else
@@ -18231,7 +18728,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:18234: result: $cf_cv_have_isascii" >&5
+echo "$as_me:18731: result: $cf_cv_have_isascii" >&5
 echo "${ECHO_T}$cf_cv_have_isascii" >&6
 test "$cf_cv_have_isascii" = yes &&
 cat >>confdefs.h <<\EOF
@@ -18239,10 +18736,10 @@
 EOF
 
 if test "$ac_cv_func_sigaction" = yes; then
-echo "$as_me:18242: checking whether sigaction needs _POSIX_SOURCE" >&5
+echo "$as_me:18739: checking whether sigaction needs _POSIX_SOURCE" >&5
 echo $ECHO_N "checking whether sigaction needs _POSIX_SOURCE... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 18245 "configure"
+#line 18742 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -18256,16 +18753,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:18259: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:18756: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:18262: \$? = $ac_status" >&5
+  echo "$as_me:18759: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:18265: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18762: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18268: \$? = $ac_status" >&5
+  echo "$as_me:18765: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   sigact_bad=no
 else
@@ -18273,7 +18770,7 @@
 cat conftest.$ac_ext >&5
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 18276 "configure"
+#line 18773 "configure"
 #include "confdefs.h"
 
 #define _POSIX_SOURCE
@@ -18288,16 +18785,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:18291: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:18788: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:18294: \$? = $ac_status" >&5
+  echo "$as_me:18791: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:18297: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18794: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18300: \$? = $ac_status" >&5
+  echo "$as_me:18797: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   sigact_bad=yes
 
@@ -18313,11 +18810,11 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
-echo "$as_me:18316: result: $sigact_bad" >&5
+echo "$as_me:18813: result: $sigact_bad" >&5
 echo "${ECHO_T}$sigact_bad" >&6
 fi
 
-echo "$as_me:18320: checking if nanosleep really works" >&5
+echo "$as_me:18817: checking if nanosleep really works" >&5
 echo $ECHO_N "checking if nanosleep really works... $ECHO_C" >&6
 if test "${cf_cv_func_nanosleep+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -18327,7 +18824,7 @@
   cf_cv_func_nanosleep=unknown
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 18330 "configure"
+#line 18827 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -18352,15 +18849,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:18355: \"$ac_link\"") >&5
+if { (eval echo "$as_me:18852: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:18358: \$? = $ac_status" >&5
+  echo "$as_me:18855: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:18360: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18857: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18363: \$? = $ac_status" >&5
+  echo "$as_me:18860: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_func_nanosleep=yes
 else
@@ -18372,7 +18869,7 @@
 rm -f core core.* *.core conftest$ac_exeext conftest.$ac_objext conftest.$ac_ext
 fi
 fi
-echo "$as_me:18375: result: $cf_cv_func_nanosleep" >&5
+echo "$as_me:18872: result: $cf_cv_func_nanosleep" >&5
 echo "${ECHO_T}$cf_cv_func_nanosleep" >&6
 
 test "$cf_cv_func_nanosleep" = "yes" &&
@@ -18389,23 +18886,23 @@
 
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:18392: checking for $ac_header" >&5
+echo "$as_me:18889: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 18398 "configure"
+#line 18895 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:18402: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:18899: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:18408: \$? = $ac_status" >&5
+  echo "$as_me:18905: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -18424,7 +18921,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:18427: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:18924: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -18441,10 +18938,10 @@
 	(*)	termios_bad=maybe ;;
 	esac
 	if test "$termios_bad" = maybe ; then
-	echo "$as_me:18444: checking whether termios.h needs _POSIX_SOURCE" >&5
+	echo "$as_me:18941: checking whether termios.h needs _POSIX_SOURCE" >&5
 echo $ECHO_N "checking whether termios.h needs _POSIX_SOURCE... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 18447 "configure"
+#line 18944 "configure"
 #include "confdefs.h"
 #include <termios.h>
 int
@@ -18456,16 +18953,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:18459: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:18956: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:18462: \$? = $ac_status" >&5
+  echo "$as_me:18959: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:18465: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18962: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18468: \$? = $ac_status" >&5
+  echo "$as_me:18965: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   termios_bad=no
 else
@@ -18473,7 +18970,7 @@
 cat conftest.$ac_ext >&5
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 18476 "configure"
+#line 18973 "configure"
 #include "confdefs.h"
 
 #define _POSIX_SOURCE
@@ -18487,16 +18984,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:18490: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:18987: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:18493: \$? = $ac_status" >&5
+  echo "$as_me:18990: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:18496: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18993: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18499: \$? = $ac_status" >&5
+  echo "$as_me:18996: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   termios_bad=unknown
 else
@@ -18512,19 +19009,19 @@
 
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
-	echo "$as_me:18515: result: $termios_bad" >&5
+	echo "$as_me:19012: result: $termios_bad" >&5
 echo "${ECHO_T}$termios_bad" >&6
 	fi
 fi
 
-echo "$as_me:18520: checking for tcgetattr" >&5
+echo "$as_me:19017: checking for tcgetattr" >&5
 echo $ECHO_N "checking for tcgetattr... $ECHO_C" >&6
 if test "${cf_cv_have_tcgetattr+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 18527 "configure"
+#line 19024 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -18552,16 +19049,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:18555: \"$ac_link\"") >&5
+if { (eval echo "$as_me:19052: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:18558: \$? = $ac_status" >&5
+  echo "$as_me:19055: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:18561: \"$ac_try\"") >&5
+  { (eval echo "$as_me:19058: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18564: \$? = $ac_status" >&5
+  echo "$as_me:19061: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_have_tcgetattr=yes
 else
@@ -18571,21 +19068,21 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:18574: result: $cf_cv_have_tcgetattr" >&5
+echo "$as_me:19071: result: $cf_cv_have_tcgetattr" >&5
 echo "${ECHO_T}$cf_cv_have_tcgetattr" >&6
 test "$cf_cv_have_tcgetattr" = yes &&
 cat >>confdefs.h <<\EOF
 #define HAVE_TCGETATTR 1
 EOF
 
-echo "$as_me:18581: checking for vsscanf function or workaround" >&5
+echo "$as_me:19078: checking for vsscanf function or workaround" >&5
 echo $ECHO_N "checking for vsscanf function or workaround... $ECHO_C" >&6
 if test "${cf_cv_func_vsscanf+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 18588 "configure"
+#line 19085 "configure"
 #include "confdefs.h"
 
 #include <stdarg.h>
@@ -18601,16 +19098,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:18604: \"$ac_link\"") >&5
+if { (eval echo "$as_me:19101: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:18607: \$? = $ac_status" >&5
+  echo "$as_me:19104: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:18610: \"$ac_try\"") >&5
+  { (eval echo "$as_me:19107: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18613: \$? = $ac_status" >&5
+  echo "$as_me:19110: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_func_vsscanf=vsscanf
 else
@@ -18618,7 +19115,7 @@
 cat conftest.$ac_ext >&5
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 18621 "configure"
+#line 19118 "configure"
 #include "confdefs.h"
 
 #include <stdarg.h>
@@ -18640,16 +19137,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:18643: \"$ac_link\"") >&5
+if { (eval echo "$as_me:19140: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:18646: \$? = $ac_status" >&5
+  echo "$as_me:19143: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:18649: \"$ac_try\"") >&5
+  { (eval echo "$as_me:19146: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18652: \$? = $ac_status" >&5
+  echo "$as_me:19149: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_func_vsscanf=vfscanf
 else
@@ -18657,7 +19154,7 @@
 cat conftest.$ac_ext >&5
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 18660 "configure"
+#line 19157 "configure"
 #include "confdefs.h"
 
 #include <stdarg.h>
@@ -18679,16 +19176,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:18682: \"$ac_link\"") >&5
+if { (eval echo "$as_me:19179: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:18685: \$? = $ac_status" >&5
+  echo "$as_me:19182: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:18688: \"$ac_try\"") >&5
+  { (eval echo "$as_me:19185: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18691: \$? = $ac_status" >&5
+  echo "$as_me:19188: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_func_vsscanf=_doscan
 else
@@ -18703,7 +19200,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:18706: result: $cf_cv_func_vsscanf" >&5
+echo "$as_me:19203: result: $cf_cv_func_vsscanf" >&5
 echo "${ECHO_T}$cf_cv_func_vsscanf" >&6
 
 case $cf_cv_func_vsscanf in
@@ -18729,23 +19226,23 @@
 
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:18732: checking for $ac_header" >&5
+echo "$as_me:19229: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 18738 "configure"
+#line 19235 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:18742: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:19239: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:18748: \$? = $ac_status" >&5
+  echo "$as_me:19245: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -18764,7 +19261,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:18767: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:19264: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -18774,7 +19271,7 @@
 fi
 done
 
-echo "$as_me:18777: checking for working mkstemp" >&5
+echo "$as_me:19274: checking for working mkstemp" >&5
 echo $ECHO_N "checking for working mkstemp... $ECHO_C" >&6
 if test "${cf_cv_func_mkstemp+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -18785,7 +19282,7 @@
   cf_cv_func_mkstemp=maybe
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 18788 "configure"
+#line 19285 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -18826,15 +19323,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:18829: \"$ac_link\"") >&5
+if { (eval echo "$as_me:19326: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:18832: \$? = $ac_status" >&5
+  echo "$as_me:19329: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:18834: \"$ac_try\"") >&5
+  { (eval echo "$as_me:19331: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18837: \$? = $ac_status" >&5
+  echo "$as_me:19334: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_func_mkstemp=yes
 
@@ -18849,16 +19346,16 @@
 fi
 
 fi
-echo "$as_me:18852: result: $cf_cv_func_mkstemp" >&5
+echo "$as_me:19349: result: $cf_cv_func_mkstemp" >&5
 echo "${ECHO_T}$cf_cv_func_mkstemp" >&6
 if test "x$cf_cv_func_mkstemp" = xmaybe ; then
-	echo "$as_me:18855: checking for mkstemp" >&5
+	echo "$as_me:19352: checking for mkstemp" >&5
 echo $ECHO_N "checking for mkstemp... $ECHO_C" >&6
 if test "${ac_cv_func_mkstemp+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 18861 "configure"
+#line 19358 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char mkstemp (); below.  */
@@ -18889,16 +19386,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:18892: \"$ac_link\"") >&5
+if { (eval echo "$as_me:19389: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:18895: \$? = $ac_status" >&5
+  echo "$as_me:19392: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:18898: \"$ac_try\"") >&5
+  { (eval echo "$as_me:19395: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18901: \$? = $ac_status" >&5
+  echo "$as_me:19398: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_mkstemp=yes
 else
@@ -18908,7 +19405,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:18911: result: $ac_cv_func_mkstemp" >&5
+echo "$as_me:19408: result: $ac_cv_func_mkstemp" >&5
 echo "${ECHO_T}$ac_cv_func_mkstemp" >&6
 
 fi
@@ -18929,21 +19426,21 @@
 fi
 
 if test "x$cross_compiling" = xyes ; then
-	{ echo "$as_me:18932: WARNING: cross compiling: assume setvbuf params not reversed" >&5
+	{ echo "$as_me:19429: WARNING: cross compiling: assume setvbuf params not reversed" >&5
 echo "$as_me: WARNING: cross compiling: assume setvbuf params not reversed" >&2;}
 else
-	echo "$as_me:18935: checking whether setvbuf arguments are reversed" >&5
+	echo "$as_me:19432: checking whether setvbuf arguments are reversed" >&5
 echo $ECHO_N "checking whether setvbuf arguments are reversed... $ECHO_C" >&6
 if test "${ac_cv_func_setvbuf_reversed+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   if test "$cross_compiling" = yes; then
-  { { echo "$as_me:18941: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:19438: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 18946 "configure"
+#line 19443 "configure"
 #include "confdefs.h"
 #include <stdio.h>
 /* If setvbuf has the reversed format, exit 0. */
@@ -18960,15 +19457,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:18963: \"$ac_link\"") >&5
+if { (eval echo "$as_me:19460: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:18966: \$? = $ac_status" >&5
+  echo "$as_me:19463: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:18968: \"$ac_try\"") >&5
+  { (eval echo "$as_me:19465: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18971: \$? = $ac_status" >&5
+  echo "$as_me:19468: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_setvbuf_reversed=yes
 else
@@ -18981,7 +19478,7 @@
 fi
 rm -f core core.* *.core
 fi
-echo "$as_me:18984: result: $ac_cv_func_setvbuf_reversed" >&5
+echo "$as_me:19481: result: $ac_cv_func_setvbuf_reversed" >&5
 echo "${ECHO_T}$ac_cv_func_setvbuf_reversed" >&6
 if test $ac_cv_func_setvbuf_reversed = yes; then
 
@@ -18992,13 +19489,13 @@
 fi
 
 fi
-echo "$as_me:18995: checking for intptr_t" >&5
+echo "$as_me:19492: checking for intptr_t" >&5
 echo $ECHO_N "checking for intptr_t... $ECHO_C" >&6
 if test "${ac_cv_type_intptr_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 19001 "configure"
+#line 19498 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -19013,16 +19510,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:19016: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:19513: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:19019: \$? = $ac_status" >&5
+  echo "$as_me:19516: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:19022: \"$ac_try\"") >&5
+  { (eval echo "$as_me:19519: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:19025: \$? = $ac_status" >&5
+  echo "$as_me:19522: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_intptr_t=yes
 else
@@ -19032,7 +19529,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:19035: result: $ac_cv_type_intptr_t" >&5
+echo "$as_me:19532: result: $ac_cv_type_intptr_t" >&5
 echo "${ECHO_T}$ac_cv_type_intptr_t" >&6
 if test $ac_cv_type_intptr_t = yes; then
   :
@@ -19044,13 +19541,13 @@
 
 fi
 
-echo "$as_me:19047: checking for ssize_t" >&5
+echo "$as_me:19544: checking for ssize_t" >&5
 echo $ECHO_N "checking for ssize_t... $ECHO_C" >&6
 if test "${ac_cv_type_ssize_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 19053 "configure"
+#line 19550 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -19065,16 +19562,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:19068: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:19565: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:19071: \$? = $ac_status" >&5
+  echo "$as_me:19568: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:19074: \"$ac_try\"") >&5
+  { (eval echo "$as_me:19571: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:19077: \$? = $ac_status" >&5
+  echo "$as_me:19574: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_ssize_t=yes
 else
@@ -19084,7 +19581,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:19087: result: $ac_cv_type_ssize_t" >&5
+echo "$as_me:19584: result: $ac_cv_type_ssize_t" >&5
 echo "${ECHO_T}$ac_cv_type_ssize_t" >&6
 if test $ac_cv_type_ssize_t = yes; then
   :
@@ -19096,14 +19593,14 @@
 
 fi
 
-echo "$as_me:19099: checking for type sigaction_t" >&5
+echo "$as_me:19596: checking for type sigaction_t" >&5
 echo $ECHO_N "checking for type sigaction_t... $ECHO_C" >&6
 if test "${cf_cv_type_sigaction+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 19106 "configure"
+#line 19603 "configure"
 #include "confdefs.h"
 
 #include <signal.h>
@@ -19116,16 +19613,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:19119: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:19616: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:19122: \$? = $ac_status" >&5
+  echo "$as_me:19619: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:19125: \"$ac_try\"") >&5
+  { (eval echo "$as_me:19622: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:19128: \$? = $ac_status" >&5
+  echo "$as_me:19625: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_type_sigaction=yes
 else
@@ -19136,14 +19633,14 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
 
-echo "$as_me:19139: result: $cf_cv_type_sigaction" >&5
+echo "$as_me:19636: result: $cf_cv_type_sigaction" >&5
 echo "${ECHO_T}$cf_cv_type_sigaction" >&6
 test "$cf_cv_type_sigaction" = yes &&
 cat >>confdefs.h <<\EOF
 #define HAVE_TYPE_SIGACTION 1
 EOF
 
-echo "$as_me:19146: checking declaration of size-change" >&5
+echo "$as_me:19643: checking declaration of size-change" >&5
 echo $ECHO_N "checking declaration of size-change... $ECHO_C" >&6
 if test "${cf_cv_sizechange+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -19164,7 +19661,7 @@
 
 	fi
 	cat >conftest.$ac_ext <<_ACEOF
-#line 19167 "configure"
+#line 19664 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #ifdef HAVE_TERMIOS_H
@@ -19210,16 +19707,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:19213: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:19710: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:19216: \$? = $ac_status" >&5
+  echo "$as_me:19713: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:19219: \"$ac_try\"") >&5
+  { (eval echo "$as_me:19716: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:19222: \$? = $ac_status" >&5
+  echo "$as_me:19719: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_sizechange=yes
 else
@@ -19238,7 +19735,7 @@
 done
 
 fi
-echo "$as_me:19241: result: $cf_cv_sizechange" >&5
+echo "$as_me:19738: result: $cf_cv_sizechange" >&5
 echo "${ECHO_T}$cf_cv_sizechange" >&6
 if test "$cf_cv_sizechange" != no ; then
 
@@ -19256,13 +19753,13 @@
 	esac
 fi
 
-echo "$as_me:19259: checking for memmove" >&5
+echo "$as_me:19756: checking for memmove" >&5
 echo $ECHO_N "checking for memmove... $ECHO_C" >&6
 if test "${ac_cv_func_memmove+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 19265 "configure"
+#line 19762 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char memmove (); below.  */
@@ -19293,16 +19790,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:19296: \"$ac_link\"") >&5
+if { (eval echo "$as_me:19793: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:19299: \$? = $ac_status" >&5
+  echo "$as_me:19796: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:19302: \"$ac_try\"") >&5
+  { (eval echo "$as_me:19799: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:19305: \$? = $ac_status" >&5
+  echo "$as_me:19802: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_memmove=yes
 else
@@ -19312,19 +19809,19 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:19315: result: $ac_cv_func_memmove" >&5
+echo "$as_me:19812: result: $ac_cv_func_memmove" >&5
 echo "${ECHO_T}$ac_cv_func_memmove" >&6
 if test $ac_cv_func_memmove = yes; then
   :
 else
 
-echo "$as_me:19321: checking for bcopy" >&5
+echo "$as_me:19818: checking for bcopy" >&5
 echo $ECHO_N "checking for bcopy... $ECHO_C" >&6
 if test "${ac_cv_func_bcopy+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 19327 "configure"
+#line 19824 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char bcopy (); below.  */
@@ -19355,16 +19852,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:19358: \"$ac_link\"") >&5
+if { (eval echo "$as_me:19855: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:19361: \$? = $ac_status" >&5
+  echo "$as_me:19858: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:19364: \"$ac_try\"") >&5
+  { (eval echo "$as_me:19861: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:19367: \$? = $ac_status" >&5
+  echo "$as_me:19864: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_bcopy=yes
 else
@@ -19374,11 +19871,11 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:19377: result: $ac_cv_func_bcopy" >&5
+echo "$as_me:19874: result: $ac_cv_func_bcopy" >&5
 echo "${ECHO_T}$ac_cv_func_bcopy" >&6
 if test $ac_cv_func_bcopy = yes; then
 
-	echo "$as_me:19381: checking if bcopy does overlapping moves" >&5
+	echo "$as_me:19878: checking if bcopy does overlapping moves" >&5
 echo $ECHO_N "checking if bcopy does overlapping moves... $ECHO_C" >&6
 if test "${cf_cv_good_bcopy+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -19388,7 +19885,7 @@
   cf_cv_good_bcopy=unknown
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 19391 "configure"
+#line 19888 "configure"
 #include "confdefs.h"
 
 int main(void) {
@@ -19402,15 +19899,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:19405: \"$ac_link\"") >&5
+if { (eval echo "$as_me:19902: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:19408: \$? = $ac_status" >&5
+  echo "$as_me:19905: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:19410: \"$ac_try\"") >&5
+  { (eval echo "$as_me:19907: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:19413: \$? = $ac_status" >&5
+  echo "$as_me:19910: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_good_bcopy=yes
 else
@@ -19423,7 +19920,7 @@
 fi
 
 fi
-echo "$as_me:19426: result: $cf_cv_good_bcopy" >&5
+echo "$as_me:19923: result: $cf_cv_good_bcopy" >&5
 echo "${ECHO_T}$cf_cv_good_bcopy" >&6
 
 else
@@ -19450,13 +19947,13 @@
 for ac_func in posix_openpt
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:19453: checking for $ac_func" >&5
+echo "$as_me:19950: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 19459 "configure"
+#line 19956 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -19487,16 +19984,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:19490: \"$ac_link\"") >&5
+if { (eval echo "$as_me:19987: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:19493: \$? = $ac_status" >&5
+  echo "$as_me:19990: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:19496: \"$ac_try\"") >&5
+  { (eval echo "$as_me:19993: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:19499: \$? = $ac_status" >&5
+  echo "$as_me:19996: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -19506,7 +20003,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:19509: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:20006: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -19516,7 +20013,7 @@
 fi
 done
  }
-echo "$as_me:19519: checking if poll really works" >&5
+echo "$as_me:20016: checking if poll really works" >&5
 echo $ECHO_N "checking if poll really works... $ECHO_C" >&6
 if test "${cf_cv_working_poll+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -19526,7 +20023,7 @@
   cf_cv_working_poll=unknown
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 19529 "configure"
+#line 20026 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -19578,15 +20075,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:19581: \"$ac_link\"") >&5
+if { (eval echo "$as_me:20078: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:19584: \$? = $ac_status" >&5
+  echo "$as_me:20081: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:19586: \"$ac_try\"") >&5
+  { (eval echo "$as_me:20083: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:19589: \$? = $ac_status" >&5
+  echo "$as_me:20086: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_working_poll=yes
 else
@@ -19598,21 +20095,21 @@
 rm -f core core.* *.core conftest$ac_exeext conftest.$ac_objext conftest.$ac_ext
 fi
 fi
-echo "$as_me:19601: result: $cf_cv_working_poll" >&5
+echo "$as_me:20098: result: $cf_cv_working_poll" >&5
 echo "${ECHO_T}$cf_cv_working_poll" >&6
 test "$cf_cv_working_poll" = "yes" &&
 cat >>confdefs.h <<\EOF
 #define HAVE_WORKING_POLL 1
 EOF
 
-echo "$as_me:19608: checking for va_copy" >&5
+echo "$as_me:20105: checking for va_copy" >&5
 echo $ECHO_N "checking for va_copy... $ECHO_C" >&6
 if test "${cf_cv_have_va_copy+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 19615 "configure"
+#line 20112 "configure"
 #include "confdefs.h"
 
 #include <stdarg.h>
@@ -19629,16 +20126,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:19632: \"$ac_link\"") >&5
+if { (eval echo "$as_me:20129: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:19635: \$? = $ac_status" >&5
+  echo "$as_me:20132: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:19638: \"$ac_try\"") >&5
+  { (eval echo "$as_me:20135: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:19641: \$? = $ac_status" >&5
+  echo "$as_me:20138: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_have_va_copy=yes
 else
@@ -19648,7 +20145,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:19651: result: $cf_cv_have_va_copy" >&5
+echo "$as_me:20148: result: $cf_cv_have_va_copy" >&5
 echo "${ECHO_T}$cf_cv_have_va_copy" >&6
 
 test "$cf_cv_have_va_copy" = yes &&
@@ -19656,14 +20153,14 @@
 #define HAVE_VA_COPY 1
 EOF
 
-echo "$as_me:19659: checking for __va_copy" >&5
+echo "$as_me:20156: checking for __va_copy" >&5
 echo $ECHO_N "checking for __va_copy... $ECHO_C" >&6
 if test "${cf_cv_have___va_copy+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 cat >conftest.$ac_ext <<_ACEOF
-#line 19666 "configure"
+#line 20163 "configure"
 #include "confdefs.h"
 
 #include <stdarg.h>
@@ -19680,16 +20177,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:19683: \"$ac_link\"") >&5
+if { (eval echo "$as_me:20180: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:19686: \$? = $ac_status" >&5
+  echo "$as_me:20183: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:19689: \"$ac_try\"") >&5
+  { (eval echo "$as_me:20186: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:19692: \$? = $ac_status" >&5
+  echo "$as_me:20189: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_have___va_copy=yes
 else
@@ -19699,7 +20196,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:19702: result: $cf_cv_have___va_copy" >&5
+echo "$as_me:20199: result: $cf_cv_have___va_copy" >&5
 echo "${ECHO_T}$cf_cv_have___va_copy" >&6
 
 test "$cf_cv_have___va_copy" = yes &&
@@ -19707,13 +20204,13 @@
 #define HAVE___VA_COPY 1
 EOF
 
-echo "$as_me:19710: checking for pid_t" >&5
+echo "$as_me:20207: checking for pid_t" >&5
 echo $ECHO_N "checking for pid_t... $ECHO_C" >&6
 if test "${ac_cv_type_pid_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 19716 "configure"
+#line 20213 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -19728,16 +20225,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:19731: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:20228: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:19734: \$? = $ac_status" >&5
+  echo "$as_me:20231: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:19737: \"$ac_try\"") >&5
+  { (eval echo "$as_me:20234: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:19740: \$? = $ac_status" >&5
+  echo "$as_me:20237: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_pid_t=yes
 else
@@ -19747,7 +20244,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:19750: result: $ac_cv_type_pid_t" >&5
+echo "$as_me:20247: result: $ac_cv_type_pid_t" >&5
 echo "${ECHO_T}$ac_cv_type_pid_t" >&6
 if test $ac_cv_type_pid_t = yes; then
   :
@@ -19762,23 +20259,23 @@
 for ac_header in unistd.h vfork.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:19765: checking for $ac_header" >&5
+echo "$as_me:20262: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 19771 "configure"
+#line 20268 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:19775: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:20272: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:19781: \$? = $ac_status" >&5
+  echo "$as_me:20278: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -19797,7 +20294,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:19800: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:20297: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -19810,13 +20307,13 @@
 for ac_func in fork vfork
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:19813: checking for $ac_func" >&5
+echo "$as_me:20310: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 19819 "configure"
+#line 20316 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -19847,16 +20344,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:19850: \"$ac_link\"") >&5
+if { (eval echo "$as_me:20347: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:19853: \$? = $ac_status" >&5
+  echo "$as_me:20350: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:19856: \"$ac_try\"") >&5
+  { (eval echo "$as_me:20353: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:19859: \$? = $ac_status" >&5
+  echo "$as_me:20356: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -19866,7 +20363,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:19869: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:20366: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -19878,7 +20375,7 @@
 
 ac_cv_func_fork_works=$ac_cv_func_fork
 if test "x$ac_cv_func_fork" = xyes; then
-  echo "$as_me:19881: checking for working fork" >&5
+  echo "$as_me:20378: checking for working fork" >&5
 echo $ECHO_N "checking for working fork... $ECHO_C" >&6
 if test "${ac_cv_func_fork_works+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -19901,15 +20398,15 @@
       }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:19904: \"$ac_link\"") >&5
+if { (eval echo "$as_me:20401: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:19907: \$? = $ac_status" >&5
+  echo "$as_me:20404: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:19909: \"$ac_try\"") >&5
+  { (eval echo "$as_me:20406: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:19912: \$? = $ac_status" >&5
+  echo "$as_me:20409: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_fork_works=yes
 else
@@ -19921,7 +20418,7 @@
 rm -f core core.* *.core conftest$ac_exeext conftest.$ac_objext conftest.$ac_ext
 fi
 fi
-echo "$as_me:19924: result: $ac_cv_func_fork_works" >&5
+echo "$as_me:20421: result: $ac_cv_func_fork_works" >&5
 echo "${ECHO_T}$ac_cv_func_fork_works" >&6
 
 fi
@@ -19935,12 +20432,12 @@
       ac_cv_func_fork_works=yes
       ;;
   esac
-  { echo "$as_me:19938: WARNING: CROSS: Result $ac_cv_func_fork_works guessed due to cross-compiling." >&5
+  { echo "$as_me:20435: WARNING: CROSS: Result $ac_cv_func_fork_works guessed due to cross-compiling." >&5
 echo "$as_me: WARNING: CROSS: Result $ac_cv_func_fork_works guessed due to cross-compiling." >&2;}
 fi
 ac_cv_func_vfork_works=$ac_cv_func_vfork
 if test "x$ac_cv_func_vfork" = xyes; then
-  echo "$as_me:19943: checking for working vfork" >&5
+  echo "$as_me:20440: checking for working vfork" >&5
 echo $ECHO_N "checking for working vfork... $ECHO_C" >&6
 if test "${ac_cv_func_vfork_works+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -19949,7 +20446,7 @@
   ac_cv_func_vfork_works=cross
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 19952 "configure"
+#line 20449 "configure"
 #include "confdefs.h"
 /* Thanks to Paul Eggert for this test.  */
 #include <stdio.h>
@@ -20046,15 +20543,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:20049: \"$ac_link\"") >&5
+if { (eval echo "$as_me:20546: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:20052: \$? = $ac_status" >&5
+  echo "$as_me:20549: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:20054: \"$ac_try\"") >&5
+  { (eval echo "$as_me:20551: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:20057: \$? = $ac_status" >&5
+  echo "$as_me:20554: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_vfork_works=yes
 else
@@ -20066,13 +20563,13 @@
 rm -f core core.* *.core conftest$ac_exeext conftest.$ac_objext conftest.$ac_ext
 fi
 fi
-echo "$as_me:20069: result: $ac_cv_func_vfork_works" >&5
+echo "$as_me:20566: result: $ac_cv_func_vfork_works" >&5
 echo "${ECHO_T}$ac_cv_func_vfork_works" >&6
 
 fi;
 if test "x$ac_cv_func_fork_works" = xcross; then
   ac_cv_func_vfork_works=ac_cv_func_vfork
-  { echo "$as_me:20075: WARNING: CROSS: Result $ac_cv_func_vfork_works guessed due to cross-compiling." >&5
+  { echo "$as_me:20572: WARNING: CROSS: Result $ac_cv_func_vfork_works guessed due to cross-compiling." >&5
 echo "$as_me: WARNING: CROSS: Result $ac_cv_func_vfork_works guessed due to cross-compiling." >&2;}
 fi
 
@@ -20099,7 +20596,7 @@
 
 # special check for test/ditto.c
 
-echo "$as_me:20102: checking for openpty in -lutil" >&5
+echo "$as_me:20599: checking for openpty in -lutil" >&5
 echo $ECHO_N "checking for openpty in -lutil... $ECHO_C" >&6
 if test "${ac_cv_lib_util_openpty+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -20107,7 +20604,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lutil  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 20110 "configure"
+#line 20607 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -20126,16 +20623,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:20129: \"$ac_link\"") >&5
+if { (eval echo "$as_me:20626: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:20132: \$? = $ac_status" >&5
+  echo "$as_me:20629: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:20135: \"$ac_try\"") >&5
+  { (eval echo "$as_me:20632: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:20138: \$? = $ac_status" >&5
+  echo "$as_me:20635: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_util_openpty=yes
 else
@@ -20146,7 +20643,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:20149: result: $ac_cv_lib_util_openpty" >&5
+echo "$as_me:20646: result: $ac_cv_lib_util_openpty" >&5
 echo "${ECHO_T}$ac_cv_lib_util_openpty" >&6
 if test $ac_cv_lib_util_openpty = yes; then
   cf_cv_lib_util=yes
@@ -20154,7 +20651,7 @@
   cf_cv_lib_util=no
 fi
 
-echo "$as_me:20157: checking for openpty header" >&5
+echo "$as_me:20654: checking for openpty header" >&5
 echo $ECHO_N "checking for openpty header... $ECHO_C" >&6
 if test "${cf_cv_func_openpty+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -20181,7 +20678,7 @@
 	for cf_header in pty.h libutil.h util.h
 	do
 	cat >conftest.$ac_ext <<_ACEOF
-#line 20184 "configure"
+#line 20681 "configure"
 #include "confdefs.h"
 
 #include <$cf_header>
@@ -20198,16 +20695,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:20201: \"$ac_link\"") >&5
+if { (eval echo "$as_me:20698: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:20204: \$? = $ac_status" >&5
+  echo "$as_me:20701: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:20207: \"$ac_try\"") >&5
+  { (eval echo "$as_me:20704: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:20210: \$? = $ac_status" >&5
+  echo "$as_me:20707: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 		cf_cv_func_openpty=$cf_header
@@ -20225,7 +20722,7 @@
 	LIBS="$cf_save_LIBS"
 
 fi
-echo "$as_me:20228: result: $cf_cv_func_openpty" >&5
+echo "$as_me:20725: result: $cf_cv_func_openpty" >&5
 echo "${ECHO_T}$cf_cv_func_openpty" >&6
 
 if test "$cf_cv_func_openpty" != no ; then
@@ -20298,7 +20795,7 @@
 	CPPFLAGS="${CPPFLAGS}-I$cf_add_incdir"
 
 			  cat >conftest.$ac_ext <<_ACEOF
-#line 20301 "configure"
+#line 20798 "configure"
 #include "confdefs.h"
 #include <stdio.h>
 int
@@ -20310,16 +20807,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:20313: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:20810: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:20316: \$? = $ac_status" >&5
+  echo "$as_me:20813: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:20319: \"$ac_try\"") >&5
+  { (eval echo "$as_me:20816: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:20322: \$? = $ac_status" >&5
+  echo "$as_me:20819: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   :
 else
@@ -20336,7 +20833,7 @@
 		if test "$cf_have_incdir" = no ; then
 		  test -n "$verbose" && echo "	adding $cf_add_incdir to include-path" 1>&6
 
-echo "${as_me:-configure}:20339: testing adding $cf_add_incdir to include-path ..." 1>&5
+echo "${as_me:-configure}:20836: testing adding $cf_add_incdir to include-path ..." 1>&5
 
 		  CPPFLAGS="$CPPFLAGS -I$cf_add_incdir"
 
@@ -20372,7 +20869,7 @@
 			if test "$cf_have_libdir" = no ; then
 				test -n "$verbose" && echo "	adding $cf_add_libdir to library-path" 1>&6
 
-echo "${as_me:-configure}:20375: testing adding $cf_add_libdir to library-path ..." 1>&5
+echo "${as_me:-configure}:20872: testing adding $cf_add_libdir to library-path ..." 1>&5
 
 				LDFLAGS="-L$cf_add_libdir $LDFLAGS"
 			fi
@@ -20383,7 +20880,7 @@
 	else
 		case "$with_hashed_db" in
 		(./*|../*|/*)
-			{ echo "$as_me:20386: WARNING: no such directory $with_hashed_db" >&5
+			{ echo "$as_me:20883: WARNING: no such directory $with_hashed_db" >&5
 echo "$as_me: WARNING: no such directory $with_hashed_db" >&2;}
 			;;
 		(*)
@@ -20455,7 +20952,7 @@
 	CPPFLAGS="${CPPFLAGS}-I$cf_add_incdir"
 
 			  cat >conftest.$ac_ext <<_ACEOF
-#line 20458 "configure"
+#line 20955 "configure"
 #include "confdefs.h"
 #include <stdio.h>
 int
@@ -20467,16 +20964,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:20470: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:20967: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:20473: \$? = $ac_status" >&5
+  echo "$as_me:20970: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:20476: \"$ac_try\"") >&5
+  { (eval echo "$as_me:20973: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:20479: \$? = $ac_status" >&5
+  echo "$as_me:20976: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   :
 else
@@ -20493,7 +20990,7 @@
 		if test "$cf_have_incdir" = no ; then
 		  test -n "$verbose" && echo "	adding $cf_add_incdir to include-path" 1>&6
 
-echo "${as_me:-configure}:20496: testing adding $cf_add_incdir to include-path ..." 1>&5
+echo "${as_me:-configure}:20993: testing adding $cf_add_incdir to include-path ..." 1>&5
 
 		  CPPFLAGS="$CPPFLAGS -I$cf_add_incdir"
 
@@ -20573,7 +21070,7 @@
 			if test "$cf_have_libdir" = no ; then
 				test -n "$verbose" && echo "	adding $cf_add_libdir to library-path" 1>&6
 
-echo "${as_me:-configure}:20576: testing adding $cf_add_libdir to library-path ..." 1>&5
+echo "${as_me:-configure}:21073: testing adding $cf_add_libdir to library-path ..." 1>&5
 
 				LDFLAGS="-L$cf_add_libdir $LDFLAGS"
 			fi
@@ -20590,23 +21087,23 @@
 	fi
 esac
 
-echo "$as_me:20593: checking for db.h" >&5
+echo "$as_me:21090: checking for db.h" >&5
 echo $ECHO_N "checking for db.h... $ECHO_C" >&6
 if test "${ac_cv_header_db_h+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 20599 "configure"
+#line 21096 "configure"
 #include "confdefs.h"
 #include <db.h>
 _ACEOF
-if { (eval echo "$as_me:20603: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:21100: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:20609: \$? = $ac_status" >&5
+  echo "$as_me:21106: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -20625,11 +21122,11 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:20628: result: $ac_cv_header_db_h" >&5
+echo "$as_me:21125: result: $ac_cv_header_db_h" >&5
 echo "${ECHO_T}$ac_cv_header_db_h" >&6
 if test $ac_cv_header_db_h = yes; then
 
-echo "$as_me:20632: checking for version of db" >&5
+echo "$as_me:21129: checking for version of db" >&5
 echo $ECHO_N "checking for version of db... $ECHO_C" >&6
 if test "${cf_cv_hashed_db_version+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -20640,10 +21137,10 @@
 for cf_db_version in 1 2 3 4 5 6
 do
 
-echo "${as_me:-configure}:20643: testing checking for db version $cf_db_version ..." 1>&5
+echo "${as_me:-configure}:21140: testing checking for db version $cf_db_version ..." 1>&5
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 20646 "configure"
+#line 21143 "configure"
 #include "confdefs.h"
 
 $ac_includes_default
@@ -20673,16 +21170,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:20676: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:21173: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:20679: \$? = $ac_status" >&5
+  echo "$as_me:21176: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:20682: \"$ac_try\"") >&5
+  { (eval echo "$as_me:21179: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:20685: \$? = $ac_status" >&5
+  echo "$as_me:21182: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 	cf_cv_hashed_db_version=$cf_db_version
@@ -20696,16 +21193,16 @@
 done
 
 fi
-echo "$as_me:20699: result: $cf_cv_hashed_db_version" >&5
+echo "$as_me:21196: result: $cf_cv_hashed_db_version" >&5
 echo "${ECHO_T}$cf_cv_hashed_db_version" >&6
 
 if test "$cf_cv_hashed_db_version" = unknown ; then
-	{ { echo "$as_me:20703: error: Cannot determine version of db" >&5
+	{ { echo "$as_me:21200: error: Cannot determine version of db" >&5
 echo "$as_me: error: Cannot determine version of db" >&2;}
    { (exit 1); exit 1; }; }
 else
 
-echo "$as_me:20708: checking for db libraries" >&5
+echo "$as_me:21205: checking for db libraries" >&5
 echo $ECHO_N "checking for db libraries... $ECHO_C" >&6
 if test "${cf_cv_hashed_db_libs+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -20735,10 +21232,10 @@
 
 	fi
 
-echo "${as_me:-configure}:20738: testing checking for library "$cf_db_libs" ..." 1>&5
+echo "${as_me:-configure}:21235: testing checking for library "$cf_db_libs" ..." 1>&5
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 20741 "configure"
+#line 21238 "configure"
 #include "confdefs.h"
 
 $ac_includes_default
@@ -20793,16 +21290,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:20796: \"$ac_link\"") >&5
+if { (eval echo "$as_me:21293: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:20799: \$? = $ac_status" >&5
+  echo "$as_me:21296: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:20802: \"$ac_try\"") >&5
+  { (eval echo "$as_me:21299: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:20805: \$? = $ac_status" >&5
+  echo "$as_me:21302: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 	if test -n "$cf_db_libs" ; then
@@ -20822,11 +21319,11 @@
 done
 
 fi
-echo "$as_me:20825: result: $cf_cv_hashed_db_libs" >&5
+echo "$as_me:21322: result: $cf_cv_hashed_db_libs" >&5
 echo "${ECHO_T}$cf_cv_hashed_db_libs" >&6
 
 	if test "$cf_cv_hashed_db_libs" = unknown ; then
-		{ { echo "$as_me:20829: error: Cannot determine library for db" >&5
+		{ { echo "$as_me:21326: error: Cannot determine library for db" >&5
 echo "$as_me: error: Cannot determine library for db" >&2;}
    { (exit 1); exit 1; }; }
 	elif test "$cf_cv_hashed_db_libs" != default ; then
@@ -20852,7 +21349,7 @@
 
 else
 
-	{ { echo "$as_me:20855: error: Cannot find db.h" >&5
+	{ { echo "$as_me:21352: error: Cannot find db.h" >&5
 echo "$as_me: error: Cannot find db.h" >&2;}
    { (exit 1); exit 1; }; }
 
@@ -20867,7 +21364,7 @@
 
 # Just in case, check if the C compiler has a bool type.
 
-echo "$as_me:20870: checking if we should include stdbool.h" >&5
+echo "$as_me:21367: checking if we should include stdbool.h" >&5
 echo $ECHO_N "checking if we should include stdbool.h... $ECHO_C" >&6
 
 if test "${cf_cv_header_stdbool_h+set}" = set; then
@@ -20875,7 +21372,7 @@
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 20878 "configure"
+#line 21375 "configure"
 #include "confdefs.h"
 
 int
@@ -20887,23 +21384,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:20890: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:21387: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:20893: \$? = $ac_status" >&5
+  echo "$as_me:21390: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:20896: \"$ac_try\"") >&5
+  { (eval echo "$as_me:21393: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:20899: \$? = $ac_status" >&5
+  echo "$as_me:21396: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_header_stdbool_h=0
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 cat >conftest.$ac_ext <<_ACEOF
-#line 20906 "configure"
+#line 21403 "configure"
 #include "confdefs.h"
 
 #ifndef __BEOS__
@@ -20919,16 +21416,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:20922: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:21419: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:20925: \$? = $ac_status" >&5
+  echo "$as_me:21422: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:20928: \"$ac_try\"") >&5
+  { (eval echo "$as_me:21425: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:20931: \$? = $ac_status" >&5
+  echo "$as_me:21428: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_header_stdbool_h=1
 else
@@ -20942,13 +21439,13 @@
 fi
 
 if test "$cf_cv_header_stdbool_h" = 1
-then	echo "$as_me:20945: result: yes" >&5
+then	echo "$as_me:21442: result: yes" >&5
 echo "${ECHO_T}yes" >&6
-else	echo "$as_me:20947: result: no" >&5
+else	echo "$as_me:21444: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
-echo "$as_me:20951: checking for builtin bool type" >&5
+echo "$as_me:21448: checking for builtin bool type" >&5
 echo $ECHO_N "checking for builtin bool type... $ECHO_C" >&6
 
 if test "${cf_cv_cc_bool_type+set}" = set; then
@@ -20956,7 +21453,7 @@
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 20959 "configure"
+#line 21456 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -20971,16 +21468,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:20974: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:21471: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:20977: \$? = $ac_status" >&5
+  echo "$as_me:21474: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:20980: \"$ac_try\"") >&5
+  { (eval echo "$as_me:21477: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:20983: \$? = $ac_status" >&5
+  echo "$as_me:21480: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_cc_bool_type=1
 else
@@ -20993,9 +21490,9 @@
 fi
 
 if test "$cf_cv_cc_bool_type" = 1
-then	echo "$as_me:20996: result: yes" >&5
+then	echo "$as_me:21493: result: yes" >&5
 echo "${ECHO_T}yes" >&6
-else	echo "$as_me:20998: result: no" >&5
+else	echo "$as_me:21495: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -21012,10 +21509,10 @@
 
 	cf_save="$LIBS"
 	LIBS="$LIBS $CXXLIBS"
-	echo "$as_me:21015: checking if we already have C++ library" >&5
+	echo "$as_me:21512: checking if we already have C++ library" >&5
 echo $ECHO_N "checking if we already have C++ library... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 21018 "configure"
+#line 21515 "configure"
 #include "confdefs.h"
 
 			#include <iostream>
@@ -21029,16 +21526,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:21032: \"$ac_link\"") >&5
+if { (eval echo "$as_me:21529: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:21035: \$? = $ac_status" >&5
+  echo "$as_me:21532: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:21038: \"$ac_try\"") >&5
+  { (eval echo "$as_me:21535: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:21041: \$? = $ac_status" >&5
+  echo "$as_me:21538: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_have_libstdcpp=yes
 else
@@ -21047,7 +21544,7 @@
 cf_have_libstdcpp=no
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
-	echo "$as_me:21050: result: $cf_have_libstdcpp" >&5
+	echo "$as_me:21547: result: $cf_have_libstdcpp" >&5
 echo "${ECHO_T}$cf_have_libstdcpp" >&6
 	LIBS="$cf_save"
 
@@ -21066,7 +21563,7 @@
 			;;
 		esac
 
-		echo "$as_me:21069: checking for library $cf_stdcpp_libname" >&5
+		echo "$as_me:21566: checking for library $cf_stdcpp_libname" >&5
 echo $ECHO_N "checking for library $cf_stdcpp_libname... $ECHO_C" >&6
 if test "${cf_cv_libstdcpp+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -21092,7 +21589,7 @@
 LIBS="$cf_add_libs"
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 21095 "configure"
+#line 21592 "configure"
 #include "confdefs.h"
 
 				#include <iostream>
@@ -21106,16 +21603,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:21109: \"$ac_link\"") >&5
+if { (eval echo "$as_me:21606: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:21112: \$? = $ac_status" >&5
+  echo "$as_me:21609: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:21115: \"$ac_try\"") >&5
+  { (eval echo "$as_me:21612: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:21118: \$? = $ac_status" >&5
+  echo "$as_me:21615: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_libstdcpp=yes
 else
@@ -21127,7 +21624,7 @@
 			LIBS="$cf_save"
 
 fi
-echo "$as_me:21130: result: $cf_cv_libstdcpp" >&5
+echo "$as_me:21627: result: $cf_cv_libstdcpp" >&5
 echo "${ECHO_T}$cf_cv_libstdcpp" >&6
 		test "$cf_cv_libstdcpp" = yes && {
 cf_add_libs="-l$cf_stdcpp_libname"
@@ -21149,7 +21646,7 @@
 	fi
 fi
 
-	echo "$as_me:21152: checking whether $CXX understands -c and -o together" >&5
+	echo "$as_me:21649: checking whether $CXX understands -c and -o together" >&5
 echo $ECHO_N "checking whether $CXX understands -c and -o together... $ECHO_C" >&6
 if test "${cf_cv_prog_CXX_c_o+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -21164,15 +21661,15 @@
 # We do the test twice because some compilers refuse to overwrite an
 # existing .o file with -o, though they will create one.
 ac_try='$CXX $CXXFLAGS $CPPFLAGS -c conftest.$ac_ext -o conftest2.$ac_objext >&5'
-if { (eval echo "$as_me:21167: \"$ac_try\"") >&5
+if { (eval echo "$as_me:21664: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:21170: \$? = $ac_status" >&5
+  echo "$as_me:21667: \$? = $ac_status" >&5
   (exit $ac_status); } &&
-  test -f conftest2.$ac_objext && { (eval echo "$as_me:21172: \"$ac_try\"") >&5
+  test -f conftest2.$ac_objext && { (eval echo "$as_me:21669: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:21175: \$? = $ac_status" >&5
+  echo "$as_me:21672: \$? = $ac_status" >&5
   (exit $ac_status); };
 then
   eval cf_cv_prog_CXX_c_o=yes
@@ -21183,10 +21680,10 @@
 
 fi
 if test $cf_cv_prog_CXX_c_o = yes; then
-  echo "$as_me:21186: result: yes" >&5
+  echo "$as_me:21683: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
-  echo "$as_me:21189: result: no" >&5
+  echo "$as_me:21686: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -21206,7 +21703,7 @@
 	;;
 esac
 if test "$GXX" = yes; then
-	echo "$as_me:21209: checking for lib$cf_gpp_libname" >&5
+	echo "$as_me:21706: checking for lib$cf_gpp_libname" >&5
 echo $ECHO_N "checking for lib$cf_gpp_libname... $ECHO_C" >&6
 	cf_save="$LIBS"
 
@@ -21227,7 +21724,7 @@
 LIBS="$cf_add_libs"
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 21230 "configure"
+#line 21727 "configure"
 #include "confdefs.h"
 
 #include <$cf_gpp_libname/builtin.h>
@@ -21241,16 +21738,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:21244: \"$ac_link\"") >&5
+if { (eval echo "$as_me:21741: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:21247: \$? = $ac_status" >&5
+  echo "$as_me:21744: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:21250: \"$ac_try\"") >&5
+  { (eval echo "$as_me:21747: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:21253: \$? = $ac_status" >&5
+  echo "$as_me:21750: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cxx_library=yes
 
@@ -21287,7 +21784,7 @@
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 cat >conftest.$ac_ext <<_ACEOF
-#line 21290 "configure"
+#line 21787 "configure"
 #include "confdefs.h"
 
 #include <builtin.h>
@@ -21301,16 +21798,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:21304: \"$ac_link\"") >&5
+if { (eval echo "$as_me:21801: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:21307: \$? = $ac_status" >&5
+  echo "$as_me:21804: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:21310: \"$ac_try\"") >&5
+  { (eval echo "$as_me:21807: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:21313: \$? = $ac_status" >&5
+  echo "$as_me:21810: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cxx_library=yes
 
@@ -21343,7 +21840,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 	LIBS="$cf_save"
-	echo "$as_me:21346: result: $cf_cxx_library" >&5
+	echo "$as_me:21843: result: $cf_cxx_library" >&5
 echo "${ECHO_T}$cf_cxx_library" >&6
 fi
 
@@ -21359,7 +21856,7 @@
 ac_link='$CXX -o conftest$ac_exeext $CXXFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
 ac_compiler_gnu=$ac_cv_cxx_compiler_gnu
 ac_main_return=return
-echo "$as_me:21362: checking how to run the C++ preprocessor" >&5
+echo "$as_me:21859: checking how to run the C++ preprocessor" >&5
 echo $ECHO_N "checking how to run the C++ preprocessor... $ECHO_C" >&6
 if test -z "$CXXCPP"; then
   if test "${ac_cv_prog_CXXCPP+set}" = set; then
@@ -21376,18 +21873,18 @@
   # On the NeXT, cc -E runs the code through the compiler's parser,
   # not just through cpp. "Syntax error" is here to catch this case.
   cat >conftest.$ac_ext <<_ACEOF
-#line 21379 "configure"
+#line 21876 "configure"
 #include "confdefs.h"
 #include <assert.h>
                      Syntax error
 _ACEOF
-if { (eval echo "$as_me:21384: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:21881: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:21390: \$? = $ac_status" >&5
+  echo "$as_me:21887: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_cxx_preproc_warn_flag
@@ -21410,17 +21907,17 @@
   # OK, works on sane cases.  Now check whether non-existent headers
   # can be detected and how.
   cat >conftest.$ac_ext <<_ACEOF
-#line 21413 "configure"
+#line 21910 "configure"
 #include "confdefs.h"
 #include <ac_nonexistent.h>
 _ACEOF
-if { (eval echo "$as_me:21417: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:21914: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:21423: \$? = $ac_status" >&5
+  echo "$as_me:21920: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_cxx_preproc_warn_flag
@@ -21457,7 +21954,7 @@
 else
   ac_cv_prog_CXXCPP=$CXXCPP
 fi
-echo "$as_me:21460: result: $CXXCPP" >&5
+echo "$as_me:21957: result: $CXXCPP" >&5
 echo "${ECHO_T}$CXXCPP" >&6
 ac_preproc_ok=false
 for ac_cxx_preproc_warn_flag in '' yes
@@ -21467,18 +21964,18 @@
   # On the NeXT, cc -E runs the code through the compiler's parser,
   # not just through cpp. "Syntax error" is here to catch this case.
   cat >conftest.$ac_ext <<_ACEOF
-#line 21470 "configure"
+#line 21967 "configure"
 #include "confdefs.h"
 #include <assert.h>
                      Syntax error
 _ACEOF
-if { (eval echo "$as_me:21475: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:21972: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:21481: \$? = $ac_status" >&5
+  echo "$as_me:21978: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_cxx_preproc_warn_flag
@@ -21501,17 +21998,17 @@
   # OK, works on sane cases.  Now check whether non-existent headers
   # can be detected and how.
   cat >conftest.$ac_ext <<_ACEOF
-#line 21504 "configure"
+#line 22001 "configure"
 #include "confdefs.h"
 #include <ac_nonexistent.h>
 _ACEOF
-if { (eval echo "$as_me:21508: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:22005: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:21514: \$? = $ac_status" >&5
+  echo "$as_me:22011: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_cxx_preproc_warn_flag
@@ -21539,7 +22036,7 @@
 if $ac_preproc_ok; then
   :
 else
-  { { echo "$as_me:21542: error: C++ preprocessor \"$CXXCPP\" fails sanity check" >&5
+  { { echo "$as_me:22039: error: C++ preprocessor \"$CXXCPP\" fails sanity check" >&5
 echo "$as_me: error: C++ preprocessor \"$CXXCPP\" fails sanity check" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -21554,23 +22051,23 @@
 for ac_header in typeinfo
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:21557: checking for $ac_header" >&5
+echo "$as_me:22054: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 21563 "configure"
+#line 22060 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:21567: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:22064: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:21573: \$? = $ac_status" >&5
+  echo "$as_me:22070: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_cxx_preproc_warn_flag
@@ -21589,7 +22086,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:21592: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:22089: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -21602,23 +22099,23 @@
 for ac_header in iostream
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:21605: checking for $ac_header" >&5
+echo "$as_me:22102: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 21611 "configure"
+#line 22108 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:21615: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:22112: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:21621: \$? = $ac_status" >&5
+  echo "$as_me:22118: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_cxx_preproc_warn_flag
@@ -21637,7 +22134,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:21640: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:22137: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -21648,10 +22145,10 @@
 done
 
 if test x"$ac_cv_header_iostream" = xyes ; then
-	echo "$as_me:21651: checking if iostream uses std-namespace" >&5
+	echo "$as_me:22148: checking if iostream uses std-namespace" >&5
 echo $ECHO_N "checking if iostream uses std-namespace... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 21654 "configure"
+#line 22151 "configure"
 #include "confdefs.h"
 
 #include <iostream>
@@ -21668,16 +22165,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:21671: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:22168: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:21674: \$? = $ac_status" >&5
+  echo "$as_me:22171: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:21677: \"$ac_try\"") >&5
+  { (eval echo "$as_me:22174: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:21680: \$? = $ac_status" >&5
+  echo "$as_me:22177: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_iostream_namespace=yes
 else
@@ -21686,7 +22183,7 @@
 cf_iostream_namespace=no
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
-	echo "$as_me:21689: result: $cf_iostream_namespace" >&5
+	echo "$as_me:22186: result: $cf_iostream_namespace" >&5
 echo "${ECHO_T}$cf_iostream_namespace" >&6
 	if test "$cf_iostream_namespace" = yes ; then
 
@@ -21697,7 +22194,7 @@
 	fi
 fi
 
-echo "$as_me:21700: checking if we should include stdbool.h" >&5
+echo "$as_me:22197: checking if we should include stdbool.h" >&5
 echo $ECHO_N "checking if we should include stdbool.h... $ECHO_C" >&6
 
 if test "${cf_cv_header_stdbool_h+set}" = set; then
@@ -21705,7 +22202,7 @@
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 21708 "configure"
+#line 22205 "configure"
 #include "confdefs.h"
 
 int
@@ -21717,23 +22214,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:21720: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:22217: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:21723: \$? = $ac_status" >&5
+  echo "$as_me:22220: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:21726: \"$ac_try\"") >&5
+  { (eval echo "$as_me:22223: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:21729: \$? = $ac_status" >&5
+  echo "$as_me:22226: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_header_stdbool_h=0
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 cat >conftest.$ac_ext <<_ACEOF
-#line 21736 "configure"
+#line 22233 "configure"
 #include "confdefs.h"
 
 #ifndef __BEOS__
@@ -21749,16 +22246,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:21752: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:22249: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:21755: \$? = $ac_status" >&5
+  echo "$as_me:22252: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:21758: \"$ac_try\"") >&5
+  { (eval echo "$as_me:22255: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:21761: \$? = $ac_status" >&5
+  echo "$as_me:22258: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_header_stdbool_h=1
 else
@@ -21772,13 +22269,13 @@
 fi
 
 if test "$cf_cv_header_stdbool_h" = 1
-then	echo "$as_me:21775: result: yes" >&5
+then	echo "$as_me:22272: result: yes" >&5
 echo "${ECHO_T}yes" >&6
-else	echo "$as_me:21777: result: no" >&5
+else	echo "$as_me:22274: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
-echo "$as_me:21781: checking for builtin bool type" >&5
+echo "$as_me:22278: checking for builtin bool type" >&5
 echo $ECHO_N "checking for builtin bool type... $ECHO_C" >&6
 
 if test "${cf_cv_builtin_bool+set}" = set; then
@@ -21786,7 +22283,7 @@
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 21789 "configure"
+#line 22286 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -21801,16 +22298,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:21804: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:22301: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:21807: \$? = $ac_status" >&5
+  echo "$as_me:22304: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:21810: \"$ac_try\"") >&5
+  { (eval echo "$as_me:22307: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:21813: \$? = $ac_status" >&5
+  echo "$as_me:22310: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_builtin_bool=1
 else
@@ -21823,13 +22320,13 @@
 fi
 
 if test "$cf_cv_builtin_bool" = 1
-then	echo "$as_me:21826: result: yes" >&5
+then	echo "$as_me:22323: result: yes" >&5
 echo "${ECHO_T}yes" >&6
-else	echo "$as_me:21828: result: no" >&5
+else	echo "$as_me:22325: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
-echo "$as_me:21832: checking for size of bool" >&5
+echo "$as_me:22329: checking for size of bool" >&5
 echo $ECHO_N "checking for size of bool... $ECHO_C" >&6
 if test "${cf_cv_type_of_bool+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -21840,7 +22337,7 @@
   cf_cv_type_of_bool=unknown
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 21843 "configure"
+#line 22340 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -21882,15 +22379,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:21885: \"$ac_link\"") >&5
+if { (eval echo "$as_me:22382: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:21888: \$? = $ac_status" >&5
+  echo "$as_me:22385: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:21890: \"$ac_try\"") >&5
+  { (eval echo "$as_me:22387: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:21893: \$? = $ac_status" >&5
+  echo "$as_me:22390: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_type_of_bool=`cat cf_test.out`
 		 if test -z "$cf_cv_type_of_bool"; then
@@ -21908,18 +22405,18 @@
 fi
 
 	rm -f cf_test.out
-echo "$as_me:21911: result: $cf_cv_type_of_bool" >&5
+echo "$as_me:22408: result: $cf_cv_type_of_bool" >&5
 echo "${ECHO_T}$cf_cv_type_of_bool" >&6
 if test "$cf_cv_type_of_bool" = unknown ; then
 	case .$NCURSES_BOOL in
 	(.auto|.) NCURSES_BOOL=unsigned;;
 	esac
-	{ echo "$as_me:21917: WARNING: Assuming $NCURSES_BOOL for type of bool" >&5
+	{ echo "$as_me:22414: WARNING: Assuming $NCURSES_BOOL for type of bool" >&5
 echo "$as_me: WARNING: Assuming $NCURSES_BOOL for type of bool" >&2;}
 	cf_cv_type_of_bool=$NCURSES_BOOL
 fi
 
-echo "$as_me:21922: checking for special defines needed for etip.h" >&5
+echo "$as_me:22419: checking for special defines needed for etip.h" >&5
 echo $ECHO_N "checking for special defines needed for etip.h... $ECHO_C" >&6
 cf_save_CXXFLAGS="$CXXFLAGS"
 cf_result="none"
@@ -21937,7 +22434,7 @@
 	test -n "$cf_math" && CXXFLAGS="$CXXFLAGS -DETIP_NEEDS_${cf_math}"
 	test -n "$cf_excp" && CXXFLAGS="$CXXFLAGS -DETIP_NEEDS_${cf_excp}"
 cat >conftest.$ac_ext <<_ACEOF
-#line 21940 "configure"
+#line 22437 "configure"
 #include "confdefs.h"
 
 #include <etip.h.in>
@@ -21951,16 +22448,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:21954: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:22451: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:21957: \$? = $ac_status" >&5
+  echo "$as_me:22454: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:21960: \"$ac_try\"") >&5
+  { (eval echo "$as_me:22457: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:21963: \$? = $ac_status" >&5
+  echo "$as_me:22460: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 	test -n "$cf_math" && cat >>confdefs.h <<EOF
@@ -21981,12 +22478,12 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 done
 done
-echo "$as_me:21984: result: $cf_result" >&5
+echo "$as_me:22481: result: $cf_result" >&5
 echo "${ECHO_T}$cf_result" >&6
 CXXFLAGS="$cf_save_CXXFLAGS"
 
 if test -n "$CXX"; then
-echo "$as_me:21989: checking if $CXX accepts parameter initialization" >&5
+echo "$as_me:22486: checking if $CXX accepts parameter initialization" >&5
 echo $ECHO_N "checking if $CXX accepts parameter initialization... $ECHO_C" >&6
 if test "${cf_cv_cpp_param_init+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -22003,7 +22500,7 @@
   cf_cv_cpp_param_init=unknown
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 22006 "configure"
+#line 22503 "configure"
 #include "confdefs.h"
 
 class TEST {
@@ -22022,15 +22519,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:22025: \"$ac_link\"") >&5
+if { (eval echo "$as_me:22522: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:22028: \$? = $ac_status" >&5
+  echo "$as_me:22525: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:22030: \"$ac_try\"") >&5
+  { (eval echo "$as_me:22527: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:22033: \$? = $ac_status" >&5
+  echo "$as_me:22530: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_cpp_param_init=yes
 else
@@ -22049,7 +22546,7 @@
 ac_main_return=return
 
 fi
-echo "$as_me:22052: result: $cf_cv_cpp_param_init" >&5
+echo "$as_me:22549: result: $cf_cv_cpp_param_init" >&5
 echo "${ECHO_T}$cf_cv_cpp_param_init" >&6
 fi
 test "$cf_cv_cpp_param_init" = yes &&
@@ -22059,7 +22556,7 @@
 
 if test -n "$CXX"; then
 
-echo "$as_me:22062: checking if $CXX accepts static_cast" >&5
+echo "$as_me:22559: checking if $CXX accepts static_cast" >&5
 echo $ECHO_N "checking if $CXX accepts static_cast... $ECHO_C" >&6
 if test "${cf_cv_cpp_static_cast+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -22073,7 +22570,7 @@
 ac_main_return=return
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 22076 "configure"
+#line 22573 "configure"
 #include "confdefs.h"
 
 class NCursesPanel
@@ -22117,16 +22614,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:22120: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:22617: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:22123: \$? = $ac_status" >&5
+  echo "$as_me:22620: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:22126: \"$ac_try\"") >&5
+  { (eval echo "$as_me:22623: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:22129: \$? = $ac_status" >&5
+  echo "$as_me:22626: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_cpp_static_cast=yes
 else
@@ -22144,7 +22641,7 @@
 ac_main_return=return
 
 fi
-echo "$as_me:22147: result: $cf_cv_cpp_static_cast" >&5
+echo "$as_me:22644: result: $cf_cv_cpp_static_cast" >&5
 echo "${ECHO_T}$cf_cv_cpp_static_cast" >&6
 
 fi
@@ -22193,7 +22690,7 @@
 	else
 		if test "$cf_cv_header_stdbool_h" = 1 ; then
 
-echo "$as_me:22196: checking for size of bool" >&5
+echo "$as_me:22693: checking for size of bool" >&5
 echo $ECHO_N "checking for size of bool... $ECHO_C" >&6
 if test "${cf_cv_type_of_bool+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -22204,7 +22701,7 @@
   cf_cv_type_of_bool=unknown
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 22207 "configure"
+#line 22704 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -22246,15 +22743,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:22249: \"$ac_link\"") >&5
+if { (eval echo "$as_me:22746: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:22252: \$? = $ac_status" >&5
+  echo "$as_me:22749: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:22254: \"$ac_try\"") >&5
+  { (eval echo "$as_me:22751: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:22257: \$? = $ac_status" >&5
+  echo "$as_me:22754: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_cv_type_of_bool=`cat cf_test.out`
 		 if test -z "$cf_cv_type_of_bool"; then
@@ -22272,25 +22769,25 @@
 fi
 
 	rm -f cf_test.out
-echo "$as_me:22275: result: $cf_cv_type_of_bool" >&5
+echo "$as_me:22772: result: $cf_cv_type_of_bool" >&5
 echo "${ECHO_T}$cf_cv_type_of_bool" >&6
 if test "$cf_cv_type_of_bool" = unknown ; then
 	case .$NCURSES_BOOL in
 	(.auto|.) NCURSES_BOOL=unsigned;;
 	esac
-	{ echo "$as_me:22281: WARNING: Assuming $NCURSES_BOOL for type of bool" >&5
+	{ echo "$as_me:22778: WARNING: Assuming $NCURSES_BOOL for type of bool" >&5
 echo "$as_me: WARNING: Assuming $NCURSES_BOOL for type of bool" >&2;}
 	cf_cv_type_of_bool=$NCURSES_BOOL
 fi
 
 		else
-			echo "$as_me:22287: checking for fallback type of bool" >&5
+			echo "$as_me:22784: checking for fallback type of bool" >&5
 echo $ECHO_N "checking for fallback type of bool... $ECHO_C" >&6
 			case "$host_cpu" in
 			(i?86)	cf_cv_type_of_bool=char	;;
 			(*)	cf_cv_type_of_bool=int	;;
 			esac
-			echo "$as_me:22293: result: $cf_cv_type_of_bool" >&5
+			echo "$as_me:22790: result: $cf_cv_type_of_bool" >&5
 echo "${ECHO_T}$cf_cv_type_of_bool" >&6
 		fi
 	fi
@@ -22319,7 +22816,7 @@
 
 	if test "$cf_with_ada" != "no" ; then
 		if test "$with_libtool" != "no"; then
-			{ echo "$as_me:22322: WARNING: libtool does not support Ada - disabling feature" >&5
+			{ echo "$as_me:22819: WARNING: libtool does not support Ada - disabling feature" >&5
 echo "$as_me: WARNING: libtool does not support Ada - disabling feature" >&2;}
 			cf_with_ada=no
 		fi
@@ -22331,7 +22828,7 @@
 cf_ada_config="#"
 # Extract the first word of "$cf_ada_make", so it can be a program name with args.
 set dummy $cf_ada_make; ac_word=$2
-echo "$as_me:22334: checking for $ac_word" >&5
+echo "$as_me:22831: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_gnatmake_exists+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -22346,7 +22843,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_gnatmake_exists="yes"
-echo "$as_me:22349: found $ac_dir/$ac_word" >&5
+echo "$as_me:22846: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -22355,10 +22852,10 @@
 fi
 gnatmake_exists=$ac_cv_prog_gnatmake_exists
 if test -n "$gnatmake_exists"; then
-  echo "$as_me:22358: result: $gnatmake_exists" >&5
+  echo "$as_me:22855: result: $gnatmake_exists" >&5
 echo "${ECHO_T}$gnatmake_exists" >&6
 else
-  echo "$as_me:22361: result: no" >&5
+  echo "$as_me:22858: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -22368,7 +22865,7 @@
 else
 	# Extract the first word of "gprconfig", so it can be a program name with args.
 set dummy gprconfig; ac_word=$2
-echo "$as_me:22371: checking for $ac_word" >&5
+echo "$as_me:22868: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_gprconfig_exists+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -22383,7 +22880,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_gprconfig_exists="yes"
-echo "$as_me:22386: found $ac_dir/$ac_word" >&5
+echo "$as_me:22883: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -22392,10 +22889,10 @@
 fi
 gprconfig_exists=$ac_cv_prog_gprconfig_exists
 if test -n "$gprconfig_exists"; then
-  echo "$as_me:22395: result: $gprconfig_exists" >&5
+  echo "$as_me:22892: result: $gprconfig_exists" >&5
 echo "${ECHO_T}$gprconfig_exists" >&6
 else
-  echo "$as_me:22398: result: no" >&5
+  echo "$as_me:22895: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -22408,16 +22905,16 @@
 			cd conftest.src
 			for cf_gprconfig in Ada C
 			do
-				echo "$as_me:22411: checking for gprconfig name for $cf_gprconfig" >&5
+				echo "$as_me:22908: checking for gprconfig name for $cf_gprconfig" >&5
 echo $ECHO_N "checking for gprconfig name for $cf_gprconfig... $ECHO_C" >&6
 				cf_gprconfig_value=`echo s| gprconfig --config=$cf_gprconfig 2>&5 | ${AWK:-awk} '/^\*/{print $3;}' | head -n 1`
 				if test -n "$cf_gprconfig_value"
 				then
 					eval cf_ada_config_$cf_gprconfig=$cf_gprconfig_value
-					echo "$as_me:22417: result: $cf_gprconfig_value" >&5
+					echo "$as_me:22914: result: $cf_gprconfig_value" >&5
 echo "${ECHO_T}$cf_gprconfig_value" >&6
 				else
-					echo "$as_me:22420: result: missing" >&5
+					echo "$as_me:22917: result: missing" >&5
 echo "${ECHO_T}missing" >&6
 					cf_ada_config="#"
 					break
@@ -22433,12 +22930,12 @@
 	if test "x$cf_ada_config" != "x#"
 	then
 
-echo "$as_me:22436: checking for gnat version" >&5
+echo "$as_me:22933: checking for gnat version" >&5
 echo $ECHO_N "checking for gnat version... $ECHO_C" >&6
 cf_gnat_version=`${cf_ada_make:-gnatmake} -v 2>&1 | \
 	grep '[0-9].[0-9][0-9]*' |\
 	sed -e '2,$d' -e 's/[^0-9 \.]//g' -e 's/^[ ]*//' -e 's/ .*//'`
-echo "$as_me:22441: result: $cf_gnat_version" >&5
+echo "$as_me:22938: result: $cf_gnat_version" >&5
 echo "${ECHO_T}$cf_gnat_version" >&6
 
 case $cf_gnat_version in
@@ -22446,7 +22943,7 @@
 	cf_cv_prog_gnat_correct=yes
 	;;
 (*)
-	{ echo "$as_me:22449: WARNING: Unsupported GNAT version $cf_gnat_version. We require 3.11 or better. Disabling Ada95 binding." >&5
+	{ echo "$as_me:22946: WARNING: Unsupported GNAT version $cf_gnat_version. We require 3.11 or better. Disabling Ada95 binding." >&5
 echo "$as_me: WARNING: Unsupported GNAT version $cf_gnat_version. We require 3.11 or better. Disabling Ada95 binding." >&2;}
 	cf_cv_prog_gnat_correct=no
 	;;
@@ -22454,7 +22951,7 @@
 
 		# Extract the first word of "m4", so it can be a program name with args.
 set dummy m4; ac_word=$2
-echo "$as_me:22457: checking for $ac_word" >&5
+echo "$as_me:22954: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_prog_M4_exists+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -22469,7 +22966,7 @@
   test -z "$ac_dir" && ac_dir=.
   $as_executable_p "$ac_dir/$ac_word" || continue
 ac_cv_prog_M4_exists="yes"
-echo "$as_me:22472: found $ac_dir/$ac_word" >&5
+echo "$as_me:22969: found $ac_dir/$ac_word" >&5
 break
 done
 
@@ -22478,10 +22975,10 @@
 fi
 M4_exists=$ac_cv_prog_M4_exists
 if test -n "$M4_exists"; then
-  echo "$as_me:22481: result: $M4_exists" >&5
+  echo "$as_me:22978: result: $M4_exists" >&5
 echo "${ECHO_T}$M4_exists" >&6
 else
-  echo "$as_me:22484: result: no" >&5
+  echo "$as_me:22981: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -22490,7 +22987,7 @@
 			echo Ada95 binding required program m4 not found. Ada95 binding disabled.
 		fi
 		if test "$cf_cv_prog_gnat_correct" = yes; then
-			echo "$as_me:22493: checking if GNAT works" >&5
+			echo "$as_me:22990: checking if GNAT works" >&5
 echo $ECHO_N "checking if GNAT works... $ECHO_C" >&6
 
 rm -rf conftest* *~conftest*
@@ -22518,7 +23015,7 @@
 fi
 rm -rf conftest* *~conftest*
 
-			echo "$as_me:22521: result: $cf_cv_prog_gnat_correct" >&5
+			echo "$as_me:23018: result: $cf_cv_prog_gnat_correct" >&5
 echo "${ECHO_T}$cf_cv_prog_gnat_correct" >&6
 		fi
 	else
@@ -22530,7 +23027,7 @@
 
  	ADAFLAGS="$ADAFLAGS -gnatpn"
 
-	echo "$as_me:22533: checking optimization options for ADAFLAGS" >&5
+	echo "$as_me:23030: checking optimization options for ADAFLAGS" >&5
 echo $ECHO_N "checking optimization options for ADAFLAGS... $ECHO_C" >&6
 	case "$CFLAGS" in
 	(*-g*)
@@ -22547,10 +23044,10 @@
 
 		;;
 	esac
-	echo "$as_me:22550: result: $ADAFLAGS" >&5
+	echo "$as_me:23047: result: $ADAFLAGS" >&5
 echo "${ECHO_T}$ADAFLAGS" >&6
 
-echo "$as_me:22553: checking if GNATPREP supports -T option" >&5
+echo "$as_me:23050: checking if GNATPREP supports -T option" >&5
 echo $ECHO_N "checking if GNATPREP supports -T option... $ECHO_C" >&6
 if test "${cf_cv_gnatprep_opt_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -22560,11 +23057,11 @@
 gnatprep -T 2>/dev/null >/dev/null && cf_cv_gnatprep_opt_t=yes
 
 fi
-echo "$as_me:22563: result: $cf_cv_gnatprep_opt_t" >&5
+echo "$as_me:23060: result: $cf_cv_gnatprep_opt_t" >&5
 echo "${ECHO_T}$cf_cv_gnatprep_opt_t" >&6
 test "$cf_cv_gnatprep_opt_t" = yes && GNATPREP_OPTS="-T $GNATPREP_OPTS"
 
-echo "$as_me:22567: checking if GNAT supports generics" >&5
+echo "$as_me:23064: checking if GNAT supports generics" >&5
 echo $ECHO_N "checking if GNAT supports generics... $ECHO_C" >&6
 case $cf_gnat_version in
 (3.[1-9]*|[4-9].*)
@@ -22574,7 +23071,7 @@
 	cf_gnat_generics=no
 	;;
 esac
-echo "$as_me:22577: result: $cf_gnat_generics" >&5
+echo "$as_me:23074: result: $cf_gnat_generics" >&5
 echo "${ECHO_T}$cf_gnat_generics" >&6
 
 if test "$cf_gnat_generics" = yes
@@ -22586,7 +23083,7 @@
 	cf_generic_objects=
 fi
 
-echo "$as_me:22589: checking if GNAT supports SIGINT" >&5
+echo "$as_me:23086: checking if GNAT supports SIGINT" >&5
 echo $ECHO_N "checking if GNAT supports SIGINT... $ECHO_C" >&6
 if test "${cf_cv_gnat_sigint+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -22634,7 +23131,7 @@
 rm -rf conftest* *~conftest*
 
 fi
-echo "$as_me:22637: result: $cf_cv_gnat_sigint" >&5
+echo "$as_me:23134: result: $cf_cv_gnat_sigint" >&5
 echo "${ECHO_T}$cf_cv_gnat_sigint" >&6
 
 if test $cf_cv_gnat_sigint = yes ; then
@@ -22647,7 +23144,7 @@
 cf_gnat_projects=no
 
 if test "$enable_gnat_projects" != no ; then
-echo "$as_me:22650: checking if GNAT supports project files" >&5
+echo "$as_me:23147: checking if GNAT supports project files" >&5
 echo $ECHO_N "checking if GNAT supports project files... $ECHO_C" >&6
 case $cf_gnat_version in
 (3.[0-9]*)
@@ -22710,15 +23207,15 @@
 	esac
 	;;
 esac
-echo "$as_me:22713: result: $cf_gnat_projects" >&5
+echo "$as_me:23210: result: $cf_gnat_projects" >&5
 echo "${ECHO_T}$cf_gnat_projects" >&6
 fi # enable_gnat_projects
 
 if test $cf_gnat_projects = yes
 then
-	echo "$as_me:22719: checking if GNAT supports libraries" >&5
+	echo "$as_me:23216: checking if GNAT supports libraries" >&5
 echo $ECHO_N "checking if GNAT supports libraries... $ECHO_C" >&6
-	echo "$as_me:22721: result: $cf_gnat_libraries" >&5
+	echo "$as_me:23218: result: $cf_gnat_libraries" >&5
 echo "${ECHO_T}$cf_gnat_libraries" >&6
 fi
 
@@ -22738,7 +23235,7 @@
 	USE_GNAT_LIBRARIES="#"
 fi
 
-echo "$as_me:22741: checking for ada-compiler" >&5
+echo "$as_me:23238: checking for ada-compiler" >&5
 echo $ECHO_N "checking for ada-compiler... $ECHO_C" >&6
 
 # Check whether --with-ada-compiler or --without-ada-compiler was given.
@@ -22749,12 +23246,12 @@
   cf_ada_compiler=gnatmake
 fi;
 
-echo "$as_me:22752: result: $cf_ada_compiler" >&5
+echo "$as_me:23249: result: $cf_ada_compiler" >&5
 echo "${ECHO_T}$cf_ada_compiler" >&6
 
 			cf_ada_package=terminal_interface
 
-echo "$as_me:22757: checking for ada-include" >&5
+echo "$as_me:23254: checking for ada-include" >&5
 echo $ECHO_N "checking for ada-include... $ECHO_C" >&6
 
 # Check whether --with-ada-include or --without-ada-include was given.
@@ -22790,7 +23287,7 @@
 	withval=`echo $withval | sed -e s%NONE%$cf_path_syntax%`
 	;;
 (*)
-	{ { echo "$as_me:22793: error: expected a pathname, not \"$withval\"" >&5
+	{ { echo "$as_me:23290: error: expected a pathname, not \"$withval\"" >&5
 echo "$as_me: error: expected a pathname, not \"$withval\"" >&2;}
    { (exit 1); exit 1; }; }
 	;;
@@ -22799,10 +23296,10 @@
 fi
 eval ADA_INCLUDE="$withval"
 
-echo "$as_me:22802: result: $ADA_INCLUDE" >&5
+echo "$as_me:23299: result: $ADA_INCLUDE" >&5
 echo "${ECHO_T}$ADA_INCLUDE" >&6
 
-echo "$as_me:22805: checking for ada-objects" >&5
+echo "$as_me:23302: checking for ada-objects" >&5
 echo $ECHO_N "checking for ada-objects... $ECHO_C" >&6
 
 # Check whether --with-ada-objects or --without-ada-objects was given.
@@ -22838,7 +23335,7 @@
 	withval=`echo $withval | sed -e s%NONE%$cf_path_syntax%`
 	;;
 (*)
-	{ { echo "$as_me:22841: error: expected a pathname, not \"$withval\"" >&5
+	{ { echo "$as_me:23338: error: expected a pathname, not \"$withval\"" >&5
 echo "$as_me: error: expected a pathname, not \"$withval\"" >&2;}
    { (exit 1); exit 1; }; }
 	;;
@@ -22847,10 +23344,10 @@
 fi
 eval ADA_OBJECTS="$withval"
 
-echo "$as_me:22850: result: $ADA_OBJECTS" >&5
+echo "$as_me:23347: result: $ADA_OBJECTS" >&5
 echo "${ECHO_T}$ADA_OBJECTS" >&6
 
-echo "$as_me:22853: checking if an Ada95 shared-library should be built" >&5
+echo "$as_me:23350: checking if an Ada95 shared-library should be built" >&5
 echo $ECHO_N "checking if an Ada95 shared-library should be built... $ECHO_C" >&6
 
 # Check whether --with-ada-sharedlib or --without-ada-sharedlib was given.
@@ -22860,7 +23357,7 @@
 else
   with_ada_sharedlib=no
 fi;
-echo "$as_me:22863: result: $with_ada_sharedlib" >&5
+echo "$as_me:23360: result: $with_ada_sharedlib" >&5
 echo "${ECHO_T}$with_ada_sharedlib" >&6
 
 ADA_SHAREDLIB='lib$(LIB_NAME).so.1'
@@ -22883,13 +23380,13 @@
 
 # do this "late" to avoid conflict with header-checks
 if test "x$with_widec" = xyes ; then
-	echo "$as_me:22886: checking for wchar_t" >&5
+	echo "$as_me:23383: checking for wchar_t" >&5
 echo $ECHO_N "checking for wchar_t... $ECHO_C" >&6
 if test "${ac_cv_type_wchar_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 22892 "configure"
+#line 23389 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -22904,16 +23401,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:22907: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:23404: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:22910: \$? = $ac_status" >&5
+  echo "$as_me:23407: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:22913: \"$ac_try\"") >&5
+  { (eval echo "$as_me:23410: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:22916: \$? = $ac_status" >&5
+  echo "$as_me:23413: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_wchar_t=yes
 else
@@ -22923,10 +23420,10 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:22926: result: $ac_cv_type_wchar_t" >&5
+echo "$as_me:23423: result: $ac_cv_type_wchar_t" >&5
 echo "${ECHO_T}$ac_cv_type_wchar_t" >&6
 
-echo "$as_me:22929: checking size of wchar_t" >&5
+echo "$as_me:23426: checking size of wchar_t" >&5
 echo $ECHO_N "checking size of wchar_t... $ECHO_C" >&6
 if test "${ac_cv_sizeof_wchar_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -22935,7 +23432,7 @@
   if test "$cross_compiling" = yes; then
   # Depending upon the size, compute the lo and hi bounds.
 cat >conftest.$ac_ext <<_ACEOF
-#line 22938 "configure"
+#line 23435 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -22947,21 +23444,21 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:22950: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:23447: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:22953: \$? = $ac_status" >&5
+  echo "$as_me:23450: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:22956: \"$ac_try\"") >&5
+  { (eval echo "$as_me:23453: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:22959: \$? = $ac_status" >&5
+  echo "$as_me:23456: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=0 ac_mid=0
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 22964 "configure"
+#line 23461 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -22973,16 +23470,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:22976: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:23473: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:22979: \$? = $ac_status" >&5
+  echo "$as_me:23476: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:22982: \"$ac_try\"") >&5
+  { (eval echo "$as_me:23479: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:22985: \$? = $ac_status" >&5
+  echo "$as_me:23482: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid; break
 else
@@ -22998,7 +23495,7 @@
 ac_hi=-1 ac_mid=-1
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 23001 "configure"
+#line 23498 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -23010,16 +23507,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:23013: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:23510: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:23016: \$? = $ac_status" >&5
+  echo "$as_me:23513: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:23019: \"$ac_try\"") >&5
+  { (eval echo "$as_me:23516: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:23022: \$? = $ac_status" >&5
+  echo "$as_me:23519: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=$ac_mid; break
 else
@@ -23035,7 +23532,7 @@
 while test "x$ac_lo" != "x$ac_hi"; do
   ac_mid=`expr '(' $ac_hi - $ac_lo ')' / 2 + $ac_lo`
   cat >conftest.$ac_ext <<_ACEOF
-#line 23038 "configure"
+#line 23535 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -23047,16 +23544,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:23050: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:23547: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:23053: \$? = $ac_status" >&5
+  echo "$as_me:23550: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:23056: \"$ac_try\"") >&5
+  { (eval echo "$as_me:23553: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:23059: \$? = $ac_status" >&5
+  echo "$as_me:23556: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid
 else
@@ -23069,12 +23566,12 @@
 ac_cv_sizeof_wchar_t=$ac_lo
 else
   if test "$cross_compiling" = yes; then
-  { { echo "$as_me:23072: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:23569: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 23077 "configure"
+#line 23574 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -23090,15 +23587,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:23093: \"$ac_link\"") >&5
+if { (eval echo "$as_me:23590: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:23096: \$? = $ac_status" >&5
+  echo "$as_me:23593: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:23098: \"$ac_try\"") >&5
+  { (eval echo "$as_me:23595: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:23101: \$? = $ac_status" >&5
+  echo "$as_me:23598: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sizeof_wchar_t=`cat conftest.val`
 else
@@ -23114,7 +23611,7 @@
   ac_cv_sizeof_wchar_t=0
 fi
 fi
-echo "$as_me:23117: result: $ac_cv_sizeof_wchar_t" >&5
+echo "$as_me:23614: result: $ac_cv_sizeof_wchar_t" >&5
 echo "${ECHO_T}$ac_cv_sizeof_wchar_t" >&6
 cat >>confdefs.h <<EOF
 #define SIZEOF_WCHAR_T $ac_cv_sizeof_wchar_t
@@ -23132,7 +23629,7 @@
 ### chooses to split module lists into libraries.
 ###
 ### (see CF_LIB_RULES).
-echo "$as_me:23135: checking for library subsets" >&5
+echo "$as_me:23632: checking for library subsets" >&5
 echo $ECHO_N "checking for library subsets... $ECHO_C" >&6
 LIB_SUBSETS=
 
@@ -23174,7 +23671,7 @@
 test "x$with_widec"     = xyes && LIB_SUBSETS="${LIB_SUBSETS}+widechar"
 test "x$with_ext_funcs" = xyes && LIB_SUBSETS="${LIB_SUBSETS}+ext_funcs"
 
-echo "$as_me:23177: result: $LIB_SUBSETS" >&5
+echo "$as_me:23674: result: $LIB_SUBSETS" >&5
 echo "${ECHO_T}$LIB_SUBSETS" >&6
 
 ### Construct the list of include-directories to be generated
@@ -23205,7 +23702,7 @@
 fi
 
 ### Build up pieces for makefile rules
-echo "$as_me:23208: checking default library suffix" >&5
+echo "$as_me:23705: checking default library suffix" >&5
 echo $ECHO_N "checking default library suffix... $ECHO_C" >&6
 
 	case $DFT_LWR_MODEL in
@@ -23216,10 +23713,10 @@
 	(shared)  DFT_ARG_SUFFIX=''   ;;
 	esac
 	test -n "$LIB_SUFFIX" && DFT_ARG_SUFFIX="${LIB_SUFFIX}${DFT_ARG_SUFFIX}"
-echo "$as_me:23219: result: $DFT_ARG_SUFFIX" >&5
+echo "$as_me:23716: result: $DFT_ARG_SUFFIX" >&5
 echo "${ECHO_T}$DFT_ARG_SUFFIX" >&6
 
-echo "$as_me:23222: checking default library-dependency suffix" >&5
+echo "$as_me:23719: checking default library-dependency suffix" >&5
 echo $ECHO_N "checking default library-dependency suffix... $ECHO_C" >&6
 
 	case X$DFT_LWR_MODEL in
@@ -23277,10 +23774,10 @@
 		DFT_LIB_SUFFIX="${LIB_SUFFIX}${EXTRA_SUFFIX}${DFT_LIB_SUFFIX}"
 		DFT_DEP_SUFFIX="${LIB_SUFFIX}${EXTRA_SUFFIX}${DFT_DEP_SUFFIX}"
 	fi
-echo "$as_me:23280: result: $DFT_DEP_SUFFIX" >&5
+echo "$as_me:23777: result: $DFT_DEP_SUFFIX" >&5
 echo "${ECHO_T}$DFT_DEP_SUFFIX" >&6
 
-echo "$as_me:23283: checking default object directory" >&5
+echo "$as_me:23780: checking default object directory" >&5
 echo $ECHO_N "checking default object directory... $ECHO_C" >&6
 
 	case $DFT_LWR_MODEL in
@@ -23296,11 +23793,11 @@
 			DFT_OBJ_SUBDIR='obj_s' ;;
 		esac
 	esac
-echo "$as_me:23299: result: $DFT_OBJ_SUBDIR" >&5
+echo "$as_me:23796: result: $DFT_OBJ_SUBDIR" >&5
 echo "${ECHO_T}$DFT_OBJ_SUBDIR" >&6
 
 if test "x$cf_with_cxx" = xyes ; then
-echo "$as_me:23303: checking c++ library-dependency suffix" >&5
+echo "$as_me:23800: checking c++ library-dependency suffix" >&5
 echo $ECHO_N "checking c++ library-dependency suffix... $ECHO_C" >&6
 if test "$with_libtool" != "no"; then
 	# libtool thinks it can make c++ shared libraries (perhaps only g++)
@@ -23368,7 +23865,7 @@
 	fi
 
 fi
-echo "$as_me:23371: result: $CXX_LIB_SUFFIX" >&5
+echo "$as_me:23868: result: $CXX_LIB_SUFFIX" >&5
 echo "${ECHO_T}$CXX_LIB_SUFFIX" >&6
 
 fi
@@ -23544,19 +24041,19 @@
 
 if test -n "$LDFLAGS_STATIC" && test -n "$LDFLAGS_SHARED"
 then
-	echo "$as_me:23547: checking if linker supports switching between static/dynamic" >&5
+	echo "$as_me:24044: checking if linker supports switching between static/dynamic" >&5
 echo $ECHO_N "checking if linker supports switching between static/dynamic... $ECHO_C" >&6
 
 	rm -f libconftest.a
 	cat >conftest.$ac_ext <<EOF
-#line 23552 "configure"
+#line 24049 "configure"
 #include <stdio.h>
 int cf_ldflags_static(FILE *fp) { return fflush(fp); }
 EOF
-	if { (eval echo "$as_me:23556: \"$ac_compile\"") >&5
+	if { (eval echo "$as_me:24053: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:23559: \$? = $ac_status" >&5
+  echo "$as_me:24056: \$? = $ac_status" >&5
   (exit $ac_status); } ; then
 		( $AR $ARFLAGS libconftest.a conftest.o ) 2>&5 1>/dev/null
 		( eval $RANLIB libconftest.a ) 2>&5 >/dev/null
@@ -23567,10 +24064,10 @@
 
 	LIBS="$LDFLAGS_STATIC -L`pwd` -lconftest $LDFLAGS_DYNAMIC $LIBS"
 	cat >conftest.$ac_ext <<_ACEOF
-#line 23570 "configure"
+#line 24067 "configure"
 #include "confdefs.h"
 
-#line 23573 "configure"
+#line 24070 "configure"
 #include <stdio.h>
 int cf_ldflags_static(FILE *fp);
 
@@ -23585,16 +24082,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:23588: \"$ac_link\"") >&5
+if { (eval echo "$as_me:24085: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:23591: \$? = $ac_status" >&5
+  echo "$as_me:24088: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:23594: \"$ac_try\"") >&5
+  { (eval echo "$as_me:24091: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:23597: \$? = $ac_status" >&5
+  echo "$as_me:24094: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 	# some linkers simply ignore the -dynamic
@@ -23617,7 +24114,7 @@
 	rm -f libconftest.*
 	LIBS="$cf_save_LIBS"
 
-	echo "$as_me:23620: result: $cf_ldflags_static" >&5
+	echo "$as_me:24117: result: $cf_ldflags_static" >&5
 echo "${ECHO_T}$cf_ldflags_static" >&6
 
 	if test $cf_ldflags_static != yes
@@ -23633,7 +24130,7 @@
 	;;
 esac
 
-echo "$as_me:23636: checking where we will install curses.h" >&5
+echo "$as_me:24133: checking where we will install curses.h" >&5
 echo $ECHO_N "checking where we will install curses.h... $ECHO_C" >&6
 
 includesubdir=
@@ -23643,7 +24140,7 @@
 then
 	includesubdir="/ncurses${USE_LIB_SUFFIX}"
 fi
-echo "$as_me:23646: result: ${includedir}${includesubdir}" >&5
+echo "$as_me:24143: result: ${includedir}${includesubdir}" >&5
 echo "${ECHO_T}${includedir}${includesubdir}" >&6
 
 ### Resolve a conflict between normal and wide-curses by forcing applications
@@ -23651,7 +24148,7 @@
 if test "$with_overwrite" != no ; then
 if test "$NCURSES_LIBUTF8" = 1 ; then
 	NCURSES_LIBUTF8='defined(HAVE_LIBUTF8_H)'
-	{ echo "$as_me:23654: WARNING: Wide-character applications must define HAVE_LIBUTF8_H to include curses.h" >&5
+	{ echo "$as_me:24151: WARNING: Wide-character applications must define HAVE_LIBUTF8_H to include curses.h" >&5
 echo "$as_me: WARNING: Wide-character applications must define HAVE_LIBUTF8_H to include curses.h" >&2;}
 fi
 fi
@@ -23669,7 +24166,7 @@
 ### Construct the list of subdirectories for which we'll customize makefiles
 ### with the appropriate compile-rules.
 
-echo "$as_me:23672: checking for src modules" >&5
+echo "$as_me:24169: checking for src modules" >&5
 echo $ECHO_N "checking for src modules... $ECHO_C" >&6
 
 # dependencies and linker-arguments for test-programs
@@ -23734,7 +24231,7 @@
 		fi
 	fi
 done
-echo "$as_me:23737: result: $cf_cv_src_modules" >&5
+echo "$as_me:24234: result: $cf_cv_src_modules" >&5
 echo "${ECHO_T}$cf_cv_src_modules" >&6
 
 TEST_ARGS="-L${LIB_DIR} $TEST_ARGS"
@@ -23971,7 +24468,7 @@
 
 # Extract the first word of "tic", so it can be a program name with args.
 set dummy tic; ac_word=$2
-echo "$as_me:23974: checking for $ac_word" >&5
+echo "$as_me:24471: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_TIC_PATH+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -23988,7 +24485,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_TIC_PATH="$ac_dir/$ac_word"
-   echo "$as_me:23991: found $ac_dir/$ac_word" >&5
+   echo "$as_me:24488: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -24000,10 +24497,10 @@
 TIC_PATH=$ac_cv_path_TIC_PATH
 
 if test -n "$TIC_PATH"; then
-  echo "$as_me:24003: result: $TIC_PATH" >&5
+  echo "$as_me:24500: result: $TIC_PATH" >&5
 echo "${ECHO_T}$TIC_PATH" >&6
 else
-  echo "$as_me:24006: result: no" >&5
+  echo "$as_me:24503: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -24011,7 +24508,7 @@
 then
 	if test "$TIC_PATH" = unknown
 	then
-		{ echo "$as_me:24014: WARNING: no tic program found for fallbacks" >&5
+		{ echo "$as_me:24511: WARNING: no tic program found for fallbacks" >&5
 echo "$as_me: WARNING: no tic program found for fallbacks" >&2;}
 	fi
 fi
@@ -24047,7 +24544,7 @@
 	(*-D_XOPEN_SOURCE_EXTENDED*)
 		test -n "$verbose" && echo "	moving _XOPEN_SOURCE_EXTENDED to work around g++ problem" 1>&6
 
-echo "${as_me:-configure}:24050: testing moving _XOPEN_SOURCE_EXTENDED to work around g++ problem ..." 1>&5
+echo "${as_me:-configure}:24547: testing moving _XOPEN_SOURCE_EXTENDED to work around g++ problem ..." 1>&5
 
 		CFLAGS="$CFLAGS -D_XOPEN_SOURCE_EXTENDED"
 		CPPFLAGS=`echo "x$CPPFLAGS" | sed -e  's/^.//' -e 's/-D_XOPEN_SOURCE_EXTENDED//'`
@@ -24058,7 +24555,7 @@
 
 # Help to automatically enable the extended curses features when using either
 # the *-config or the ".pc" files by adding defines.
-echo "$as_me:24061: checking for defines to add to ncurses${USE_CFG_SUFFIX}-config script" >&5
+echo "$as_me:24558: checking for defines to add to ncurses${USE_CFG_SUFFIX}-config script" >&5
 echo $ECHO_N "checking for defines to add to ncurses${USE_CFG_SUFFIX}-config script... $ECHO_C" >&6
 PKG_CFLAGS=
 for cf_loop1 in $CPPFLAGS_after_XOPEN
@@ -24074,7 +24571,7 @@
 	done
 	test "$cf_found" = no && PKG_CFLAGS="$PKG_CFLAGS $cf_loop1"
 done
-echo "$as_me:24077: result: $PKG_CFLAGS" >&5
+echo "$as_me:24574: result: $PKG_CFLAGS" >&5
 echo "${ECHO_T}$PKG_CFLAGS" >&6
 
 # AC_CHECK_SIZEOF demands a literal parameter, no variables.  So we do this.
@@ -24131,7 +24628,7 @@
 	cf_filter_syms=$cf_dft_filter_syms
 	test -n "$verbose" && echo "	will map symbols to ABI=$cf_cv_abi_version" 1>&6
 
-echo "${as_me:-configure}:24134: testing will map symbols to ABI=$cf_cv_abi_version ..." 1>&5
+echo "${as_me:-configure}:24631: testing will map symbols to ABI=$cf_cv_abi_version ..." 1>&5
 
 fi
 
@@ -24241,7 +24738,7 @@
 : ${CONFIG_STATUS=./config.status}
 ac_clean_files_save=$ac_clean_files
 ac_clean_files="$ac_clean_files $CONFIG_STATUS"
-{ echo "$as_me:24244: creating $CONFIG_STATUS" >&5
+{ echo "$as_me:24741: creating $CONFIG_STATUS" >&5
 echo "$as_me: creating $CONFIG_STATUS" >&6;}
 cat >$CONFIG_STATUS <<_ACEOF
 #! $SHELL
@@ -24417,7 +24914,7 @@
     echo "$ac_cs_version"; exit 0 ;;
   --he | --h)
     # Conflict between --help and --header
-    { { echo "$as_me:24420: error: ambiguous option: $1
+    { { echo "$as_me:24917: error: ambiguous option: $1
 Try \`$0 --help' for more information." >&5
 echo "$as_me: error: ambiguous option: $1
 Try \`$0 --help' for more information." >&2;}
@@ -24436,7 +24933,7 @@
     ac_need_defaults=false;;
 
   # This is an error.
-  -*) { { echo "$as_me:24439: error: unrecognized option: $1
+  -*) { { echo "$as_me:24936: error: unrecognized option: $1
 Try \`$0 --help' for more information." >&5
 echo "$as_me: error: unrecognized option: $1
 Try \`$0 --help' for more information." >&2;}
@@ -24555,7 +25052,7 @@
   "Makefile" ) CONFIG_FILES="$CONFIG_FILES Makefile" ;;
   "default" ) CONFIG_COMMANDS="$CONFIG_COMMANDS default" ;;
   "include/ncurses_cfg.h" ) CONFIG_HEADERS="$CONFIG_HEADERS include/ncurses_cfg.h:include/ncurses_cfg.hin" ;;
-  *) { { echo "$as_me:24558: error: invalid argument: $ac_config_target" >&5
+  *) { { echo "$as_me:25055: error: invalid argument: $ac_config_target" >&5
 echo "$as_me: error: invalid argument: $ac_config_target" >&2;}
    { (exit 1); exit 1; }; };;
   esac
@@ -25045,7 +25542,7 @@
   esac
 
   if test x"$ac_file" != x-; then
-    { echo "$as_me:25048: creating $ac_file" >&5
+    { echo "$as_me:25545: creating $ac_file" >&5
 echo "$as_me: creating $ac_file" >&6;}
     rm -f "$ac_file"
   fi
@@ -25063,7 +25560,7 @@
       -) echo $tmp/stdin ;;
       [\\/$]*)
          # Absolute (can't be DOS-style, as IFS=:)
-         test -f "$f" || { { echo "$as_me:25066: error: cannot find input file: $f" >&5
+         test -f "$f" || { { echo "$as_me:25563: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          echo $f;;
@@ -25076,7 +25573,7 @@
            echo $srcdir/$f
          else
            # /dev/null tree
-           { { echo "$as_me:25079: error: cannot find input file: $f" >&5
+           { { echo "$as_me:25576: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          fi;;
@@ -25092,7 +25589,7 @@
       if test -n "$ac_seen"; then
         ac_used=`grep '@datarootdir@' $ac_item`
         if test -z "$ac_used"; then
-          { echo "$as_me:25095: WARNING: datarootdir was used implicitly but not set:
+          { echo "$as_me:25592: WARNING: datarootdir was used implicitly but not set:
 $ac_seen" >&5
 echo "$as_me: WARNING: datarootdir was used implicitly but not set:
 $ac_seen" >&2;}
@@ -25101,7 +25598,7 @@
       fi
       ac_seen=`grep '${datarootdir}' $ac_item`
       if test -n "$ac_seen"; then
-        { echo "$as_me:25104: WARNING: datarootdir was used explicitly but not set:
+        { echo "$as_me:25601: WARNING: datarootdir was used explicitly but not set:
 $ac_seen" >&5
 echo "$as_me: WARNING: datarootdir was used explicitly but not set:
 $ac_seen" >&2;}
@@ -25138,7 +25635,7 @@
             ac_init=`egrep '[ 	]*'$ac_name'[ 	]*=' $ac_file`
             if test -z "$ac_init"; then
               ac_seen=`echo "$ac_seen" |sed -e 's,^,'$ac_file':,'`
-              { echo "$as_me:25141: WARNING: Variable $ac_name is used but was not set:
+              { echo "$as_me:25638: WARNING: Variable $ac_name is used but was not set:
 $ac_seen" >&5
 echo "$as_me: WARNING: Variable $ac_name is used but was not set:
 $ac_seen" >&2;}
@@ -25149,7 +25646,7 @@
     egrep -n '@[A-Z_][A-Z_0-9]+@' $ac_file >>$tmp/out
     if test -s $tmp/out; then
       ac_seen=`sed -e 's,^,'$ac_file':,' < $tmp/out`
-      { echo "$as_me:25152: WARNING: Some variables may not be substituted:
+      { echo "$as_me:25649: WARNING: Some variables may not be substituted:
 $ac_seen" >&5
 echo "$as_me: WARNING: Some variables may not be substituted:
 $ac_seen" >&2;}
@@ -25198,7 +25695,7 @@
   * )   ac_file_in=$ac_file.in ;;
   esac
 
-  test x"$ac_file" != x- && { echo "$as_me:25201: creating $ac_file" >&5
+  test x"$ac_file" != x- && { echo "$as_me:25698: creating $ac_file" >&5
 echo "$as_me: creating $ac_file" >&6;}
 
   # First look for the input files in the build tree, otherwise in the
@@ -25209,7 +25706,7 @@
       -) echo $tmp/stdin ;;
       [\\/$]*)
          # Absolute (can't be DOS-style, as IFS=:)
-         test -f "$f" || { { echo "$as_me:25212: error: cannot find input file: $f" >&5
+         test -f "$f" || { { echo "$as_me:25709: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          echo $f;;
@@ -25222,7 +25719,7 @@
            echo $srcdir/$f
          else
            # /dev/null tree
-           { { echo "$as_me:25225: error: cannot find input file: $f" >&5
+           { { echo "$as_me:25722: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          fi;;
@@ -25280,7 +25777,7 @@
   rm -f $tmp/in
   if test x"$ac_file" != x-; then
     if cmp -s $ac_file $tmp/config.h 2>/dev/null; then
-      { echo "$as_me:25283: $ac_file is unchanged" >&5
+      { echo "$as_me:25780: $ac_file is unchanged" >&5
 echo "$as_me: $ac_file is unchanged" >&6;}
     else
       ac_dir=`$as_expr X"$ac_file" : 'X\(.*[^/]\)//*[^/][^/]*/*$' \| \
@@ -25625,7 +26122,7 @@
 				(cygdll|msysdll|mingw)
 					test "x$with_shared_cxx" = xno && test -n "$verbose" && echo "	overriding CXX_MODEL to SHARED" 1>&6
 
-echo "${as_me:-configure}:25628: testing overriding CXX_MODEL to SHARED ..." 1>&5
+echo "${as_me:-configure}:26125: testing overriding CXX_MODEL to SHARED ..." 1>&5
 
 					with_shared_cxx=yes
 					;;
Index: configure.in
Prereq:  1.659 
--- ncurses-6.1-20180707+/configure.in	2018-06-16 21:26:41.000000000 +0000
+++ ncurses-6.1-20180714/configure.in	2018-07-14 19:04:04.000000000 +0000
@@ -28,14 +28,14 @@
 dnl
 dnl Author: Thomas E. Dickey 1995-on
 dnl
-dnl $Id: configure.in,v 1.659 2018/06/16 21:26:41 tom Exp $
+dnl $Id: configure.in,v 1.660 2018/07/14 19:04:04 tom Exp $
 dnl Process this file with autoconf to produce a configure script.
 dnl
 dnl See https://invisible-island.net/autoconf/ for additional information.
 dnl
 dnl ---------------------------------------------------------------------------
 AC_PREREQ(2.52.20170501)
-AC_REVISION($Revision: 1.659 $)
+AC_REVISION($Revision: 1.660 $)
 AC_INIT(ncurses/base/lib_initscr.c)
 AC_CONFIG_HEADER(include/ncurses_cfg.h:include/ncurses_cfg.hin)
 
@@ -521,6 +521,7 @@
 	CF_CHECK_GPM_WGETCH
 fi
 
+CF_WITH_PCRE2
 CF_WITH_SYSMOUSE
 
 # pretend that ncurses==ncursesw==ncursest
Index: dist.mk
Prereq:  1.1231 
--- ncurses-6.1-20180707+/dist.mk	2018-07-01 14:34:06.000000000 +0000
+++ ncurses-6.1-20180714/dist.mk	2018-07-14 14:25:29.000000000 +0000
@@ -25,7 +25,7 @@
 # use or other dealings in this Software without prior written               #
 # authorization.                                                             #
 ##############################################################################
-# $Id: dist.mk,v 1.1231 2018/07/01 14:34:06 tom Exp $
+# $Id: dist.mk,v 1.1232 2018/07/14 14:25:29 tom Exp $
 # Makefile for creating ncurses distributions.
 #
 # This only needs to be used directly as a makefile by developers, but
@@ -37,7 +37,7 @@
 # These define the major/minor/patch versions of ncurses.
 NCURSES_MAJOR = 6
 NCURSES_MINOR = 1
-NCURSES_PATCH = 20180707
+NCURSES_PATCH = 20180714
 
 # We don't append the patch to the version, since this only applies to releases
 VERSION = $(NCURSES_MAJOR).$(NCURSES_MINOR)
Index: form/fty_regex.c
Prereq:  1.26 
--- ncurses-6.1-20180707+/form/fty_regex.c	2015-01-10 17:10:25.000000000 +0000
+++ ncurses-6.1-20180714/form/fty_regex.c	2018-07-14 21:41:39.000000000 +0000
@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 1998-2012,2015 Free Software Foundation, Inc.              *
+ * Copyright (c) 1998-2015,2018 Free Software Foundation, Inc.              *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -34,10 +34,17 @@
 
 #include "form.priv.h"
 
-MODULE_ID("$Id: fty_regex.c,v 1.26 2015/01/10 17:10:25 tom Exp $")
+MODULE_ID("$Id: fty_regex.c,v 1.27 2018/07/14 21:41:39 tom Exp $")
 
-#if HAVE_REGEX_H_FUNCS		/* We prefer POSIX regex */
+#if HAVE_REGEX_H_FUNCS || HAVE_LIB_PCRE2	/* We prefer POSIX regex */
+
+#if HAVE_PCRE2_POSIX_H
+#include <pcre2-posix.h>
+#elif HAVE_PCREPOSIX_H
+#include <pcreposix.h>
+#else
 #include <regex.h>
+#endif
 
 typedef struct
   {
Index: include/ncurses_defs
Prereq:  1.84 
--- ncurses-6.1-20180707+/include/ncurses_defs	2017-12-26 22:43:14.000000000 +0000
+++ ncurses-6.1-20180714/include/ncurses_defs	2018-07-14 21:20:36.000000000 +0000
@@ -1,6 +1,6 @@
-# $Id: ncurses_defs,v 1.84 2017/12/26 22:43:14 tom Exp $
+# $Id: ncurses_defs,v 1.85 2018/07/14 21:20:36 tom Exp $
 ##############################################################################
-# Copyright (c) 2000-2016,2017 Free Software Foundation, Inc.                #
+# Copyright (c) 2000-2017,2018 Free Software Foundation, Inc.                #
 #                                                                            #
 # Permission is hereby granted, free of charge, to any person obtaining a    #
 # copy of this software and associated documentation files (the "Software"), #
@@ -94,6 +94,7 @@
 HAVE_LIBMENU
 HAVE_LIBMPATROL
 HAVE_LIBPANEL
+HAVE_LIB_PCRE2
 HAVE_LIMITS_H
 HAVE_LINK
 HAVE_LOCALE_H
@@ -115,6 +116,8 @@
 HAVE_NC_ALLOC_H
 HAVE_NEWPAD	1
 HAVE_PANEL_H
+HAVE_PCRE2_POSIX_H
+HAVE_PCREPOSIX_H
 HAVE_POLL
 HAVE_POLL_H
 HAVE_PURIFY
Index: man/form_field_validation.3x
Prereq:  1.21 
--- ncurses-6.1-20180707+/man/form_field_validation.3x	2017-11-20 01:28:31.000000000 +0000
+++ ncurses-6.1-20180714/man/form_field_validation.3x	2018-07-14 22:39:06.000000000 +0000
@@ -1,5 +1,5 @@
 .\"***************************************************************************
-.\" Copyright (c) 1998-2010,2017 Free Software Foundation, Inc.              *
+.\" Copyright (c) 1998-2017,2018 Free Software Foundation, Inc.              *
 .\"                                                                          *
 .\" Permission is hereby granted, free of charge, to any person obtaining a  *
 .\" copy of this software and associated documentation files (the            *
@@ -26,8 +26,12 @@
 .\" authorization.                                                           *
 .\"***************************************************************************
 .\"
-.\" $Id: form_field_validation.3x,v 1.21 2017/11/20 01:28:31 tom Exp $
+.\" $Id: form_field_validation.3x,v 1.22 2018/07/14 22:39:06 tom Exp $
 .TH form_field_validation 3X ""
+.de bP
+.ie n  .IP \(bu 4
+.el    .IP \(bu 2
+..
 .SH NAME
 \fBform_field_validation\fR \- data type validation for fields
 .SH SYNOPSIS
@@ -65,52 +69,92 @@
 Character data.  Requires a third \fBint\fR argument, a minimum field width.
 .TP 5
 TYPE_ENUM
-Accept one of a specified set of strings.  Requires a third \fB(char **)\fR
-argument pointing to a string list; a fourth \fBint\fR flag argument to enable
-case-sensitivity; and a fifth \fBint\fR flag argument specifying whether a partial
-match must be a unique one (if this flag is off, a prefix matches the first
-of any set of more than one list elements with that prefix). Please notice
-that the string list is copied. So you may use a list that lives in automatic variables on the stack.
+Accept one of a specified set of strings.  Requires additional
+parameters:
+.RS
+.bP
+a third \fB(char **)\fR argument pointing to a string list;
+.bP
+a fourth \fBint\fR flag argument to enable case-sensitivity;
+.bP
+and a fifth \fBint\fR flag argument specifying whether a partial
+match must be a unique one.
+If this flag is off, a prefix matches the first
+of any set of more than one list elements with that prefix.
+.IP
+The library copies the string list,
+so you may use a list that lives in automatic variables on the stack.
+.RE
 .TP 5
 TYPE_INTEGER
-Integer data, parsable to an integer by \fBatoi\fP(3).  Requires a third
-\fBint\fR argument controlling the precision, a fourth \fBlong\fR argument
-constraining minimum value, and a fifth \fBlong\fR constraining maximum value.
+Integer data, parsable to an integer by \fBatoi\fP(3).
+Requires additional parameters:
+.RS
+.bP
+a third \fBint\fR argument controlling the precision,
+.bP
+a fourth \fBlong\fR argument constraining minimum value,
+.bP
+and a fifth \fBlong\fR constraining maximum value.
 If the maximum value is less than or equal to the minimum value, the range is
-simply ignored. On return the field buffer is formatted according to the
+simply ignored.
+On return, the field buffer is formatted according to the
 \fBprintf\fR format specification ".*ld", where the '*' is replaced by the
 precision argument.
+.IP
 For details of the precision handling see \fBprintf's\fR man-page.
+.RE
 .TP 5
 TYPE_NUMERIC
-Numeric data (may have a decimal-point part). Requires a third
-\fBint\fR argument controlling the precision, a fourth \fBdouble\fR
-argument constraining minimum value, and a fifth \fBdouble\fR constraining
-maximum value. If your system supports locales, the decimal point character
-to be used must be the one specified by your locale.
-If the maximum value is less than or equal to the minimum value, the range is
-simply ignored. On return the field buffer is formatted according to the
+Numeric data (may have a decimal-point part).
+This requires additional parameters:
+.RS
+.bP
+a third \fBint\fR argument controlling the precision,
+.bP
+a fourth \fBdouble\fR argument constraining minimum value,
+.bP
+and a fifth \fBdouble\fR constraining maximum value.
+If your system supports locales,
+the decimal point character must be the one specified by your locale.
+If the maximum value is less than or equal to the minimum value,
+the range is simply ignored.
+.IP
+On return, the field buffer is formatted according to the
 \fBprintf\fR format specification ".*f", where the '*' is replaced by the
 precision argument.
+.IP
 For details of the precision handling see \fBprintf's\fR man-page.
+.RE
 .TP 5
 TYPE_REGEXP
-Regular expression data.  Requires a regular expression \fB(char *)\fR third argument;
-the data is valid if the regular expression matches it.  Regular expressions
-are in the format of \fBregcomp\fR and \fBregexec\fR. Please notice
-that the regular expression must match the whole field. If you have for
-example an eight character wide field, a regular expression "^[0\-9]*$" always
-means that you have to fill all eight positions with digits. If you want to
-allow fewer digits, you may use for example "^[0\-9]* *$" which is good for
-trailing spaces (up to an empty field), or "^ *[0\-9]* *$" which is good for
+Regular expression data.
+Requires a regular expression \fB(char *)\fR third argument.
+The data is valid if the regular expression matches it.
+.IP
+Regular expressions
+are in the format of \fBregcomp\fR and \fBregexec\fR.
+.IP
+The regular expression must match the whole field.
+If you have for example, an eight character wide field,
+a regular expression "^[0\-9]*$" always
+means that you have to fill all eight positions with digits.
+If you want to allow fewer digits,
+you may use for example "^[0\-9]* *$" which is good for
+trailing spaces (up to an empty field),
+or "^ *[0\-9]* *$" which is good for
 leading and trailing spaces around the digits.
 .TP 5
 TYPE_IPV4
-An Internet Protocol Version 4 address. This requires no additional argument. It
-is checked whether or not the buffer has the form a.b.c.d, where a,b,c and d are
-numbers between 0 and 255. Trailing blanks in the buffer are ignored. The address
-itself is not validated. Please note that this is an ncurses extension. This
-field type may not be available in other curses implementations.
+An Internet Protocol Version 4 address.
+This requires no additional argument.
+The library checks whether or not the buffer has the form a.b.c.d,
+where a,b,c and d are numbers between 0 and 255.
+Trailing blanks in the buffer are ignored.
+The address itself is not validated.
+.IP
+This is an ncurses extension;
+this field type may not be available in other curses implementations.
 .PP
 It is possible to set up new programmer-defined field types.  See the
 \fBform_fieldtype\fR(3X) manual page.
Index: package/debian-mingw/changelog
--- ncurses-6.1-20180707+/package/debian-mingw/changelog	2018-07-01 14:34:06.000000000 +0000
+++ ncurses-6.1-20180714/package/debian-mingw/changelog	2018-07-14 14:25:29.000000000 +0000
@@ -1,8 +1,8 @@
-ncurses6 (6.1+20180707) unstable; urgency=low
+ncurses6 (6.1+20180714) unstable; urgency=low
 
   * latest weekly patch
 
- -- Thomas E. Dickey <dickey@invisible-island.net>  Sun, 01 Jul 2018 10:34:06 -0400
+ -- Thomas E. Dickey <dickey@invisible-island.net>  Sat, 14 Jul 2018 10:25:29 -0400
 
 ncurses6 (5.9-20131005) unstable; urgency=low
 
Index: package/debian-mingw64/changelog
--- ncurses-6.1-20180707+/package/debian-mingw64/changelog	2018-07-01 14:34:06.000000000 +0000
+++ ncurses-6.1-20180714/package/debian-mingw64/changelog	2018-07-14 14:25:29.000000000 +0000
@@ -1,8 +1,8 @@
-ncurses6 (6.1+20180707) unstable; urgency=low
+ncurses6 (6.1+20180714) unstable; urgency=low
 
   * latest weekly patch
 
- -- Thomas E. Dickey <dickey@invisible-island.net>  Sun, 01 Jul 2018 10:34:06 -0400
+ -- Thomas E. Dickey <dickey@invisible-island.net>  Sat, 14 Jul 2018 10:25:29 -0400
 
 ncurses6 (5.9-20131005) unstable; urgency=low
 
Index: package/debian/changelog
--- ncurses-6.1-20180707+/package/debian/changelog	2018-07-01 14:34:06.000000000 +0000
+++ ncurses-6.1-20180714/package/debian/changelog	2018-07-14 14:25:29.000000000 +0000
@@ -1,8 +1,8 @@
-ncurses6 (6.1+20180707) unstable; urgency=low
+ncurses6 (6.1+20180714) unstable; urgency=low
 
   * latest weekly patch
 
- -- Thomas E. Dickey <dickey@invisible-island.net>  Sun, 01 Jul 2018 10:34:06 -0400
+ -- Thomas E. Dickey <dickey@invisible-island.net>  Sat, 14 Jul 2018 10:25:29 -0400
 
 ncurses6 (5.9-20120608) unstable; urgency=low
 
Index: package/mingw-ncurses.nsi
Prereq:  1.278 
--- ncurses-6.1-20180707+/package/mingw-ncurses.nsi	2018-07-01 14:34:06.000000000 +0000
+++ ncurses-6.1-20180714/package/mingw-ncurses.nsi	2018-07-14 14:25:29.000000000 +0000
@@ -1,4 +1,4 @@
-; $Id: mingw-ncurses.nsi,v 1.278 2018/07/01 14:34:06 tom Exp $
+; $Id: mingw-ncurses.nsi,v 1.279 2018/07/14 14:25:29 tom Exp $
 
 ; TODO add examples
 ; TODO bump ABI to 6
@@ -10,7 +10,7 @@
 !define VERSION_MAJOR "6"
 !define VERSION_MINOR "1"
 !define VERSION_YYYY  "2018"
-!define VERSION_MMDD  "0707"
+!define VERSION_MMDD  "0714"
 !define VERSION_PATCH ${VERSION_YYYY}${VERSION_MMDD}
 
 !define MY_ABI   "5"
Index: package/mingw-ncurses.spec
--- ncurses-6.1-20180707+/package/mingw-ncurses.spec	2018-07-01 14:34:06.000000000 +0000
+++ ncurses-6.1-20180714/package/mingw-ncurses.spec	2018-07-14 23:45:27.000000000 +0000
@@ -3,7 +3,7 @@
 Summary: shared libraries for terminal handling
 Name: mingw32-ncurses6
 Version: 6.1
-Release: 20180707
+Release: 20180714
 License: X11
 Group: Development/Libraries
 Source: ncurses-%{version}-%{release}.tgz
@@ -70,6 +70,7 @@
 	--with-fallbacks=unknown,xterm \\\
 	--with-install-prefix=$RPM_BUILD_ROOT \\\
 	--with-pc-suffix=%{MY_ABI} \\\
+	--with-pcre2 \\\
 	--with-shared \\\
 	--with-tparm-arg=intptr_t \\\
 	--with-trace \\\
Index: package/ncurses.spec
--- ncurses-6.1-20180707+/package/ncurses.spec	2018-07-01 14:34:06.000000000 +0000
+++ ncurses-6.1-20180714/package/ncurses.spec	2018-07-14 14:25:29.000000000 +0000
@@ -1,7 +1,7 @@
 Summary: shared libraries for terminal handling
 Name: ncurses6
 Version: 6.1
-Release: 20180707
+Release: 20180714
 License: X11
 Group: Development/Libraries
 Source: ncurses-%{version}-%{release}.tgz
Index: test/demo_forms.c
Prereq:  1.53 
--- ncurses-6.1-20180707+/test/demo_forms.c	2017-04-10 00:28:54.000000000 +0000
+++ ncurses-6.1-20180714/test/demo_forms.c	2018-07-14 23:26:02.000000000 +0000
@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2003-2016,2017 Free Software Foundation, Inc.              *
+ * Copyright (c) 2003-2017,2018 Free Software Foundation, Inc.              *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -26,14 +26,12 @@
  * authorization.                                                           *
  ****************************************************************************/
 /*
- * $Id: demo_forms.c,v 1.53 2017/04/10 00:28:54 tom Exp $
+ * $Id: demo_forms.c,v 1.55 2018/07/14 23:26:02 tom Exp $
  *
  * Demonstrate a variety of functions from the form library.
  * Thomas Dickey - 2003/4/26
  */
 /*
-TYPE_ENUM			-
-TYPE_REGEXP			-
 dup_field			-
 field_init			-
 field_just			-
@@ -440,6 +438,8 @@
     int pg;
     WINDOW *also;
     const char *fname;
+    static const char *my_enum[] =
+    {"first", "second", "third", 0};
 
 #ifdef NCURSES_MOUSE_VERSION
     mousemask(ALL_MOUSE_EVENTS, (mmask_t *) 0);
@@ -478,23 +478,30 @@
 	    f[n++] = make_field(fname, 3, 34, 1, 12);
 	    set_field_type(f[n - 1], TYPE_ALPHA, 1);
 	    break;
+
 	case 1:
 	    fname = "Last Name";
 	    f[n++] = make_label(fname, 2, 0);
-	    f[n++] = make_field(fname, 3, 0, 1, 18);
+	    f[n++] = make_field(fname, 3, 0, 1, 12);
 	    set_field_type(f[n - 1], TYPE_ALPHA, 1);
 
 	    fname = "First Name";
-	    f[n++] = make_label(fname, 2, 20);
-	    f[n++] = make_field(fname, 3, 20, 1, 12);
+	    f[n++] = make_label(fname, 2, 14);
+	    f[n++] = make_field(fname, 3, 14, 1, 12);
 	    set_field_type(f[n - 1], TYPE_ALPHA, 1);
 
 	    fname = "MI";
-	    f[n++] = make_label(fname, 2, 34);
-	    f[n++] = make_field(fname, 3, 34, 1, 1);
+	    f[n++] = make_label(fname, 2, 28);
+	    f[n++] = make_field(fname, 3, 28, 1, 1);
 	    set_field_pad(f[n - 1], '?');
 	    set_field_type(f[n - 1], TYPE_ALPHA, 1);
+
+	    fname = "First/Second/Third";
+	    f[n++] = make_label(fname, 2, 32);
+	    f[n++] = make_field(fname, 3, 32, 1, 12);
+	    set_field_type(f[n - 1], TYPE_ENUM, my_enum, 0, 0);
 	    break;
+
 	case 2:
 	    fname = "Host Name";
 	    f[n++] = make_label(fname, 2, 0);
@@ -507,20 +514,24 @@
 	    f[n++] = make_field(fname, 3, 26, 1, 16);
 	    set_field_type(f[n - 1], TYPE_IPV4, 1);
 #endif
-
 	    break;
 
 	case 3:
 	    fname = "Four digits";
 	    f[n++] = make_label(fname, 2, 0);
-	    f[n++] = make_field(fname, 3, 0, 1, 18);
+	    f[n++] = make_field(fname, 3, 0, 1, 10);
 	    set_field_type(f[n - 1], TYPE_INTEGER, 4, 0, 0);
 
 	    fname = "Numeric";
-	    f[n++] = make_label(fname, 2, 20);
-	    f[n++] = make_field(fname, 3, 20, 1, 12);
+	    f[n++] = make_label(fname, 2, 13);
+	    f[n++] = make_field(fname, 3, 13, 1, 12);
 	    set_field_type(f[n - 1], TYPE_NUMERIC, 3, -10000.0, 100000000.0);
 
+	    fname = "Phone number";
+	    f[n++] = make_label(fname, 2, 27);
+	    f[n++] = make_field(fname, 3, 27, 1, 16);
+	    set_field_type(f[n - 1], TYPE_REGEXP,
+			   "^([0-9]-)?[0-9]{3}-[0-9]{3}-[0-9]{4} *$");;
 	    break;
 	}
 
